Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1892
1893
1894
1895
1896
# File 'lib/stripe/resources/subscription_schedule.rb', line 1892

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1886
1887
1888
# File 'lib/stripe/resources/subscription_schedule.rb', line 1886

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1888
1889
1890
# File 'lib/stripe/resources/subscription_schedule.rb', line 1888

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1890
1891
1892
# File 'lib/stripe/resources/subscription_schedule.rb', line 1890

def promotion_code
  @promotion_code
end