Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1773
1774
1775
1776
1777
# File 'lib/stripe/resources/subscription_schedule.rb', line 1773

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1767
1768
1769
# File 'lib/stripe/resources/subscription_schedule.rb', line 1767

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1769
1770
1771
# File 'lib/stripe/resources/subscription_schedule.rb', line 1769

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1771
1772
1773
# File 'lib/stripe/resources/subscription_schedule.rb', line 1771

def promotion_code
  @promotion_code
end