Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1899
1900
1901
1902
1903
# File 'lib/stripe/resources/subscription_schedule.rb', line 1899

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1893
1894
1895
# File 'lib/stripe/resources/subscription_schedule.rb', line 1893

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1895
1896
1897
# File 'lib/stripe/resources/subscription_schedule.rb', line 1895

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1897
1898
1899
# File 'lib/stripe/resources/subscription_schedule.rb', line 1897

def promotion_code
  @promotion_code
end