Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2151
2152
2153
2154
2155
2156
# File 'lib/stripe/resources/subscription_schedule.rb', line 2151

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2143
2144
2145
# File 'lib/stripe/resources/subscription_schedule.rb', line 2143

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2145
2146
2147
# File 'lib/stripe/resources/subscription_schedule.rb', line 2145

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2147
2148
2149
# File 'lib/stripe/resources/subscription_schedule.rb', line 2147

def set
  @set
end

#typeObject

Determines the type of item action.



2149
2150
2151
# File 'lib/stripe/resources/subscription_schedule.rb', line 2149

def type
  @type
end