Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2119
2120
2121
2122
2123
2124
# File 'lib/stripe/resources/subscription_schedule.rb', line 2119

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2111
2112
2113
# File 'lib/stripe/resources/subscription_schedule.rb', line 2111

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2113
2114
2115
# File 'lib/stripe/resources/subscription_schedule.rb', line 2113

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2115
2116
2117
# File 'lib/stripe/resources/subscription_schedule.rb', line 2115

def set
  @set
end

#typeObject

Determines the type of item action.



2117
2118
2119
# File 'lib/stripe/resources/subscription_schedule.rb', line 2117

def type
  @type
end