Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



1984
1985
1986
1987
1988
1989
# File 'lib/stripe/resources/subscription_schedule.rb', line 1984

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



1976
1977
1978
# File 'lib/stripe/resources/subscription_schedule.rb', line 1976

def add
  @add
end

#removeObject

Details of the subscription item to remove.



1978
1979
1980
# File 'lib/stripe/resources/subscription_schedule.rb', line 1978

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



1980
1981
1982
# File 'lib/stripe/resources/subscription_schedule.rb', line 1980

def set
  @set
end

#typeObject

Determines the type of item action.



1982
1983
1984
# File 'lib/stripe/resources/subscription_schedule.rb', line 1982

def type
  @type
end