Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the subscription item to add.
-
#remove ⇒ Object
Details of the subscription item to remove.
-
#set ⇒ Object
Details of the subscription item to replace the existing items with.
-
#type ⇒ Object
Determines the type of item action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
constructor
A new instance of ItemAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
Returns a new instance of ItemAction.
1984 1985 1986 1987 1988 1989 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1984 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.
1976 1977 1978 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1976 def add @add end |
#remove ⇒ Object
Details of the subscription item to remove.
1978 1979 1980 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1978 def remove @remove end |
#set ⇒ Object
Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.
1980 1981 1982 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1980 def set @set end |
#type ⇒ Object
Determines the type of item action.
1982 1983 1984 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1982 def type @type end |