Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2110
2111
2112
2113
2114
2115
# File 'lib/stripe/resources/subscription_schedule.rb', line 2110

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2102
2103
2104
# File 'lib/stripe/resources/subscription_schedule.rb', line 2102

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2104
2105
2106
# File 'lib/stripe/resources/subscription_schedule.rb', line 2104

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2106
2107
2108
# File 'lib/stripe/resources/subscription_schedule.rb', line 2106

def set
  @set
end

#typeObject

Determines the type of item action.



2108
2109
2110
# File 'lib/stripe/resources/subscription_schedule.rb', line 2108

def type
  @type
end