Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2449
2450
2451
2452
2453
2454
# File 'lib/stripe/resources/subscription_schedule.rb', line 2449

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2438
2439
2440
# File 'lib/stripe/resources/subscription_schedule.rb', line 2438

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2441
2442
2443
# File 'lib/stripe/resources/subscription_schedule.rb', line 2441

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2444
2445
2446
# File 'lib/stripe/resources/subscription_schedule.rb', line 2444

def set
  @set
end

#typeObject

Determines the type of item action.



2447
2448
2449
# File 'lib/stripe/resources/subscription_schedule.rb', line 2447

def type
  @type
end