Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
# File 'lib/stripe/resources/subscription_schedule.rb', line 2032

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



2020
2021
2022
# File 'lib/stripe/resources/subscription_schedule.rb', line 2020

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2022
2023
2024
# File 'lib/stripe/resources/subscription_schedule.rb', line 2022

def 
  @metadata
end

#priceObject

The ID of the price object.



2024
2025
2026
# File 'lib/stripe/resources/subscription_schedule.rb', line 2024

def price
  @price
end

#quantityObject

Quantity for this item.



2026
2027
2028
# File 'lib/stripe/resources/subscription_schedule.rb', line 2026

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



2028
2029
2030
# File 'lib/stripe/resources/subscription_schedule.rb', line 2028

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



2030
2031
2032
# File 'lib/stripe/resources/subscription_schedule.rb', line 2030

def trial
  @trial
end