Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2000 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1988 1989 1990 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1988 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1990 1991 1992 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1990 def @metadata end |
#price ⇒ Object
The ID of the price object.
1992 1993 1994 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1992 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1994 1995 1996 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1994 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1996 1997 1998 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1996 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1998 1999 2000 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1998 def trial @trial end |