Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1984 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1972 1973 1974 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1972 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1974 1975 1976 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1974 def @metadata end |
#price ⇒ Object
The ID of the price object.
1976 1977 1978 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1976 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1978 1979 1980 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1978 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1980 1981 1982 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1980 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1982 1983 1984 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1982 def trial @trial end |