Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1865 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1853 1854 1855 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1853 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1855 1856 1857 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1855 def @metadata end |
#price ⇒ Object
The ID of the price object.
1857 1858 1859 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1857 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1859 1860 1861 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1859 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1861 1862 1863 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1861 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1863 1864 1865 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1863 def trial @trial end |