Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
# File 'lib/stripe/resources/subscription_schedule.rb', line 1991

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1979
1980
1981
# File 'lib/stripe/resources/subscription_schedule.rb', line 1979

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1981
1982
1983
# File 'lib/stripe/resources/subscription_schedule.rb', line 1981

def 
  @metadata
end

#priceObject

The ID of the price object.



1983
1984
1985
# File 'lib/stripe/resources/subscription_schedule.rb', line 1983

def price
  @price
end

#quantityObject

Quantity for this item.



1985
1986
1987
# File 'lib/stripe/resources/subscription_schedule.rb', line 1985

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1987
1988
1989
# File 'lib/stripe/resources/subscription_schedule.rb', line 1987

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1989
1990
1991
# File 'lib/stripe/resources/subscription_schedule.rb', line 1989

def trial
  @trial
end