Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2000
2001
2002
2003
2004
2005
# File 'lib/stripe/resources/subscription_schedule.rb', line 2000

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1992
1993
1994
# File 'lib/stripe/resources/subscription_schedule.rb', line 1992

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1994
1995
1996
# File 'lib/stripe/resources/subscription_schedule.rb', line 1994

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1996
1997
1998
# File 'lib/stripe/resources/subscription_schedule.rb', line 1996

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1998
1999
2000
# File 'lib/stripe/resources/subscription_schedule.rb', line 1998

def promotion_code
  @promotion_code
end