Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1833
1834
1835
1836
1837
1838
# File 'lib/stripe/resources/subscription_schedule.rb', line 1833

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1825
1826
1827
# File 'lib/stripe/resources/subscription_schedule.rb', line 1825

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1827
1828
1829
# File 'lib/stripe/resources/subscription_schedule.rb', line 1827

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1829
1830
1831
# File 'lib/stripe/resources/subscription_schedule.rb', line 1829

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1831
1832
1833
# File 'lib/stripe/resources/subscription_schedule.rb', line 1831

def promotion_code
  @promotion_code
end