Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2277
2278
2279
2280
2281
2282
# File 'lib/stripe/resources/subscription_schedule.rb', line 2277

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2266
2267
2268
# File 'lib/stripe/resources/subscription_schedule.rb', line 2266

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2269
2270
2271
# File 'lib/stripe/resources/subscription_schedule.rb', line 2269

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2272
2273
2274
# File 'lib/stripe/resources/subscription_schedule.rb', line 2272

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2275
2276
2277
# File 'lib/stripe/resources/subscription_schedule.rb', line 2275

def promotion_code
  @promotion_code
end