Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1959
1960
1961
1962
1963
1964
# File 'lib/stripe/resources/subscription_schedule.rb', line 1959

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1951
1952
1953
# File 'lib/stripe/resources/subscription_schedule.rb', line 1951

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1953
1954
1955
# File 'lib/stripe/resources/subscription_schedule.rb', line 1953

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1955
1956
1957
# File 'lib/stripe/resources/subscription_schedule.rb', line 1955

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1957
1958
1959
# File 'lib/stripe/resources/subscription_schedule.rb', line 1957

def promotion_code
  @promotion_code
end