Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2107
2108
2109
2110
2111
# File 'lib/stripe/resources/subscription_schedule.rb', line 2107

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2101
2102
2103
# File 'lib/stripe/resources/subscription_schedule.rb', line 2101

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2103
2104
2105
# File 'lib/stripe/resources/subscription_schedule.rb', line 2103

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2105
2106
2107
# File 'lib/stripe/resources/subscription_schedule.rb', line 2105

def type
  @type
end