Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1953
1954
1955
1956
1957
# File 'lib/stripe/resources/subscription_schedule.rb', line 1953

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1947
1948
1949
# File 'lib/stripe/resources/subscription_schedule.rb', line 1947

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1949
1950
1951
# File 'lib/stripe/resources/subscription_schedule.rb', line 1949

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1951
1952
1953
# File 'lib/stripe/resources/subscription_schedule.rb', line 1951

def type
  @type
end