Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1937
1938
1939
1940
1941
# File 'lib/stripe/resources/subscription_schedule.rb', line 1937

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1931
1932
1933
# File 'lib/stripe/resources/subscription_schedule.rb', line 1931

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1933
1934
1935
# File 'lib/stripe/resources/subscription_schedule.rb', line 1933

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1935
1936
1937
# File 'lib/stripe/resources/subscription_schedule.rb', line 1935

def type
  @type
end