Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2259
2260
2261
2262
2263
# File 'lib/stripe/resources/subscription_schedule.rb', line 2259

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2251
2252
2253
# File 'lib/stripe/resources/subscription_schedule.rb', line 2251

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2254
2255
2256
# File 'lib/stripe/resources/subscription_schedule.rb', line 2254

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2257
2258
2259
# File 'lib/stripe/resources/subscription_schedule.rb', line 2257

def type
  @type
end