Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2216
2217
2218
2219
2220
2221
# File 'lib/stripe/resources/subscription_schedule.rb', line 2216

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2208
2209
2210
# File 'lib/stripe/resources/subscription_schedule.rb', line 2208

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2210
2211
2212
# File 'lib/stripe/resources/subscription_schedule.rb', line 2210

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2212
2213
2214
# File 'lib/stripe/resources/subscription_schedule.rb', line 2212

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2214
2215
2216
# File 'lib/stripe/resources/subscription_schedule.rb', line 2214

def promotion_code
  @promotion_code
end