Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2216 2217 2218 2219 2220 2221 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2216 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2208 2209 2210 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2208 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2210 2211 2212 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2210 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2212 2213 2214 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2212 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2214 2215 2216 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2214 def promotion_code @promotion_code end |