Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2094
2095
2096
2097
2098
2099
# File 'lib/stripe/resources/subscription_schedule.rb', line 2094

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2086
2087
2088
# File 'lib/stripe/resources/subscription_schedule.rb', line 2086

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2088
2089
2090
# File 'lib/stripe/resources/subscription_schedule.rb', line 2088

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2090
2091
2092
# File 'lib/stripe/resources/subscription_schedule.rb', line 2090

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2092
2093
2094
# File 'lib/stripe/resources/subscription_schedule.rb', line 2092

def promotion_code
  @promotion_code
end