Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2046 2047 2048 2049 2050 2051 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2046 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2038 2039 2040 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2038 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2040 2041 2042 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2040 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2042 2043 2044 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2042 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2044 2045 2046 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2044 def promotion_code @promotion_code end |