Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1927
1928
1929
1930
1931
1932
# File 'lib/stripe/resources/subscription_schedule.rb', line 1927

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1919
1920
1921
# File 'lib/stripe/resources/subscription_schedule.rb', line 1919

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1921
1922
1923
# File 'lib/stripe/resources/subscription_schedule.rb', line 1921

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1923
1924
1925
# File 'lib/stripe/resources/subscription_schedule.rb', line 1923

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1925
1926
1927
# File 'lib/stripe/resources/subscription_schedule.rb', line 1925

def promotion_code
  @promotion_code
end