Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2500
2501
2502
2503
2504
# File 'lib/stripe/resources/subscription_schedule.rb', line 2500

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2494
2495
2496
# File 'lib/stripe/resources/subscription_schedule.rb', line 2494

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2496
2497
2498
# File 'lib/stripe/resources/subscription_schedule.rb', line 2496

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2498
2499
2500
# File 'lib/stripe/resources/subscription_schedule.rb', line 2498

def type
  @type
end