Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2031
2032
2033
2034
2035
# File 'lib/stripe/resources/subscription_schedule.rb', line 2031

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2025
2026
2027
# File 'lib/stripe/resources/subscription_schedule.rb', line 2025

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2027
2028
2029
# File 'lib/stripe/resources/subscription_schedule.rb', line 2027

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2029
2030
2031
# File 'lib/stripe/resources/subscription_schedule.rb', line 2029

def type
  @type
end