Class: Stripe::SubscriptionSchedule::AmendParams::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2038
2039
2040
2041
2042
# File 'lib/stripe/resources/subscription_schedule.rb', line 2038

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2032
2033
2034
# File 'lib/stripe/resources/subscription_schedule.rb', line 2032

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2034
2035
2036
# File 'lib/stripe/resources/subscription_schedule.rb', line 2034

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2036
2037
2038
# File 'lib/stripe/resources/subscription_schedule.rb', line 2036

def type
  @type
end