Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The beginning of the prebilled time period.
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#invoice_at ⇒ Object
When the prebilling invoice should be created.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
2162 2163 2164 2165 2166 2167 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2162 def initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) @bill_from = bill_from @bill_until = bill_until @invoice_at = invoice_at @update_behavior = update_behavior end |
Instance Attribute Details
#bill_from ⇒ Object
The beginning of the prebilled time period. The default value is ‘now`.
2154 2155 2156 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2154 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the prebilled time period.
2156 2157 2158 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2156 def bill_until @bill_until end |
#invoice_at ⇒ Object
When the prebilling invoice should be created. The default value is ‘now`.
2158 2159 2160 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2158 def invoice_at @invoice_at end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
2160 2161 2162 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2160 def update_behavior @update_behavior end |