Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#bill_from ⇒ Object
The beginning of the prebilled time period.
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#invoice_at ⇒ Object
When the prebilling invoice should be created.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
2649 2650 2651 2652 2653 2654 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2649 def initialize(bill_from: nil, bill_until: nil, invoice_at: nil, update_behavior: nil) @bill_from = bill_from @bill_until = bill_until @invoice_at = invoice_at @update_behavior = update_behavior end |
Instance Attribute Details
#bill_from ⇒ Object
The beginning of the prebilled time period. The default value is ‘now`.
2638 2639 2640 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2638 def bill_from @bill_from end |
#bill_until ⇒ Object
The end of the prebilled time period.
2641 2642 2643 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2641 def bill_until @bill_until end |
#invoice_at ⇒ Object
When the prebilling invoice should be created. The default value is ‘now`.
2644 2645 2646 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2644 def invoice_at @invoice_at end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
2647 2648 2649 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2647 def update_behavior @update_behavior end |