Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



2228
2229
2230
2231
2232
# File 'lib/stripe/resources/subscription_schedule.rb', line 2228

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



2222
2223
2224
# File 'lib/stripe/resources/subscription_schedule.rb', line 2222

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2224
2225
2226
# File 'lib/stripe/resources/subscription_schedule.rb', line 2224

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



2226
2227
2228
# File 'lib/stripe/resources/subscription_schedule.rb', line 2226

def type
  @type
end