Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentStart
Instance Attribute Summary collapse
-
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
-
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
Instance Method Summary collapse
-
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
2228 2229 2230 2231 2232 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2228 def initialize(amendment_start: nil, timestamp: nil, type: nil) @amendment_start = amendment_start @timestamp = @type = type end |
Instance Attribute Details
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
2222 2223 2224 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2222 def amendment_start @amendment_start end |
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
2224 2225 2226 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2224 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
2226 2227 2228 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2226 def type @type end |