Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



2113
2114
2115
2116
2117
# File 'lib/stripe/resources/subscription_schedule.rb', line 2113

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



2107
2108
2109
# File 'lib/stripe/resources/subscription_schedule.rb', line 2107

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2109
2110
2111
# File 'lib/stripe/resources/subscription_schedule.rb', line 2109

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



2111
2112
2113
# File 'lib/stripe/resources/subscription_schedule.rb', line 2111

def type
  @type
end