Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



2589
2590
2591
2592
2593
# File 'lib/stripe/resources/subscription_schedule.rb', line 2589

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



2581
2582
2583
# File 'lib/stripe/resources/subscription_schedule.rb', line 2581

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2584
2585
2586
# File 'lib/stripe/resources/subscription_schedule.rb', line 2584

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



2587
2588
2589
# File 'lib/stripe/resources/subscription_schedule.rb', line 2587

def type
  @type
end