Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



2235
2236
2237
2238
2239
# File 'lib/stripe/resources/subscription_schedule.rb', line 2235

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



2229
2230
2231
# File 'lib/stripe/resources/subscription_schedule.rb', line 2229

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2231
2232
2233
# File 'lib/stripe/resources/subscription_schedule.rb', line 2231

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



2233
2234
2235
# File 'lib/stripe/resources/subscription_schedule.rb', line 2233

def type
  @type
end