Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



2313
2314
2315
2316
2317
2318
# File 'lib/stripe/resources/subscription_schedule.rb', line 2313

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



2305
2306
2307
# File 'lib/stripe/resources/subscription_schedule.rb', line 2305

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



2307
2308
2309
# File 'lib/stripe/resources/subscription_schedule.rb', line 2307

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2309
2310
2311
# File 'lib/stripe/resources/subscription_schedule.rb', line 2309

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



2311
2312
2313
# File 'lib/stripe/resources/subscription_schedule.rb', line 2311

def type
  @type
end