Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



2265
2266
2267
2268
2269
2270
# File 'lib/stripe/resources/subscription_schedule.rb', line 2265

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



2257
2258
2259
# File 'lib/stripe/resources/subscription_schedule.rb', line 2257

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



2259
2260
2261
# File 'lib/stripe/resources/subscription_schedule.rb', line 2259

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2261
2262
2263
# File 'lib/stripe/resources/subscription_schedule.rb', line 2261

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



2263
2264
2265
# File 'lib/stripe/resources/subscription_schedule.rb', line 2263

def type
  @type
end