Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2265 2266 2267 2268 2269 2270 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2265 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
2257 2258 2259 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2257 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
2259 2260 2261 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2259 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
2261 2262 2263 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2261 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
2263 2264 2265 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2263 def type @type end |