Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2150 2151 2152 2153 2154 2155 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2150 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
2142 2143 2144 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2142 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
2144 2145 2146 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2144 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
2146 2147 2148 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2146 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
2148 2149 2150 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2148 def type @type end |