Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
2630 2631 2632 2633 2634 2635 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2630 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
2619 2620 2621 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2619 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
2622 2623 2624 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2622 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
2625 2626 2627 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2625 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
2628 2629 2630 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2628 def type @type end |