Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



2272
2273
2274
2275
2276
2277
# File 'lib/stripe/resources/subscription_schedule.rb', line 2272

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



2264
2265
2266
# File 'lib/stripe/resources/subscription_schedule.rb', line 2264

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



2266
2267
2268
# File 'lib/stripe/resources/subscription_schedule.rb', line 2266

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2268
2269
2270
# File 'lib/stripe/resources/subscription_schedule.rb', line 2268

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



2270
2271
2272
# File 'lib/stripe/resources/subscription_schedule.rb', line 2270

def type
  @type
end