Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2136
2137
2138
2139
# File 'lib/stripe/resources/subscription_schedule.rb', line 2136

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2132
2133
2134
# File 'lib/stripe/resources/subscription_schedule.rb', line 2132

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2134
2135
2136
# File 'lib/stripe/resources/subscription_schedule.rb', line 2134

def interval_count
  @interval_count
end