Class: Stripe::SubscriptionSchedule::AmendParams::Prebilling::BillUntil::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2613
2614
2615
2616
# File 'lib/stripe/resources/subscription_schedule.rb', line 2613

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2608
2609
2610
# File 'lib/stripe/resources/subscription_schedule.rb', line 2608

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2611
2612
2613
# File 'lib/stripe/resources/subscription_schedule.rb', line 2611

def interval_count
  @interval_count
end