Class: Stripe::SubscriptionSchedule::BillingSchedule::BillFrom

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AmendmentStart, LineStartsAt, Relative

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amendment_startObject (readonly)

Use an index to specify the position of an amendment to start prebilling with.



718
719
720
# File 'lib/stripe/resources/subscription_schedule.rb', line 718

def amendment_start
  @amendment_start
end

#computed_timestampObject (readonly)

The time the billing schedule applies from.



720
721
722
# File 'lib/stripe/resources/subscription_schedule.rb', line 720

def computed_timestamp
  @computed_timestamp
end

#line_starts_atObject (readonly)

Lets you bill the period starting from a particular Quote line.



722
723
724
# File 'lib/stripe/resources/subscription_schedule.rb', line 722

def line_starts_at
  @line_starts_at
end

#relativeObject (readonly)

Timestamp is calculated from the request time.



724
725
726
# File 'lib/stripe/resources/subscription_schedule.rb', line 724

def relative
  @relative
end

#timestampObject (readonly)

Use a precise Unix timestamp for prebilling to start. Must be earlier than ‘bill_until`.



726
727
728
# File 'lib/stripe/resources/subscription_schedule.rb', line 726

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule determines the start date. Possible values are ‘timestamp`, `relative`, `amendment_start`, `now`, `quote_acceptance_date`, `line_starts_at`, or `pause_collection_start`.



728
729
730
# File 'lib/stripe/resources/subscription_schedule.rb', line 728

def type
  @type
end

Class Method Details

.field_remappingsObject



738
739
740
# File 'lib/stripe/resources/subscription_schedule.rb', line 738

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



730
731
732
733
734
735
736
# File 'lib/stripe/resources/subscription_schedule.rb', line 730

def self.inner_class_types
  @inner_class_types = {
    amendment_start: AmendmentStart,
    line_starts_at: LineStartsAt,
    relative: Relative,
  }
end