Class: Stripe::SubscriptionSchedule::BillingSchedule::BillFrom

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#computed_timestampObject (readonly)

The time the billing schedule applies from.



682
683
684
# File 'lib/stripe/resources/subscription_schedule.rb', line 682

def computed_timestamp
  @computed_timestamp
end

#timestampObject (readonly)

Use a precise Unix timestamp for prebilling to start. Must be earlier than ‘bill_until`.



684
685
686
# File 'lib/stripe/resources/subscription_schedule.rb', line 684

def timestamp
  @timestamp
end

#typeObject (readonly)

Describes how the billing schedule determines the start date. Possible values are ‘timestamp`.



686
687
688
# File 'lib/stripe/resources/subscription_schedule.rb', line 686

def type
  @type
end

Class Method Details

.field_remappingsObject



692
693
694
# File 'lib/stripe/resources/subscription_schedule.rb', line 692

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



688
689
690
# File 'lib/stripe/resources/subscription_schedule.rb', line 688

def self.inner_class_types
  @inner_class_types = {}
end