Class: Stripe::SubscriptionSchedule::BillingSchedule::BillUntil
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration, LineEndsAt
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
readonly
Use an index to specify the position of an amendment to end prebilling with.
-
#computed_timestamp ⇒ Object
readonly
The timestamp the billing schedule will apply until.
-
#duration ⇒ Object
readonly
Specifies the billing period.
-
#line_ends_at ⇒ Object
readonly
Lets you bill the period ending at a particular Quote line.
-
#timestamp ⇒ Object
readonly
If specified, the billing schedule will apply until the specified timestamp.
-
#type ⇒ Object
readonly
Describes how the billing schedule will determine the end date.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amendment_end ⇒ Object (readonly)
Use an index to specify the position of an amendment to end prebilling with.
785 786 787 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 785 def amendment_end @amendment_end end |
#computed_timestamp ⇒ Object (readonly)
The timestamp the billing schedule will apply until.
787 788 789 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 787 def @computed_timestamp end |
#duration ⇒ Object (readonly)
Specifies the billing period.
789 790 791 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 789 def duration @duration end |
#line_ends_at ⇒ Object (readonly)
Lets you bill the period ending at a particular Quote line.
791 792 793 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 791 def line_ends_at @line_ends_at end |
#timestamp ⇒ Object (readonly)
If specified, the billing schedule will apply until the specified timestamp.
793 794 795 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 793 def @timestamp end |
#type ⇒ Object (readonly)
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
795 796 797 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 795 def type @type end |
Class Method Details
.field_remappings ⇒ Object
805 806 807 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 805 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
797 798 799 800 801 802 803 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 797 def self.inner_class_types @inner_class_types = { amendment_end: AmendmentEnd, duration: Duration, line_ends_at: LineEndsAt, } end |