Class: Stripe::SubscriptionSchedule::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



1533
1534
1535
1536
1537
# File 'lib/stripe/resources/subscription_schedule.rb', line 1533

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1527
1528
1529
# File 'lib/stripe/resources/subscription_schedule.rb', line 1527

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



1529
1530
1531
# File 'lib/stripe/resources/subscription_schedule.rb', line 1529

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



1531
1532
1533
# File 'lib/stripe/resources/subscription_schedule.rb', line 1531

def prorate
  @prorate
end