Class: Stripe::SubscriptionSchedule::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



1411
1412
1413
1414
1415
# File 'lib/stripe/resources/subscription_schedule.rb', line 1411

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1405
1406
1407
# File 'lib/stripe/resources/subscription_schedule.rb', line 1405

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



1407
1408
1409
# File 'lib/stripe/resources/subscription_schedule.rb', line 1407

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



1409
1410
1411
# File 'lib/stripe/resources/subscription_schedule.rb', line 1409

def prorate
  @prorate
end