Class: Stripe::SubscriptionSchedule::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CancelParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
2332 2333 2334 2335 2336 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2332 def initialize(expand: nil, invoice_now: nil, prorate: nil) @expand = @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2326 2327 2328 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2326 def @expand end |
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.
2328 2329 2330 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2328 def invoice_now @invoice_now end |
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.
2330 2331 2332 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2330 def prorate @prorate end |