Class: Stripe::SubscriptionSchedule::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



2217
2218
2219
2220
2221
# File 'lib/stripe/resources/subscription_schedule.rb', line 2217

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2211
2212
2213
# File 'lib/stripe/resources/subscription_schedule.rb', line 2211

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



2213
2214
2215
# File 'lib/stripe/resources/subscription_schedule.rb', line 2213

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



2215
2216
2217
# File 'lib/stripe/resources/subscription_schedule.rb', line 2215

def prorate
  @prorate
end