Class: Stripe::SubscriptionSchedule::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingMode, DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
# File 'lib/stripe/resources/subscription_schedule.rb', line 1478

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1454
1455
1456
# File 'lib/stripe/resources/subscription_schedule.rb', line 1454

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1456
1457
1458
# File 'lib/stripe/resources/subscription_schedule.rb', line 1456

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



1458
1459
1460
# File 'lib/stripe/resources/subscription_schedule.rb', line 1458

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



1460
1461
1462
# File 'lib/stripe/resources/subscription_schedule.rb', line 1460

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1462
1463
1464
# File 'lib/stripe/resources/subscription_schedule.rb', line 1462

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1464
1465
1466
# File 'lib/stripe/resources/subscription_schedule.rb', line 1464

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1466
1467
1468
# File 'lib/stripe/resources/subscription_schedule.rb', line 1466

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



1468
1469
1470
# File 'lib/stripe/resources/subscription_schedule.rb', line 1468

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1470
1471
1472
# File 'lib/stripe/resources/subscription_schedule.rb', line 1470

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



1472
1473
1474
# File 'lib/stripe/resources/subscription_schedule.rb', line 1472

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1474
1475
1476
# File 'lib/stripe/resources/subscription_schedule.rb', line 1474

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



1476
1477
1478
# File 'lib/stripe/resources/subscription_schedule.rb', line 1476

def start_date
  @start_date
end