Class: Stripe::SubscriptionSchedule::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingMode, DefaultSettings, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
# File 'lib/stripe/resources/subscription_schedule.rb', line 940

def initialize(
  billing_mode: nil,
  customer: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  start_date: nil
)
  @billing_mode = billing_mode
  @customer = customer
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @start_date = start_date
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



922
923
924
# File 'lib/stripe/resources/subscription_schedule.rb', line 922

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



924
925
926
# File 'lib/stripe/resources/subscription_schedule.rb', line 924

def customer
  @customer
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



926
927
928
# File 'lib/stripe/resources/subscription_schedule.rb', line 926

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



928
929
930
# File 'lib/stripe/resources/subscription_schedule.rb', line 928

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



930
931
932
# File 'lib/stripe/resources/subscription_schedule.rb', line 930

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



932
933
934
# File 'lib/stripe/resources/subscription_schedule.rb', line 932

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



934
935
936
# File 'lib/stripe/resources/subscription_schedule.rb', line 934

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



936
937
938
# File 'lib/stripe/resources/subscription_schedule.rb', line 936

def phases
  @phases
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



938
939
940
# File 'lib/stripe/resources/subscription_schedule.rb', line 938

def start_date
  @start_date
end