Class: Stripe::SubscriptionSchedule::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillingMode, DefaultSettings, Phase
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#customer ⇒ Object
The identifier of the customer to create the subscription schedule for.
-
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
Migrate an existing subscription to be managed by a subscription schedule.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#start_date ⇒ Object
When the subscription schedule starts.
Instance Method Summary collapse
-
#initialize(billing_mode: nil, customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_mode: nil, customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 867 def initialize( billing_mode: nil, customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil ) @billing_mode = billing_mode @customer = customer @default_settings = default_settings @end_behavior = end_behavior @expand = @from_subscription = from_subscription @metadata = @phases = phases @start_date = start_date end |
Instance Attribute Details
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
849 850 851 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 849 def billing_mode @billing_mode end |
#customer ⇒ Object
The identifier of the customer to create the subscription schedule for.
851 852 853 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 851 def customer @customer end |
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
853 854 855 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 853 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
855 856 857 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 855 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
857 858 859 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 857 def @expand end |
#from_subscription ⇒ Object
Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.
859 860 861 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 859 def from_subscription @from_subscription end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
861 862 863 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 861 def @metadata end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.
863 864 865 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 863 def phases @phases end |
#start_date ⇒ Object
When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.
865 866 867 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 865 def start_date @start_date end |