Class: Stripe::SubscriptionSchedule::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
# File 'lib/stripe/resources/subscription_schedule.rb', line 833

def initialize(
  customer: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  start_date: nil
)
  @customer = customer
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @start_date = start_date
end

Instance Attribute Details

#customerObject

The identifier of the customer to create the subscription schedule for.



817
818
819
# File 'lib/stripe/resources/subscription_schedule.rb', line 817

def customer
  @customer
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



819
820
821
# File 'lib/stripe/resources/subscription_schedule.rb', line 819

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



821
822
823
# File 'lib/stripe/resources/subscription_schedule.rb', line 821

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



823
824
825
# File 'lib/stripe/resources/subscription_schedule.rb', line 823

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



825
826
827
# File 'lib/stripe/resources/subscription_schedule.rb', line 825

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



827
828
829
# File 'lib/stripe/resources/subscription_schedule.rb', line 827

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



829
830
831
# File 'lib/stripe/resources/subscription_schedule.rb', line 829

def phases
  @phases
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



831
832
833
# File 'lib/stripe/resources/subscription_schedule.rb', line 831

def start_date
  @start_date
end