Class: Stripe::SubscriptionSchedule::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
# File 'lib/stripe/resources/subscription_schedule.rb', line 1002

def initialize(
  billing_behavior: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



980
981
982
# File 'lib/stripe/resources/subscription_schedule.rb', line 980

def billing_behavior
  @billing_behavior
end

#customerObject

The identifier of the customer to create the subscription schedule for.



982
983
984
# File 'lib/stripe/resources/subscription_schedule.rb', line 982

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



984
985
986
# File 'lib/stripe/resources/subscription_schedule.rb', line 984

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



986
987
988
# File 'lib/stripe/resources/subscription_schedule.rb', line 986

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



988
989
990
# File 'lib/stripe/resources/subscription_schedule.rb', line 988

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



990
991
992
# File 'lib/stripe/resources/subscription_schedule.rb', line 990

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



992
993
994
# File 'lib/stripe/resources/subscription_schedule.rb', line 992

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



994
995
996
# File 'lib/stripe/resources/subscription_schedule.rb', line 994

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



996
997
998
# File 'lib/stripe/resources/subscription_schedule.rb', line 996

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



998
999
1000
# File 'lib/stripe/resources/subscription_schedule.rb', line 998

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



1000
1001
1002
# File 'lib/stripe/resources/subscription_schedule.rb', line 1000

def start_date
  @start_date
end