Class: Stripe::SubscriptionSchedule::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
# File 'lib/stripe/resources/subscription_schedule.rb', line 1072

def initialize(
  billing_behavior: nil,
  customer: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @customer = customer
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1052
1053
1054
# File 'lib/stripe/resources/subscription_schedule.rb', line 1052

def billing_behavior
  @billing_behavior
end

#customerObject

The identifier of the customer to create the subscription schedule for.



1054
1055
1056
# File 'lib/stripe/resources/subscription_schedule.rb', line 1054

def customer
  @customer
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1056
1057
1058
# File 'lib/stripe/resources/subscription_schedule.rb', line 1056

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1058
1059
1060
# File 'lib/stripe/resources/subscription_schedule.rb', line 1058

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1060
1061
1062
# File 'lib/stripe/resources/subscription_schedule.rb', line 1060

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



1062
1063
1064
# File 'lib/stripe/resources/subscription_schedule.rb', line 1062

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1064
1065
1066
# File 'lib/stripe/resources/subscription_schedule.rb', line 1064

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



1066
1067
1068
# File 'lib/stripe/resources/subscription_schedule.rb', line 1066

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1068
1069
1070
# File 'lib/stripe/resources/subscription_schedule.rb', line 1068

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



1070
1071
1072
# File 'lib/stripe/resources/subscription_schedule.rb', line 1070

def start_date
  @start_date
end