Class: Stripe::SubscriptionSchedule::CreateParams::DefaultSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings

Returns a new instance of DefaultSettings.



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/stripe/resources/subscription_schedule.rb', line 547

def initialize(
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  default_payment_method: nil,
  description: nil,
  invoice_settings: nil,
  on_behalf_of: nil,
  transfer_data: nil
)
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @default_payment_method = default_payment_method
  @description = description
  @invoice_settings = invoice_settings
  @on_behalf_of = on_behalf_of
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



527
528
529
# File 'lib/stripe/resources/subscription_schedule.rb', line 527

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Default settings for automatic tax computation.



529
530
531
# File 'lib/stripe/resources/subscription_schedule.rb', line 529

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



531
532
533
# File 'lib/stripe/resources/subscription_schedule.rb', line 531

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



533
534
535
# File 'lib/stripe/resources/subscription_schedule.rb', line 533

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.



535
536
537
# File 'lib/stripe/resources/subscription_schedule.rb', line 535

def collection_method
  @collection_method
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



537
538
539
# File 'lib/stripe/resources/subscription_schedule.rb', line 537

def default_payment_method
  @default_payment_method
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



539
540
541
# File 'lib/stripe/resources/subscription_schedule.rb', line 539

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



541
542
543
# File 'lib/stripe/resources/subscription_schedule.rb', line 541

def invoice_settings
  @invoice_settings
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription’s invoices.



543
544
545
# File 'lib/stripe/resources/subscription_schedule.rb', line 543

def on_behalf_of
  @on_behalf_of
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription’s invoices.



545
546
547
# File 'lib/stripe/resources/subscription_schedule.rb', line 545

def transfer_data
  @transfer_data
end