Class: Stripe::SubscriptionSchedule::CreateParams::DefaultSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings

Returns a new instance of DefaultSettings.



644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
# File 'lib/stripe/resources/subscription_schedule.rb', line 644

def initialize(
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  default_payment_method: nil,
  description: nil,
  invoice_settings: nil,
  on_behalf_of: nil,
  transfer_data: nil
)
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @default_payment_method = default_payment_method
  @description = description
  @invoice_settings = invoice_settings
  @on_behalf_of = on_behalf_of
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



615
616
617
# File 'lib/stripe/resources/subscription_schedule.rb', line 615

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Default settings for automatic tax computation.



618
619
620
# File 'lib/stripe/resources/subscription_schedule.rb', line 618

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



621
622
623
# File 'lib/stripe/resources/subscription_schedule.rb', line 621

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



624
625
626
# File 'lib/stripe/resources/subscription_schedule.rb', line 624

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.



627
628
629
# File 'lib/stripe/resources/subscription_schedule.rb', line 627

def collection_method
  @collection_method
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



630
631
632
# File 'lib/stripe/resources/subscription_schedule.rb', line 630

def default_payment_method
  @default_payment_method
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



633
634
635
# File 'lib/stripe/resources/subscription_schedule.rb', line 633

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



636
637
638
# File 'lib/stripe/resources/subscription_schedule.rb', line 636

def invoice_settings
  @invoice_settings
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription’s invoices.



639
640
641
# File 'lib/stripe/resources/subscription_schedule.rb', line 639

def on_behalf_of
  @on_behalf_of
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription’s invoices.



642
643
644
# File 'lib/stripe/resources/subscription_schedule.rb', line 642

def transfer_data
  @transfer_data
end