Class: Stripe::SubscriptionSchedule::CreateParams::DefaultSettings::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::DefaultSettings::TransferData
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
545 546 547 548 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 545 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
541 542 543 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 541 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
543 544 545 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 543 def destination @destination end |