Class: Stripe::SubscriptionSchedule::CreateParams::DefaultSettings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



438
439
440
441
# File 'lib/stripe/resources/subscription_schedule.rb', line 438

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



434
435
436
# File 'lib/stripe/resources/subscription_schedule.rb', line 434

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



436
437
438
# File 'lib/stripe/resources/subscription_schedule.rb', line 436

def destination
  @destination
end