Class: Stripe::SubscriptionSchedule::CreateParams::Phase

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, Duration, InvoiceSettings, Item, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, proration_behavior: nil, transfer_data: nil, trial: nil, trial_end: nil) ⇒ Phase

Returns a new instance of Phase.



800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
# File 'lib/stripe/resources/subscription_schedule.rb', line 800

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  currency: nil,
  default_payment_method: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  duration: nil,
  end_date: nil,
  invoice_settings: nil,
  items: nil,
  iterations: nil,
  metadata: nil,
  on_behalf_of: nil,
  proration_behavior: nil,
  transfer_data: nil,
  trial: nil,
  trial_end: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @currency = currency
  @default_payment_method = default_payment_method
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @duration = duration
  @end_date = end_date
  @invoice_settings = invoice_settings
  @items = items
  @iterations = iterations
  @metadata = 
  @on_behalf_of = on_behalf_of
  @proration_behavior = proration_behavior
  @transfer_data = transfer_data
  @trial = trial
  @trial_end = trial_end
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.



756
757
758
# File 'lib/stripe/resources/subscription_schedule.rb', line 756

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



758
759
760
# File 'lib/stripe/resources/subscription_schedule.rb', line 758

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this phase.



760
761
762
# File 'lib/stripe/resources/subscription_schedule.rb', line 760

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



762
763
764
# File 'lib/stripe/resources/subscription_schedule.rb', line 762

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



764
765
766
# File 'lib/stripe/resources/subscription_schedule.rb', line 764

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.



766
767
768
# File 'lib/stripe/resources/subscription_schedule.rb', line 766

def collection_method
  @collection_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



768
769
770
# File 'lib/stripe/resources/subscription_schedule.rb', line 768

def currency
  @currency
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



770
771
772
# File 'lib/stripe/resources/subscription_schedule.rb', line 770

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](stripe.com/docs/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.



772
773
774
# File 'lib/stripe/resources/subscription_schedule.rb', line 772

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



774
775
776
# File 'lib/stripe/resources/subscription_schedule.rb', line 774

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.



776
777
778
# File 'lib/stripe/resources/subscription_schedule.rb', line 776

def discounts
  @discounts
end

#durationObject

The number of intervals the phase should last. If set, ‘end_date` must not be set.



778
779
780
# File 'lib/stripe/resources/subscription_schedule.rb', line 778

def duration
  @duration
end

#end_dateObject

The date at which this phase of the subscription schedule ends. If set, ‘iterations` must not be set.



780
781
782
# File 'lib/stripe/resources/subscription_schedule.rb', line 780

def end_date
  @end_date
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



782
783
784
# File 'lib/stripe/resources/subscription_schedule.rb', line 782

def invoice_settings
  @invoice_settings
end

#itemsObject

List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.



784
785
786
# File 'lib/stripe/resources/subscription_schedule.rb', line 784

def items
  @items
end

#iterationsObject

Integer representing the multiplier applied to the price interval. For example, ‘iterations=2` applied to a price with `interval=month` and `interval_count=3` results in a phase of duration `2 * 3 months = 6 months`. If set, `end_date` must not be set. This parameter is deprecated and will be removed in a future version. Use `duration` instead.



786
787
788
# File 'lib/stripe/resources/subscription_schedule.rb', line 786

def iterations
  @iterations
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.



788
789
790
# File 'lib/stripe/resources/subscription_schedule.rb', line 788

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription’s invoices.



790
791
792
# File 'lib/stripe/resources/subscription_schedule.rb', line 790

def on_behalf_of
  @on_behalf_of
end

#proration_behaviorObject

Controls whether the subscription schedule should create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase if there is a difference in billing configuration. It’s different from the request-level [proration_behavior](stripe.com/docs/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration (item price, quantity, etc.) of the current phase.



792
793
794
# File 'lib/stripe/resources/subscription_schedule.rb', line 792

def proration_behavior
  @proration_behavior
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription’s invoices.



794
795
796
# File 'lib/stripe/resources/subscription_schedule.rb', line 794

def transfer_data
  @transfer_data
end

#trialObject

If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.



796
797
798
# File 'lib/stripe/resources/subscription_schedule.rb', line 796

def trial
  @trial
end

#trial_endObject

Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`



798
799
800
# File 'lib/stripe/resources/subscription_schedule.rb', line 798

def trial_end
  @trial_end
end