Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 606 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
592 593 594 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 592 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
594 595 596 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 594 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.
596 597 598 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 596 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
598 599 600 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 598 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
600 601 602 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 600 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
602 603 604 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 602 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
604 605 606 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 604 def tax_rates @tax_rates end |