Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
597 598 599 600 601 602 603 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 597 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
587 588 589 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 587 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
589 590 591 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 589 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
591 592 593 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 591 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
593 594 595 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 593 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
595 596 597 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 595 def tax_rates @tax_rates end |