Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



633
634
635
636
637
638
# File 'lib/stripe/resources/subscription_schedule.rb', line 633

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



625
626
627
# File 'lib/stripe/resources/subscription_schedule.rb', line 625

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



627
628
629
# File 'lib/stripe/resources/subscription_schedule.rb', line 627

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



629
630
631
# File 'lib/stripe/resources/subscription_schedule.rb', line 629

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



631
632
633
# File 'lib/stripe/resources/subscription_schedule.rb', line 631

def promotion_code
  @promotion_code
end