Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
523 524 525 526 527 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 523 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
517 518 519 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 517 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
519 520 521 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 519 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
521 522 523 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 521 def promotion_code @promotion_code end |