Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
483 484 485 486 487 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 483 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
477 478 479 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 477 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
479 480 481 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 479 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
481 482 483 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 481 def promotion_code @promotion_code end |