Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



552
553
554
555
556
557
# File 'lib/stripe/resources/subscription_schedule.rb', line 552

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



544
545
546
# File 'lib/stripe/resources/subscription_schedule.rb', line 544

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



546
547
548
# File 'lib/stripe/resources/subscription_schedule.rb', line 546

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



548
549
550
# File 'lib/stripe/resources/subscription_schedule.rb', line 548

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



550
551
552
# File 'lib/stripe/resources/subscription_schedule.rb', line 550

def promotion_code
  @promotion_code
end