Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



591
592
593
594
595
596
# File 'lib/stripe/resources/subscription_schedule.rb', line 591

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



583
584
585
# File 'lib/stripe/resources/subscription_schedule.rb', line 583

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



585
586
587
# File 'lib/stripe/resources/subscription_schedule.rb', line 585

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



587
588
589
# File 'lib/stripe/resources/subscription_schedule.rb', line 587

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



589
590
591
# File 'lib/stripe/resources/subscription_schedule.rb', line 589

def promotion_code
  @promotion_code
end