Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



712
713
714
715
716
717
# File 'lib/stripe/resources/subscription_schedule.rb', line 712

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



701
702
703
# File 'lib/stripe/resources/subscription_schedule.rb', line 701

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



704
705
706
# File 'lib/stripe/resources/subscription_schedule.rb', line 704

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



707
708
709
# File 'lib/stripe/resources/subscription_schedule.rb', line 707

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



710
711
712
# File 'lib/stripe/resources/subscription_schedule.rb', line 710

def promotion_code
  @promotion_code
end