Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
947 948 949 950 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 947 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
943 944 945 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 943 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
945 946 947 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 945 def type @type end |