Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
959 960 961 962 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 959 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
955 956 957 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 955 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
957 958 959 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 957 def type @type end |