Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
660 661 662 663 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 660 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
656 657 658 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 656 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
658 659 660 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 658 def type @type end |