Class: Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
549 550 551 552 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 549 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
545 546 547 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 545 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
547 548 549 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 547 def type @type end |