Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
595 596 597 598 599 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 595 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
589 590 591 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 589 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
591 592 593 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 591 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
593 594 595 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 593 def promotion_code @promotion_code end |