Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



717
718
719
720
721
722
# File 'lib/stripe/resources/subscription_schedule.rb', line 717

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



709
710
711
# File 'lib/stripe/resources/subscription_schedule.rb', line 709

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



711
712
713
# File 'lib/stripe/resources/subscription_schedule.rb', line 711

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



713
714
715
# File 'lib/stripe/resources/subscription_schedule.rb', line 713

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



715
716
717
# File 'lib/stripe/resources/subscription_schedule.rb', line 715

def promotion_code
  @promotion_code
end