Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::CreateParams::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
579 580 581 582 583 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 579 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
573 574 575 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 573 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
575 576 577 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 575 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
577 578 579 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 577 def promotion_code @promotion_code end |