Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



702
703
704
705
706
# File 'lib/stripe/resources/subscription_schedule.rb', line 702

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



696
697
698
# File 'lib/stripe/resources/subscription_schedule.rb', line 696

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



698
699
700
# File 'lib/stripe/resources/subscription_schedule.rb', line 698

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



700
701
702
# File 'lib/stripe/resources/subscription_schedule.rb', line 700

def type
  @type
end