Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



835
836
837
838
839
# File 'lib/stripe/resources/subscription_schedule.rb', line 835

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



827
828
829
# File 'lib/stripe/resources/subscription_schedule.rb', line 827

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



830
831
832
# File 'lib/stripe/resources/subscription_schedule.rb', line 830

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



833
834
835
# File 'lib/stripe/resources/subscription_schedule.rb', line 833

def type
  @type
end