Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



731
732
733
734
735
# File 'lib/stripe/resources/subscription_schedule.rb', line 731

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



725
726
727
# File 'lib/stripe/resources/subscription_schedule.rb', line 725

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



727
728
729
# File 'lib/stripe/resources/subscription_schedule.rb', line 727

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



729
730
731
# File 'lib/stripe/resources/subscription_schedule.rb', line 729

def promotion_code
  @promotion_code
end