Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



824
825
826
827
828
829
# File 'lib/stripe/resources/subscription_schedule.rb', line 824

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



816
817
818
# File 'lib/stripe/resources/subscription_schedule.rb', line 816

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



818
819
820
# File 'lib/stripe/resources/subscription_schedule.rb', line 818

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



820
821
822
# File 'lib/stripe/resources/subscription_schedule.rb', line 820

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



822
823
824
# File 'lib/stripe/resources/subscription_schedule.rb', line 822

def promotion_code
  @promotion_code
end