Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



646
647
648
649
650
# File 'lib/stripe/resources/subscription_schedule.rb', line 646

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



640
641
642
# File 'lib/stripe/resources/subscription_schedule.rb', line 640

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



642
643
644
# File 'lib/stripe/resources/subscription_schedule.rb', line 642

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



644
645
646
# File 'lib/stripe/resources/subscription_schedule.rb', line 644

def promotion_code
  @promotion_code
end