Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



734
735
736
737
738
739
# File 'lib/stripe/resources/subscription_schedule.rb', line 734

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



726
727
728
# File 'lib/stripe/resources/subscription_schedule.rb', line 726

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



728
729
730
# File 'lib/stripe/resources/subscription_schedule.rb', line 728

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



730
731
732
# File 'lib/stripe/resources/subscription_schedule.rb', line 730

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



732
733
734
# File 'lib/stripe/resources/subscription_schedule.rb', line 732

def promotion_code
  @promotion_code
end