Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



794
795
796
797
798
799
# File 'lib/stripe/resources/subscription_schedule.rb', line 794

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



786
787
788
# File 'lib/stripe/resources/subscription_schedule.rb', line 786

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



788
789
790
# File 'lib/stripe/resources/subscription_schedule.rb', line 788

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



790
791
792
# File 'lib/stripe/resources/subscription_schedule.rb', line 790

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



792
793
794
# File 'lib/stripe/resources/subscription_schedule.rb', line 792

def promotion_code
  @promotion_code
end