Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



797
798
799
800
801
# File 'lib/stripe/resources/subscription_schedule.rb', line 797

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



791
792
793
# File 'lib/stripe/resources/subscription_schedule.rb', line 791

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



793
794
795
# File 'lib/stripe/resources/subscription_schedule.rb', line 793

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



795
796
797
# File 'lib/stripe/resources/subscription_schedule.rb', line 795

def type
  @type
end