Class: Stripe::SubscriptionSchedule::CreateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



923
924
925
926
927
# File 'lib/stripe/resources/subscription_schedule.rb', line 923

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



915
916
917
# File 'lib/stripe/resources/subscription_schedule.rb', line 915

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



918
919
920
# File 'lib/stripe/resources/subscription_schedule.rb', line 918

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



921
922
923
# File 'lib/stripe/resources/subscription_schedule.rb', line 921

def type
  @type
end