Class: Stripe::SubscriptionSchedule::DefaultSettings
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::DefaultSettings
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application_fee_percent ⇒ Object
readonly
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
readonly
Attribute for field automatic_tax.
-
#billing_cycle_anchor ⇒ Object
readonly
Possible values are
phase_startorautomatic. -
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
readonly
Either
charge_automatically, orsend_invoice. -
#default_payment_method ⇒ Object
readonly
ID of the default payment method for the subscription schedule.
-
#description ⇒ Object
readonly
Subscription description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
readonly
Attribute for field invoice_settings.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of for charges associated with the schedule's subscription.
-
#transfer_data ⇒ Object
readonly
The account (if any) the associated subscription's payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription's invoices.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application_fee_percent ⇒ Object (readonly)
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account during this phase of the schedule.
176 177 178 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 176 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object (readonly)
Attribute for field automatic_tax
178 179 180 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 178 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object (readonly)
Possible values are phase_start or automatic. If phase_start then billing cycle anchor of the subscription is set to the start of the phase when entering the phase. If automatic then the billing cycle anchor is automatically modified as needed when entering the phase. For more information, see the billing cycle documentation.
180 181 182 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 180 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period
182 183 184 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 182 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object (readonly)
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active.
184 185 186 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 184 def collection_method @collection_method end |
#default_payment_method ⇒ Object (readonly)
ID of the default payment method for the subscription schedule. If not set, invoices will use the default payment method in the customer's invoice settings.
186 187 188 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 186 def default_payment_method @default_payment_method end |
#description ⇒ Object (readonly)
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
188 189 190 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 188 def description @description end |
#invoice_settings ⇒ Object (readonly)
Attribute for field invoice_settings
190 191 192 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 190 def invoice_settings @invoice_settings end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of for charges associated with the schedule's subscription. See the Connect documentation for details.
192 193 194 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 192 def on_behalf_of @on_behalf_of end |
#transfer_data ⇒ Object (readonly)
The account (if any) the associated subscription's payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription's invoices.
194 195 196 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 194 def transfer_data @transfer_data end |
Class Method Details
.field_remappings ⇒ Object
205 206 207 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 205 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
196 197 198 199 200 201 202 203 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 196 def self.inner_class_types @inner_class_types = { automatic_tax: AutomaticTax, billing_thresholds: BillingThresholds, invoice_settings: InvoiceSettings, transfer_data: TransferData, } end |