Class: Stripe::SubscriptionSchedule::DefaultSettings

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#application_fee_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account during this phase of the schedule.



70
71
72
# File 'lib/stripe/resources/subscription_schedule.rb', line 70

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



72
73
74
# File 'lib/stripe/resources/subscription_schedule.rb', line 72

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject (readonly)

Possible values are ‘phase_start` or `automatic`. If `phase_start` then billing cycle anchor of the subscription is set to the start of the phase when entering the phase. If `automatic` then the billing cycle anchor is automatically modified as needed when entering the phase. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



74
75
76
# File 'lib/stripe/resources/subscription_schedule.rb', line 74

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period



76
77
78
# File 'lib/stripe/resources/subscription_schedule.rb', line 76

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`.



78
79
80
# File 'lib/stripe/resources/subscription_schedule.rb', line 78

def collection_method
  @collection_method
end

#default_payment_methodObject (readonly)

ID of the default payment method for the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



80
81
82
# File 'lib/stripe/resources/subscription_schedule.rb', line 80

def default_payment_method
  @default_payment_method
end

#descriptionObject (readonly)

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



82
83
84
# File 'lib/stripe/resources/subscription_schedule.rb', line 82

def description
  @description
end

#invoice_settingsObject (readonly)

Attribute for field invoice_settings



84
85
86
# File 'lib/stripe/resources/subscription_schedule.rb', line 84

def invoice_settings
  @invoice_settings
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of for charges associated with the schedule’s subscription. See the Connect documentation for details.



86
87
88
# File 'lib/stripe/resources/subscription_schedule.rb', line 86

def on_behalf_of
  @on_behalf_of
end

#transfer_dataObject (readonly)

The account (if any) the associated subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.



88
89
90
# File 'lib/stripe/resources/subscription_schedule.rb', line 88

def transfer_data
  @transfer_data
end