Class: Stripe::SubscriptionSchedule::DefaultSettings::AutomaticTax

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Liability

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#disabled_reasonObject (readonly)

If Stripe disabled automatic tax, this enum describes why.



65
66
67
# File 'lib/stripe/resources/subscription_schedule.rb', line 65

def disabled_reason
  @disabled_reason
end

#enabledObject (readonly)

Whether Stripe automatically computes tax on invoices created during this phase.



67
68
69
# File 'lib/stripe/resources/subscription_schedule.rb', line 67

def enabled
  @enabled
end

#liabilityObject (readonly)

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



69
70
71
# File 'lib/stripe/resources/subscription_schedule.rb', line 69

def liability
  @liability
end

Class Method Details

.field_remappingsObject



75
76
77
# File 'lib/stripe/resources/subscription_schedule.rb', line 75

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



71
72
73
# File 'lib/stripe/resources/subscription_schedule.rb', line 71

def self.inner_class_types
  @inner_class_types = { liability: Liability }
end