Class: Stripe::SubscriptionSchedule::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CanceledAt, CompletedAt, Created, ReleasedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/stripe/resources/subscription_schedule.rb', line 359

def initialize(
  canceled_at: nil,
  completed_at: nil,
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  released_at: nil,
  scheduled: nil,
  starting_after: nil
)
  @canceled_at = canceled_at
  @completed_at = completed_at
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @released_at = released_at
  @scheduled = scheduled
  @starting_after = starting_after
end

Instance Attribute Details

#canceled_atObject

Only return subscription schedules that were created canceled the given date interval.



339
340
341
# File 'lib/stripe/resources/subscription_schedule.rb', line 339

def canceled_at
  @canceled_at
end

#completed_atObject

Only return subscription schedules that completed during the given date interval.



341
342
343
# File 'lib/stripe/resources/subscription_schedule.rb', line 341

def completed_at
  @completed_at
end

#createdObject

Only return subscription schedules that were created during the given date interval.



343
344
345
# File 'lib/stripe/resources/subscription_schedule.rb', line 343

def created
  @created
end

#customerObject

Only return subscription schedules for the given customer.



345
346
347
# File 'lib/stripe/resources/subscription_schedule.rb', line 345

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



347
348
349
# File 'lib/stripe/resources/subscription_schedule.rb', line 347

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



349
350
351
# File 'lib/stripe/resources/subscription_schedule.rb', line 349

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



351
352
353
# File 'lib/stripe/resources/subscription_schedule.rb', line 351

def limit
  @limit
end

#released_atObject

Only return subscription schedules that were released during the given date interval.



353
354
355
# File 'lib/stripe/resources/subscription_schedule.rb', line 353

def released_at
  @released_at
end

#scheduledObject

Only return subscription schedules that have not started yet.



355
356
357
# File 'lib/stripe/resources/subscription_schedule.rb', line 355

def scheduled
  @scheduled
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



357
358
359
# File 'lib/stripe/resources/subscription_schedule.rb', line 357

def starting_after
  @starting_after
end