Class: Stripe::SubscriptionSchedule::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::ListParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: CanceledAt, CompletedAt, Created, ReleasedAt
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
-
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
-
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
-
#customer ⇒ Object
Only return subscription schedules for the given customer.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
-
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 359 def initialize( canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil ) @canceled_at = canceled_at @completed_at = completed_at @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @released_at = released_at @scheduled = scheduled @starting_after = starting_after end |
Instance Attribute Details
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
339 340 341 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 339 def canceled_at @canceled_at end |
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
341 342 343 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 341 def completed_at @completed_at end |
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
343 344 345 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 343 def created @created end |
#customer ⇒ Object
Only return subscription schedules for the given customer.
345 346 347 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 345 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
347 348 349 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 347 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
349 350 351 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 349 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
351 352 353 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 351 def limit @limit end |
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
353 354 355 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 353 def released_at @released_at end |
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
355 356 357 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 355 def scheduled @scheduled end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
357 358 359 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 357 def starting_after @starting_after end |