Class: Stripe::SubscriptionSchedule::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CanceledAt, CompletedAt, Created, ReleasedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/stripe/resources/subscription_schedule.rb', line 335

def initialize(
  canceled_at: nil,
  completed_at: nil,
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  released_at: nil,
  scheduled: nil,
  starting_after: nil
)
  @canceled_at = canceled_at
  @completed_at = completed_at
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @released_at = released_at
  @scheduled = scheduled
  @starting_after = starting_after
end

Instance Attribute Details

#canceled_atObject

Only return subscription schedules that were created canceled the given date interval.



315
316
317
# File 'lib/stripe/resources/subscription_schedule.rb', line 315

def canceled_at
  @canceled_at
end

#completed_atObject

Only return subscription schedules that completed during the given date interval.



317
318
319
# File 'lib/stripe/resources/subscription_schedule.rb', line 317

def completed_at
  @completed_at
end

#createdObject

Only return subscription schedules that were created during the given date interval.



319
320
321
# File 'lib/stripe/resources/subscription_schedule.rb', line 319

def created
  @created
end

#customerObject

Only return subscription schedules for the given customer.



321
322
323
# File 'lib/stripe/resources/subscription_schedule.rb', line 321

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



323
324
325
# File 'lib/stripe/resources/subscription_schedule.rb', line 323

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



325
326
327
# File 'lib/stripe/resources/subscription_schedule.rb', line 325

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



327
328
329
# File 'lib/stripe/resources/subscription_schedule.rb', line 327

def limit
  @limit
end

#released_atObject

Only return subscription schedules that were released during the given date interval.



329
330
331
# File 'lib/stripe/resources/subscription_schedule.rb', line 329

def released_at
  @released_at
end

#scheduledObject

Only return subscription schedules that have not started yet.



331
332
333
# File 'lib/stripe/resources/subscription_schedule.rb', line 331

def scheduled
  @scheduled
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



333
334
335
# File 'lib/stripe/resources/subscription_schedule.rb', line 333

def starting_after
  @starting_after
end