Class: Stripe::SubscriptionSchedule::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CanceledAt, CompletedAt, Created, ReleasedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/stripe/resources/subscription_schedule.rb', line 409

def initialize(
  canceled_at: nil,
  completed_at: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  released_at: nil,
  scheduled: nil,
  starting_after: nil
)
  @canceled_at = canceled_at
  @completed_at = completed_at
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @released_at = released_at
  @scheduled = scheduled
  @starting_after = starting_after
end

Instance Attribute Details

#canceled_atObject

Only return subscription schedules that were created canceled the given date interval.



387
388
389
# File 'lib/stripe/resources/subscription_schedule.rb', line 387

def canceled_at
  @canceled_at
end

#completed_atObject

Only return subscription schedules that completed during the given date interval.



389
390
391
# File 'lib/stripe/resources/subscription_schedule.rb', line 389

def completed_at
  @completed_at
end

#createdObject

Only return subscription schedules that were created during the given date interval.



391
392
393
# File 'lib/stripe/resources/subscription_schedule.rb', line 391

def created
  @created
end

#customerObject

Only return subscription schedules for the given customer.



393
394
395
# File 'lib/stripe/resources/subscription_schedule.rb', line 393

def customer
  @customer
end

#customer_accountObject

Only return subscription schedules for the given account.



395
396
397
# File 'lib/stripe/resources/subscription_schedule.rb', line 395

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



397
398
399
# File 'lib/stripe/resources/subscription_schedule.rb', line 397

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



399
400
401
# File 'lib/stripe/resources/subscription_schedule.rb', line 399

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



401
402
403
# File 'lib/stripe/resources/subscription_schedule.rb', line 401

def limit
  @limit
end

#released_atObject

Only return subscription schedules that were released during the given date interval.



403
404
405
# File 'lib/stripe/resources/subscription_schedule.rb', line 403

def released_at
  @released_at
end

#scheduledObject

Only return subscription schedules that have not started yet.



405
406
407
# File 'lib/stripe/resources/subscription_schedule.rb', line 405

def scheduled
  @scheduled
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



407
408
409
# File 'lib/stripe/resources/subscription_schedule.rb', line 407

def starting_after
  @starting_after
end