Class: Stripe::SubscriptionSchedule::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CanceledAt, CompletedAt, Created, ReleasedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/stripe/resources/subscription_schedule.rb', line 328

def initialize(
  canceled_at: nil,
  completed_at: nil,
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  released_at: nil,
  scheduled: nil,
  starting_after: nil
)
  @canceled_at = canceled_at
  @completed_at = completed_at
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @released_at = released_at
  @scheduled = scheduled
  @starting_after = starting_after
end

Instance Attribute Details

#canceled_atObject

Only return subscription schedules that were created canceled the given date interval.



308
309
310
# File 'lib/stripe/resources/subscription_schedule.rb', line 308

def canceled_at
  @canceled_at
end

#completed_atObject

Only return subscription schedules that completed during the given date interval.



310
311
312
# File 'lib/stripe/resources/subscription_schedule.rb', line 310

def completed_at
  @completed_at
end

#createdObject

Only return subscription schedules that were created during the given date interval.



312
313
314
# File 'lib/stripe/resources/subscription_schedule.rb', line 312

def created
  @created
end

#customerObject

Only return subscription schedules for the given customer.



314
315
316
# File 'lib/stripe/resources/subscription_schedule.rb', line 314

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



316
317
318
# File 'lib/stripe/resources/subscription_schedule.rb', line 316

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



318
319
320
# File 'lib/stripe/resources/subscription_schedule.rb', line 318

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



320
321
322
# File 'lib/stripe/resources/subscription_schedule.rb', line 320

def limit
  @limit
end

#released_atObject

Only return subscription schedules that were released during the given date interval.



322
323
324
# File 'lib/stripe/resources/subscription_schedule.rb', line 322

def released_at
  @released_at
end

#scheduledObject

Only return subscription schedules that have not started yet.



324
325
326
# File 'lib/stripe/resources/subscription_schedule.rb', line 324

def scheduled
  @scheduled
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



326
327
328
# File 'lib/stripe/resources/subscription_schedule.rb', line 326

def starting_after
  @starting_after
end