Class: Stripe::SubscriptionSchedule::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::ListParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: CanceledAt, CompletedAt, Created, ReleasedAt
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
-
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
-
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
-
#customer ⇒ Object
Only return subscription schedules for the given customer.
-
#customer_account ⇒ Object
Only return subscription schedules for the given account.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
-
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 384 def initialize( canceled_at: nil, completed_at: nil, created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil ) @canceled_at = canceled_at @completed_at = completed_at @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @released_at = released_at @scheduled = scheduled @starting_after = starting_after end |
Instance Attribute Details
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
362 363 364 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 362 def canceled_at @canceled_at end |
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
364 365 366 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 364 def completed_at @completed_at end |
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
366 367 368 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 366 def created @created end |
#customer ⇒ Object
Only return subscription schedules for the given customer.
368 369 370 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 368 def customer @customer end |
#customer_account ⇒ Object
Only return subscription schedules for the given account.
370 371 372 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 370 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
372 373 374 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 372 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
374 375 376 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 374 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
376 377 378 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 376 def limit @limit end |
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
378 379 380 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 378 def released_at @released_at end |
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
380 381 382 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 380 def scheduled @scheduled end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
382 383 384 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 382 def starting_after @starting_after end |