Class: Stripe::SubscriptionSchedule::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CanceledAt, CompletedAt, Created, ReleasedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/stripe/resources/subscription_schedule.rb', line 303

def initialize(
  canceled_at: nil,
  completed_at: nil,
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  released_at: nil,
  scheduled: nil,
  starting_after: nil
)
  @canceled_at = canceled_at
  @completed_at = completed_at
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @released_at = released_at
  @scheduled = scheduled
  @starting_after = starting_after
end

Instance Attribute Details

#canceled_atObject

Only return subscription schedules that were created canceled the given date interval.



283
284
285
# File 'lib/stripe/resources/subscription_schedule.rb', line 283

def canceled_at
  @canceled_at
end

#completed_atObject

Only return subscription schedules that completed during the given date interval.



285
286
287
# File 'lib/stripe/resources/subscription_schedule.rb', line 285

def completed_at
  @completed_at
end

#createdObject

Only return subscription schedules that were created during the given date interval.



287
288
289
# File 'lib/stripe/resources/subscription_schedule.rb', line 287

def created
  @created
end

#customerObject

Only return subscription schedules for the given customer.



289
290
291
# File 'lib/stripe/resources/subscription_schedule.rb', line 289

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



291
292
293
# File 'lib/stripe/resources/subscription_schedule.rb', line 291

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



293
294
295
# File 'lib/stripe/resources/subscription_schedule.rb', line 293

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



295
296
297
# File 'lib/stripe/resources/subscription_schedule.rb', line 295

def limit
  @limit
end

#released_atObject

Only return subscription schedules that were released during the given date interval.



297
298
299
# File 'lib/stripe/resources/subscription_schedule.rb', line 297

def released_at
  @released_at
end

#scheduledObject

Only return subscription schedules that have not started yet.



299
300
301
# File 'lib/stripe/resources/subscription_schedule.rb', line 299

def scheduled
  @scheduled
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



301
302
303
# File 'lib/stripe/resources/subscription_schedule.rb', line 301

def starting_after
  @starting_after
end