Class: Stripe::SubscriptionSchedule::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: CanceledAt, CompletedAt, Created, ReleasedAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/stripe/resources/subscription_schedule.rb', line 508

def initialize(
  canceled_at: nil,
  completed_at: nil,
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  released_at: nil,
  scheduled: nil,
  starting_after: nil
)
  @canceled_at = canceled_at
  @completed_at = completed_at
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @released_at = released_at
  @scheduled = scheduled
  @starting_after = starting_after
end

Instance Attribute Details

#canceled_atObject

Only return subscription schedules that were created canceled the given date interval.



479
480
481
# File 'lib/stripe/resources/subscription_schedule.rb', line 479

def canceled_at
  @canceled_at
end

#completed_atObject

Only return subscription schedules that completed during the given date interval.



482
483
484
# File 'lib/stripe/resources/subscription_schedule.rb', line 482

def completed_at
  @completed_at
end

#createdObject

Only return subscription schedules that were created during the given date interval.



485
486
487
# File 'lib/stripe/resources/subscription_schedule.rb', line 485

def created
  @created
end

#customerObject

Only return subscription schedules for the given customer.



488
489
490
# File 'lib/stripe/resources/subscription_schedule.rb', line 488

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



491
492
493
# File 'lib/stripe/resources/subscription_schedule.rb', line 491

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



494
495
496
# File 'lib/stripe/resources/subscription_schedule.rb', line 494

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



497
498
499
# File 'lib/stripe/resources/subscription_schedule.rb', line 497

def limit
  @limit
end

#released_atObject

Only return subscription schedules that were released during the given date interval.



500
501
502
# File 'lib/stripe/resources/subscription_schedule.rb', line 500

def released_at
  @released_at
end

#scheduledObject

Only return subscription schedules that have not started yet.



503
504
505
# File 'lib/stripe/resources/subscription_schedule.rb', line 503

def scheduled
  @scheduled
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



506
507
508
# File 'lib/stripe/resources/subscription_schedule.rb', line 506

def starting_after
  @starting_after
end