Class: Stripe::SubscriptionSchedule::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::ListParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: CanceledAt, CompletedAt, Created, ReleasedAt
Instance Attribute Summary collapse
-
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
-
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
-
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
-
#customer ⇒ Object
Only return subscription schedules for the given customer.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
-
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 508 def initialize( canceled_at: nil, completed_at: nil, created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, released_at: nil, scheduled: nil, starting_after: nil ) @canceled_at = canceled_at @completed_at = completed_at @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @released_at = released_at @scheduled = scheduled @starting_after = starting_after end |
Instance Attribute Details
#canceled_at ⇒ Object
Only return subscription schedules that were created canceled the given date interval.
479 480 481 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 479 def canceled_at @canceled_at end |
#completed_at ⇒ Object
Only return subscription schedules that completed during the given date interval.
482 483 484 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 482 def completed_at @completed_at end |
#created ⇒ Object
Only return subscription schedules that were created during the given date interval.
485 486 487 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 485 def created @created end |
#customer ⇒ Object
Only return subscription schedules for the given customer.
488 489 490 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 488 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
491 492 493 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 491 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
494 495 496 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 494 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
497 498 499 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 497 def limit @limit end |
#released_at ⇒ Object
Only return subscription schedules that were released during the given date interval.
500 501 502 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 500 def released_at @released_at end |
#scheduled ⇒ Object
Only return subscription schedules that have not started yet.
503 504 505 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 503 def scheduled @scheduled end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
506 507 508 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 506 def starting_after @starting_after end |