Class: Stripe::SubscriptionSchedule::PauseSchedule::Pause::Settings
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::PauseSchedule::Pause::Settings
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillFor
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
readonly
Attribute for field bill_for.
-
#invoicing_behavior ⇒ Object
readonly
Determines how to handle debits and credits when pausing.
-
#type ⇒ Object
readonly
The type of pause settings.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_for ⇒ Object (readonly)
Attribute for field bill_for
353 354 355 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 353 def bill_for @bill_for end |
#invoicing_behavior ⇒ Object (readonly)
Determines how to handle debits and credits when pausing.
355 356 357 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 355 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object (readonly)
The type of pause settings.
357 358 359 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 357 def type @type end |
Class Method Details
.field_remappings ⇒ Object
363 364 365 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 363 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
359 360 361 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 359 def self.inner_class_types @inner_class_types = { bill_for: BillFor } end |