Class: Stripe::SubscriptionSchedule::Phase

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#add_invoice_itemsObject (readonly)

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.



746
747
748
# File 'lib/stripe/resources/subscription_schedule.rb', line 746

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject (readonly)

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account during this phase of the schedule.



748
749
750
# File 'lib/stripe/resources/subscription_schedule.rb', line 748

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



750
751
752
# File 'lib/stripe/resources/subscription_schedule.rb', line 750

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject (readonly)

Possible values are ‘phase_start` or `automatic`. If `phase_start` then billing cycle anchor of the subscription is set to the start of the phase when entering the phase. If `automatic` then the billing cycle anchor is automatically modified as needed when entering the phase. For more information, see the billing cycle [documentation](docs.stripe.com/billing/subscriptions/billing-cycle).



752
753
754
# File 'lib/stripe/resources/subscription_schedule.rb', line 752

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period



754
755
756
# File 'lib/stripe/resources/subscription_schedule.rb', line 754

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`.



756
757
758
# File 'lib/stripe/resources/subscription_schedule.rb', line 756

def collection_method
  @collection_method
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



758
759
760
# File 'lib/stripe/resources/subscription_schedule.rb', line 758

def currency
  @currency
end

#default_payment_methodObject (readonly)

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



760
761
762
# File 'lib/stripe/resources/subscription_schedule.rb', line 760

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject (readonly)

The default tax rates to apply to the subscription during this phase of the subscription schedule.



762
763
764
# File 'lib/stripe/resources/subscription_schedule.rb', line 762

def default_tax_rates
  @default_tax_rates
end

#descriptionObject (readonly)

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



764
765
766
# File 'lib/stripe/resources/subscription_schedule.rb', line 764

def description
  @description
end

#discountsObject (readonly)

The stackable discounts that will be applied to the subscription on this phase. Subscription item discounts are applied before subscription discounts.



766
767
768
# File 'lib/stripe/resources/subscription_schedule.rb', line 766

def discounts
  @discounts
end

#effective_atObject (readonly)

Configures how the subscription schedule handles billing for phase transitions. Possible values are ‘phase_start` (default) or `billing_period_start`. `phase_start` bills based on the current state of the subscription, ignoring changes scheduled in future phases. `billing_period_start` bills predictively for upcoming phase transitions within the current billing cycle, including pricing changes and service period adjustments that will occur before the next invoice.



768
769
770
# File 'lib/stripe/resources/subscription_schedule.rb', line 768

def effective_at
  @effective_at
end

#end_dateObject (readonly)

The end of this phase of the subscription schedule.



770
771
772
# File 'lib/stripe/resources/subscription_schedule.rb', line 770

def end_date
  @end_date
end

#invoice_settingsObject (readonly)

The invoice settings applicable during this phase.



772
773
774
# File 'lib/stripe/resources/subscription_schedule.rb', line 772

def invoice_settings
  @invoice_settings
end

#itemsObject (readonly)

Subscription items to configure the subscription to during this phase of the subscription schedule.



774
775
776
# File 'lib/stripe/resources/subscription_schedule.rb', line 774

def items
  @items
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered. Updating the underlying subscription’s ‘metadata` directly will not affect the current phase’s ‘metadata`.



776
777
778
# File 'lib/stripe/resources/subscription_schedule.rb', line 776

def 
  @metadata
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of for charges associated with the schedule’s subscription. See the Connect documentation for details.



778
779
780
# File 'lib/stripe/resources/subscription_schedule.rb', line 778

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject (readonly)

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](docs.stripe.com/billing/subscriptions/pause-payment).



780
781
782
# File 'lib/stripe/resources/subscription_schedule.rb', line 780

def pause_collection
  @pause_collection
end

#proration_behaviorObject (readonly)

When transitioning phases, controls how prorations are handled (if any). Possible values are ‘create_prorations`, `none`, and `always_invoice`.



782
783
784
# File 'lib/stripe/resources/subscription_schedule.rb', line 782

def proration_behavior
  @proration_behavior
end

#start_dateObject (readonly)

The start of this phase of the subscription schedule.



784
785
786
# File 'lib/stripe/resources/subscription_schedule.rb', line 784

def start_date
  @start_date
end

#transfer_dataObject (readonly)

The account (if any) the associated subscription’s payments will be attributed to for tax reporting, and where funds from each payment will be transferred to for each of the subscription’s invoices.



786
787
788
# File 'lib/stripe/resources/subscription_schedule.rb', line 786

def transfer_data
  @transfer_data
end

#trial_continuationObject (readonly)

Specify behavior of the trial when crossing schedule phase boundaries



788
789
790
# File 'lib/stripe/resources/subscription_schedule.rb', line 788

def trial_continuation
  @trial_continuation
end

#trial_endObject (readonly)

When the trial ends within the phase.



790
791
792
# File 'lib/stripe/resources/subscription_schedule.rb', line 790

def trial_end
  @trial_end
end

#trial_settingsObject (readonly)

Settings related to any trials on the subscription during this phase.



792
793
794
# File 'lib/stripe/resources/subscription_schedule.rb', line 792

def trial_settings
  @trial_settings
end

Class Method Details

.field_remappingsObject



808
809
810
# File 'lib/stripe/resources/subscription_schedule.rb', line 808

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



794
795
796
797
798
799
800
801
802
803
804
805
806
# File 'lib/stripe/resources/subscription_schedule.rb', line 794

def self.inner_class_types
  @inner_class_types = {
    add_invoice_items: AddInvoiceItem,
    automatic_tax: AutomaticTax,
    billing_thresholds: BillingThresholds,
    discounts: Discount,
    invoice_settings: InvoiceSettings,
    items: Item,
    pause_collection: PauseCollection,
    transfer_data: TransferData,
    trial_settings: TrialSettings,
  }
end