Class: Stripe::SubscriptionSchedule::Phase::AddInvoiceItem
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discounts ⇒ Object
readonly
The stackable discounts that will be applied to the item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
readonly
Attribute for field period.
-
#price ⇒ Object
readonly
ID of the price used to generate the invoice item.
-
#quantity ⇒ Object
readonly
The quantity of the invoice item.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to the item.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discounts ⇒ Object (readonly)
The stackable discounts that will be applied to the item.
152 153 154 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 152 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
154 155 156 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 154 def @metadata end |
#period ⇒ Object (readonly)
Attribute for field period
156 157 158 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 156 def period @period end |
#price ⇒ Object (readonly)
ID of the price used to generate the invoice item.
158 159 160 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 158 def price @price end |
#quantity ⇒ Object (readonly)
The quantity of the invoice item.
160 161 162 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 160 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
162 163 164 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 162 def tax_rates @tax_rates end |