Class: Stripe::SubscriptionSchedule::Phase::AddInvoiceItem

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountsObject (readonly)

The stackable discounts that will be applied to the item.



116
117
118
# File 'lib/stripe/resources/subscription_schedule.rb', line 116

def discounts
  @discounts
end

#priceObject (readonly)

ID of the price used to generate the invoice item.



118
119
120
# File 'lib/stripe/resources/subscription_schedule.rb', line 118

def price
  @price
end

#quantityObject (readonly)

The quantity of the invoice item.



120
121
122
# File 'lib/stripe/resources/subscription_schedule.rb', line 120

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



122
123
124
# File 'lib/stripe/resources/subscription_schedule.rb', line 122

def tax_rates
  @tax_rates
end