Class: Stripe::SubscriptionSchedule::Phase::AddInvoiceItem
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Discount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discounts ⇒ Object
readonly
The stackable discounts that will be applied to the item.
-
#price ⇒ Object
readonly
ID of the price used to generate the invoice item.
-
#quantity ⇒ Object
readonly
The quantity of the invoice item.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to the item.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discounts ⇒ Object (readonly)
The stackable discounts that will be applied to the item.
125 126 127 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 125 def discounts @discounts end |
#price ⇒ Object (readonly)
ID of the price used to generate the invoice item.
127 128 129 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 127 def price @price end |
#quantity ⇒ Object (readonly)
The quantity of the invoice item.
129 130 131 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 129 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
131 132 133 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 131 def tax_rates @tax_rates end |