Class: Stripe::SubscriptionSchedule::Phase::Discount
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#coupon ⇒ Object
readonly
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
readonly
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
readonly
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
readonly
ID of the promotion code to create a new discount for.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#coupon ⇒ Object (readonly)
ID of the coupon to create a new discount for.
382 383 384 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 382 def coupon @coupon end |
#discount ⇒ Object (readonly)
ID of an existing discount on the object (or one of its ancestors) to reuse.
384 385 386 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 384 def discount @discount end |
#discount_end ⇒ Object (readonly)
Details to determine how long the discount should be applied for.
386 387 388 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 386 def discount_end @discount_end end |
#promotion_code ⇒ Object (readonly)
ID of the promotion code to create a new discount for.
388 389 390 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 388 def promotion_code @promotion_code end |
Class Method Details
.field_remappings ⇒ Object
394 395 396 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 394 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
390 391 392 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 390 def self.inner_class_types @inner_class_types = { discount_end: DiscountEnd } end |