Class: Stripe::SubscriptionSchedule::Phase::InvoiceSettings

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Issuer

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.



134
135
136
# File 'lib/stripe/resources/subscription_schedule.rb', line 134

def 
  @account_tax_ids
end

#days_until_dueObject (readonly)

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.



136
137
138
# File 'lib/stripe/resources/subscription_schedule.rb', line 136

def days_until_due
  @days_until_due
end

#issuerObject (readonly)

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



138
139
140
# File 'lib/stripe/resources/subscription_schedule.rb', line 138

def issuer
  @issuer
end