Class: Stripe::SubscriptionSchedule::Phase::Item
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::Item
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, Trial
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period.
-
#discounts ⇒ Object
readonly
The discounts applied to the subscription item.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an item.
-
#plan ⇒ Object
readonly
ID of the plan to which the customer should be subscribed.
-
#price ⇒ Object
readonly
ID of the price to which the customer should be subscribed.
-
#quantity ⇒ Object
readonly
Quantity of the plan to which the customer should be subscribed.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to this
phase_item. -
#trial ⇒ Object
readonly
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
readonly
The ID of the trial offer to apply to the configuration item.
Attributes inherited from Stripe::StripeObject
Class Method Summary collapse
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
886 887 888 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 886 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object (readonly)
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use expand[]=discounts to expand each discount.
888 889 890 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 888 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item's metadata when the phase is entered.
890 891 892 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 890 def @metadata end |
#plan ⇒ Object (readonly)
ID of the plan to which the customer should be subscribed.
892 893 894 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 892 def plan @plan end |
#price ⇒ Object (readonly)
ID of the price to which the customer should be subscribed.
894 895 896 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 894 def price @price end |
#quantity ⇒ Object (readonly)
Quantity of the plan to which the customer should be subscribed.
896 897 898 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 896 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to this phase_item. When set, the default_tax_rates on the phase do not apply to this phase_item.
898 899 900 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 898 def tax_rates @tax_rates end |
#trial ⇒ Object (readonly)
Options that configure the trial on the subscription item.
900 901 902 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 900 def trial @trial end |
#trial_offer ⇒ Object (readonly)
The ID of the trial offer to apply to the configuration item.
902 903 904 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 902 def trial_offer @trial_offer end |
Class Method Details
.field_remappings ⇒ Object
912 913 914 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 912 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
904 905 906 907 908 909 910 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 904 def self.inner_class_types @inner_class_types = { billing_thresholds: BillingThresholds, discounts: Discount, trial: Trial, } end |