Class: Stripe::SubscriptionSchedule::Phase::Item

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, Trial

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



492
493
494
# File 'lib/stripe/resources/subscription_schedule.rb', line 492

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



494
495
496
# File 'lib/stripe/resources/subscription_schedule.rb', line 494

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



496
497
498
# File 'lib/stripe/resources/subscription_schedule.rb', line 496

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



498
499
500
# File 'lib/stripe/resources/subscription_schedule.rb', line 498

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



500
501
502
# File 'lib/stripe/resources/subscription_schedule.rb', line 500

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



502
503
504
# File 'lib/stripe/resources/subscription_schedule.rb', line 502

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



504
505
506
# File 'lib/stripe/resources/subscription_schedule.rb', line 504

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



506
507
508
# File 'lib/stripe/resources/subscription_schedule.rb', line 506

def trial
  @trial
end

#trial_offerObject (readonly)

The ID of the trial offer to apply to the configuration item.



508
509
510
# File 'lib/stripe/resources/subscription_schedule.rb', line 508

def trial_offer
  @trial_offer
end

Class Method Details

.field_remappingsObject



518
519
520
# File 'lib/stripe/resources/subscription_schedule.rb', line 518

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



510
511
512
513
514
515
516
# File 'lib/stripe/resources/subscription_schedule.rb', line 510

def self.inner_class_types
  @inner_class_types = {
    billing_thresholds: BillingThresholds,
    discounts: Discount,
    trial: Trial,
  }
end