Class: Stripe::SubscriptionSchedule::Phase::Item

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, Trial

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Class Method Summary collapse

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



478
479
480
# File 'lib/stripe/resources/subscription_schedule.rb', line 478

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



480
481
482
# File 'lib/stripe/resources/subscription_schedule.rb', line 480

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



482
483
484
# File 'lib/stripe/resources/subscription_schedule.rb', line 482

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



484
485
486
# File 'lib/stripe/resources/subscription_schedule.rb', line 484

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



486
487
488
# File 'lib/stripe/resources/subscription_schedule.rb', line 486

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



488
489
490
# File 'lib/stripe/resources/subscription_schedule.rb', line 488

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



490
491
492
# File 'lib/stripe/resources/subscription_schedule.rb', line 490

def tax_rates
  @tax_rates
end

#trialObject (readonly)

Options that configure the trial on the subscription item.



492
493
494
# File 'lib/stripe/resources/subscription_schedule.rb', line 492

def trial
  @trial
end

Class Method Details

.field_remappingsObject



502
503
504
# File 'lib/stripe/resources/subscription_schedule.rb', line 502

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



494
495
496
497
498
499
500
# File 'lib/stripe/resources/subscription_schedule.rb', line 494

def self.inner_class_types
  @inner_class_types = {
    billing_thresholds: BillingThresholds,
    discounts: Discount,
    trial: Trial,
  }
end