Class: Stripe::SubscriptionSchedule::Phase::Item
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::Item
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillingThresholds, Discount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period.
-
#discounts ⇒ Object
readonly
The discounts applied to the subscription item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item.
-
#plan ⇒ Object
readonly
ID of the plan to which the customer should be subscribed.
-
#price ⇒ Object
readonly
ID of the price to which the customer should be subscribed.
-
#quantity ⇒ Object
readonly
Quantity of the plan to which the customer should be subscribed.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to this ‘phase_item`.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
203 204 205 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 203 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object (readonly)
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.
205 206 207 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 205 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.
207 208 209 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 207 def @metadata end |
#plan ⇒ Object (readonly)
ID of the plan to which the customer should be subscribed.
209 210 211 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 209 def plan @plan end |
#price ⇒ Object (readonly)
ID of the price to which the customer should be subscribed.
211 212 213 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 211 def price @price end |
#quantity ⇒ Object (readonly)
Quantity of the plan to which the customer should be subscribed.
213 214 215 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 213 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.
215 216 217 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 215 def tax_rates @tax_rates end |