Class: Stripe::SubscriptionSchedule::Phase::Item

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: BillingThresholds, Discount

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_thresholdsObject (readonly)

Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period



179
180
181
# File 'lib/stripe/resources/subscription_schedule.rb', line 179

def billing_thresholds
  @billing_thresholds
end

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



181
182
183
# File 'lib/stripe/resources/subscription_schedule.rb', line 181

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



183
184
185
# File 'lib/stripe/resources/subscription_schedule.rb', line 183

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



185
186
187
# File 'lib/stripe/resources/subscription_schedule.rb', line 185

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



187
188
189
# File 'lib/stripe/resources/subscription_schedule.rb', line 187

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



189
190
191
# File 'lib/stripe/resources/subscription_schedule.rb', line 189

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



191
192
193
# File 'lib/stripe/resources/subscription_schedule.rb', line 191

def tax_rates
  @tax_rates
end