Class: Stripe::SubscriptionSchedule::Phase::Item
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Phase::Item
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillingThresholds, Discount
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
readonly
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period.
-
#discounts ⇒ Object
readonly
The discounts applied to the subscription item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item.
-
#plan ⇒ Object
readonly
ID of the plan to which the customer should be subscribed.
-
#price ⇒ Object
readonly
ID of the price to which the customer should be subscribed.
-
#quantity ⇒ Object
readonly
Quantity of the plan to which the customer should be subscribed.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to this ‘phase_item`.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_thresholds ⇒ Object (readonly)
Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period
172 173 174 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 172 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object (readonly)
The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.
174 175 176 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 174 def discounts @discounts end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.
176 177 178 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 176 def @metadata end |
#plan ⇒ Object (readonly)
ID of the plan to which the customer should be subscribed.
178 179 180 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 178 def plan @plan end |
#price ⇒ Object (readonly)
ID of the price to which the customer should be subscribed.
180 181 182 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 180 def price @price end |
#quantity ⇒ Object (readonly)
Quantity of the plan to which the customer should be subscribed.
182 183 184 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 182 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.
184 185 186 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 184 def tax_rates @tax_rates end |