Class: Stripe::SubscriptionSchedule::Phase::Item

Inherits:
Stripe::StripeObject show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Discount

Constant Summary

Constants inherited from Stripe::StripeObject

Stripe::StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from Stripe::StripeObject

#last_response

Method Summary

Methods inherited from Stripe::StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discountsObject (readonly)

The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Use ‘expand[]=discounts` to expand each discount.



151
152
153
# File 'lib/stripe/resources/subscription_schedule.rb', line 151

def discounts
  @discounts
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an item. Metadata on this item will update the underlying subscription item’s ‘metadata` when the phase is entered.



153
154
155
# File 'lib/stripe/resources/subscription_schedule.rb', line 153

def 
  @metadata
end

#planObject (readonly)

ID of the plan to which the customer should be subscribed.



155
156
157
# File 'lib/stripe/resources/subscription_schedule.rb', line 155

def plan
  @plan
end

#priceObject (readonly)

ID of the price to which the customer should be subscribed.



157
158
159
# File 'lib/stripe/resources/subscription_schedule.rb', line 157

def price
  @price
end

#quantityObject (readonly)

Quantity of the plan to which the customer should be subscribed.



159
160
161
# File 'lib/stripe/resources/subscription_schedule.rb', line 159

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to this ‘phase_item`. When set, the `default_tax_rates` on the phase do not apply to this `phase_item`.



161
162
163
# File 'lib/stripe/resources/subscription_schedule.rb', line 161

def tax_rates
  @tax_rates
end