Class: Stripe::SubscriptionSchedule::Prebilling
- Inherits:
-
Stripe::StripeObject
- Object
- Stripe::StripeObject
- Stripe::SubscriptionSchedule::Prebilling
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Constant Summary
Constants inherited from Stripe::StripeObject
Stripe::StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice ⇒ Object
readonly
ID of the prebilling invoice.
-
#period_end ⇒ Object
readonly
The end of the last period for which the invoice pre-bills.
-
#period_start ⇒ Object
readonly
The start of the first period for which the invoice pre-bills.
-
#update_behavior ⇒ Object
readonly
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Attributes inherited from Stripe::StripeObject
Method Summary
Methods inherited from Stripe::StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice ⇒ Object (readonly)
ID of the prebilling invoice.
312 313 314 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 312 def invoice @invoice end |
#period_end ⇒ Object (readonly)
The end of the last period for which the invoice pre-bills.
314 315 316 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 314 def period_end @period_end end |
#period_start ⇒ Object (readonly)
The start of the first period for which the invoice pre-bills.
316 317 318 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 316 def period_start @period_start end |
#update_behavior ⇒ Object (readonly)
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
318 319 320 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 318 def update_behavior @update_behavior end |