Class: Stripe::SubscriptionSchedule::ReleaseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::ReleaseParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set.
Instance Method Summary collapse
-
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
constructor
A new instance of ReleaseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
Returns a new instance of ReleaseParams.
1546 1547 1548 1549 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1546 def initialize(expand: nil, preserve_cancel_date: nil) @expand = @preserve_cancel_date = preserve_cancel_date end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1542 1543 1544 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1542 def @expand end |
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set
1544 1545 1546 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1544 def preserve_cancel_date @preserve_cancel_date end |