Class: Stripe::SubscriptionSchedule::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DefaultSettings, Phase
Instance Attribute Summary collapse
-
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#proration_behavior ⇒ Object
If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled.
Instance Method Summary collapse
-
#initialize(default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, proration_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, proration_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1508 def initialize( default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, proration_behavior: nil ) @default_settings = default_settings @end_behavior = end_behavior @expand = @metadata = @phases = phases @proration_behavior = proration_behavior end |
Instance Attribute Details
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
1496 1497 1498 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1496 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
1498 1499 1500 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1498 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1500 1501 1502 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1500 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1502 1503 1504 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1502 def @metadata end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.
1504 1505 1506 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1504 def phases @phases end |
#proration_behavior ⇒ Object
If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.
1506 1507 1508 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1506 def proration_behavior @proration_behavior end |