Class: Stripe::SubscriptionSchedule::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
# File 'lib/stripe/resources/subscription_schedule.rb', line 1386

def initialize(
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  proration_behavior: nil
)
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#default_settingsObject

Object representing the subscription schedule’s default settings.



1374
1375
1376
# File 'lib/stripe/resources/subscription_schedule.rb', line 1374

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1376
1377
1378
# File 'lib/stripe/resources/subscription_schedule.rb', line 1376

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1378
1379
1380
# File 'lib/stripe/resources/subscription_schedule.rb', line 1378

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1380
1381
1382
# File 'lib/stripe/resources/subscription_schedule.rb', line 1380

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1382
1383
1384
# File 'lib/stripe/resources/subscription_schedule.rb', line 1382

def phases
  @phases
end

#proration_behaviorObject

If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.



1384
1385
1386
# File 'lib/stripe/resources/subscription_schedule.rb', line 1384

def proration_behavior
  @proration_behavior
end