Class: Stripe::SubscriptionSchedule::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/stripe/resources/subscription_schedule.rb', line 1354

def initialize(
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  proration_behavior: nil
)
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#default_settingsObject

Object representing the subscription schedule’s default settings.



1342
1343
1344
# File 'lib/stripe/resources/subscription_schedule.rb', line 1342

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1344
1345
1346
# File 'lib/stripe/resources/subscription_schedule.rb', line 1344

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1346
1347
1348
# File 'lib/stripe/resources/subscription_schedule.rb', line 1346

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1348
1349
1350
# File 'lib/stripe/resources/subscription_schedule.rb', line 1348

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1350
1351
1352
# File 'lib/stripe/resources/subscription_schedule.rb', line 1350

def phases
  @phases
end

#proration_behaviorObject

If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.



1352
1353
1354
# File 'lib/stripe/resources/subscription_schedule.rb', line 1352

def proration_behavior
  @proration_behavior
end