Class: Stripe::SubscriptionSchedule::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
# File 'lib/stripe/resources/subscription_schedule.rb', line 1618

def initialize(
  billing_behavior: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  proration_behavior: nil
)
  @billing_behavior = billing_behavior
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1602
1603
1604
# File 'lib/stripe/resources/subscription_schedule.rb', line 1602

def billing_behavior
  @billing_behavior
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1604
1605
1606
# File 'lib/stripe/resources/subscription_schedule.rb', line 1604

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1606
1607
1608
# File 'lib/stripe/resources/subscription_schedule.rb', line 1606

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1608
1609
1610
# File 'lib/stripe/resources/subscription_schedule.rb', line 1608

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1610
1611
1612
# File 'lib/stripe/resources/subscription_schedule.rb', line 1610

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1612
1613
1614
# File 'lib/stripe/resources/subscription_schedule.rb', line 1612

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1614
1615
1616
# File 'lib/stripe/resources/subscription_schedule.rb', line 1614

def prebilling
  @prebilling
end

#proration_behaviorObject

If the update changes the current phase, indicates whether the changes should be prorated. The default value is ‘create_prorations`.



1616
1617
1618
# File 'lib/stripe/resources/subscription_schedule.rb', line 1616

def proration_behavior
  @proration_behavior
end