Class: Stripe::SubscriptionSchedule::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
# File 'lib/stripe/resources/subscription_schedule.rb', line 1744

def initialize(
  billing_behavior: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  proration_behavior: nil
)
  @billing_behavior = billing_behavior
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1728
1729
1730
# File 'lib/stripe/resources/subscription_schedule.rb', line 1728

def billing_behavior
  @billing_behavior
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1730
1731
1732
# File 'lib/stripe/resources/subscription_schedule.rb', line 1730

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1732
1733
1734
# File 'lib/stripe/resources/subscription_schedule.rb', line 1732

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1734
1735
1736
# File 'lib/stripe/resources/subscription_schedule.rb', line 1734

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1736
1737
1738
# File 'lib/stripe/resources/subscription_schedule.rb', line 1736

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1738
1739
1740
# File 'lib/stripe/resources/subscription_schedule.rb', line 1738

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1740
1741
1742
# File 'lib/stripe/resources/subscription_schedule.rb', line 1740

def prebilling
  @prebilling
end

#proration_behaviorObject

If the update changes the current phase, indicates whether the changes should be prorated. The default value is ‘create_prorations`.



1742
1743
1744
# File 'lib/stripe/resources/subscription_schedule.rb', line 1742

def proration_behavior
  @proration_behavior
end