Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData
Instance Attribute Summary collapse
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Default settings for automatic tax computation.
-
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
Instance Method Summary collapse
-
#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings
constructor
A new instance of DefaultSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings
Returns a new instance of DefaultSettings.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1602 def initialize( application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil ) @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_thresholds = billing_thresholds @collection_method = collection_method @default_payment_method = default_payment_method @description = description @invoice_settings = invoice_settings @on_behalf_of = on_behalf_of @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
1582 1583 1584 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1582 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Default settings for automatic tax computation.
1584 1585 1586 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1584 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
1586 1587 1588 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1586 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1588 1589 1590 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1588 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.
1590 1591 1592 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1590 def collection_method @collection_method end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.
1592 1593 1594 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1592 def default_payment_method @default_payment_method end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1594 1595 1596 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1594 def description @description end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1596 1597 1598 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1596 def invoice_settings @invoice_settings end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
1598 1599 1600 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1598 def on_behalf_of @on_behalf_of end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
1600 1601 1602 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1600 def transfer_data @transfer_data end |