Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: AutomaticTax, BillingThresholds, InvoiceSettings, TransferData
Instance Attribute Summary collapse
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Default settings for automatic tax computation.
-
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
Instance Method Summary collapse
-
#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings
constructor
A new instance of DefaultSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings
Returns a new instance of DefaultSettings.
1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1198 def initialize( application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil ) @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_thresholds = billing_thresholds @collection_method = collection_method @default_payment_method = default_payment_method @description = description @invoice_settings = invoice_settings @on_behalf_of = on_behalf_of @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
1178 1179 1180 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1178 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Default settings for automatic tax computation.
1180 1181 1182 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1180 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
1182 1183 1184 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1182 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1184 1185 1186 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1184 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.
1186 1187 1188 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1186 def collection_method @collection_method end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.
1188 1189 1190 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1188 def default_payment_method @default_payment_method end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1190 1191 1192 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1190 def description @description end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1192 1193 1194 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1192 def invoice_settings @invoice_settings end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
1194 1195 1196 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1194 def on_behalf_of @on_behalf_of end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
1196 1197 1198 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1196 def transfer_data @transfer_data end |