Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings::AutomaticTax
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1154 1155 1156 1157 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1154 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
1150 1151 1152 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1150 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1152 1153 1154 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1152 def liability @liability end |