Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



893
894
895
896
# File 'lib/stripe/resources/subscription_schedule.rb', line 893

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



889
890
891
# File 'lib/stripe/resources/subscription_schedule.rb', line 889

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



891
892
893
# File 'lib/stripe/resources/subscription_schedule.rb', line 891

def liability
  @liability
end