Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1125
1126
1127
1128
# File 'lib/stripe/resources/subscription_schedule.rb', line 1125

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



1121
1122
1123
# File 'lib/stripe/resources/subscription_schedule.rb', line 1121

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1123
1124
1125
# File 'lib/stripe/resources/subscription_schedule.rb', line 1123

def liability
  @liability
end