Class: Stripe::SubscriptionSchedule::UpdateParams::DefaultSettings::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1324
1325
1326
1327
# File 'lib/stripe/resources/subscription_schedule.rb', line 1324

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



1319
1320
1321
# File 'lib/stripe/resources/subscription_schedule.rb', line 1319

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1322
1323
1324
# File 'lib/stripe/resources/subscription_schedule.rb', line 1322

def liability
  @liability
end