Class: Stripe::SubscriptionSchedule::UpdateParams::Phase

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, coupon: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase

Returns a new instance of Phase.



1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
# File 'lib/stripe/resources/subscription_schedule.rb', line 1659

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  coupon: nil,
  currency: nil,
  default_payment_method: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  end_date: nil,
  invoice_settings: nil,
  items: nil,
  iterations: nil,
  metadata: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  proration_behavior: nil,
  start_date: nil,
  transfer_data: nil,
  trial: nil,
  trial_continuation: nil,
  trial_end: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @coupon = coupon
  @currency = currency
  @default_payment_method = default_payment_method
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @end_date = end_date
  @invoice_settings = invoice_settings
  @items = items
  @iterations = iterations
  @metadata = 
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @proration_behavior = proration_behavior
  @start_date = start_date
  @transfer_data = transfer_data
  @trial = trial
  @trial_continuation = trial_continuation
  @trial_end = trial_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.



1607
1608
1609
# File 'lib/stripe/resources/subscription_schedule.rb', line 1607

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



1609
1610
1611
# File 'lib/stripe/resources/subscription_schedule.rb', line 1609

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this phase.



1611
1612
1613
# File 'lib/stripe/resources/subscription_schedule.rb', line 1611

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



1613
1614
1615
# File 'lib/stripe/resources/subscription_schedule.rb', line 1613

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1615
1616
1617
# File 'lib/stripe/resources/subscription_schedule.rb', line 1615

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.



1617
1618
1619
# File 'lib/stripe/resources/subscription_schedule.rb', line 1617

def collection_method
  @collection_method
end

#couponObject

The ID of the coupon to apply to this phase of the subscription schedule. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.



1619
1620
1621
# File 'lib/stripe/resources/subscription_schedule.rb', line 1619

def coupon
  @coupon
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1621
1622
1623
# File 'lib/stripe/resources/subscription_schedule.rb', line 1621

def currency
  @currency
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



1623
1624
1625
# File 'lib/stripe/resources/subscription_schedule.rb', line 1623

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](stripe.com/docs/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.



1625
1626
1627
# File 'lib/stripe/resources/subscription_schedule.rb', line 1625

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1627
1628
1629
# File 'lib/stripe/resources/subscription_schedule.rb', line 1627

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.



1629
1630
1631
# File 'lib/stripe/resources/subscription_schedule.rb', line 1629

def discounts
  @discounts
end

#end_dateObject

The date at which this phase of the subscription schedule ends. If set, ‘iterations` must not be set.



1631
1632
1633
# File 'lib/stripe/resources/subscription_schedule.rb', line 1631

def end_date
  @end_date
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



1633
1634
1635
# File 'lib/stripe/resources/subscription_schedule.rb', line 1633

def invoice_settings
  @invoice_settings
end

#itemsObject

List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.



1635
1636
1637
# File 'lib/stripe/resources/subscription_schedule.rb', line 1635

def items
  @items
end

#iterationsObject

Integer representing the multiplier applied to the price interval. For example, ‘iterations=2` applied to a price with `interval=month` and `interval_count=3` results in a phase of duration `2 * 3 months = 6 months`. If set, `end_date` must not be set.



1637
1638
1639
# File 'lib/stripe/resources/subscription_schedule.rb', line 1637

def iterations
  @iterations
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.



1639
1640
1641
# File 'lib/stripe/resources/subscription_schedule.rb', line 1639

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription’s invoices.



1641
1642
1643
# File 'lib/stripe/resources/subscription_schedule.rb', line 1641

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).



1643
1644
1645
# File 'lib/stripe/resources/subscription_schedule.rb', line 1643

def pause_collection
  @pause_collection
end

#proration_behaviorObject

Whether the subscription schedule will create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase. The default value is ‘create_prorations`. This setting controls prorations when a phase is started asynchronously and it is persisted as a field on the phase. It’s different from the request-level [proration_behavior](stripe.com/docs/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration of the current phase.



1645
1646
1647
# File 'lib/stripe/resources/subscription_schedule.rb', line 1645

def proration_behavior
  @proration_behavior
end

#start_dateObject

The date at which this phase of the subscription schedule starts or ‘now`. Must be set on the first phase.



1647
1648
1649
# File 'lib/stripe/resources/subscription_schedule.rb', line 1647

def start_date
  @start_date
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription’s invoices.



1649
1650
1651
# File 'lib/stripe/resources/subscription_schedule.rb', line 1649

def transfer_data
  @transfer_data
end

#trialObject

If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.



1651
1652
1653
# File 'lib/stripe/resources/subscription_schedule.rb', line 1651

def trial
  @trial
end

#trial_continuationObject

Specify trial behavior when crossing phase boundaries



1653
1654
1655
# File 'lib/stripe/resources/subscription_schedule.rb', line 1653

def trial_continuation
  @trial_continuation
end

#trial_endObject

Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`



1655
1656
1657
# File 'lib/stripe/resources/subscription_schedule.rb', line 1655

def trial_end
  @trial_end
end

#trial_settingsObject

Settings related to subscription trials.



1657
1658
1659
# File 'lib/stripe/resources/subscription_schedule.rb', line 1657

def trial_settings
  @trial_settings
end