Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
1215 1216 1217 1218 1219 1220 1221 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1215 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
1205 1206 1207 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1205 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1207 1208 1209 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1207 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1209 1210 1211 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1209 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
1211 1212 1213 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1211 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
1213 1214 1215 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1213 def tax_rates @tax_rates end |