Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
1308 1309 1310 1311 1312 1313 1314 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1308 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
1298 1299 1300 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1298 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1300 1301 1302 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1300 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1302 1303 1304 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1302 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
1304 1305 1306 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1304 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
1306 1307 1308 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1306 def tax_rates @tax_rates end |