Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1093
1094
1095
1096
1097
# File 'lib/stripe/resources/subscription_schedule.rb', line 1093

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1087
1088
1089
# File 'lib/stripe/resources/subscription_schedule.rb', line 1087

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1089
1090
1091
# File 'lib/stripe/resources/subscription_schedule.rb', line 1089

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1091
1092
1093
# File 'lib/stripe/resources/subscription_schedule.rb', line 1091

def promotion_code
  @promotion_code
end