Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1020
1021
1022
1023
1024
# File 'lib/stripe/resources/subscription_schedule.rb', line 1020

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1014
1015
1016
# File 'lib/stripe/resources/subscription_schedule.rb', line 1014

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1016
1017
1018
# File 'lib/stripe/resources/subscription_schedule.rb', line 1016

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1018
1019
1020
# File 'lib/stripe/resources/subscription_schedule.rb', line 1018

def promotion_code
  @promotion_code
end