Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1276
1277
1278
1279
1280
1281
# File 'lib/stripe/resources/subscription_schedule.rb', line 1276

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1268
1269
1270
# File 'lib/stripe/resources/subscription_schedule.rb', line 1268

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1270
1271
1272
# File 'lib/stripe/resources/subscription_schedule.rb', line 1270

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1272
1273
1274
# File 'lib/stripe/resources/subscription_schedule.rb', line 1272

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1274
1275
1276
# File 'lib/stripe/resources/subscription_schedule.rb', line 1274

def promotion_code
  @promotion_code
end