Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1004
1005
1006
1007
1008
# File 'lib/stripe/resources/subscription_schedule.rb', line 1004

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



998
999
1000
# File 'lib/stripe/resources/subscription_schedule.rb', line 998

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1000
1001
1002
# File 'lib/stripe/resources/subscription_schedule.rb', line 1000

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1002
1003
1004
# File 'lib/stripe/resources/subscription_schedule.rb', line 1002

def promotion_code
  @promotion_code
end