Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1174
1175
1176
1177
1178
1179
# File 'lib/stripe/resources/subscription_schedule.rb', line 1174

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1166
1167
1168
# File 'lib/stripe/resources/subscription_schedule.rb', line 1166

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1168
1169
1170
# File 'lib/stripe/resources/subscription_schedule.rb', line 1168

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1170
1171
1172
# File 'lib/stripe/resources/subscription_schedule.rb', line 1170

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1172
1173
1174
# File 'lib/stripe/resources/subscription_schedule.rb', line 1172

def promotion_code
  @promotion_code
end