Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1263
1264
1265
1266
1267
1268
# File 'lib/stripe/resources/subscription_schedule.rb', line 1263

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1255
1256
1257
# File 'lib/stripe/resources/subscription_schedule.rb', line 1255

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1257
1258
1259
# File 'lib/stripe/resources/subscription_schedule.rb', line 1257

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1259
1260
1261
# File 'lib/stripe/resources/subscription_schedule.rb', line 1259

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1261
1262
1263
# File 'lib/stripe/resources/subscription_schedule.rb', line 1261

def promotion_code
  @promotion_code
end