Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1277
1278
1279
1280
1281
# File 'lib/stripe/resources/subscription_schedule.rb', line 1277

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1271
1272
1273
# File 'lib/stripe/resources/subscription_schedule.rb', line 1271

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1273
1274
1275
# File 'lib/stripe/resources/subscription_schedule.rb', line 1273

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1275
1276
1277
# File 'lib/stripe/resources/subscription_schedule.rb', line 1275

def type
  @type
end