Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1261
1262
1263
1264
1265
# File 'lib/stripe/resources/subscription_schedule.rb', line 1261

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1255
1256
1257
# File 'lib/stripe/resources/subscription_schedule.rb', line 1255

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1257
1258
1259
# File 'lib/stripe/resources/subscription_schedule.rb', line 1257

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1259
1260
1261
# File 'lib/stripe/resources/subscription_schedule.rb', line 1259

def type
  @type
end