Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1245
1246
1247
1248
1249
# File 'lib/stripe/resources/subscription_schedule.rb', line 1245

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1239
1240
1241
# File 'lib/stripe/resources/subscription_schedule.rb', line 1239

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1241
1242
1243
# File 'lib/stripe/resources/subscription_schedule.rb', line 1241

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1243
1244
1245
# File 'lib/stripe/resources/subscription_schedule.rb', line 1243

def type
  @type
end