Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1159
1160
1161
1162
1163
# File 'lib/stripe/resources/subscription_schedule.rb', line 1159

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1153
1154
1155
# File 'lib/stripe/resources/subscription_schedule.rb', line 1153

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1155
1156
1157
# File 'lib/stripe/resources/subscription_schedule.rb', line 1155

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1157
1158
1159
# File 'lib/stripe/resources/subscription_schedule.rb', line 1157

def type
  @type
end