Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



1679
1680
1681
1682
# File 'lib/stripe/resources/subscription_schedule.rb', line 1679

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



1675
1676
1677
# File 'lib/stripe/resources/subscription_schedule.rb', line 1675

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



1677
1678
1679
# File 'lib/stripe/resources/subscription_schedule.rb', line 1677

def type
  @type
end