Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
1107 1108 1109 1110 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1107 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
1103 1104 1105 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1103 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
1105 1106 1107 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1105 def type @type end |