Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
1119 1120 1121 1122 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1119 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
1115 1116 1117 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1115 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
1117 1118 1119 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1117 def type @type end |