Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::AddInvoiceItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
# File 'lib/stripe/resources/subscription_schedule.rb', line 1283

def initialize(
  currency: nil,
  product: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1273
1274
1275
# File 'lib/stripe/resources/subscription_schedule.rb', line 1273

def currency
  @currency
end

#productObject

The ID of the product that this price will belong to.



1275
1276
1277
# File 'lib/stripe/resources/subscription_schedule.rb', line 1275

def product
  @product
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



1277
1278
1279
# File 'lib/stripe/resources/subscription_schedule.rb', line 1277

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge or a negative integer representing the amount to credit to the customer.



1279
1280
1281
# File 'lib/stripe/resources/subscription_schedule.rb', line 1279

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



1281
1282
1283
# File 'lib/stripe/resources/subscription_schedule.rb', line 1281

def unit_amount_decimal
  @unit_amount_decimal
end