Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1538
1539
1540
1541
1542
1543
# File 'lib/stripe/resources/subscription_schedule.rb', line 1538

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1530
1531
1532
# File 'lib/stripe/resources/subscription_schedule.rb', line 1530

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1532
1533
1534
# File 'lib/stripe/resources/subscription_schedule.rb', line 1532

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1534
1535
1536
# File 'lib/stripe/resources/subscription_schedule.rb', line 1534

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1536
1537
1538
# File 'lib/stripe/resources/subscription_schedule.rb', line 1536

def promotion_code
  @promotion_code
end