Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1238 1239 1240 1241 1242 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1238 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1232 1233 1234 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1232 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1234 1235 1236 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1234 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1236 1237 1238 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1236 def promotion_code @promotion_code end |