Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1100 1101 1102 1103 1104 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1100 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1094 1095 1096 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1094 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1096 1097 1098 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1096 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1098 1099 1100 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1098 def promotion_code @promotion_code end |