Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1384 1385 1386 1387 1388 1389 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1384 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1376 1377 1378 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1376 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1378 1379 1380 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1378 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1380 1381 1382 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1380 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1382 1383 1384 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1382 def promotion_code @promotion_code end |