Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1080 1081 1082 1083 1084 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1080 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1074 1075 1076 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1074 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1076 1077 1078 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1076 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1078 1079 1080 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1078 def promotion_code @promotion_code end |