Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1286
1287
1288
1289
1290
1291
# File 'lib/stripe/resources/subscription_schedule.rb', line 1286

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1278
1279
1280
# File 'lib/stripe/resources/subscription_schedule.rb', line 1278

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1280
1281
1282
# File 'lib/stripe/resources/subscription_schedule.rb', line 1280

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1282
1283
1284
# File 'lib/stripe/resources/subscription_schedule.rb', line 1282

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1284
1285
1286
# File 'lib/stripe/resources/subscription_schedule.rb', line 1284

def promotion_code
  @promotion_code
end