Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1387
1388
1389
1390
1391
1392
# File 'lib/stripe/resources/subscription_schedule.rb', line 1387

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1379
1380
1381
# File 'lib/stripe/resources/subscription_schedule.rb', line 1379

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1381
1382
1383
# File 'lib/stripe/resources/subscription_schedule.rb', line 1381

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1383
1384
1385
# File 'lib/stripe/resources/subscription_schedule.rb', line 1383

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1385
1386
1387
# File 'lib/stripe/resources/subscription_schedule.rb', line 1385

def promotion_code
  @promotion_code
end