Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1271
1272
1273
1274
1275
# File 'lib/stripe/resources/subscription_schedule.rb', line 1271

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1265
1266
1267
# File 'lib/stripe/resources/subscription_schedule.rb', line 1265

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1267
1268
1269
# File 'lib/stripe/resources/subscription_schedule.rb', line 1267

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1269
1270
1271
# File 'lib/stripe/resources/subscription_schedule.rb', line 1269

def type
  @type
end