Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1605
1606
1607
1608
1609
# File 'lib/stripe/resources/subscription_schedule.rb', line 1605

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1597
1598
1599
# File 'lib/stripe/resources/subscription_schedule.rb', line 1597

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1600
1601
1602
# File 'lib/stripe/resources/subscription_schedule.rb', line 1600

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1603
1604
1605
# File 'lib/stripe/resources/subscription_schedule.rb', line 1603

def type
  @type
end