Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Item
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
Returns a new instance of Item.
2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2008 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1990 1991 1992 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1990 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1992 1993 1994 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1992 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.
1994 1995 1996 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1994 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.
1996 1997 1998 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1996 def plan @plan end |
#price ⇒ Object
The ID of the price object.
1998 1999 2000 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1998 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
2000 2001 2002 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2000 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.
2002 2003 2004 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2002 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
2004 2005 2006 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2004 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
2006 2007 2008 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2006 def trial @trial end |