Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1179 1180 1181 1182 1183 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1179 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1173 1174 1175 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1173 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1175 1176 1177 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1175 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1177 1178 1179 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1177 def promotion_code @promotion_code end |