Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1151
1152
1153
1154
1155
# File 'lib/stripe/resources/subscription_schedule.rb', line 1151

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1145
1146
1147
# File 'lib/stripe/resources/subscription_schedule.rb', line 1145

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1147
1148
1149
# File 'lib/stripe/resources/subscription_schedule.rb', line 1147

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1149
1150
1151
# File 'lib/stripe/resources/subscription_schedule.rb', line 1149

def promotion_code
  @promotion_code
end