Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1352
1353
1354
1355
1356
1357
# File 'lib/stripe/resources/subscription_schedule.rb', line 1352

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1344
1345
1346
# File 'lib/stripe/resources/subscription_schedule.rb', line 1344

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1346
1347
1348
# File 'lib/stripe/resources/subscription_schedule.rb', line 1346

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1348
1349
1350
# File 'lib/stripe/resources/subscription_schedule.rb', line 1348

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1350
1351
1352
# File 'lib/stripe/resources/subscription_schedule.rb', line 1350

def promotion_code
  @promotion_code
end