Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1711
1712
1713
1714
1715
1716
# File 'lib/stripe/resources/subscription_schedule.rb', line 1711

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1700
1701
1702
# File 'lib/stripe/resources/subscription_schedule.rb', line 1700

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1703
1704
1705
# File 'lib/stripe/resources/subscription_schedule.rb', line 1703

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1706
1707
1708
# File 'lib/stripe/resources/subscription_schedule.rb', line 1706

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1709
1710
1711
# File 'lib/stripe/resources/subscription_schedule.rb', line 1709

def promotion_code
  @promotion_code
end