Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1466
1467
1468
1469
1470
1471
# File 'lib/stripe/resources/subscription_schedule.rb', line 1466

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1458
1459
1460
# File 'lib/stripe/resources/subscription_schedule.rb', line 1458

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1460
1461
1462
# File 'lib/stripe/resources/subscription_schedule.rb', line 1460

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1462
1463
1464
# File 'lib/stripe/resources/subscription_schedule.rb', line 1462

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1464
1465
1466
# File 'lib/stripe/resources/subscription_schedule.rb', line 1464

def promotion_code
  @promotion_code
end