Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1913
1914
1915
1916
1917
# File 'lib/stripe/resources/subscription_schedule.rb', line 1913

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1907
1908
1909
# File 'lib/stripe/resources/subscription_schedule.rb', line 1907

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1909
1910
1911
# File 'lib/stripe/resources/subscription_schedule.rb', line 1909

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1911
1912
1913
# File 'lib/stripe/resources/subscription_schedule.rb', line 1911

def type
  @type
end