Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1913 1914 1915 1916 1917 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1913 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1907 1908 1909 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1907 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1909 1910 1911 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1909 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1911 1912 1913 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1911 def type @type end |