Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1492
1493
1494
1495
1496
# File 'lib/stripe/resources/subscription_schedule.rb', line 1492

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1486
1487
1488
# File 'lib/stripe/resources/subscription_schedule.rb', line 1486

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1488
1489
1490
# File 'lib/stripe/resources/subscription_schedule.rb', line 1488

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1490
1491
1492
# File 'lib/stripe/resources/subscription_schedule.rb', line 1490

def type
  @type
end