Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1341 1342 1343 1344 1345 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1341 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1335 1336 1337 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1335 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1337 1338 1339 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1337 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1339 1340 1341 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1339 def type @type end |