Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1451
1452
1453
1454
1455
# File 'lib/stripe/resources/subscription_schedule.rb', line 1451

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1445
1446
1447
# File 'lib/stripe/resources/subscription_schedule.rb', line 1445

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1447
1448
1449
# File 'lib/stripe/resources/subscription_schedule.rb', line 1447

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1449
1450
1451
# File 'lib/stripe/resources/subscription_schedule.rb', line 1449

def type
  @type
end