Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1451 1452 1453 1454 1455 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1451 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1445 1446 1447 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1445 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1447 1448 1449 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1447 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1449 1450 1451 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1449 def type @type end |