Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1271
1272
1273
1274
# File 'lib/stripe/resources/subscription_schedule.rb', line 1271

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1267
1268
1269
# File 'lib/stripe/resources/subscription_schedule.rb', line 1267

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1269
1270
1271
# File 'lib/stripe/resources/subscription_schedule.rb', line 1269

def destination
  @destination
end