Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Phase::TransferData
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1223 1224 1225 1226 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1223 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1219 1220 1221 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1219 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1221 1222 1223 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 1221 def destination @destination end |