Class: Stripe::SubscriptionSchedule::UpdateParams::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1470
1471
1472
1473
# File 'lib/stripe/resources/subscription_schedule.rb', line 1470

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1466
1467
1468
# File 'lib/stripe/resources/subscription_schedule.rb', line 1466

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1468
1469
1470
# File 'lib/stripe/resources/subscription_schedule.rb', line 1468

def destination
  @destination
end