Class: Stripe::SubscriptionSchedule::UpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



1731
1732
1733
1734
# File 'lib/stripe/resources/subscription_schedule.rb', line 1731

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



1727
1728
1729
# File 'lib/stripe/resources/subscription_schedule.rb', line 1727

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



1729
1730
1731
# File 'lib/stripe/resources/subscription_schedule.rb', line 1729

def update_behavior
  @update_behavior
end