Class: Stripe::SubscriptionSchedule::UpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



1715
1716
1717
1718
# File 'lib/stripe/resources/subscription_schedule.rb', line 1715

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



1711
1712
1713
# File 'lib/stripe/resources/subscription_schedule.rb', line 1711

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



1713
1714
1715
# File 'lib/stripe/resources/subscription_schedule.rb', line 1713

def update_behavior
  @update_behavior
end