Class: Stripe::SubscriptionSchedule::UpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/subscription_schedule.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



1596
1597
1598
1599
# File 'lib/stripe/resources/subscription_schedule.rb', line 1596

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



1592
1593
1594
# File 'lib/stripe/resources/subscription_schedule.rb', line 1592

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



1594
1595
1596
# File 'lib/stripe/resources/subscription_schedule.rb', line 1594

def update_behavior
  @update_behavior
end