Class: Stripe::SubscriptionSchedule::UpdateParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionSchedule::UpdateParams::Prebilling
- Defined in:
- lib/stripe/resources/subscription_schedule.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
2009 2010 2011 2012 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2009 def initialize(iterations: nil, update_behavior: nil) @iterations = iterations @update_behavior = update_behavior end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
2004 2005 2006 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2004 def iterations @iterations end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
2007 2008 2009 |
# File 'lib/stripe/resources/subscription_schedule.rb', line 2007 def update_behavior @update_behavior end |