Class: Stripe::SubscriptionScheduleAmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams
constructor
A new instance of SubscriptionScheduleAmendParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams
Returns a new instance of SubscriptionScheduleAmendParams.
564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 564 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
553 554 555 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 553 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
555 556 557 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 555 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
557 558 559 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 557 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
560 561 562 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 560 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
562 563 564 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 562 def schedule_settings @schedule_settings end |