Class: Stripe::SubscriptionScheduleAmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams

Returns a new instance of SubscriptionScheduleAmendParams.



791
792
793
794
795
796
797
798
799
800
801
802
803
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 791

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



780
781
782
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 780

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



782
783
784
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 782

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



784
785
786
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 784

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


787
788
789
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 787

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



789
790
791
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 789

def schedule_settings
  @schedule_settings
end