Class: Stripe::SubscriptionScheduleAmendParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams

Returns a new instance of SubscriptionScheduleAmendParams.



583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 583

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



572
573
574
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 572

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



574
575
576
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 574

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



576
577
578
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 576

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


579
580
581
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 579

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



581
582
583
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 581

def schedule_settings
  @schedule_settings
end