Class: Stripe::SubscriptionScheduleAmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams
constructor
A new instance of SubscriptionScheduleAmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams
Returns a new instance of SubscriptionScheduleAmendParams.
595 596 597 598 599 600 601 602 603 604 605 606 607 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 595 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
584 585 586 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 584 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
586 587 588 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 586 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
588 589 590 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 588 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
591 592 593 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 591 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
593 594 595 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 593 def schedule_settings @schedule_settings end |