Class: Stripe::SubscriptionScheduleAmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams
constructor
A new instance of SubscriptionScheduleAmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ SubscriptionScheduleAmendParams
Returns a new instance of SubscriptionScheduleAmendParams.
556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 556 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
545 546 547 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 545 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
547 548 549 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 547 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
549 550 551 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 549 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
552 553 554 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 552 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
554 555 556 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 554 def schedule_settings @schedule_settings end |