Class: Stripe::SubscriptionScheduleAmendParams::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, BillingSchedulesAction, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, billing_schedules_actions: nil, discount_actions: nil, effective_at: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 664

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  billing_schedules_actions: nil,
  discount_actions: nil,
  effective_at: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules_actions = billing_schedules_actions
  @discount_actions = discount_actions
  @effective_at = effective_at
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



640
641
642
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 640

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



642
643
644
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 642

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



644
645
646
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 644

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedules_actionsObject

Actions to apply to the billing schedules.



646
647
648
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 646

def billing_schedules_actions
  @billing_schedules_actions
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



648
649
650
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 648

def discount_actions
  @discount_actions
end

#effective_atObject

Configures how the subscription schedule handles billing for phase transitions.



650
651
652
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 650

def effective_at
  @effective_at
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



652
653
654
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 652

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



654
655
656
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 654

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



656
657
658
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 656

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



658
659
660
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 658

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



660
661
662
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 660

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



662
663
664
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 662

def trial_settings
  @trial_settings
end