Class: Stripe::SubscriptionScheduleAmendParams::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, BillingSchedulesAction, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, billing_schedules_actions: nil, discount_actions: nil, effective_at: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 468

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  billing_schedules_actions: nil,
  discount_actions: nil,
  effective_at: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules_actions = billing_schedules_actions
  @discount_actions = discount_actions
  @effective_at = effective_at
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



444
445
446
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 444

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



446
447
448
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 446

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



448
449
450
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 448

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedules_actionsObject

Actions to apply to the billing schedules.



450
451
452
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 450

def billing_schedules_actions
  @billing_schedules_actions
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



452
453
454
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 452

def discount_actions
  @discount_actions
end

#effective_atObject

Configures how the subscription schedule handles billing for phase transitions.



454
455
456
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 454

def effective_at
  @effective_at
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



456
457
458
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 456

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



458
459
460
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 458

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



460
461
462
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 460

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



462
463
464
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 462

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



464
465
466
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 464

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



466
467
468
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 466

def trial_settings
  @trial_settings
end