Class: Stripe::SubscriptionScheduleAmendParams::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, BillingSchedulesAction, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil, billing_schedules_actions: nil) ⇒ Amendment

Returns a new instance of Amendment.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 458

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  discount_actions: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil,
  billing_schedules_actions: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @discount_actions = discount_actions
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
  @billing_schedules_actions = billing_schedules_actions
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



436
437
438
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 436

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



438
439
440
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 438

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



440
441
442
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 440

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedules_actionsObject

Actions to apply to the billing schedules.



456
457
458
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 456

def billing_schedules_actions
  @billing_schedules_actions
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



442
443
444
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 442

def discount_actions
  @discount_actions
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



444
445
446
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 444

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



446
447
448
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 446

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



448
449
450
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 448

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



450
451
452
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 450

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



452
453
454
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 452

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



454
455
456
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 454

def trial_settings
  @trial_settings
end