Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
177 178 179 180 181 182 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 177 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
169 170 171 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 169 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
171 172 173 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 171 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
173 174 175 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 173 def set @set end |
#type ⇒ Object
Determines the type of discount action.
175 176 177 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 175 def type @type end |