Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 101 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
91 92 93 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 91 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
93 94 95 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 93 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
95 96 97 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 95 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
97 98 99 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 97 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
99 100 101 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 99 def promotion_code @promotion_code end |