Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ Add
Returns a new instance of Add.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 169 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
157 158 159 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 157 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
159 160 161 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 159 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
161 162 163 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 161 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
163 164 165 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 163 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
165 166 167 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 165 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
167 168 169 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 167 def settings @settings end |