Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 124

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



114
115
116
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 114

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



116
117
118
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 116

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



118
119
120
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 118

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



120
121
122
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 120

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



122
123
124
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 122

def promotion_code
  @promotion_code
end