Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Add::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



128
129
130
131
132
133
134
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 128

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



118
119
120
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 118

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



120
121
122
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 120

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



122
123
124
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 122

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



124
125
126
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 124

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



126
127
128
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 126

def second
  @second
end