Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



124
125
126
127
128
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 124

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



118
119
120
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 118

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



120
121
122
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 120

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



122
123
124
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 122

def promotion_code
  @promotion_code
end