Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



194
195
196
197
198
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 194

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



188
189
190
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 188

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



190
191
192
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 190

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



192
193
194
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 192

def promotion_code
  @promotion_code
end