Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
Returns a new instance of Set.
139 140 141 142 143 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 139 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
133 134 135 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 133 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
135 136 137 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 135 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
137 138 139 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 137 def promotion_code @promotion_code end |