Class: Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
Returns a new instance of Set.
162 163 164 165 166 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 162 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
156 157 158 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 156 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
158 159 160 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 158 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
160 161 162 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 160 def promotion_code @promotion_code end |