Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



358
359
360
361
362
363
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 358

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



350
351
352
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 350

def add
  @add
end

#removeObject

Details of the subscription item to remove.



352
353
354
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 352

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



354
355
356
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 354

def set
  @set
end

#typeObject

Determines the type of item action.



356
357
358
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 356

def type
  @type
end