Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the subscription item to add.
-
#remove ⇒ Object
Details of the subscription item to remove.
-
#set ⇒ Object
Details of the subscription item to replace the existing items with.
-
#type ⇒ Object
Determines the type of item action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
constructor
A new instance of ItemAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
Returns a new instance of ItemAction.
381 382 383 384 385 386 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 381 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.
373 374 375 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 373 def add @add end |
#remove ⇒ Object
Details of the subscription item to remove.
375 376 377 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 375 def remove @remove end |
#set ⇒ Object
Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.
377 378 379 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 377 def set @set end |
#type ⇒ Object
Determines the type of item action.
379 380 381 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 379 def type @type end |