Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



381
382
383
384
385
386
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 381

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



373
374
375
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 373

def add
  @add
end

#removeObject

Details of the subscription item to remove.



375
376
377
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 375

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



377
378
379
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 377

def set
  @set
end

#typeObject

Determines the type of item action.



379
380
381
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 379

def type
  @type
end