Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



350
351
352
353
354
355
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 350

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



342
343
344
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 342

def add
  @add
end

#removeObject

Details of the subscription item to remove.



344
345
346
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 344

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



346
347
348
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 346

def set
  @set
end

#typeObject

Determines the type of item action.



348
349
350
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 348

def type
  @type
end