Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
Returns a new instance of Add.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 233 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
219 220 221 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 219 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
221 222 223 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 221 def @metadata end |
#price ⇒ Object
The ID of the price object.
223 224 225 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 223 def price @price end |
#quantity ⇒ Object
Quantity for this item.
225 226 227 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 225 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
227 228 229 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 227 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
229 230 231 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 229 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
231 232 233 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 231 def trial_offer @trial_offer end |