Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
Returns a new instance of Add.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 400 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
386 387 388 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 386 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
388 389 390 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 388 def @metadata end |
#price ⇒ Object
The ID of the price object.
390 391 392 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 390 def price @price end |
#quantity ⇒ Object
Quantity for this item.
392 393 394 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 392 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
394 395 396 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 394 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
396 397 398 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 396 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
398 399 400 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 398 def trial_offer @trial_offer end |