Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add

Returns a new instance of Add.



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 256

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



242
243
244
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 242

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



244
245
246
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 244

def 
  @metadata
end

#priceObject

The ID of the price object.



246
247
248
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 246

def price
  @price
end

#quantityObject

Quantity for this item.



248
249
250
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 248

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



250
251
252
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 250

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



252
253
254
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 252

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



254
255
256
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 254

def trial_offer
  @trial_offer
end