Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
199 200 201 202 203 204 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 199 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
191 192 193 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 191 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
193 194 195 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 193 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
195 196 197 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 195 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
197 198 199 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 197 def promotion_code @promotion_code end |