Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 359

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



349
350
351
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 349

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



351
352
353
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 351

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



353
354
355
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 353

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



355
356
357
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 355

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



357
358
359
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 357

def settings
  @settings
end