Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Trial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Add::Trial
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Instance Attribute Summary collapse
-
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial.
-
#type ⇒ Object
Determines the type of trial for this item.
Instance Method Summary collapse
-
#initialize(converts_to: nil, type: nil) ⇒ Trial
constructor
A new instance of Trial.
Methods inherited from RequestParams
Constructor Details
#initialize(converts_to: nil, type: nil) ⇒ Trial
Returns a new instance of Trial.
236 237 238 239 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 236 def initialize(converts_to: nil, type: nil) @converts_to = converts_to @type = type end |
Instance Attribute Details
#converts_to ⇒ Object
List of price IDs which, if present on the subscription following a paid trial, constitute opting-in to the paid trial. Currently only supports at most 1 price ID.
232 233 234 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 232 def converts_to @converts_to end |
#type ⇒ Object
Determines the type of trial for this item.
234 235 236 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 234 def type @type end |