Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the
pricealready exists, passing this will override thediscountsarray on the subscription item that matches that price. -
#metadata ⇒ Object
If an item with the
pricealready exists, passing this will override themetadataon the subscription item that matches that price. -
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the
pricealready exists, passing this will override the quantity on the subscription item that matches that price. -
#tax_rates ⇒ Object
If an item with the
pricealready exists, passing this will override thetax_ratesarray on the subscription item that matches that price. -
#trial ⇒ Object
If an item with the
pricealready exists, passing this will override thetrialconfiguration on the subscription item that matches that price. -
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set
Returns a new instance of Set.
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 550 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the price already exists, passing this will override the discounts array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied discounts.
536 537 538 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 536 def discounts @discounts end |
#metadata ⇒ Object
If an item with the price already exists, passing this will override the metadata on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied metadata.
538 539 540 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 538 def @metadata end |
#price ⇒ Object
The ID of the price object.
540 541 542 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 540 def price @price end |
#quantity ⇒ Object
If an item with the price already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied quantity.
542 543 544 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 542 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the price already exists, passing this will override the tax_rates array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied tax_rates.
544 545 546 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 544 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the price already exists, passing this will override the trial configuration on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied trial.
546 547 548 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 546 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
548 549 550 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 548 def trial_offer @trial_offer end |