Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set

Returns a new instance of Set.



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 331

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



317
318
319
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 317

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



319
320
321
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 319

def 
  @metadata
end

#priceObject

The ID of the price object.



321
322
323
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 321

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



323
324
325
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 323

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



325
326
327
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 325

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



327
328
329
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 327

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



329
330
331
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 329

def trial_offer
  @trial_offer
end