Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Set

Returns a new instance of Set.



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 348

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



336
337
338
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 336

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



338
339
340
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 338

def 
  @metadata
end

#priceObject

The ID of the price object.



340
341
342
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 340

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



342
343
344
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 342

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



344
345
346
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 344

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



346
347
348
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 346

def trial
  @trial
end