Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Set

Returns a new instance of Set.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 325

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



313
314
315
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 313

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



315
316
317
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 315

def 
  @metadata
end

#priceObject

The ID of the price object.



317
318
319
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 317

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



319
320
321
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 319

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



321
322
323
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 321

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



323
324
325
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 323

def trial
  @trial
end