Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
297 298 299 300 301 302 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 297 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
289 290 291 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 289 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
291 292 293 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 291 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
293 294 295 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 293 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
295 296 297 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 295 def promotion_code @promotion_code end |