Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 509

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



499
500
501
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 499

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



501
502
503
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 501

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



503
504
505
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 503

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



505
506
507
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 505

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



507
508
509
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 507

def settings
  @settings
end