Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 509 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
499 500 501 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 499 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
501 502 503 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 501 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
503 504 505 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 503 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
505 506 507 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 505 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
507 508 509 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 507 def settings @settings end |