Class: Stripe::SubscriptionScheduleAmendParams::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



449
450
451
452
453
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 449

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



443
444
445
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 443

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



445
446
447
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 445

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



447
448
449
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 447

def type
  @type
end