Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



483
484
485
486
487
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 483

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



477
478
479
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 477

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



479
480
481
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 479

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



481
482
483
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 481

def type
  @type
end