Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Prebilling::BillFrom
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: AmendmentStart
Instance Attribute Summary collapse
-
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
-
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
Instance Method Summary collapse
-
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
483 484 485 486 487 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 483 def initialize(amendment_start: nil, timestamp: nil, type: nil) @amendment_start = amendment_start @timestamp = @type = type end |
Instance Attribute Details
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
477 478 479 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 477 def amendment_start @amendment_start end |
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
479 480 481 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 479 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
481 482 483 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 481 def type @type end |