Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



514
515
516
517
518
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 514

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



508
509
510
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 508

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



510
511
512
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 510

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



512
513
514
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 512

def type
  @type
end