Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Prebilling::BillFrom
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: AmendmentStart
Instance Attribute Summary collapse
-
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
-
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
Instance Method Summary collapse
-
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
514 515 516 517 518 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 514 def initialize(amendment_start: nil, timestamp: nil, type: nil) @amendment_start = amendment_start @timestamp = @type = type end |
Instance Attribute Details
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
508 509 510 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 508 def amendment_start @amendment_start end |
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
510 511 512 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 510 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
512 513 514 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 512 def type @type end |