Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::Prebilling::BillUntil
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
520 521 522 523 524 525 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 520 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
512 513 514 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 512 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
514 515 516 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 514 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
516 517 518 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 516 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
518 519 520 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 518 def type @type end |