Class: Stripe::SubscriptionScheduleAmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_amend_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



551
552
553
554
555
556
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 551

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



543
544
545
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 543

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



545
546
547
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 545

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



547
548
549
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 547

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



549
550
551
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 549

def type
  @type
end