Class: Stripe::SubscriptionScheduleAmendParams::ScheduleSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleAmendParams::ScheduleSettings
- Defined in:
- lib/stripe/params/subscription_schedule_amend_params.rb
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ ScheduleSettings
constructor
A new instance of ScheduleSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(end_behavior: nil) ⇒ ScheduleSettings
Returns a new instance of ScheduleSettings.
775 776 777 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 775 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
773 774 775 |
# File 'lib/stripe/params/subscription_schedule_amend_params.rb', line 773 def end_behavior @end_behavior end |