Class: Stripe::SubscriptionScheduleCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillingMode, BillingSchedule, DefaultSettings, PauseSchedule, Phase, Prebilling

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, billing_schedules: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, pause_schedules: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams

Returns a new instance of SubscriptionScheduleCreateParams.



1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1127

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  billing_schedules: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  pause_schedules: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @billing_schedules = billing_schedules
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @pause_schedules = pause_schedules
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.



1099
1100
1101
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1099

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1101
1102
1103
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1101

def billing_mode
  @billing_mode
end

#billing_schedulesObject

Sets the billing schedules for the subscription schedule.



1103
1104
1105
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1103

def billing_schedules
  @billing_schedules
end

#customerObject

The identifier of the customer to create the subscription schedule for.



1105
1106
1107
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1105

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



1107
1108
1109
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1107

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule's default settings.



1109
1110
1111
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1109

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.



1111
1112
1113
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1111

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1113
1114
1115
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1113

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription's item(s), set to auto-renew using the subscription's interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



1115
1116
1117
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1115

def from_subscription
  @from_subscription
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1117
1118
1119
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1117

def 
  @metadata
end

#pause_schedulesObject

Configures the subscription's pause behavior and, optionally, its resume behavior. Only one entry is supported.



1119
1120
1121
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1119

def pause_schedules
  @pause_schedules
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the end_date of one phase will always equal the start_date of the next phase.



1121
1122
1123
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1121

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1123
1124
1125
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1123

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using now so that it starts the subscription immediately, and to avoid unexpected behavior due to request delays or clock skew resulting in a slightly backdated or postdated start. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



1125
1126
1127
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1125

def start_date
  @start_date
end

Class Method Details

.field_encodingsObject



1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 1159

def self.field_encodings
  @field_encodings = {
    phases: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          add_invoice_items: {
            kind: :array,
            element: {
              kind: :object,
              fields: {
                price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
              },
            },
          },
          items: {
            kind: :array,
            element: {
              kind: :object,
              fields: {
                price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
              },
            },
          },
        },
      },
    },
  }
end