Class: Stripe::SubscriptionScheduleCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: BillingMode, DefaultSettings, Phase
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#customer ⇒ Object
The identifier of the customer to create the subscription schedule for.
-
#customer_account ⇒ Object
The identifier of the account to create the subscription schedule for.
-
#default_settings ⇒ Object
Object representing the subscription schedule's default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
Migrate an existing subscription to be managed by a subscription schedule.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#start_date ⇒ Object
When the subscription schedule starts.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams
constructor
A new instance of SubscriptionScheduleCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams
Returns a new instance of SubscriptionScheduleCreateParams.
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 669 def initialize( billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil ) @billing_mode = billing_mode @customer = customer @customer_account = customer_account @default_settings = default_settings @end_behavior = end_behavior @expand = @from_subscription = from_subscription @metadata = @phases = phases @start_date = start_date end |
Instance Attribute Details
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
649 650 651 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 649 def billing_mode @billing_mode end |
#customer ⇒ Object
The identifier of the customer to create the subscription schedule for.
651 652 653 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 651 def customer @customer end |
#customer_account ⇒ Object
The identifier of the account to create the subscription schedule for.
653 654 655 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 653 def customer_account @customer_account end |
#default_settings ⇒ Object
Object representing the subscription schedule's default settings.
655 656 657 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 655 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.
657 658 659 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 657 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
659 660 661 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 659 def @expand end |
#from_subscription ⇒ Object
Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription's item(s), set to auto-renew using the subscription's interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.
661 662 663 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 661 def from_subscription @from_subscription end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
663 664 665 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 663 def @metadata end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the end_date of one phase will always equal the start_date of the next phase.
665 666 667 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 665 def phases @phases end |
#start_date ⇒ Object
When the subscription schedule starts. We recommend using now so that it starts the subscription immediately, and to avoid unexpected behavior due to request delays or clock skew resulting in a slightly backdated or postdated start. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.
667 668 669 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 667 def start_date @start_date end |
Class Method Details
.field_encodings ⇒ Object
693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 693 def self.field_encodings @field_encodings = { phases: { kind: :array, element: { kind: :object, fields: { add_invoice_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, }, }, }, items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, }, }, }, }, }, }, } end |