Class: Stripe::SubscriptionScheduleCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillingMode, DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams

Returns a new instance of SubscriptionScheduleCreateParams.



767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 767

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



743
744
745
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 743

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



745
746
747
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 745

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



747
748
749
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 747

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



749
750
751
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 749

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



751
752
753
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 751

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



753
754
755
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 753

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



755
756
757
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 755

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



757
758
759
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 757

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



759
760
761
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 759

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



761
762
763
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 761

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



763
764
765
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 763

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



765
766
767
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 765

def start_date
  @start_date
end

Class Method Details

.field_encodingsObject



795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 795

def self.field_encodings
  @field_encodings = {
    phases: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          add_invoice_items: {
            kind: :array,
            element: {
              kind: :object,
              fields: {
                price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
              },
            },
          },
          items: {
            kind: :array,
            element: {
              kind: :object,
              fields: {
                price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
              },
            },
          },
        },
      },
    },
  }
end