Class: Stripe::SubscriptionScheduleCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillingMode, BillingSchedule, DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, billing_schedules: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams

Returns a new instance of SubscriptionScheduleCreateParams.



894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 894

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  billing_schedules: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @billing_schedules = billing_schedules
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



868
869
870
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 868

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



870
871
872
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 870

def billing_mode
  @billing_mode
end

#billing_schedulesObject

Sets the billing schedules for the subscription schedule.



872
873
874
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 872

def billing_schedules
  @billing_schedules
end

#customerObject

The identifier of the customer to create the subscription schedule for.



874
875
876
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 874

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



876
877
878
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 876

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



878
879
880
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 878

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



880
881
882
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 880

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



882
883
884
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 882

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



884
885
886
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 884

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



886
887
888
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 886

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



888
889
890
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 888

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



890
891
892
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 890

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



892
893
894
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 892

def start_date
  @start_date
end