Class: Stripe::SubscriptionScheduleCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: BillingMode, DefaultSettings, Phase, Prebilling
Instance Attribute Summary collapse
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#customer ⇒ Object
The identifier of the customer to create the subscription schedule for.
-
#customer_account ⇒ Object
The identifier of the account to create the subscription schedule for.
-
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_subscription ⇒ Object
Migrate an existing subscription to be managed by a subscription schedule.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#start_date ⇒ Object
When the subscription schedule starts.
Instance Method Summary collapse
-
#initialize(billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams
constructor
A new instance of SubscriptionScheduleCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams
Returns a new instance of SubscriptionScheduleCreateParams.
724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 724 def initialize( billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil ) @billing_behavior = billing_behavior @billing_mode = billing_mode @customer = customer @customer_account = customer_account @default_settings = default_settings @end_behavior = end_behavior @expand = @from_subscription = from_subscription @metadata = @phases = phases @prebilling = prebilling @start_date = start_date end |
Instance Attribute Details
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
700 701 702 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 700 def billing_behavior @billing_behavior end |
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
702 703 704 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 702 def billing_mode @billing_mode end |
#customer ⇒ Object
The identifier of the customer to create the subscription schedule for.
704 705 706 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 704 def customer @customer end |
#customer_account ⇒ Object
The identifier of the account to create the subscription schedule for.
706 707 708 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 706 def customer_account @customer_account end |
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
708 709 710 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 708 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
710 711 712 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 710 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
712 713 714 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 712 def @expand end |
#from_subscription ⇒ Object
Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.
714 715 716 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 714 def from_subscription @from_subscription end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
716 717 718 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 716 def @metadata end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.
718 719 720 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 718 def phases @phases end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
720 721 722 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 720 def prebilling @prebilling end |
#start_date ⇒ Object
When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.
722 723 724 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 722 def start_date @start_date end |