Class: Stripe::SubscriptionScheduleCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillingMode, BillingSchedule, DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, billing_schedules: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ SubscriptionScheduleCreateParams

Returns a new instance of SubscriptionScheduleCreateParams.



790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 790

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  billing_schedules: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @billing_schedules = billing_schedules
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



764
765
766
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 764

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



766
767
768
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 766

def billing_mode
  @billing_mode
end

#billing_schedulesObject

Sets the billing schedules for the subscription schedule.



768
769
770
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 768

def billing_schedules
  @billing_schedules
end

#customerObject

The identifier of the customer to create the subscription schedule for.



770
771
772
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 770

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



772
773
774
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 772

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



774
775
776
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 774

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



776
777
778
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 776

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



778
779
780
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 778

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



780
781
782
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 780

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



782
783
784
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 782

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



784
785
786
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 784

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



786
787
788
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 786

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



788
789
790
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 788

def start_date
  @start_date
end