Class: Stripe::SubscriptionScheduleCreateParams::DefaultSettings::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::DefaultSettings::InvoiceSettings
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: CustomField, Issuer
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the subscription schedule.
-
#custom_fields ⇒ Object
Attribute for param field custom_fields.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#description ⇒ Object
Attribute for param field description.
-
#footer ⇒ Object
Attribute for param field footer.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 151 def initialize( account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @days_until_due = days_until_due @description = description @footer = @issuer = issuer end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
139 140 141 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 139 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
Attribute for param field custom_fields
141 142 143 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 141 def custom_fields @custom_fields end |
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where collection_method=charge_automatically.
143 144 145 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 143 def days_until_due @days_until_due end |
#description ⇒ Object
Attribute for param field description
145 146 147 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 145 def description @description end |
#footer ⇒ Object
Attribute for param field footer
147 148 149 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 147 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
149 150 151 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 149 def issuer @issuer end |