Class: Stripe::SubscriptionScheduleCreateParams::DefaultSettings::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::DefaultSettings::InvoiceSettings
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: CustomField, Issuer
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the subscription schedule.
-
#custom_fields ⇒ Object
Attribute for param field custom_fields.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#description ⇒ Object
Attribute for param field description.
-
#footer ⇒ Object
Attribute for param field footer.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 99 def initialize( account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @days_until_due = days_until_due @description = description @footer = @issuer = issuer end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
87 88 89 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 87 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
Attribute for param field custom_fields
89 90 91 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 89 def custom_fields @custom_fields end |
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where collection_method=charge_automatically.
91 92 93 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 91 def days_until_due @days_until_due end |
#description ⇒ Object
Attribute for param field description
93 94 95 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 93 def description @description end |
#footer ⇒ Object
Attribute for param field footer
95 96 97 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 95 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
97 98 99 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 97 def issuer @issuer end |