Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::PauseAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ PauseAt

Returns a new instance of PauseAt.



237
238
239
240
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 237

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

The Unix timestamp at which to pause the subscription. Required when type is timestamp.



233
234
235
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 233

def timestamp
  @timestamp
end

#typeObject

When to pause the subscription. Use now to pause immediately or timestamp to pause at a specific time.



235
236
237
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 235

def type
  @type
end