Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::PauseAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::PauseAt
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The Unix timestamp at which to pause the subscription.
-
#type ⇒ Object
When to pause the subscription.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ PauseAt
constructor
A new instance of PauseAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ PauseAt
Returns a new instance of PauseAt.
237 238 239 240 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 237 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The Unix timestamp at which to pause the subscription. Required when type is timestamp.
233 234 235 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 233 def @timestamp end |
#type ⇒ Object
When to pause the subscription. Use now to pause immediately or timestamp to pause at a specific time.
235 236 237 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 235 def type @type end |