Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillFor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Settings

Returns a new instance of Settings.



279
280
281
282
283
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 279

def initialize(bill_for: nil, invoicing_behavior: nil, type: nil)
  @bill_for = bill_for
  @invoicing_behavior = invoicing_behavior
  @type = type
end

Instance Attribute Details

#bill_forObject

Controls what to bill for when pausing the subscription.



273
274
275
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 273

def bill_for
  @bill_for
end

#invoicing_behaviorObject

Determines whether to generate an invoice for outstanding amounts when pausing.



275
276
277
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 275

def invoicing_behavior
  @invoicing_behavior
end

#typeObject

The pause type. Currently only subscription is supported.



277
278
279
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 277

def type
  @type
end