Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: BillFor
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
-
#invoicing_behavior ⇒ Object
Determines whether to generate an invoice for outstanding amounts when pausing.
-
#type ⇒ Object
The pause type.
Instance Method Summary collapse
-
#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Settings
Returns a new instance of Settings.
223 224 225 226 227 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 223 def initialize(bill_for: nil, invoicing_behavior: nil, type: nil) @bill_for = bill_for @invoicing_behavior = invoicing_behavior @type = type end |
Instance Attribute Details
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
217 218 219 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 217 def bill_for @bill_for end |
#invoicing_behavior ⇒ Object
Determines whether to generate an invoice for outstanding amounts when pausing. When adding a pause schedule, defaults to pending_invoice_item. On updates, the existing value is preserved if not provided.
219 220 221 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 219 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object
The pause type. Currently only subscription is supported.
221 222 223 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 221 def type @type end |