Class: Stripe::SubscriptionScheduleCreateParams::PauseSchedule::Pause::Settings::BillFor

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: OutstandingUsageThrough, UnusedTimeFrom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor

Returns a new instance of BillFor.



267
268
269
270
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 267

def initialize(outstanding_usage_through: nil, unused_time_from: nil)
  @outstanding_usage_through = outstanding_usage_through
  @unused_time_from = unused_time_from
end

Instance Attribute Details

#outstanding_usage_throughObject

Controls whether to collect metered usage accrued up to the pause date.



263
264
265
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 263

def outstanding_usage_through
  @outstanding_usage_through
end

#unused_time_fromObject

Controls how unused time on subscription items is credited when pausing.



265
266
267
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 265

def unused_time_from
  @unused_time_from
end