Class: Stripe::SubscriptionScheduleCreateParams::Phase
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, Duration, InvoiceSettings, Item, TransferData
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
-
#billing_cycle_anchor ⇒ Object
Can be set to
phase_startto set the anchor to the start of the phase orautomaticto automatically change it if needed. -
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
Either
charge_automatically, orsend_invoice. -
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#default_tax_rates ⇒ Object
A list of Tax Rate ids.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase.
-
#duration ⇒ Object
The number of intervals the phase should last.
-
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a phase.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription's invoices.
-
#proration_behavior ⇒ Object
Controls whether the subscription schedule should create prorations when transitioning to this phase if there is a difference in billing configuration.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription's invoices.
-
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
-
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, end_date: nil, invoice_settings: nil, items: nil, metadata: nil, on_behalf_of: nil, proration_behavior: nil, transfer_data: nil, trial: nil, trial_end: nil) ⇒ Phase
Returns a new instance of Phase.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 583 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, end_date: nil, invoice_settings: nil, items: nil, metadata: nil, on_behalf_of: nil, proration_behavior: nil, transfer_data: nil, trial: nil, trial_end: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_thresholds = billing_thresholds @collection_method = collection_method @currency = currency @default_payment_method = default_payment_method @default_tax_rates = default_tax_rates @description = description @discounts = discounts @duration = duration @end_date = end_date @invoice_settings = invoice_settings @items = items @metadata = @on_behalf_of = on_behalf_of @proration_behavior = proration_behavior @transfer_data = transfer_data @trial = trial @trial_end = trial_end end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.
541 542 543 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 541 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees documentation.
543 544 545 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 543 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
545 546 547 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 545 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to phase_start to set the anchor to the start of the phase or automatic to automatically change it if needed. Cannot be set to phase_start if this phase specifies a trial. For more information, see the billing cycle documentation.
547 548 549 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 547 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
549 550 551 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 549 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically on creation.
551 552 553 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 551 def collection_method @collection_method end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
553 554 555 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 553 def currency @currency end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer's invoice settings.
555 556 557 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 555 def default_payment_method @default_payment_method end |
#default_tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will set the Subscription's default_tax_rates, which means they will be the Invoice's default_tax_rates for any Invoices issued by the Subscription during this Phase.
557 558 559 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 557 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
559 560 561 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 559 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription's customer. Pass an empty string to avoid inheriting any discounts.
561 562 563 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 561 def discounts @discounts end |
#duration ⇒ Object
The number of intervals the phase should last. If set, end_date must not be set.
563 564 565 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 563 def duration @duration end |
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends. If set, duration must not be set.
565 566 567 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 565 def end_date @end_date end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
567 568 569 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 567 def invoice_settings @invoice_settings end |
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
569 570 571 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 569 def items @items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a phase. Metadata on a schedule's phase will update the underlying subscription's metadata when the phase is entered, adding new keys and replacing existing keys in the subscription's metadata. Individual keys in the subscription's metadata can be unset by posting an empty value to them in the phase's metadata. To unset all keys in the subscription's metadata, update the subscription directly or unset every key individually from the phase's metadata.
571 572 573 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 571 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription's invoices.
573 574 575 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 573 def on_behalf_of @on_behalf_of end |
#proration_behavior ⇒ Object
Controls whether the subscription schedule should create prorations when transitioning to this phase if there is a difference in billing configuration. It's different from the request-level proration_behavior parameter which controls what happens if the update request affects the billing configuration (item price, quantity, etc.) of the current phase.
575 576 577 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 575 def proration_behavior @proration_behavior end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription's invoices.
577 578 579 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 577 def transfer_data @transfer_data end |
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
579 580 581 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 579 def trial @trial end |
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with trial
581 582 583 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 581 def trial_end @trial_end end |
Class Method Details
.field_encodings ⇒ Object
629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 629 def self.field_encodings @field_encodings = { add_invoice_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |