Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 488

def initialize(
  discountable: nil,
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discountable = discountable
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.



472
473
474
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 472

def discountable
  @discountable
end

#discountsObject

The coupons to redeem into discounts for the item.



474
475
476
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 474

def discounts
  @discounts
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



476
477
478
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 476

def 
  @metadata
end

#periodObject

The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.



478
479
480
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 478

def period
  @period
end

#priceObject

The ID of the price object. One of price or price_data is required.



480
481
482
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 480

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline. One of price or price_data is required.



482
483
484
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 482

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



484
485
486
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 484

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.



486
487
488
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 486

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



508
509
510
511
512
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 508

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end