Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discountable ⇒ Object
Controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 300 def initialize( discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discountable = discountable @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discountable ⇒ Object
Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.
284 285 286 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 284 def discountable @discountable end |
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
286 287 288 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 286 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
288 289 290 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 288 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.
290 291 292 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 290 def period @period end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
292 293 294 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 292 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline. One of price or price_data is required.
294 295 296 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 294 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
296 297 298 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 296 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.
298 299 300 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 298 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
320 321 322 323 324 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 320 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |