Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 270

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



256
257
258
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 256

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



258
259
260
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 258

def 
  @metadata
end

#periodObject

The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.



260
261
262
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 260

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



262
263
264
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 262

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



264
265
266
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 264

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



266
267
268
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 266

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



268
269
270
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 268

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



288
289
290
291
292
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 288

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end