Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 326 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
312 313 314 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 312 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
314 315 316 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 314 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.
316 317 318 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 316 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
318 319 320 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 318 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
320 321 322 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 320 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
322 323 324 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 322 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
324 325 326 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 324 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
344 345 346 347 348 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 344 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |