Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
238 239 240 241 242 243 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 238 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
230 231 232 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 230 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
232 233 234 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 232 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
234 235 236 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 234 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
236 237 238 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 236 def promotion_code @promotion_code end |