Class: Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::AddInvoiceItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
167 168 169 170 171 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 167 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
161 162 163 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 161 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
163 164 165 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 163 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
165 166 167 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 165 def type @type end |