Class: Stripe::SubscriptionScheduleCreateParams::Phase::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



368
369
370
371
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 368

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



364
365
366
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 364

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



366
367
368
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 366

def liability
  @liability
end