Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
350 351 352 353 354 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 350 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
344 345 346 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 344 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
346 347 348 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 346 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
348 349 350 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 348 def type @type end |