Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



340
341
342
343
344
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 340

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



334
335
336
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 334

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



336
337
338
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 336

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



338
339
340
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 338

def type
  @type
end