Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



384
385
386
387
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 384

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



380
381
382
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 380

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



382
383
384
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 382

def interval_count
  @interval_count
end