Class: Stripe::SubscriptionScheduleCreateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
417 418 419 420 421 422 423 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 417 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
407 408 409 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 407 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
409 410 411 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 409 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
411 412 413 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 411 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
413 414 415 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 413 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
415 416 417 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 415 def second @second end |