Class: Stripe::SubscriptionScheduleCreateParams::Phase::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: CustomField, Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 454

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  days_until_due: nil,
  description: nil,
  footer: nil,
  issuer: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @days_until_due = days_until_due
  @description = description
  @footer = footer
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.



442
443
444
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 442

def 
  @account_tax_ids
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



444
445
446
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 444

def custom_fields
  @custom_fields
end

#days_until_dueObject

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where collection_method=charge_automatically.



446
447
448
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 446

def days_until_due
  @days_until_due
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



448
449
450
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 448

def description
  @description
end

Footer to be displayed on the invoice.



450
451
452
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 450

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



452
453
454
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 452

def issuer
  @issuer
end