Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
Returns a new instance of Item.
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 894 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
874 875 876 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 874 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
876 877 878 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 876 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item's metadata when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item's metadata can be unset by posting an empty value to them in the configuration item's metadata. To unset all keys in the subscription item's metadata, update the subscription item directly or unset every key individually from the configuration item's metadata.
878 879 880 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 878 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in plan and price.
880 881 882 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 880 def plan @plan end |
#price ⇒ Object
The ID of the price object.
882 883 884 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 882 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
884 885 886 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 884 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price's usage_type is licensed and not metered.
886 887 888 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 886 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
888 889 890 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 888 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
890 891 892 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 890 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
892 893 894 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 892 def trial_offer @trial_offer end |
Class Method Details
.field_encodings ⇒ Object
918 919 920 921 922 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 918 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |