Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
Returns a new instance of Item.
602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 602 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
582 583 584 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 582 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
584 585 586 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 584 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item's metadata when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item's metadata can be unset by posting an empty value to them in the configuration item's metadata. To unset all keys in the subscription item's metadata, update the subscription item directly or unset every key individually from the configuration item's metadata.
586 587 588 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 586 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in plan and price.
588 589 590 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 588 def plan @plan end |
#price ⇒ Object
The ID of the price object.
590 591 592 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 590 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
592 593 594 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 592 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price's usage_type is licensed and not metered.
594 595 596 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 594 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
596 597 598 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 596 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
598 599 600 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 598 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
600 601 602 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 600 def trial_offer @trial_offer end |
Class Method Details
.field_encodings ⇒ Object
626 627 628 629 630 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 626 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |