Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item

Returns a new instance of Item.



702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 702

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



682
683
684
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 682

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



684
685
686
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 684

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



686
687
688
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 686

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



688
689
690
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 688

def plan
  @plan
end

#priceObject

The ID of the price object.



690
691
692
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 690

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



692
693
694
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 692

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



694
695
696
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 694

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



696
697
698
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 696

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



698
699
700
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 698

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



700
701
702
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 700

def trial_offer
  @trial_offer
end

Class Method Details

.field_encodingsObject



726
727
728
729
730
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 726

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end