Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
801 802 803 804 805 806 807 808 809 810 811 812 813 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 801 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
791 792 793 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 791 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
793 794 795 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 793 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
795 796 797 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 795 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
797 798 799 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 797 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
799 800 801 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 799 def settings @settings end |