Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 613 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
603 604 605 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 603 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
605 606 607 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 605 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
607 608 609 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 607 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
609 610 611 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 609 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
611 612 613 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 611 def settings @settings end |