Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



456
457
458
459
460
461
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 456

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



448
449
450
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 448

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



450
451
452
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 450

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



452
453
454
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 452

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



454
455
456
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 454

def promotion_code
  @promotion_code
end