Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 599

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



589
590
591
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 589

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



591
592
593
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 591

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



593
594
595
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 593

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



595
596
597
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 595

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



597
598
599
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 597

def settings
  @settings
end