Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



502
503
504
505
506
507
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 502

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



494
495
496
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 494

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



496
497
498
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 496

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



498
499
500
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 498

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



500
501
502
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 500

def promotion_code
  @promotion_code
end