Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



446
447
448
449
450
451
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 446

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



438
439
440
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 438

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



440
441
442
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 440

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



442
443
444
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 442

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



444
445
446
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 444

def promotion_code
  @promotion_code
end