Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



539
540
541
542
543
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 539

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



533
534
535
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 533

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



535
536
537
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 535

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



537
538
539
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 537

def type
  @type
end