Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
431 432 433 434 435 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 431 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
425 426 427 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 425 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
427 428 429 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 427 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
429 430 431 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 429 def type @type end |