Class: Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Phase::Item::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
527 528 529 530 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 527 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
523 524 525 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 523 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
525 526 527 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 525 def interval_count @interval_count end |