Class: Stripe::SubscriptionScheduleCreateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



862
863
864
865
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 862

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



858
859
860
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 858

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



860
861
862
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 860

def update_behavior
  @update_behavior
end