Class: Stripe::SubscriptionScheduleCreateParams::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleCreateParams::Prebilling
- Defined in:
- lib/stripe/params/subscription_schedule_create_params.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
-
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period.
Instance Method Summary collapse
-
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
694 695 696 697 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 694 def initialize(iterations: nil, update_behavior: nil) @iterations = iterations @update_behavior = update_behavior end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
690 691 692 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 690 def iterations @iterations end |
#update_behavior ⇒ Object
Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.
692 693 694 |
# File 'lib/stripe/params/subscription_schedule_create_params.rb', line 692 def update_behavior @update_behavior end |