Class: Stripe::SubscriptionScheduleService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SubscriptionScheduleService
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: CancelParams, CreateParams, ListParams, ReleaseParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#cancel(schedule, params = {}, opts = {}) ⇒ Object
Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription).
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription schedule object.
-
#list(params = {}, opts = {}) ⇒ Object
Retrieves the list of your subscription schedules.
-
#release(schedule, params = {}, opts = {}) ⇒ Object
Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place.
-
#retrieve(schedule, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing subscription schedule.
-
#update(schedule, params = {}, opts = {}) ⇒ Object
Updates an existing subscription schedule.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#cancel(schedule, params = {}, opts = {}) ⇒ Object
Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.
1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1159 def cancel(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.
1170 1171 1172 1173 1174 1175 1176 1177 1178 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1170 def create(params = {}, opts = {}) request( method: :post, path: "/v1/subscription_schedules", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Retrieves the list of your subscription schedules.
1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1181 def list(params = {}, opts = {}) request( method: :get, path: "/v1/subscription_schedules", params: params, opts: opts, base_address: :api ) end |
#release(schedule, params = {}, opts = {}) ⇒ Object
Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.
1192 1193 1194 1195 1196 1197 1198 1199 1200 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1192 def release(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(schedule, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing subscription schedule. You only need to supply the unique subscription schedule identifier that was returned upon subscription schedule creation.
1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1203 def retrieve(schedule, params = {}, opts = {}) request( method: :get, path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#update(schedule, params = {}, opts = {}) ⇒ Object
Updates an existing subscription schedule.
1214 1215 1216 1217 1218 1219 1220 1221 1222 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1214 def update(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |