Class: Stripe::SubscriptionScheduleService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SubscriptionScheduleService
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: CancelParams, CreateParams, ListParams, ReleaseParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#cancel(schedule, params = {}, opts = {}) ⇒ Object
Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription).
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription schedule object.
-
#list(params = {}, opts = {}) ⇒ Object
Retrieves the list of your subscription schedules.
-
#release(schedule, params = {}, opts = {}) ⇒ Object
Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place.
-
#retrieve(schedule, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing subscription schedule.
-
#update(schedule, params = {}, opts = {}) ⇒ Object
Updates an existing subscription schedule.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#cancel(schedule, params = {}, opts = {}) ⇒ Object
Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.
1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1069 def cancel(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.
1080 1081 1082 1083 1084 1085 1086 1087 1088 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1080 def create(params = {}, opts = {}) request( method: :post, path: "/v1/subscription_schedules", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Retrieves the list of your subscription schedules.
1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1091 def list(params = {}, opts = {}) request( method: :get, path: "/v1/subscription_schedules", params: params, opts: opts, base_address: :api ) end |
#release(schedule, params = {}, opts = {}) ⇒ Object
Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.
1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1102 def release(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(schedule, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing subscription schedule. You only need to supply the unique subscription schedule identifier that was returned upon subscription schedule creation.
1113 1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1113 def retrieve(schedule, params = {}, opts = {}) request( method: :get, path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#update(schedule, params = {}, opts = {}) ⇒ Object
Updates an existing subscription schedule.
1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1124 def update(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |