Class: Stripe::SubscriptionScheduleService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SubscriptionScheduleService
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendParams, CancelParams, CreateParams, ListParams, ReleaseParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#amend(schedule, params = {}, opts = {}) ⇒ Object
Amends an existing subscription schedule.
-
#cancel(schedule, params = {}, opts = {}) ⇒ Object
Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription).
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription schedule object.
-
#list(params = {}, opts = {}) ⇒ Object
Retrieves the list of your subscription schedules.
-
#release(schedule, params = {}, opts = {}) ⇒ Object
Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place.
-
#retrieve(schedule, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing subscription schedule.
-
#update(schedule, params = {}, opts = {}) ⇒ Object
Updates an existing subscription schedule.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#amend(schedule, params = {}, opts = {}) ⇒ Object
Amends an existing subscription schedule.
2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2049 def amend(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/amend", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#cancel(schedule, params = {}, opts = {}) ⇒ Object
Cancels a subscription schedule and its associated subscription immediately (if the subscription schedule has an active subscription). A subscription schedule can only be canceled if its status is not_started or active.
2060 2061 2062 2063 2064 2065 2066 2067 2068 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2060 def cancel(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/cancel", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription schedule object. Each customer can have up to 500 active or scheduled subscriptions.
2071 2072 2073 2074 2075 2076 2077 2078 2079 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2071 def create(params = {}, opts = {}) request( method: :post, path: "/v1/subscription_schedules", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Retrieves the list of your subscription schedules.
2082 2083 2084 2085 2086 2087 2088 2089 2090 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2082 def list(params = {}, opts = {}) request( method: :get, path: "/v1/subscription_schedules", params: params, opts: opts, base_address: :api ) end |
#release(schedule, params = {}, opts = {}) ⇒ Object
Releases the subscription schedule immediately, which will stop scheduling of its phases, but leave any existing subscription in place. A schedule can only be released if its status is not_started or active. If the subscription schedule is currently associated with a subscription, releasing it will remove its subscription property and set the subscription’s ID to the released_subscription property.
2093 2094 2095 2096 2097 2098 2099 2100 2101 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2093 def release(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s/release", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(schedule, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing subscription schedule. You only need to supply the unique subscription schedule identifier that was returned upon subscription schedule creation.
2104 2105 2106 2107 2108 2109 2110 2111 2112 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2104 def retrieve(schedule, params = {}, opts = {}) request( method: :get, path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |
#update(schedule, params = {}, opts = {}) ⇒ Object
Updates an existing subscription schedule.
2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2115 def update(schedule, params = {}, opts = {}) request( method: :post, path: format("/v1/subscription_schedules/%<schedule>s", { schedule: CGI.escape(schedule) }), params: params, opts: opts, base_address: :api ) end |