Class: Stripe::SubscriptionScheduleService::AmendParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2051

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



2040
2041
2042
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2040

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



2042
2043
2044
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2042

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



2044
2045
2046
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2044

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2047
2048
2049
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2047

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2049
2050
2051
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2049

def schedule_settings
  @schedule_settings
end