Class: Stripe::SubscriptionScheduleService::AmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
constructor
A new instance of AmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
Returns a new instance of AmendParams.
2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2019 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
2008 2009 2010 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2008 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2010 2011 2012 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2010 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
2012 2013 2014 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2012 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
2015 2016 2017 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2015 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
2017 2018 2019 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2017 def schedule_settings @schedule_settings end |