Class: Stripe::SubscriptionScheduleService::AmendParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1920

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



1909
1910
1911
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1909

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



1911
1912
1913
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1911

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



1913
1914
1915
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1913

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


1916
1917
1918
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1916

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



1918
1919
1920
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1918

def schedule_settings
  @schedule_settings
end