Class: Stripe::SubscriptionScheduleService::AmendParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Amendment, Prebilling, ScheduleSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams

Returns a new instance of AmendParams.



2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2006

def initialize(
  amendments: nil,
  expand: nil,
  prebilling: nil,
  proration_behavior: nil,
  schedule_settings: nil
)
  @amendments = amendments
  @expand = expand
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @schedule_settings = schedule_settings
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



1995
1996
1997
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1995

def amendments
  @amendments
end

#expandObject

Specifies which fields in the response should be expanded.



1997
1998
1999
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1997

def expand
  @expand
end

#prebillingObject

Provide any time periods to bill in advance.



1999
2000
2001
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1999

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the amendment changes the currently active phase,

specifies if and how to prorate at the time of the request.


2002
2003
2004
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2002

def proration_behavior
  @proration_behavior
end

#schedule_settingsObject

Changes to apply to the subscription schedule.



2004
2005
2006
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2004

def schedule_settings
  @schedule_settings
end