Class: Stripe::SubscriptionScheduleService::AmendParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Amendment, Prebilling, ScheduleSettings
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase, specifies if and how to prorate at the time of the request.
-
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
Instance Method Summary collapse
-
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
constructor
A new instance of AmendParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil) ⇒ AmendParams
Returns a new instance of AmendParams.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2293 def initialize( amendments: nil, expand: nil, prebilling: nil, proration_behavior: nil, schedule_settings: nil ) @amendments = amendments @expand = @prebilling = prebilling @proration_behavior = proration_behavior @schedule_settings = schedule_settings end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
2278 2279 2280 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2278 def amendments @amendments end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2281 2282 2283 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2281 def @expand end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
2284 2285 2286 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2284 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the amendment changes the currently active phase,
specifies if and how to prorate at the time of the request.
2288 2289 2290 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2288 def proration_behavior @proration_behavior end |
#schedule_settings ⇒ Object
Changes to apply to the subscription schedule.
2291 2292 2293 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2291 def schedule_settings @schedule_settings end |