Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1928

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  discount_actions: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @discount_actions = discount_actions
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



1908
1909
1910
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1908

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



1910
1911
1912
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1910

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



1912
1913
1914
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1912

def billing_cycle_anchor
  @billing_cycle_anchor
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



1914
1915
1916
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1914

def discount_actions
  @discount_actions
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



1916
1917
1918
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1916

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



1918
1919
1920
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1918

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



1920
1921
1922
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1920

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



1922
1923
1924
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1922

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



1924
1925
1926
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1924

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



1926
1927
1928
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1926

def trial_settings
  @trial_settings
end