Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
-
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
-
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
-
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
constructor
A new instance of Amendment.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
Returns a new instance of Amendment.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1797 def initialize( amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil ) @amendment_end = amendment_end @amendment_start = amendment_start @billing_cycle_anchor = billing_cycle_anchor @discount_actions = discount_actions @item_actions = item_actions @metadata_actions = @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @trial_settings = trial_settings end |
Instance Attribute Details
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.
1777 1778 1779 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1777 def amendment_end @amendment_end end |
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
1779 1780 1781 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1779 def amendment_start @amendment_start end |
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
1781 1782 1783 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1781 def billing_cycle_anchor @billing_cycle_anchor end |
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
1783 1784 1785 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1783 def discount_actions @discount_actions end |
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
1785 1786 1787 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1785 def item_actions @item_actions end |
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata
1787 1788 1789 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1787 def @metadata_actions end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.
1789 1790 1791 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1789 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
1791 1792 1793 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1791 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
1793 1794 1795 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1793 def set_schedule_end @set_schedule_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
1795 1796 1797 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1795 def trial_settings @trial_settings end |