Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
1532 1533 1534 1535 1536 1537 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1532 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1524 1525 1526 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1524 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
1526 1527 1528 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1526 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
1528 1529 1530 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1528 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
1530 1531 1532 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1530 def type @type end |