Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



1500
1501
1502
1503
1504
1505
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1500

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



1492
1493
1494
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1492

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



1494
1495
1496
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1494

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



1496
1497
1498
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1496

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



1498
1499
1500
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1498

def type
  @type
end