Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
1500 1501 1502 1503 1504 1505 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1500 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1492 1493 1494 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1492 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
1494 1495 1496 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1494 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
1496 1497 1498 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1496 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
1498 1499 1500 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1498 def type @type end |