Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentEnd, DiscountEnd
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
constructor
A new instance of AmendmentStart.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
Returns a new instance of AmendmentStart.
1567 1568 1569 1570 1571 1572 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1567 def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @discount_end = discount_end @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
1559 1560 1561 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1559 def amendment_end @amendment_end end |
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1561 1562 1563 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1561 def discount_end @discount_end end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
1563 1564 1565 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1563 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
1565 1566 1567 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1565 def type @type end |