Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



1535
1536
1537
1538
1539
1540
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1535

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



1527
1528
1529
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1527

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



1529
1530
1531
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1529

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



1531
1532
1533
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1531

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



1533
1534
1535
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1533

def type
  @type
end