Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



1526
1527
1528
1529
1530
1531
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1526

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



1518
1519
1520
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1518

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



1520
1521
1522
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1520

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



1522
1523
1524
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1522

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



1524
1525
1526
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1524

def type
  @type
end