Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentEnd, DiscountEnd
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
constructor
A new instance of AmendmentStart.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
Returns a new instance of AmendmentStart.
1526 1527 1528 1529 1530 1531 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1526 def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @discount_end = discount_end @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
1518 1519 1520 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1518 def amendment_end @amendment_end end |
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
1520 1521 1522 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1520 def discount_end @discount_end end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
1522 1523 1524 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1522 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
1524 1525 1526 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1524 def type @type end |