Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::AmendmentStart::AmendmentEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin.
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(index: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
1504 1505 1506 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1504 def initialize(index: nil) @index = index end |
Instance Attribute Details
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.
1502 1503 1504 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1502 def index @index end |