Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1649 1650 1651 1652 1653 1654 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1649 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1641 1642 1643 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1641 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1643 1644 1645 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1643 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1645 1646 1647 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1645 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1647 1648 1649 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1647 def type @type end |