Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1617 1618 1619 1620 1621 1622 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1617 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1609 1610 1611 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1609 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1611 1612 1613 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1611 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1613 1614 1615 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1613 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1615 1616 1617 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1615 def type @type end |