Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1514 1515 1516 1517 1518 1519 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1514 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1506 1507 1508 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1506 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1508 1509 1510 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1508 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1510 1511 1512 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1510 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1512 1513 1514 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1512 def type @type end |