Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
1604 1605 1606 1607 1608 1609 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1604 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
1596 1597 1598 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1596 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
1598 1599 1600 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1598 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
1600 1601 1602 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1600 def set @set end |
#type ⇒ Object
Determines the type of discount action.
1602 1603 1604 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1602 def type @type end |