Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1596 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1586 1587 1588 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1586 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1588 1589 1590 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1588 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1590 1591 1592 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1590 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1592 1593 1594 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1592 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1594 1595 1596 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1594 def promotion_code @promotion_code end |