Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1564 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1554 1555 1556 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1554 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1556 1557 1558 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1556 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1558 1559 1560 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1558 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1560 1561 1562 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1560 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1562 1563 1564 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1562 def promotion_code @promotion_code end |