Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1555

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1545
1546
1547
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1545

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1547
1548
1549
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1547

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1549
1550
1551
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1549

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1551
1552
1553
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1551

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1553
1554
1555
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1553

def promotion_code
  @promotion_code
end