Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1465

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1455
1456
1457
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1455

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1457
1458
1459
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1457

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1459
1460
1461
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1459

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1461
1462
1463
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1461

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1463
1464
1465
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1463

def promotion_code
  @promotion_code
end