Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1461 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1451 1452 1453 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1451 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1453 1454 1455 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1453 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1455 1456 1457 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1455 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1457 1458 1459 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1457 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1459 1460 1461 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1459 def promotion_code @promotion_code end |