Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1778

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



1764
1765
1766
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1764

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



1767
1768
1769
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1767

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1770
1771
1772
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1770

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



1773
1774
1775
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1773

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



1776
1777
1778
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1776

def promotion_code
  @promotion_code
end