Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1551 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
1541 1542 1543 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1541 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
1543 1544 1545 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1543 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1545 1546 1547 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1545 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
1547 1548 1549 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1547 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
1549 1550 1551 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1549 def promotion_code @promotion_code end |