Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Remove
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Remove
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
-
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
-
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove
constructor
A new instance of Remove.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove
Returns a new instance of Remove.
1717 1718 1719 1720 1721 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1717 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
1711 1712 1713 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1711 def coupon @coupon end |
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
1713 1714 1715 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1713 def discount @discount end |
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
1715 1716 1717 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1715 def promotion_code @promotion_code end |