Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1484
1485
1486
1487
1488
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1484

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1478
1479
1480
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1478

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1480
1481
1482
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1480

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1482
1483
1484
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1482

def promotion_code
  @promotion_code
end