Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1574
1575
1576
1577
1578
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1574

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1568
1569
1570
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1568

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1570
1571
1572
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1570

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1572
1573
1574
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1572

def promotion_code
  @promotion_code
end