Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1803
1804
1805
1806
1807
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1803

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1795
1796
1797
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1795

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1798
1799
1800
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1798

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1801
1802
1803
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1801

def promotion_code
  @promotion_code
end