Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1634
1635
1636
1637
1638
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1634

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1628
1629
1630
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1628

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1630
1631
1632
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1630

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1632
1633
1634
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1632

def promotion_code
  @promotion_code
end