Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1602
1603
1604
1605
1606
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1602

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1596
1597
1598
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1596

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1598
1599
1600
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1598

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1600
1601
1602
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1600

def promotion_code
  @promotion_code
end