Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
Returns a new instance of Set.
1503 1504 1505 1506 1507 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1503 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
1497 1498 1499 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1497 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
1499 1500 1501 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1499 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
1501 1502 1503 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1501 def promotion_code @promotion_code end |