Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
Returns a new instance of Set.
1589 1590 1591 1592 1593 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1589 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
1583 1584 1585 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1583 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
1585 1586 1587 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1585 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
1587 1588 1589 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1587 def promotion_code @promotion_code end |