Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



1589
1590
1591
1592
1593
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1589

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



1583
1584
1585
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1583

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



1585
1586
1587
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1585

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



1587
1588
1589
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1587

def promotion_code
  @promotion_code
end