Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set
Returns a new instance of Set.
1820 1821 1822 1823 1824 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1820 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
1812 1813 1814 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1812 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
1815 1816 1817 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1815 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
1818 1819 1820 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1818 def promotion_code @promotion_code end |