Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the subscription item to add.
-
#remove ⇒ Object
Details of the subscription item to remove.
-
#set ⇒ Object
Details of the subscription item to replace the existing items with.
-
#type ⇒ Object
Determines the type of item action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
constructor
A new instance of ItemAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
Returns a new instance of ItemAction.
1710 1711 1712 1713 1714 1715 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1710 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.
1702 1703 1704 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1702 def add @add end |
#remove ⇒ Object
Details of the subscription item to remove.
1704 1705 1706 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1704 def remove @remove end |
#set ⇒ Object
Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.
1706 1707 1708 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1706 def set @set end |
#type ⇒ Object
Determines the type of item action.
1708 1709 1710 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1708 def type @type end |