Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



1710
1711
1712
1713
1714
1715
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1710

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



1702
1703
1704
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1702

def add
  @add
end

#removeObject

Details of the subscription item to remove.



1704
1705
1706
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1704

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



1706
1707
1708
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1706

def set
  @set
end

#typeObject

Determines the type of item action.



1708
1709
1710
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1708

def type
  @type
end