Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2061
2062
2063
2064
2065
2066
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2061

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2050
2051
2052
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2050

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2053
2054
2055
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2053

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2056
2057
2058
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2056

def set
  @set
end

#typeObject

Determines the type of item action.



2059
2060
2061
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2059

def type
  @type
end