Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1726 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1714 1715 1716 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1714 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1716 1717 1718 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1716 def @metadata end |
#price ⇒ Object
The ID of the price object.
1718 1719 1720 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1718 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1720 1721 1722 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1720 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1722 1723 1724 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1722 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1724 1725 1726 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1724 def trial @trial end |