Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1694 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1682 1683 1684 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1682 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1684 1685 1686 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1684 def @metadata end |
#price ⇒ Object
The ID of the price object.
1686 1687 1688 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1686 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1688 1689 1690 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1688 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1690 1691 1692 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1690 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1692 1693 1694 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1692 def trial @trial end |