Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1595 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1583 1584 1585 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1583 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1585 1586 1587 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1585 def @metadata end |
#price ⇒ Object
The ID of the price object.
1587 1588 1589 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1587 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1589 1590 1591 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1589 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1591 1592 1593 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1591 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1593 1594 1595 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1593 def trial @trial end |