Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1927

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



1910
1911
1912
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1910

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1913
1914
1915
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1913

def 
  @metadata
end

#priceObject

The ID of the price object.



1916
1917
1918
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1916

def price
  @price
end

#quantityObject

Quantity for this item.



1919
1920
1921
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1919

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



1922
1923
1924
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1922

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1925
1926
1927
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1925

def trial
  @trial
end