Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1681 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
1669 1670 1671 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1669 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1671 1672 1673 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1671 def @metadata end |
#price ⇒ Object
The ID of the price object.
1673 1674 1675 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1673 def price @price end |
#quantity ⇒ Object
Quantity for this item.
1675 1676 1677 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1675 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
1677 1678 1679 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1677 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1679 1680 1681 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1679 def trial @trial end |