Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1563
1564
1565
1566
1567
1568
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1563

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1555
1556
1557
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1555

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1557
1558
1559
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1557

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1559
1560
1561
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1559

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1561
1562
1563
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1561

def promotion_code
  @promotion_code
end