Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Set
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price.
-
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price.
-
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price.
-
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Set
Returns a new instance of Set.
1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1685 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.
1673 1674 1675 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1673 def discounts @discounts end |
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.
1675 1676 1677 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1675 def @metadata end |
#price ⇒ Object
The ID of the price object.
1677 1678 1679 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1677 def price @price end |
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.
1679 1680 1681 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1679 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.
1681 1682 1683 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1681 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.
1683 1684 1685 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1683 def trial @trial end |