Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1653
1654
1655
1656
1657
1658
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1653

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1645
1646
1647
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1645

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1647
1648
1649
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1647

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1649
1650
1651
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1649

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1651
1652
1653
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1651

def promotion_code
  @promotion_code
end