Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1773
1774
1775
1776
1777
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1773

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1767
1768
1769
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1767

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1769
1770
1771
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1769

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1771
1772
1773
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1771

def type
  @type
end