Class: Stripe::SubscriptionScheduleService::AmendParams::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1977
1978
1979
1980
1981
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1977

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1969
1970
1971
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1969

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1972
1973
1974
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1972

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1975
1976
1977
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1975

def type
  @type
end