Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



1970
1971
1972
1973
1974
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1970

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



1964
1965
1966
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1964

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1966
1967
1968
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1966

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



1968
1969
1970
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1968

def type
  @type
end