Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



1938
1939
1940
1941
1942
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1938

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



1932
1933
1934
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1932

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1934
1935
1936
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1934

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



1936
1937
1938
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1936

def type
  @type
end