Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



1839
1840
1841
1842
1843
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1839

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



1833
1834
1835
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1833

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1835
1836
1837
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1835

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



1837
1838
1839
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1837

def type
  @type
end