Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentStart
Instance Attribute Summary collapse
-
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
-
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
Instance Method Summary collapse
-
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
constructor
A new instance of BillFrom.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom
Returns a new instance of BillFrom.
1839 1840 1841 1842 1843 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1839 def initialize(amendment_start: nil, timestamp: nil, type: nil) @amendment_start = amendment_start @timestamp = @type = type end |
Instance Attribute Details
#amendment_start ⇒ Object
Start the prebilled period when a specified amendment begins.
1833 1834 1835 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1833 def amendment_start @amendment_start end |
#timestamp ⇒ Object
Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.
1835 1836 1837 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1835 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_from` value.
1837 1838 1839 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1837 def type @type end |