Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



1835
1836
1837
1838
1839
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1835

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



1829
1830
1831
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1829

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1831
1832
1833
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1831

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



1833
1834
1835
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1833

def type
  @type
end