Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



1925
1926
1927
1928
1929
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1925

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



1919
1920
1921
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1919

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1921
1922
1923
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1921

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



1923
1924
1925
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1923

def type
  @type
end