Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillFrom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_start: nil, timestamp: nil, type: nil) ⇒ BillFrom

Returns a new instance of BillFrom.



2201
2202
2203
2204
2205
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2201

def initialize(amendment_start: nil, timestamp: nil, type: nil)
  @amendment_start = amendment_start
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_startObject

Start the prebilled period when a specified amendment begins.



2193
2194
2195
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2193

def amendment_start
  @amendment_start
end

#timestampObject

Start the prebilled period at a precise integer timestamp, starting from the Unix epoch.



2196
2197
2198
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2196

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_from` value.



2199
2200
2201
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2199

def type
  @type
end