Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1975
1976
1977
1978
1979
1980
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1975

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1967
1968
1969
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1967

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1969
1970
1971
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1969

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1971
1972
1973
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1971

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1973
1974
1975
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1973

def type
  @type
end