Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1975 1976 1977 1978 1979 1980 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1975 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
1967 1968 1969 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1967 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
1969 1970 1971 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1969 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
1971 1972 1973 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1971 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
1973 1974 1975 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1973 def type @type end |