Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1966
1967
1968
1969
1970
1971
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1966

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1958
1959
1960
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1958

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1960
1961
1962
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1960

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1962
1963
1964
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1962

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1964
1965
1966
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1964

def type
  @type
end