Class: Stripe::SubscriptionScheduleService::AmendParams::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1876
1877
1878
1879
1880
1881
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1876

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1868
1869
1870
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1868

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1870
1871
1872
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1870

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1872
1873
1874
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1872

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1874
1875
1876
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1874

def type
  @type
end