Class: Stripe::SubscriptionScheduleService::AmendParams::ScheduleSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::AmendParams::ScheduleSettings
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ ScheduleSettings
constructor
A new instance of ScheduleSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ ScheduleSettings
Returns a new instance of ScheduleSettings.
2003 2004 2005 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2003 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
2001 2002 2003 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2001 def end_behavior @end_behavior end |