Class: Stripe::SubscriptionScheduleService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CancelParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
1282 1283 1284 1285 1286 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1282 def initialize(expand: nil, invoice_now: nil, prorate: nil) @expand = @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1276 1277 1278 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1276 def @expand end |
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.
1278 1279 1280 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1278 def invoice_now @invoice_now end |
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.
1280 1281 1282 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1280 def prorate @prorate end |