Class: Stripe::SubscriptionScheduleService::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



1184
1185
1186
1187
1188
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1184

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1178
1179
1180
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1178

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



1180
1181
1182
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1180

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



1182
1183
1184
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1182

def prorate
  @prorate
end