Class: Stripe::SubscriptionScheduleService::CancelParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams

Returns a new instance of CancelParams.



2033
2034
2035
2036
2037
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2033

def initialize(expand: nil, invoice_now: nil, prorate: nil)
  @expand = expand
  @invoice_now = invoice_now
  @prorate = prorate
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2027
2028
2029
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2027

def expand
  @expand
end

#invoice_nowObject

If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.



2029
2030
2031
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2029

def invoice_now
  @invoice_now
end

#prorateObject

If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.



2031
2032
2033
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2031

def prorate
  @prorate
end