Class: Stripe::SubscriptionScheduleService::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CancelParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items.
-
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_now: nil, prorate: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
1939 1940 1941 1942 1943 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1939 def initialize(expand: nil, invoice_now: nil, prorate: nil) @expand = @invoice_now = invoice_now @prorate = prorate end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1933 1934 1935 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1933 def @expand end |
#invoice_now ⇒ Object
If the subscription schedule is ‘active`, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to `true`.
1935 1936 1937 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1935 def invoice_now @invoice_now end |
#prorate ⇒ Object
If the subscription schedule is ‘active`, indicates if the cancellation should be prorated. Defaults to `true`.
1937 1938 1939 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1937 def prorate @prorate end |