Class: Stripe::SubscriptionScheduleService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: BillingMode, DefaultSettings, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, customer: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/stripe/services/subscription_schedule_service.rb', line 615

def initialize(
  billing_mode: nil,
  customer: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  start_date: nil
)
  @billing_mode = billing_mode
  @customer = customer
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @start_date = start_date
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



597
598
599
# File 'lib/stripe/services/subscription_schedule_service.rb', line 597

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



599
600
601
# File 'lib/stripe/services/subscription_schedule_service.rb', line 599

def customer
  @customer
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



601
602
603
# File 'lib/stripe/services/subscription_schedule_service.rb', line 601

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



603
604
605
# File 'lib/stripe/services/subscription_schedule_service.rb', line 603

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



605
606
607
# File 'lib/stripe/services/subscription_schedule_service.rb', line 605

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



607
608
609
# File 'lib/stripe/services/subscription_schedule_service.rb', line 607

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



609
610
611
# File 'lib/stripe/services/subscription_schedule_service.rb', line 609

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



611
612
613
# File 'lib/stripe/services/subscription_schedule_service.rb', line 611

def phases
  @phases
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



613
614
615
# File 'lib/stripe/services/subscription_schedule_service.rb', line 613

def start_date
  @start_date
end