Class: Stripe::SubscriptionScheduleService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, billing_mode: nil, customer: nil, customer_account: nil, default_settings: nil, end_behavior: nil, expand: nil, from_subscription: nil, metadata: nil, phases: nil, prebilling: nil, start_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/stripe/services/subscription_schedule_service.rb', line 721

def initialize(
  billing_behavior: nil,
  billing_mode: nil,
  customer: nil,
  customer_account: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  from_subscription: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  start_date: nil
)
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @customer = customer
  @customer_account = 
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @from_subscription = from_subscription
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @start_date = start_date
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



697
698
699
# File 'lib/stripe/services/subscription_schedule_service.rb', line 697

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Configure billing_mode to opt in improved credit proration behavior.When the schedule creates a subscription, the subscription’s ‘billing_mode` will be set to the same value as the schedule’s ‘billing_mode`.



699
700
701
# File 'lib/stripe/services/subscription_schedule_service.rb', line 699

def billing_mode
  @billing_mode
end

#customerObject

The identifier of the customer to create the subscription schedule for.



701
702
703
# File 'lib/stripe/services/subscription_schedule_service.rb', line 701

def customer
  @customer
end

#customer_accountObject

The identifier of the account to create the subscription schedule for.



703
704
705
# File 'lib/stripe/services/subscription_schedule_service.rb', line 703

def 
  @customer_account
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



705
706
707
# File 'lib/stripe/services/subscription_schedule_service.rb', line 705

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



707
708
709
# File 'lib/stripe/services/subscription_schedule_service.rb', line 707

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



709
710
711
# File 'lib/stripe/services/subscription_schedule_service.rb', line 709

def expand
  @expand
end

#from_subscriptionObject

Migrate an existing subscription to be managed by a subscription schedule. If this parameter is set, a subscription schedule will be created using the subscription’s item(s), set to auto-renew using the subscription’s interval. When using this parameter, other parameters (such as phase values) cannot be set. To create a subscription schedule with other modifications, we recommend making two separate API calls.



711
712
713
# File 'lib/stripe/services/subscription_schedule_service.rb', line 711

def from_subscription
  @from_subscription
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



713
714
715
# File 'lib/stripe/services/subscription_schedule_service.rb', line 713

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



715
716
717
# File 'lib/stripe/services/subscription_schedule_service.rb', line 715

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



717
718
719
# File 'lib/stripe/services/subscription_schedule_service.rb', line 717

def prebilling
  @prebilling
end

#start_dateObject

When the subscription schedule starts. We recommend using ‘now` so that it starts the subscription immediately. You can also use a Unix timestamp to backdate the subscription so that it starts on a past date, or set a future date for the subscription to start on.



719
720
721
# File 'lib/stripe/services/subscription_schedule_service.rb', line 719

def start_date
  @start_date
end