Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/stripe/services/subscription_schedule_service.rb', line 346

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



332
333
334
# File 'lib/stripe/services/subscription_schedule_service.rb', line 332

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



334
335
336
# File 'lib/stripe/services/subscription_schedule_service.rb', line 334

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



336
337
338
# File 'lib/stripe/services/subscription_schedule_service.rb', line 336

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



338
339
340
# File 'lib/stripe/services/subscription_schedule_service.rb', line 338

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



340
341
342
# File 'lib/stripe/services/subscription_schedule_service.rb', line 340

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



342
343
344
# File 'lib/stripe/services/subscription_schedule_service.rb', line 342

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



344
345
346
# File 'lib/stripe/services/subscription_schedule_service.rb', line 344

def tax_rates
  @tax_rates
end