Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



279
280
281
282
283
# File 'lib/stripe/services/subscription_schedule_service.rb', line 279

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



273
274
275
# File 'lib/stripe/services/subscription_schedule_service.rb', line 273

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



275
276
277
# File 'lib/stripe/services/subscription_schedule_service.rb', line 275

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



277
278
279
# File 'lib/stripe/services/subscription_schedule_service.rb', line 277

def type
  @type
end