Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



254
255
256
257
258
# File 'lib/stripe/services/subscription_schedule_service.rb', line 254

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



248
249
250
# File 'lib/stripe/services/subscription_schedule_service.rb', line 248

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



250
251
252
# File 'lib/stripe/services/subscription_schedule_service.rb', line 250

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



252
253
254
# File 'lib/stripe/services/subscription_schedule_service.rb', line 252

def type
  @type
end