Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
309 310 311 312 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 309 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
305 306 307 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 305 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
307 308 309 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 307 def type @type end |