Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
277 278 279 280 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 277 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
273 274 275 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 273 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
275 276 277 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 275 def type @type end |