Class: Stripe::SubscriptionScheduleService::CreateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::CreateParams::Phase::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
418 419 420 421 422 423 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 418 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
410 411 412 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 410 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
412 413 414 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 412 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
414 415 416 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 414 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
416 417 418 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 416 def promotion_code @promotion_code end |