Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



1295
1296
1297
1298
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1295

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1291
1292
1293
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1291

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



1293
1294
1295
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1293

def preserve_cancel_date
  @preserve_cancel_date
end