Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



1197
1198
1199
1200
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1197

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1193
1194
1195
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1193

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



1195
1196
1197
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1195

def preserve_cancel_date
  @preserve_cancel_date
end