Class: Stripe::SubscriptionScheduleService::ReleaseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::ReleaseParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set.
Instance Method Summary collapse
-
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
constructor
A new instance of ReleaseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
Returns a new instance of ReleaseParams.
2055 2056 2057 2058 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2055 def initialize(expand: nil, preserve_cancel_date: nil) @expand = @preserve_cancel_date = preserve_cancel_date end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2051 2052 2053 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2051 def @expand end |
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set
2053 2054 2055 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2053 def preserve_cancel_date @preserve_cancel_date end |