Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



2046
2047
2048
2049
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2046

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2042
2043
2044
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2042

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



2044
2045
2046
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2044

def preserve_cancel_date
  @preserve_cancel_date
end