Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



1152
1153
1154
1155
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1152

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1148
1149
1150
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1148

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



1150
1151
1152
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1150

def preserve_cancel_date
  @preserve_cancel_date
end