Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



1062
1063
1064
1065
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1062

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1058
1059
1060
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1058

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



1060
1061
1062
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1060

def preserve_cancel_date
  @preserve_cancel_date
end