Class: Stripe::SubscriptionScheduleService::ReleaseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::ReleaseParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set.
Instance Method Summary collapse
-
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
constructor
A new instance of ReleaseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
Returns a new instance of ReleaseParams.
1062 1063 1064 1065 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1062 def initialize(expand: nil, preserve_cancel_date: nil) @expand = @preserve_cancel_date = preserve_cancel_date end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1058 1059 1060 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1058 def @expand end |
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set
1060 1061 1062 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1060 def preserve_cancel_date @preserve_cancel_date end |