Class: Stripe::SubscriptionScheduleService::ReleaseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams

Returns a new instance of ReleaseParams.



2332
2333
2334
2335
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2332

def initialize(expand: nil, preserve_cancel_date: nil)
  @expand = expand
  @preserve_cancel_date = preserve_cancel_date
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2327
2328
2329
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2327

def expand
  @expand
end

#preserve_cancel_dateObject

Keep any cancellation on the subscription that the schedule has set



2330
2331
2332
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2330

def preserve_cancel_date
  @preserve_cancel_date
end