Class: Stripe::SubscriptionScheduleService::ReleaseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::ReleaseParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set.
Instance Method Summary collapse
-
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
constructor
A new instance of ReleaseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, preserve_cancel_date: nil) ⇒ ReleaseParams
Returns a new instance of ReleaseParams.
2332 2333 2334 2335 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2332 def initialize(expand: nil, preserve_cancel_date: nil) @expand = @preserve_cancel_date = preserve_cancel_date end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2327 2328 2329 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2327 def @expand end |
#preserve_cancel_date ⇒ Object
Keep any cancellation on the subscription that the schedule has set
2330 2331 2332 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 2330 def preserve_cancel_date @preserve_cancel_date end |