Class: Stripe::SubscriptionScheduleService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1479

def initialize(
  billing_behavior: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  proration_behavior: nil
)
  @billing_behavior = billing_behavior
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1463
1464
1465
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1463

def billing_behavior
  @billing_behavior
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



1465
1466
1467
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1465

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1467
1468
1469
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1467

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1469
1470
1471
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1469

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1471
1472
1473
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1471

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1473
1474
1475
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1473

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1475
1476
1477
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1475

def prebilling
  @prebilling
end

#proration_behaviorObject

If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.



1477
1478
1479
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1477

def proration_behavior
  @proration_behavior
end