Class: Stripe::SubscriptionScheduleService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: DefaultSettings, Phase

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, proration_behavior: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1024

def initialize(
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  proration_behavior: nil
)
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#default_settingsObject

Object representing the subscription schedule’s default settings.



1012
1013
1014
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1012

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1014
1015
1016
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1014

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



1016
1017
1018
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1016

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1018
1019
1020
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1018

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



1020
1021
1022
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1020

def phases
  @phases
end

#proration_behaviorObject

If the update changes the current phase, indicates whether the changes should be prorated. The default value is ‘create_prorations`.



1022
1023
1024
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1022

def proration_behavior
  @proration_behavior
end