Class: Stripe::SubscriptionScheduleService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DefaultSettings, Phase, Prebilling
Instance Attribute Summary collapse
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#proration_behavior ⇒ Object
If the update changes the current phase, indicates whether the changes should be prorated.
Instance Method Summary collapse
-
#initialize(billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1650 def initialize( billing_behavior: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil ) @billing_behavior = billing_behavior @default_settings = default_settings @end_behavior = end_behavior @expand = @metadata = @phases = phases @prebilling = prebilling @proration_behavior = proration_behavior end |
Instance Attribute Details
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
1627 1628 1629 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1627 def billing_behavior @billing_behavior end |
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
1630 1631 1632 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1630 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
1633 1634 1635 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1633 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1636 1637 1638 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1636 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1639 1640 1641 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1639 def @metadata end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.
1642 1643 1644 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1642 def phases @phases end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
1645 1646 1647 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1645 def prebilling @prebilling end |
#proration_behavior ⇒ Object
If the update changes the current phase, indicates whether the changes should be prorated. The default value is ‘create_prorations`.
1648 1649 1650 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1648 def proration_behavior @proration_behavior end |