Class: Stripe::SubscriptionScheduleService::UpdateParams::DefaultSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::DefaultSettings
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: AutomaticTax, InvoiceSettings, TransferData
Instance Attribute Summary collapse
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Default settings for automatic tax computation.
-
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
Instance Method Summary collapse
-
#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings
constructor
A new instance of DefaultSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil) ⇒ DefaultSettings
Returns a new instance of DefaultSettings.
840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 840 def initialize( application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, collection_method: nil, default_payment_method: nil, description: nil, invoice_settings: nil, on_behalf_of: nil, transfer_data: nil ) @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @collection_method = collection_method @default_payment_method = default_payment_method @description = description @invoice_settings = invoice_settings @on_behalf_of = on_behalf_of @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
822 823 824 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 822 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Default settings for automatic tax computation.
824 825 826 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 824 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
826 827 828 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 826 def billing_cycle_anchor @billing_cycle_anchor end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.
828 829 830 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 828 def collection_method @collection_method end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.
830 831 832 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 830 def default_payment_method @default_payment_method end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
832 833 834 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 832 def description @description end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
834 835 836 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 834 def invoice_settings @invoice_settings end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
836 837 838 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 836 def on_behalf_of @on_behalf_of end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
838 839 840 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 838 def transfer_data @transfer_data end |