Class: Stripe::SubscriptionScheduleService::UpdateParams::DefaultSettings::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::DefaultSettings::AutomaticTax
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
936 937 938 939 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 936 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
931 932 933 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 931 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
934 935 936 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 934 def liability @liability end |