Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 925 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
911 912 913 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 911 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
913 914 915 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 913 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.
915 916 917 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 915 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
917 918 919 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 917 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
919 920 921 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 919 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
921 922 923 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 921 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
923 924 925 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 923 def tax_rates @tax_rates end |