Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
821 822 823 824 825 826 827 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 821 def initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
811 812 813 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 811 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
813 814 815 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 813 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
815 816 817 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 815 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
817 818 819 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 817 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
819 820 821 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 819 def tax_rates @tax_rates end |