Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



971
972
973
974
975
# File 'lib/stripe/services/subscription_schedule_service.rb', line 971

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



965
966
967
# File 'lib/stripe/services/subscription_schedule_service.rb', line 965

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



967
968
969
# File 'lib/stripe/services/subscription_schedule_service.rb', line 967

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



969
970
971
# File 'lib/stripe/services/subscription_schedule_service.rb', line 969

def type
  @type
end