Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



955
956
957
958
959
# File 'lib/stripe/services/subscription_schedule_service.rb', line 955

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



949
950
951
# File 'lib/stripe/services/subscription_schedule_service.rb', line 949

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



951
952
953
# File 'lib/stripe/services/subscription_schedule_service.rb', line 951

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



953
954
955
# File 'lib/stripe/services/subscription_schedule_service.rb', line 953

def type
  @type
end