Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



881
882
883
884
885
# File 'lib/stripe/services/subscription_schedule_service.rb', line 881

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



875
876
877
# File 'lib/stripe/services/subscription_schedule_service.rb', line 875

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



877
878
879
# File 'lib/stripe/services/subscription_schedule_service.rb', line 877

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



879
880
881
# File 'lib/stripe/services/subscription_schedule_service.rb', line 879

def type
  @type
end