Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



856
857
858
859
# File 'lib/stripe/services/subscription_schedule_service.rb', line 856

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



852
853
854
# File 'lib/stripe/services/subscription_schedule_service.rb', line 852

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



854
855
856
# File 'lib/stripe/services/subscription_schedule_service.rb', line 854

def type
  @type
end