Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
1062 1063 1064 1065 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1062 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
1058 1059 1060 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1058 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
1060 1061 1062 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1060 def type @type end |