Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
868 869 870 871 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 868 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
864 865 866 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 864 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
866 867 868 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 866 def type @type end |