Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



847
848
849
850
# File 'lib/stripe/services/subscription_schedule_service.rb', line 847

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



843
844
845
# File 'lib/stripe/services/subscription_schedule_service.rb', line 843

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



845
846
847
# File 'lib/stripe/services/subscription_schedule_service.rb', line 845

def liability
  @liability
end