Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1070 1071 1072 1073 1074 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1070 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1064 1065 1066 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1064 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1066 1067 1068 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1066 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1068 1069 1070 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1068 def type @type end |