Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
997 998 999 1000 1001 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 997 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
991 992 993 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 991 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
993 994 995 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 993 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
995 996 997 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 995 def type @type end |