Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



993
994
995
996
997
# File 'lib/stripe/services/subscription_schedule_service.rb', line 993

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



987
988
989
# File 'lib/stripe/services/subscription_schedule_service.rb', line 987

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



989
990
991
# File 'lib/stripe/services/subscription_schedule_service.rb', line 989

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



991
992
993
# File 'lib/stripe/services/subscription_schedule_service.rb', line 991

def type
  @type
end