Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1115

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1099
1100
1101
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1099

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1101
1102
1103
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1101

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



1103
1104
1105
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1103

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



1105
1106
1107
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1105

def plan
  @plan
end

#priceObject

The ID of the price object.



1107
1108
1109
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1107

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1109
1110
1111
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1109

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



1111
1112
1113
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1111

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1113
1114
1115
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1113

def tax_rates
  @tax_rates
end