Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1017

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1001
1002
1003
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1001

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1003
1004
1005
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1003

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



1005
1006
1007
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1005

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



1007
1008
1009
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1007

def plan
  @plan
end

#priceObject

The ID of the price object.



1009
1010
1011
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1009

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1011
1012
1013
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1011

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



1013
1014
1015
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1013

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1015
1016
1017
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1015

def tax_rates
  @tax_rates
end