Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1173 1174 1175 1176 1177 1178 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1173 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1165 1166 1167 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1165 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1167 1168 1169 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1167 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1169 1170 1171 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1169 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1171 1172 1173 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1171 def promotion_code @promotion_code end |