Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
911 912 913 914 915 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 911 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
905 906 907 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 905 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
907 908 909 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 907 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
909 910 911 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 909 def promotion_code @promotion_code end |