Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1156 1157 1158 1159 1160 1161 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1156 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1148 1149 1150 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1148 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1150 1151 1152 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1150 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1152 1153 1154 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1152 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1154 1155 1156 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1154 def promotion_code @promotion_code end |