Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1142
1143
1144
1145
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1142

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1138
1139
1140
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1138

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1140
1141
1142
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1140

def destination
  @destination
end