Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1319 1320 1321 1322 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1319 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1315 1316 1317 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1315 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1317 1318 1319 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1317 def destination @destination end |