Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1044
1045
1046
1047
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1044

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1040
1041
1042
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1040

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1042
1043
1044
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1042

def destination
  @destination
end