Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData
- Defined in:
- lib/stripe/services/subscription_schedule_service.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1291 1292 1293 1294 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1291 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1287 1288 1289 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1287 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1289 1290 1291 |
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1289 def destination @destination end |