Class: Stripe::SubscriptionScheduleService::UpdateParams::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_schedule_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1196
1197
1198
1199
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1196

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1192
1193
1194
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1192

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1194
1195
1196
# File 'lib/stripe/services/subscription_schedule_service.rb', line 1194

def destination
  @destination
end