Class: Stripe::SubscriptionScheduleUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: BillingSchedule, DefaultSettings, PauseSchedule, Phase, Prebilling
Instance Attribute Summary collapse
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription schedule.
-
#default_settings ⇒ Object
Object representing the subscription schedule's default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#pause_schedules ⇒ Object
Configures the subscription's pause behavior and, optionally, its resume behavior.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#proration_behavior ⇒ Object
If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, pause_schedules: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ SubscriptionScheduleUpdateParams
constructor
A new instance of SubscriptionScheduleUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, pause_schedules: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ SubscriptionScheduleUpdateParams
Returns a new instance of SubscriptionScheduleUpdateParams.
1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1103 def initialize( billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, pause_schedules: nil, phases: nil, prebilling: nil, proration_behavior: nil ) @billing_behavior = billing_behavior @billing_schedules = billing_schedules @default_settings = default_settings @end_behavior = end_behavior @expand = @metadata = @pause_schedules = pause_schedules @phases = phases @prebilling = prebilling @proration_behavior = proration_behavior end |
Instance Attribute Details
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are prorate_on_next_phase or prorate_up_front with the default being prorate_on_next_phase. prorate_on_next_phase will apply phase changes and generate prorations at transition time. prorate_up_front will bill for all phases within the current billing cycle up front.
1083 1084 1085 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1083 def billing_behavior @billing_behavior end |
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription schedule.
1085 1086 1087 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1085 def billing_schedules @billing_schedules end |
#default_settings ⇒ Object
Object representing the subscription schedule's default settings.
1087 1088 1089 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1087 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are release or cancel with the default being release. release will end the subscription schedule and keep the underlying subscription running. cancel will end the subscription schedule and cancel the underlying subscription.
1089 1090 1091 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1089 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1091 1092 1093 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1091 def @expand end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
1093 1094 1095 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1093 def @metadata end |
#pause_schedules ⇒ Object
Configures the subscription's pause behavior and, optionally, its resume behavior. Only one entry is supported. Include a key to update an existing entry. Omit to leave an existing pause schedule unchanged, or pass "" to clear it.
1095 1096 1097 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1095 def pause_schedules @pause_schedules end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the end_date of one phase will always equal the start_date of the next phase. Note that past phases can be omitted.
1097 1098 1099 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1097 def phases @phases end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
1099 1100 1101 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1099 def prebilling @prebilling end |
#proration_behavior ⇒ Object
If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is create_prorations.
1101 1102 1103 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1101 def proration_behavior @proration_behavior end |
Class Method Details
.field_encodings ⇒ Object
1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 1127 def self.field_encodings @field_encodings = { phases: { kind: :array, element: { kind: :object, fields: { add_invoice_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, }, }, }, items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, }, }, }, }, }, }, } end |