Class: Stripe::SubscriptionScheduleUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: BillingSchedule, DefaultSettings, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ SubscriptionScheduleUpdateParams

Returns a new instance of SubscriptionScheduleUpdateParams.



870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 870

def initialize(
  billing_behavior: nil,
  billing_schedules: nil,
  default_settings: nil,
  end_behavior: nil,
  expand: nil,
  metadata: nil,
  phases: nil,
  prebilling: nil,
  proration_behavior: nil
)
  @billing_behavior = billing_behavior
  @billing_schedules = billing_schedules
  @default_settings = default_settings
  @end_behavior = end_behavior
  @expand = expand
  @metadata = 
  @phases = phases
  @prebilling = prebilling
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



852
853
854
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 852

def billing_behavior
  @billing_behavior
end

#billing_schedulesObject

Sets the billing schedules for the subscription schedule.



854
855
856
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 854

def billing_schedules
  @billing_schedules
end

#default_settingsObject

Object representing the subscription schedule’s default settings.



856
857
858
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 856

def default_settings
  @default_settings
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



858
859
860
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 858

def end_behavior
  @end_behavior
end

#expandObject

Specifies which fields in the response should be expanded.



860
861
862
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 860

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



862
863
864
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 862

def 
  @metadata
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.



864
865
866
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 864

def phases
  @phases
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



866
867
868
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 866

def prebilling
  @prebilling
end

#proration_behaviorObject

If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.



868
869
870
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 868

def proration_behavior
  @proration_behavior
end