Class: Stripe::SubscriptionScheduleUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: BillingSchedule, DefaultSettings, Phase, Prebilling
Instance Attribute Summary collapse
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription schedule.
-
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#proration_behavior ⇒ Object
If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled.
Instance Method Summary collapse
-
#initialize(billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ SubscriptionScheduleUpdateParams
constructor
A new instance of SubscriptionScheduleUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ SubscriptionScheduleUpdateParams
Returns a new instance of SubscriptionScheduleUpdateParams.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 766 def initialize( billing_behavior: nil, billing_schedules: nil, default_settings: nil, end_behavior: nil, expand: nil, metadata: nil, phases: nil, prebilling: nil, proration_behavior: nil ) @billing_behavior = billing_behavior @billing_schedules = billing_schedules @default_settings = default_settings @end_behavior = end_behavior @expand = @metadata = @phases = phases @prebilling = prebilling @proration_behavior = proration_behavior end |
Instance Attribute Details
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
748 749 750 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 748 def billing_behavior @billing_behavior end |
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription schedule.
750 751 752 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 750 def billing_schedules @billing_schedules end |
#default_settings ⇒ Object
Object representing the subscription schedule’s default settings.
752 753 754 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 752 def default_settings @default_settings end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
754 755 756 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 754 def end_behavior @end_behavior end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
756 757 758 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 756 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
758 759 760 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 758 def @metadata end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase. Note that past phases can be omitted.
760 761 762 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 760 def phases @phases end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
762 763 764 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 762 def prebilling @prebilling end |
#proration_behavior ⇒ Object
If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value is ‘create_prorations`.
764 765 766 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 764 def proration_behavior @proration_behavior end |