Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::PauseAt

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ PauseAt

Returns a new instance of PauseAt.



217
218
219
220
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 217

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

The Unix timestamp at which to pause the subscription. Required when type is timestamp.



213
214
215
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 213

def timestamp
  @timestamp
end

#typeObject

When to pause the subscription. Use now to pause immediately or timestamp to pause at a specific time.



215
216
217
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 215

def type
  @type
end