Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::PauseAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::PauseAt
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The Unix timestamp at which to pause the subscription.
-
#type ⇒ Object
When to pause the subscription.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ PauseAt
constructor
A new instance of PauseAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ PauseAt
Returns a new instance of PauseAt.
217 218 219 220 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 217 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The Unix timestamp at which to pause the subscription. Required when type is timestamp.
213 214 215 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 213 def @timestamp end |
#type ⇒ Object
When to pause the subscription. Use now to pause immediately or timestamp to pause at a specific time.
215 216 217 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 215 def type @type end |