Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::Settings
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: BillFor
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
-
#invoicing_behavior ⇒ Object
Determines whether to generate an invoice for outstanding amounts when pausing.
-
#type ⇒ Object
The pause type.
Instance Method Summary collapse
-
#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Settings
Returns a new instance of Settings.
259 260 261 262 263 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 259 def initialize(bill_for: nil, invoicing_behavior: nil, type: nil) @bill_for = bill_for @invoicing_behavior = invoicing_behavior @type = type end |
Instance Attribute Details
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
253 254 255 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 253 def bill_for @bill_for end |
#invoicing_behavior ⇒ Object
Determines whether to generate an invoice for outstanding amounts when pausing.
255 256 257 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 255 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object
The pause type. Currently only subscription is supported.
257 258 259 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 257 def type @type end |