Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::Settings::BillFor::OutstandingUsageThrough
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Pause::Settings::BillFor::OutstandingUsageThrough
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Determines whether to collect metered usage accrued up to the pause date.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ OutstandingUsageThrough
constructor
A new instance of OutstandingUsageThrough.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(type: nil) ⇒ OutstandingUsageThrough
Returns a new instance of OutstandingUsageThrough.
173 174 175 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 173 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Determines whether to collect metered usage accrued up to the pause date. When adding a pause schedule, defaults to pause_at. On updates, the existing value is preserved if not provided.
171 172 173 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 171 def type @type end |