Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Resume::ResumeAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Resume::ResumeAt
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
The duration after which to resume the subscription.
-
#timestamp ⇒ Object
The Unix timestamp at which to resume the subscription.
-
#type ⇒ Object
When to resume the subscription.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ ResumeAt
constructor
A new instance of ResumeAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ ResumeAt
Returns a new instance of ResumeAt.
296 297 298 299 300 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 296 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
The duration after which to resume the subscription. Required when type is duration.
290 291 292 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 290 def duration @duration end |
#timestamp ⇒ Object
The Unix timestamp at which to resume the subscription. Required when type is timestamp.
292 293 294 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 292 def @timestamp end |
#type ⇒ Object
When to resume the subscription. Use now to resume immediately, duration to resume after a set duration, or timestamp to resume at a specific time.
294 295 296 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 294 def type @type end |