Class: Stripe::SubscriptionScheduleUpdateParams::PauseSchedule::Resume::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_cycle_anchor: nil, payment_behavior: nil, proration_behavior: nil) ⇒ Settings

Returns a new instance of Settings.



311
312
313
314
315
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 311

def initialize(billing_cycle_anchor: nil, payment_behavior: nil, proration_behavior: nil)
  @billing_cycle_anchor = billing_cycle_anchor
  @payment_behavior = payment_behavior
  @proration_behavior = proration_behavior
end

Instance Attribute Details

#billing_cycle_anchorObject

Controls the billing cycle anchor when the subscription resumes.



305
306
307
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 305

def billing_cycle_anchor
  @billing_cycle_anchor
end

#payment_behaviorObject

Controls whether Stripe attempts payment on the resumption invoice and how payment affects the subscription's status. The default is resume_on_payment_success.



307
308
309
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 307

def payment_behavior
  @payment_behavior
end

#proration_behaviorObject

Determines how to handle prorations when the subscription resumes. The default is create_prorations.



309
310
311
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 309

def proration_behavior
  @proration_behavior
end