Class: Stripe::SubscriptionScheduleUpdateParams::Phase
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, Duration, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
-
#billing_cycle_anchor ⇒ Object
Can be set to
phase_startto set the anchor to the start of the phase orautomaticto automatically change it if needed. -
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
Either
charge_automatically, orsend_invoice. -
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#default_tax_rates ⇒ Object
A list of Tax Rate ids.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase.
-
#duration ⇒ Object
The number of intervals the phase should last.
-
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a phase.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription's invoices.
-
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused.
-
#proration_behavior ⇒ Object
Controls whether the subscription schedule should create prorations when transitioning to this phase if there is a difference in billing configuration.
-
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or
now. -
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription's invoices.
-
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
-
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries.
-
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, end_date: nil, invoice_settings: nil, items: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase
Returns a new instance of Phase.
701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 701 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, end_date: nil, invoice_settings: nil, items: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_thresholds = billing_thresholds @collection_method = collection_method @currency = currency @default_payment_method = default_payment_method @default_tax_rates = default_tax_rates @description = description @discounts = discounts @duration = duration @end_date = end_date @invoice_settings = invoice_settings @items = items @metadata = @on_behalf_of = on_behalf_of @pause_collection = pause_collection @proration_behavior = proration_behavior @start_date = start_date @transfer_data = transfer_data @trial = trial @trial_continuation = trial_continuation @trial_end = trial_end @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.
651 652 653 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 651 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees documentation.
653 654 655 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 653 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
655 656 657 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 655 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to phase_start to set the anchor to the start of the phase or automatic to automatically change it if needed. Cannot be set to phase_start if this phase specifies a trial. For more information, see the billing cycle documentation.
657 658 659 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 657 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
659 660 661 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 659 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object
Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically on creation.
661 662 663 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 661 def collection_method @collection_method end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
663 664 665 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 663 def currency @currency end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer's invoice settings.
665 666 667 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 665 def default_payment_method @default_payment_method end |
#default_tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will set the Subscription's default_tax_rates, which means they will be the Invoice's default_tax_rates for any Invoices issued by the Subscription during this Phase.
667 668 669 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 667 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
669 670 671 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 669 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription's customer. Pass an empty string to avoid inheriting any discounts.
671 672 673 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 671 def discounts @discounts end |
#duration ⇒ Object
The number of intervals the phase should last. If set, end_date must not be set.
673 674 675 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 673 def duration @duration end |
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends. If set, duration must not be set.
675 676 677 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 675 def end_date @end_date end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
677 678 679 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 677 def invoice_settings @invoice_settings end |
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
679 680 681 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 679 def items @items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a phase. Metadata on a schedule's phase will update the underlying subscription's metadata when the phase is entered, adding new keys and replacing existing keys in the subscription's metadata. Individual keys in the subscription's metadata can be unset by posting an empty value to them in the phase's metadata. To unset all keys in the subscription's metadata, update the subscription directly or unset every key individually from the phase's metadata.
681 682 683 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 681 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription's invoices.
683 684 685 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 683 def on_behalf_of @on_behalf_of end |
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to paused. Learn more about pausing collection.
685 686 687 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 685 def pause_collection @pause_collection end |
#proration_behavior ⇒ Object
Controls whether the subscription schedule should create prorations when transitioning to this phase if there is a difference in billing configuration. It's different from the request-level proration_behavior parameter which controls what happens if the update request affects the billing configuration (item price, quantity, etc.) of the current phase.
687 688 689 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 687 def proration_behavior @proration_behavior end |
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or now. Must be set on the first phase. Prefer to specify now over an explicit timestamp when appropriate to avoid unexpected behavior due to request delays or clock skew resulting in the phase being slightly backdated or postdated.
689 690 691 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 689 def start_date @start_date end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription's invoices.
691 692 693 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 691 def transfer_data @transfer_data end |
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
693 694 695 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 693 def trial @trial end |
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries
695 696 697 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 695 def trial_continuation @trial_continuation end |
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date. Must be within the phase. When combined with trial=true, it must match the phase end date.
697 698 699 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 697 def trial_end @trial_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
699 700 701 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 699 def trial_settings @trial_settings end |
Class Method Details
.field_encodings ⇒ Object
755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 755 def self.field_encodings @field_encodings = { add_invoice_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |