Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discountable ⇒ Object
Controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 468 def initialize( discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discountable = discountable @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discountable ⇒ Object
Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.
452 453 454 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 452 def discountable @discountable end |
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
454 455 456 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 454 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
456 457 458 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 456 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.
458 459 460 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 458 def period @period end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required.
460 461 462 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 460 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline. One of price or price_data is required.
462 463 464 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 462 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
464 465 466 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 464 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.
466 467 468 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 466 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
488 489 490 491 492 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 488 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |