Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 308

def initialize(
  discountable: nil,
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discountable = discountable
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.



292
293
294
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 292

def discountable
  @discountable
end

#discountsObject

The coupons to redeem into discounts for the item.



294
295
296
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 294

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



296
297
298
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 296

def 
  @metadata
end

#periodObject

The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.



298
299
300
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 298

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



300
301
302
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 300

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



302
303
304
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 302

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



304
305
306
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 304

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



306
307
308
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 306

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



328
329
330
331
332
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 328

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end