Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discountable ⇒ Object
Controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 252 def initialize( discountable: nil, discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discountable = discountable @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discountable ⇒ Object
Controls whether discounts apply to this invoice item. Defaults to true if no value is provided.
236 237 238 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 236 def discountable @discountable end |
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
238 239 240 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 238 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
240 241 242 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 240 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.
242 243 244 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 242 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
244 245 246 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 244 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
246 247 248 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 246 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
248 249 250 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 248 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
250 251 252 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 250 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
272 273 274 275 276 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 272 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |