Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



218
219
220
221
222
223
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 218

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



210
211
212
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 210

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



212
213
214
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 212

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



214
215
216
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 214

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



216
217
218
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 216

def promotion_code
  @promotion_code
end