Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



162
163
164
165
166
167
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 162

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



154
155
156
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 154

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



156
157
158
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 156

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



158
159
160
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 158

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



160
161
162
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 160

def promotion_code
  @promotion_code
end