Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



203
204
205
206
207
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 203

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



197
198
199
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 197

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



199
200
201
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 199

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



201
202
203
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 201

def type
  @type
end