Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



147
148
149
150
151
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 147

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



141
142
143
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 141

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



143
144
145
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 143

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



145
146
147
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 145

def type
  @type
end