Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



177
178
179
180
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 177

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



173
174
175
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 173

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



175
176
177
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 175

def type
  @type
end