Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
233 234 235 236 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 233 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
229 230 231 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 229 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
231 232 233 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 231 def type @type end |