Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



189
190
191
192
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 189

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



185
186
187
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 185

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



187
188
189
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 187

def type
  @type
end