Class: Stripe::SubscriptionScheduleUpdateParams::Phase::AddInvoiceItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 245

def initialize(
  currency: nil,
  product: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



235
236
237
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 235

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



237
238
239
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 237

def product
  @product
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



239
240
241
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 239

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge or a negative integer representing the amount to credit to the customer.



241
242
243
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 241

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



243
244
245
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 243

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



259
260
261
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 259

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end