Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 446 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
436 437 438 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 436 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
438 439 440 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 438 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
440 441 442 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 440 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
442 443 444 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 442 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
444 445 446 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 444 def settings @settings end |