Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
436 437 438 439 440 441 442 443 444 445 446 447 448 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 436 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
426 427 428 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 426 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
428 429 430 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 428 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
430 431 432 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 430 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
432 433 434 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 432 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
434 435 436 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 434 def settings @settings end |