Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



391
392
393
394
395
396
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 391

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



383
384
385
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 383

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



385
386
387
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 385

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



387
388
389
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 387

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



389
390
391
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 389

def promotion_code
  @promotion_code
end