Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
330 331 332 333 334 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 330 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
324 325 326 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 324 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
326 327 328 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 326 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
328 329 330 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 328 def type @type end |