Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



376
377
378
379
380
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 376

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



370
371
372
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 370

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



372
373
374
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 372

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



374
375
376
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 374

def type
  @type
end