Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



407
408
409
410
411
412
413
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 407

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



397
398
399
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 397

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



399
400
401
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 399

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



401
402
403
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 401

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



403
404
405
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 403

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



405
406
407
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 405

def second
  @second
end