Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



397
398
399
400
401
402
403
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 397

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



387
388
389
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 387

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



389
390
391
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 389

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



391
392
393
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 391

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



393
394
395
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 393

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



395
396
397
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 395

def second
  @second
end