Class: Stripe::SubscriptionScheduleUpdateParams::Phase::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::InvoiceSettings
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: CustomField, Issuer
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with this phase of the subscription schedule.
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 378 def initialize( account_tax_ids: nil, custom_fields: nil, days_until_due: nil, description: nil, footer: nil, issuer: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @days_until_due = days_until_due @description = description @footer = @issuer = issuer end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
366 367 368 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 366 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
368 369 370 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 368 def custom_fields @custom_fields end |
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where collection_method=charge_automatically.
370 371 372 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 370 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
372 373 374 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 372 def description @description end |
#footer ⇒ Object
Footer to be displayed on the invoice.
374 375 376 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 374 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
376 377 378 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 376 def issuer @issuer end |