Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Item
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
Returns a new instance of Item.
874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 874 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
854 855 856 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 854 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
856 857 858 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 856 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item's metadata when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item's metadata can be unset by posting an empty value to them in the configuration item's metadata. To unset all keys in the subscription item's metadata, update the subscription item directly or unset every key individually from the configuration item's metadata.
858 859 860 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 858 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in plan and price.
860 861 862 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 860 def plan @plan end |
#price ⇒ Object
The ID of the price object.
862 863 864 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 862 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
864 865 866 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 864 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price's usage_type is licensed and not metered.
866 867 868 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 866 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
868 869 870 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 868 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
870 871 872 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 870 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
872 873 874 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 872 def trial_offer @trial_offer end |
Class Method Details
.field_encodings ⇒ Object
898 899 900 901 902 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 898 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |