Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item

Returns a new instance of Item.



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 526

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



506
507
508
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 506

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



508
509
510
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 508

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



510
511
512
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 510

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



512
513
514
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 512

def plan
  @plan
end

#priceObject

The ID of the price object.



514
515
516
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 514

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



516
517
518
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 516

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



518
519
520
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 518

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



520
521
522
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 520

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



522
523
524
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 522

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



524
525
526
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 524

def trial_offer
  @trial_offer
end

Class Method Details

.field_encodingsObject



550
551
552
553
554
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 550

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end