Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Item
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
Returns a new instance of Item.
682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 682 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
662 663 664 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 662 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
664 665 666 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 664 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.
666 667 668 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 666 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.
668 669 670 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 668 def plan @plan end |
#price ⇒ Object
The ID of the price object.
670 671 672 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 670 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
672 673 674 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 672 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.
674 675 676 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 674 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
676 677 678 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 676 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
678 679 680 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 678 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
680 681 682 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 680 def trial_offer @trial_offer end |
Class Method Details
.field_encodings ⇒ Object
706 707 708 709 710 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 706 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |