Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 506

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



488
489
490
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 488

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



490
491
492
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 490

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



492
493
494
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 492

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



494
495
496
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 494

def plan
  @plan
end

#priceObject

The ID of the price object.



496
497
498
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 496

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



498
499
500
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 498

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



500
501
502
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 500

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



502
503
504
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 502

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



504
505
506
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 504

def trial
  @trial
end