Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item

Returns a new instance of Item.



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 564

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



544
545
546
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 544

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



546
547
548
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 546

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



548
549
550
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 548

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



550
551
552
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 550

def plan
  @plan
end

#priceObject

The ID of the price object.



552
553
554
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 552

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



554
555
556
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 554

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



556
557
558
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 556

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



558
559
560
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 558

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



560
561
562
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 560

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



562
563
564
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 562

def trial_offer
  @trial_offer
end