Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 589

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



579
580
581
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 579

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



581
582
583
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 581

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



583
584
585
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 583

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



585
586
587
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 585

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



587
588
589
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 587

def settings
  @settings
end