Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
426 427 428 429 430 431 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 426 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
418 419 420 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 418 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
420 421 422 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 420 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
422 423 424 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 422 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
424 425 426 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 424 def promotion_code @promotion_code end |