Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



426
427
428
429
430
431
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 426

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



418
419
420
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 418

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



420
421
422
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 420

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



422
423
424
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 422

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



424
425
426
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 424

def promotion_code
  @promotion_code
end