Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



529
530
531
532
533
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 529

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



523
524
525
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 523

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



525
526
527
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 525

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



527
528
529
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 527

def type
  @type
end