Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



519
520
521
522
523
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 519

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



513
514
515
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 513

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



515
516
517
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 515

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



517
518
519
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 517

def type
  @type
end