Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



411
412
413
414
415
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 411

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



405
406
407
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 405

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



407
408
409
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 407

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



409
410
411
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 409

def type
  @type
end