Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



554
555
556
557
558
559
560
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 554

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



544
545
546
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 544

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



546
547
548
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 546

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



548
549
550
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 548

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



550
551
552
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 550

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



552
553
554
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 552

def second
  @second
end