Class: Stripe::SubscriptionScheduleUpdateParams::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



540
541
542
543
544
545
546
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 540

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



530
531
532
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 530

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



532
533
534
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 532

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



534
535
536
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 534

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



536
537
538
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 536

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



538
539
540
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 538

def second
  @second
end