Class: Stripe::SubscriptionScheduleUpdateParams::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::TransferData
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
459 460 461 462 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 459 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
455 456 457 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 455 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
457 458 459 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 457 def destination @destination end |