Class: Stripe::SubscriptionScheduleUpdateParams::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionScheduleUpdateParams::Phase::TransferData
- Defined in:
- lib/stripe/params/subscription_schedule_update_params.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
604 605 606 607 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 604 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
600 601 602 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 600 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
602 603 604 |
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 602 def destination @destination end |