Class: Stripe::SubscriptionScheduleUpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



846
847
848
849
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 846

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



842
843
844
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 842

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



844
845
846
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 844

def update_behavior
  @update_behavior
end