Class: Stripe::SubscriptionScheduleUpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



678
679
680
681
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 678

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



674
675
676
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 674

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



676
677
678
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 676

def update_behavior
  @update_behavior
end