Class: Stripe::SubscriptionScheduleUpdateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_schedule_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



742
743
744
745
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 742

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



738
739
740
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 738

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



740
741
742
# File 'lib/stripe/params/subscription_schedule_update_params.rb', line 740

def update_behavior
  @update_behavior
end