Class: Stripe::SubscriptionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::SubscriptionService
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Method Summary collapse
-
#attach_cadence(subscription, params = {}, opts = {}) ⇒ Object
Attach a Billing Cadence to an existing subscription.
-
#cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Cancels a customer’s subscription immediately.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription on an existing customer.
-
#delete_discount(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a subscription.
-
#list(params = {}, opts = {}) ⇒ Object
By default, returns a list of subscriptions that have not been canceled.
-
#migrate(subscription, params = {}, opts = {}) ⇒ Object
Upgrade the billing_mode of an existing subscription.
-
#pause(subscription, params = {}, opts = {}) ⇒ Object
Pauses a subscription by transitioning it to the paused status.
-
#resume(subscription, params = {}, opts = {}) ⇒ Object
Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations.
-
#retrieve(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Retrieves the subscription with the given ID.
-
#search(params = {}, opts = {}) ⇒ Object
Search for subscriptions you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language).
-
#serialize_batch_cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Serializes a Subscription cancel request into a batch job JSONL line.
-
#serialize_batch_create(params = {}, opts = {}) ⇒ Object
Serializes a Subscription create request into a batch job JSONL line.
-
#serialize_batch_migrate(subscription, params = {}, opts = {}) ⇒ Object
Serializes a Subscription migrate request into a batch job JSONL line.
-
#serialize_batch_pause(subscription, params = {}, opts = {}) ⇒ Object
Serializes a Subscription pause request into a batch job JSONL line.
-
#serialize_batch_resume(subscription, params = {}, opts = {}) ⇒ Object
Serializes a Subscription resume request into a batch job JSONL line.
-
#serialize_batch_update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Serializes a Subscription update request into a batch job JSONL line.
-
#update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Updates an existing subscription to match the specified parameters.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#attach_cadence(subscription, params = {}, opts = {}) ⇒ Object
Attach a Billing Cadence to an existing subscription. When attached, the subscription is billed by the Billing Cadence, potentially sharing invoices with the other subscriptions linked to the Billing Cadence.
7 8 9 10 11 12 13 14 15 |
# File 'lib/stripe/services/subscription_service.rb', line 7 def attach_cadence(subscription, params = {}, opts = {}) request( method: :post, path: format("/v1/subscriptions/%<subscription>s/attach_cadence", { subscription: CGI.escape(subscription) }), params: params, opts: opts, base_address: :api ) end |
#cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Cancels a customer’s subscription immediately. The customer won’t be charged again for the subscription. After it’s canceled, the subscription is largely immutable. You can still update its [metadata](docs.stripe.com/metadata) and cancellation_details.
Any pending invoice items that you’ve created are still charged at the end of the period, unless manually [deleted](docs.stripe.com/api/invoiceitems/delete). If you’ve set the subscription to cancel at the end of the period, any pending prorations are also left in place and collected at the end of the period. But if the subscription is set to cancel immediately, pending prorations are removed if invoice_now and prorate are both set to true.
By default, upon subscription cancellation, Stripe stops automatic collection of all finalized invoices for the customer. This is intended to prevent unexpected payment attempts after the customer has canceled a subscription. However, you can resume automatic collection of the invoices manually after subscription cancellation to have us proceed. Or, you could check for unpaid invoices before allowing the customer to cancel the subscription at all.
22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/services/subscription_service.rb', line 22 def cancel(subscription_exposed_id, params = {}, opts = {}) request( method: :delete, path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a new subscription on an existing customer. Each customer can have up to 500 active or scheduled subscriptions.
When you create a subscription with collection_method=charge_automatically, the first invoice is finalized as part of the request. The payment_behavior parameter determines the exact behavior of the initial payment.
To start subscriptions where the first invoice always begins in a draft status, use [subscription schedules](docs.stripe.com/docs/billing/subscriptions/subscription-schedules#managing) instead. Schedules provide the flexibility to model more complex billing configurations that change over time.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/services/subscription_service.rb', line 39 def create(params = {}, opts = {}) params = ::Stripe::SubscriptionCreateParams.coerce_params(params) unless params.is_a?(Stripe::RequestParams) request( method: :post, path: "/v1/subscriptions", params: params, opts: opts, base_address: :api ) end |
#delete_discount(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a subscription.
52 53 54 55 56 57 58 59 60 |
# File 'lib/stripe/services/subscription_service.rb', line 52 def delete_discount(subscription_exposed_id, params = {}, opts = {}) request( method: :delete, path: format("/v1/subscriptions/%<subscription_exposed_id>s/discount", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
By default, returns a list of subscriptions that have not been canceled. In order to list canceled subscriptions, specify status=canceled.
63 64 65 66 67 68 69 70 71 |
# File 'lib/stripe/services/subscription_service.rb', line 63 def list(params = {}, opts = {}) request( method: :get, path: "/v1/subscriptions", params: params, opts: opts, base_address: :api ) end |
#migrate(subscription, params = {}, opts = {}) ⇒ Object
Upgrade the billing_mode of an existing subscription.
74 75 76 77 78 79 80 81 82 |
# File 'lib/stripe/services/subscription_service.rb', line 74 def migrate(subscription, params = {}, opts = {}) request( method: :post, path: format("/v1/subscriptions/%<subscription>s/migrate", { subscription: CGI.escape(subscription) }), params: params, opts: opts, base_address: :api ) end |
#pause(subscription, params = {}, opts = {}) ⇒ Object
Pauses a subscription by transitioning it to the paused status. A paused subscription does not generate invoices and will not advance to new billing periods. The subscription can be resumed later using the resume endpoint. Cannot pause subscriptions with attached schedules.
85 86 87 88 89 90 91 92 93 |
# File 'lib/stripe/services/subscription_service.rb', line 85 def pause(subscription, params = {}, opts = {}) request( method: :post, path: format("/v1/subscriptions/%<subscription>s/pause", { subscription: CGI.escape(subscription) }), params: params, opts: opts, base_address: :api ) end |
#resume(subscription, params = {}, opts = {}) ⇒ Object
Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations. Resume is only available for subscriptions that use charge_automatically collection. If Stripe doesn’t generate a resumption invoice, the subscription becomes active immediately. When a resumption invoice is generated, Stripe finalizes it immediately. If the invoice is paid or marked uncollectible, the subscription becomes active. If the invoice is manually voided, the subscription stays paused. If there is no payment attempt within 23 hours, Stripe voids the invoice and the subscription stays paused. Learn more about [resuming subscriptions](docs.stripe.com/docs/billing/subscriptions/pause#resume-subscriptions).
96 97 98 99 100 101 102 103 104 |
# File 'lib/stripe/services/subscription_service.rb', line 96 def resume(subscription, params = {}, opts = {}) request( method: :post, path: format("/v1/subscriptions/%<subscription>s/resume", { subscription: CGI.escape(subscription) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Retrieves the subscription with the given ID.
107 108 109 110 111 112 113 114 115 |
# File 'lib/stripe/services/subscription_service.rb', line 107 def retrieve(subscription_exposed_id, params = {}, opts = {}) request( method: :get, path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts, base_address: :api ) end |
#search(params = {}, opts = {}) ⇒ Object
Search for subscriptions you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.
121 122 123 124 125 126 127 128 129 |
# File 'lib/stripe/services/subscription_service.rb', line 121 def search(params = {}, opts = {}) request( method: :get, path: "/v1/subscriptions/search", params: params, opts: opts, base_address: :api ) end |
#serialize_batch_cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Serializes a Subscription cancel request into a batch job JSONL line.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/stripe/services/subscription_service.rb', line 132 def serialize_batch_cancel(subscription_exposed_id, params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:path_params] = { subscription_exposed_id: subscription_exposed_id } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |
#serialize_batch_create(params = {}, opts = {}) ⇒ Object
Serializes a Subscription create request into a batch job JSONL line.
147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/stripe/services/subscription_service.rb', line 147 def serialize_batch_create(params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |
#serialize_batch_migrate(subscription, params = {}, opts = {}) ⇒ Object
Serializes a Subscription migrate request into a batch job JSONL line.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/stripe/services/subscription_service.rb', line 161 def serialize_batch_migrate(subscription, params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:path_params] = { subscription: subscription } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |
#serialize_batch_pause(subscription, params = {}, opts = {}) ⇒ Object
Serializes a Subscription pause request into a batch job JSONL line.
176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/stripe/services/subscription_service.rb', line 176 def serialize_batch_pause(subscription, params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:path_params] = { subscription: subscription } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |
#serialize_batch_resume(subscription, params = {}, opts = {}) ⇒ Object
Serializes a Subscription resume request into a batch job JSONL line.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/stripe/services/subscription_service.rb', line 191 def serialize_batch_resume(subscription, params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:path_params] = { subscription: subscription } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |
#serialize_batch_update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Serializes a Subscription update request into a batch job JSONL line.
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/stripe/services/subscription_service.rb', line 206 def serialize_batch_update(subscription_exposed_id, params = {}, opts = {}) request_id = SecureRandom.uuid stripe_version = opts[:stripe_version] || Stripe.api_version request_body = { id: request_id, params: params, stripe_version: stripe_version, } request_body[:path_params] = { subscription_exposed_id: subscription_exposed_id } request_body[:context] = opts[:stripe_context] if opts[:stripe_context] JSON.generate(request_body) end |
#update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object
Updates an existing subscription to match the specified parameters. When changing prices or quantities, we optionally prorate the price we charge next month to make up for any price changes. To preview how the proration is calculated, use the [create preview](docs.stripe.com/docs/api/invoices/create_preview) endpoint.
By default, we prorate subscription changes. For example, if a customer signs up on May 1 for a 100 price, they’ll be billed 100 immediately. If on May 15 they switch to a 200 price, then on June 1 they’ll be billed 250 (200 for a renewal of her subscription, plus a 50 prorating adjustment for half of the previous month’s 100 difference). Similarly, a downgrade generates a credit that is applied to the next invoice. We also prorate when you make quantity changes.
Switching prices does not normally change the billing date or generate an immediate charge unless:
The billing interval is changed (for example, from monthly to yearly). The subscription moves from free to paid. A trial starts or ends.
In these cases, we apply a credit for the unused time on the previous price, immediately charge the customer using the new price, and reset the billing date. Learn about how [Stripe immediately attempts payment for subscription changes](docs.stripe.com/docs/billing/subscriptions/upgrade-downgrade#immediate-payment).
If you want to charge for an upgrade immediately, pass proration_behavior as always_invoice to create prorations, automatically invoice the customer for those proration adjustments, and attempt to collect payment. If you pass create_prorations, the prorations are created but not automatically invoiced. If you want to bill the customer for the prorations before the subscription’s renewal date, you need to manually [invoice the customer](docs.stripe.com/docs/api/invoices/create).
If you don’t want to prorate, set the proration_behavior option to none. With this option, the customer is billed 100 on May 1 and 200 on June 1. Similarly, if you set proration_behavior to none when switching between different billing intervals (for example, from monthly to yearly), we don’t generate any credits for the old subscription’s unused time. We still reset the billing date and bill immediately for the new subscription.
Updating the quantity on a subscription many times in an hour may result in [rate limiting. If you need to bill for a frequently changing quantity, consider integrating <a href=“/docs/billing/subscriptions/usage-based”>usage-based billing](docs.stripe.com/docs/rate-limits) instead.
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/stripe/services/subscription_service.rb', line 241 def update(subscription_exposed_id, params = {}, opts = {}) params = ::Stripe::SubscriptionUpdateParams.coerce_params(params) unless params.is_a?(Stripe::RequestParams) request( method: :post, path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }), params: params, opts: opts, base_address: :api ) end |