Class: Stripe::SubscriptionService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AttachCadenceParams, CancelParams, CreateParams, DeleteDiscountParams, ListParams, MigrateParams, ResumeParams, RetrieveParams, SearchParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#attach_cadence(subscription, params = {}, opts = {}) ⇒ Object

Attach a Billing Cadence to an existing subscription. When attached, the subscription is billed by the Billing Cadence, potentially sharing invoices with the other subscriptions linked to the Billing Cadence.



1917
1918
1919
1920
1921
1922
1923
1924
1925
# File 'lib/stripe/services/subscription_service.rb', line 1917

def attach_cadence(subscription, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/attach_cadence", { subscription: CGI.escape(subscription) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#cancel(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Cancels a customer’s subscription immediately. The customer won’t be charged again for the subscription. After it’s canceled, you can no longer update the subscription or its [metadata](docs.stripe.com/metadata).

Any pending invoice items that you’ve created are still charged at the end of the period, unless manually [deleted](docs.stripe.com/api#delete_invoiceitem). If you’ve set the subscription to cancel at the end of the period, any pending prorations are also left in place and collected at the end of the period. But if the subscription is set to cancel immediately, pending prorations are removed if invoice_now and prorate are both set to true.

By default, upon subscription cancellation, Stripe stops automatic collection of all finalized invoices for the customer. This is intended to prevent unexpected payment attempts after the customer has canceled a subscription. However, you can resume automatic collection of the invoices manually after subscription cancellation to have us proceed. Or, you could check for unpaid invoices before allowing the customer to cancel the subscription at all.



1932
1933
1934
1935
1936
1937
1938
1939
1940
# File 'lib/stripe/services/subscription_service.rb', line 1932

def cancel(subscription_exposed_id, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

Creates a new subscription on an existing customer. Each customer can have up to 500 active or scheduled subscriptions.

When you create a subscription with collection_method=charge_automatically, the first invoice is finalized as part of the request. The payment_behavior parameter determines the exact behavior of the initial payment.

To start subscriptions where the first invoice always begins in a draft status, use [subscription schedules](docs.stripe.com/docs/billing/subscriptions/subscription-schedules#managing) instead. Schedules provide the flexibility to model more complex billing configurations that change over time.



1949
1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/stripe/services/subscription_service.rb', line 1949

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/subscriptions",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#delete_discount(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Removes the currently applied discount on a subscription.



1960
1961
1962
1963
1964
1965
1966
1967
1968
# File 'lib/stripe/services/subscription_service.rb', line 1960

def delete_discount(subscription_exposed_id, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s/discount", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

By default, returns a list of subscriptions that have not been canceled. In order to list canceled subscriptions, specify status=canceled.



1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/stripe/services/subscription_service.rb', line 1971

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/subscriptions",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#migrate(subscription, params = {}, opts = {}) ⇒ Object

Upgrade the billing_mode of an existing subscription.



1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/stripe/services/subscription_service.rb', line 1982

def migrate(subscription, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/migrate", { subscription: CGI.escape(subscription) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#resume(subscription, params = {}, opts = {}) ⇒ Object

Initiates resumption of a paused subscription, optionally resetting the billing cycle anchor and creating prorations. If a resumption invoice is generated, it must be paid or marked uncollectible before the subscription will be unpaused. If payment succeeds the subscription will become active, and if payment fails the subscription will be past_due. The resumption invoice will void automatically if not paid by the expiration date.



1993
1994
1995
1996
1997
1998
1999
2000
2001
# File 'lib/stripe/services/subscription_service.rb', line 1993

def resume(subscription, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/subscriptions/%<subscription>s/resume", { subscription: CGI.escape(subscription) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Retrieves the subscription with the given ID.



2004
2005
2006
2007
2008
2009
2010
2011
2012
# File 'lib/stripe/services/subscription_service.rb', line 2004

def retrieve(subscription_exposed_id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#search(params = {}, opts = {}) ⇒ Object

Search for subscriptions you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.



2018
2019
2020
2021
2022
2023
2024
2025
2026
# File 'lib/stripe/services/subscription_service.rb', line 2018

def search(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/subscriptions/search",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(subscription_exposed_id, params = {}, opts = {}) ⇒ Object

Updates an existing subscription to match the specified parameters. When changing prices or quantities, we optionally prorate the price we charge next month to make up for any price changes. To preview how the proration is calculated, use the [create preview](docs.stripe.com/docs/api/invoices/create_preview) endpoint.

By default, we prorate subscription changes. For example, if a customer signs up on May 1 for a 100 price, they’ll be billed 100 immediately. If on May 15 they switch to a 200 price, then on June 1 they’ll be billed 250 (200 for a renewal of her subscription, plus a 50 prorating adjustment for half of the previous month’s 100 difference). Similarly, a downgrade generates a credit that is applied to the next invoice. We also prorate when you make quantity changes.

Switching prices does not normally change the billing date or generate an immediate charge unless:

The billing interval is changed (for example, from monthly to yearly). The subscription moves from free to paid. A trial starts or ends.

In these cases, we apply a credit for the unused time on the previous price, immediately charge the customer using the new price, and reset the billing date. Learn about how [Stripe immediately attempts payment for subscription changes](docs.stripe.com/docs/billing/subscriptions/upgrade-downgrade#immediate-payment).

If you want to charge for an upgrade immediately, pass proration_behavior as always_invoice to create prorations, automatically invoice the customer for those proration adjustments, and attempt to collect payment. If you pass create_prorations, the prorations are created but not automatically invoiced. If you want to bill the customer for the prorations before the subscription’s renewal date, you need to manually [invoice the customer](docs.stripe.com/docs/api/invoices/create).

If you don’t want to prorate, set the proration_behavior option to none. With this option, the customer is billed 100 on May 1 and 200 on June 1. Similarly, if you set proration_behavior to none when switching between different billing intervals (for example, from monthly to yearly), we don’t generate any credits for the old subscription’s unused time. We still reset the billing date and bill immediately for the new subscription.

Updating the quantity on a subscription many times in an hour may result in [rate limiting. If you need to bill for a frequently changing quantity, consider integrating <a href=“/docs/billing/subscriptions/usage-based”>usage-based billing](docs.stripe.com/docs/rate-limits) instead.



2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/stripe/services/subscription_service.rb', line 2049

def update(subscription_exposed_id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/subscriptions/%<subscription_exposed_id>s", { subscription_exposed_id: CGI.escape(subscription_exposed_id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end