Class: Stripe::SubscriptionService::AttachCadenceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::AttachCadenceParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
The Billing Cadence which controls the timing of recurring invoice generation for this subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(billing_cadence: nil, expand: nil) ⇒ AttachCadenceParams
constructor
A new instance of AttachCadenceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_cadence: nil, expand: nil) ⇒ AttachCadenceParams
Returns a new instance of AttachCadenceParams.
1867 1868 1869 1870 |
# File 'lib/stripe/services/subscription_service.rb', line 1867 def initialize(billing_cadence: nil, expand: nil) @billing_cadence = billing_cadence @expand = end |
Instance Attribute Details
#billing_cadence ⇒ Object
The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.
1863 1864 1865 |
# File 'lib/stripe/services/subscription_service.rb', line 1863 def billing_cadence @billing_cadence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1865 1866 1867 |
# File 'lib/stripe/services/subscription_service.rb', line 1865 def @expand end |