Class: Stripe::SubscriptionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingCycleAnchorConfig, BillingThresholds, Discount, InvoiceSettings, Item, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this subscription.
-
#backdate_start_date ⇒ Object
For new subscriptions, a past timestamp to backdate the subscription’s start date to.
-
#billing_cycle_anchor ⇒ Object
A future timestamp in UTC format to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle).
-
#billing_cycle_anchor_config ⇒ Object
Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel.
-
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`).
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#coupon ⇒ Object
The ID of the coupon to apply to this subscription.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The identifier of the customer to subscribe.
-
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription.
-
#default_source ⇒ Object
ID of the default payment source for the subscription.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
-
#payment_behavior ⇒ Object
Only applies to subscriptions with ‘collection_method=charge_automatically`.
-
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
-
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items.
-
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
-
#promotion_code ⇒ Object
The promotion code to apply to this subscription.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`.
-
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, coupon: nil, currency: nil, customer: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, promotion_code: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 |
# File 'lib/stripe/services/subscription_service.rb', line 1610 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, backdate_start_date: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, collection_method: nil, coupon: nil, currency: nil, customer: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, promotion_code: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_period_days: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @backdate_start_date = backdate_start_date @billing_cycle_anchor = billing_cycle_anchor @billing_cycle_anchor_config = billing_cycle_anchor_config @billing_thresholds = billing_thresholds @cancel_at = cancel_at @cancel_at_period_end = cancel_at_period_end @collection_method = collection_method @coupon = coupon @currency = currency @customer = customer @days_until_due = days_until_due @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @invoice_settings = invoice_settings @items = items @metadata = @off_session = off_session @on_behalf_of = on_behalf_of @payment_behavior = payment_behavior @payment_settings = payment_settings @pending_invoice_item_interval = pending_invoice_item_interval @prebilling = prebilling @promotion_code = promotion_code @proration_behavior = proration_behavior @transfer_data = transfer_data @trial_end = trial_end @trial_from_plan = trial_from_plan @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.
1528 1529 1530 |
# File 'lib/stripe/services/subscription_service.rb', line 1528 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
1530 1531 1532 |
# File 'lib/stripe/services/subscription_service.rb', line 1530 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.
1532 1533 1534 |
# File 'lib/stripe/services/subscription_service.rb', line 1532 def automatic_tax @automatic_tax end |
#backdate_start_date ⇒ Object
For new subscriptions, a past timestamp to backdate the subscription’s start date to. If set, the first invoice will contain a proration for the timespan between the start date and the current time. Can be combined with trials and the billing cycle anchor.
1534 1535 1536 |
# File 'lib/stripe/services/subscription_service.rb', line 1534 def backdate_start_date @backdate_start_date end |
#billing_cycle_anchor ⇒ Object
A future timestamp in UTC format to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle). The anchor is the reference point that aligns future billing cycle dates. It sets the day of week for ‘week` intervals, the day of month for `month` and `year` intervals, and the month of year for `year` intervals.
1536 1537 1538 |
# File 'lib/stripe/services/subscription_service.rb', line 1536 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_cycle_anchor_config ⇒ Object
Mutually exclusive with billing_cycle_anchor and only valid with monthly and yearly price intervals. When provided, the billing_cycle_anchor is set to the next occurence of the day_of_month at the hour, minute, and second UTC.
1538 1539 1540 |
# File 'lib/stripe/services/subscription_service.rb', line 1538 def billing_cycle_anchor_config @billing_cycle_anchor_config end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1540 1541 1542 |
# File 'lib/stripe/services/subscription_service.rb', line 1540 def billing_thresholds @billing_thresholds end |
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period.
1542 1543 1544 |
# File 'lib/stripe/services/subscription_service.rb', line 1542 def cancel_at @cancel_at end |
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`.
1544 1545 1546 |
# File 'lib/stripe/services/subscription_service.rb', line 1544 def cancel_at_period_end @cancel_at_period_end end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.
1546 1547 1548 |
# File 'lib/stripe/services/subscription_service.rb', line 1546 def collection_method @collection_method end |
#coupon ⇒ Object
The ID of the coupon to apply to this subscription. A coupon applied to a subscription will only affect invoices created for that particular subscription. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.
1548 1549 1550 |
# File 'lib/stripe/services/subscription_service.rb', line 1548 def coupon @coupon end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1550 1551 1552 |
# File 'lib/stripe/services/subscription_service.rb', line 1550 def currency @currency end |
#customer ⇒ Object
The identifier of the customer to subscribe.
1552 1553 1554 |
# File 'lib/stripe/services/subscription_service.rb', line 1552 def customer @customer end |
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where ‘collection_method` is set to `send_invoice`.
1554 1555 1556 |
# File 'lib/stripe/services/subscription_service.rb', line 1554 def days_until_due @days_until_due end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).
1556 1557 1558 |
# File 'lib/stripe/services/subscription_service.rb', line 1556 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](stripe.com/docs/api/customers/object#customer_object-default_source).
1558 1559 1560 |
# File 'lib/stripe/services/subscription_service.rb', line 1558 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.
1560 1561 1562 |
# File 'lib/stripe/services/subscription_service.rb', line 1560 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
1562 1563 1564 |
# File 'lib/stripe/services/subscription_service.rb', line 1562 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription. If not specified or empty, inherits the discount from the subscription’s customer.
1564 1565 1566 |
# File 'lib/stripe/services/subscription_service.rb', line 1564 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1566 1567 1568 |
# File 'lib/stripe/services/subscription_service.rb', line 1566 def @expand end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
1568 1569 1570 |
# File 'lib/stripe/services/subscription_service.rb', line 1568 def invoice_settings @invoice_settings end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
1570 1571 1572 |
# File 'lib/stripe/services/subscription_service.rb', line 1570 def items @items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1572 1573 1574 |
# File 'lib/stripe/services/subscription_service.rb', line 1572 def @metadata end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).
1574 1575 1576 |
# File 'lib/stripe/services/subscription_service.rb', line 1574 def off_session @off_session end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
1576 1577 1578 |
# File 'lib/stripe/services/subscription_service.rb', line 1576 def on_behalf_of @on_behalf_of end |
#payment_behavior ⇒ Object
Only applies to subscriptions with ‘collection_method=charge_automatically`.
Use ‘allow_incomplete` to create Subscriptions with `status=incomplete` if the first invoice can’t be paid. Creating Subscriptions with this status allows you to manage scenarios where additional customer actions are needed to pay a subscription’s invoice. For example, SCA regulation may require 3DS authentication to complete payment. See the [SCA Migration Guide](stripe.com/docs/billing/migration/strong-customer-authentication) for Billing to learn more. This is the default behavior.
Use ‘default_incomplete` to create Subscriptions with `status=incomplete` when the first invoice requires payment, otherwise start as active. Subscriptions transition to `status=active` when successfully confirming the PaymentIntent on the first invoice. This allows simpler management of scenarios where additional customer actions are needed to pay a subscription’s invoice, such as failed payments, [SCA regulation](stripe.com/docs/billing/migration/strong-customer-authentication), or collecting a mandate for a bank debit payment method. If the PaymentIntent is not confirmed within 23 hours Subscriptions transition to `status=incomplete_expired`, which is a terminal state.
Use ‘error_if_incomplete` if you want Stripe to return an HTTP 402 status code if a subscription’s first invoice can’t be paid. For example, if a payment method requires 3DS authentication due to SCA regulation and further customer action is needed, this parameter doesn’t create a Subscription and returns an error instead. This was the default behavior for API versions prior to 2019-03-14. See the [changelog](stripe.com/docs/upgrades#2019-03-14) to learn more.
‘pending_if_incomplete` is only used with updates and cannot be passed when creating a Subscription.
Subscriptions with ‘collection_method=send_invoice` are automatically activated regardless of the first Invoice status.
1588 1589 1590 |
# File 'lib/stripe/services/subscription_service.rb', line 1588 def payment_behavior @payment_behavior end |
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
1590 1591 1592 |
# File 'lib/stripe/services/subscription_service.rb', line 1590 def payment_settings @payment_settings end |
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](stripe.com/docs/api#create_invoice) for the given subscription at the specified interval.
1592 1593 1594 |
# File 'lib/stripe/services/subscription_service.rb', line 1592 def pending_invoice_item_interval @pending_invoice_item_interval end |
#prebilling ⇒ Object
If specified, the invoicing for the given billing cycle iterations will be processed now.
1594 1595 1596 |
# File 'lib/stripe/services/subscription_service.rb', line 1594 def prebilling @prebilling end |
#promotion_code ⇒ Object
The promotion code to apply to this subscription. A promotion code applied to a subscription will only affect invoices created for that particular subscription. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.
1596 1597 1598 |
# File 'lib/stripe/services/subscription_service.rb', line 1596 def promotion_code @promotion_code end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.
1598 1599 1600 |
# File 'lib/stripe/services/subscription_service.rb', line 1598 def proration_behavior @proration_behavior end |
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
1600 1601 1602 |
# File 'lib/stripe/services/subscription_service.rb', line 1600 def transfer_data @transfer_data end |
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The special value ‘now` can be provided to end the customer’s trial immediately. Can be at most two years from ‘billing_cycle_anchor`. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
1602 1603 1604 |
# File 'lib/stripe/services/subscription_service.rb', line 1602 def trial_end @trial_end end |
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
1604 1605 1606 |
# File 'lib/stripe/services/subscription_service.rb', line 1604 def trial_from_plan @trial_from_plan end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.
1606 1607 1608 |
# File 'lib/stripe/services/subscription_service.rb', line 1606 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
1608 1609 1610 |
# File 'lib/stripe/services/subscription_service.rb', line 1608 def trial_settings @trial_settings end |