Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
# File 'lib/stripe/services/subscription_service.rb', line 943

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



929
930
931
# File 'lib/stripe/services/subscription_service.rb', line 929

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



931
932
933
# File 'lib/stripe/services/subscription_service.rb', line 931

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the current period of the subscription.



933
934
935
# File 'lib/stripe/services/subscription_service.rb', line 933

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



935
936
937
# File 'lib/stripe/services/subscription_service.rb', line 935

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



937
938
939
# File 'lib/stripe/services/subscription_service.rb', line 937

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



939
940
941
# File 'lib/stripe/services/subscription_service.rb', line 939

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



941
942
943
# File 'lib/stripe/services/subscription_service.rb', line 941

def tax_rates
  @tax_rates
end