Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



912
913
914
915
916
# File 'lib/stripe/services/subscription_service.rb', line 912

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



906
907
908
# File 'lib/stripe/services/subscription_service.rb', line 906

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



908
909
910
# File 'lib/stripe/services/subscription_service.rb', line 908

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



910
911
912
# File 'lib/stripe/services/subscription_service.rb', line 910

def type
  @type
end