Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
1044 1045 1046 1047 |
# File 'lib/stripe/services/subscription_service.rb', line 1044 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
1040 1041 1042 |
# File 'lib/stripe/services/subscription_service.rb', line 1040 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
1042 1043 1044 |
# File 'lib/stripe/services/subscription_service.rb', line 1042 def type @type end |