Class: Stripe::SubscriptionService::CreateParams::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



874
875
876
877
# File 'lib/stripe/services/subscription_service.rb', line 874

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



870
871
872
# File 'lib/stripe/services/subscription_service.rb', line 870

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



872
873
874
# File 'lib/stripe/services/subscription_service.rb', line 872

def type
  @type
end