Class: Stripe::SubscriptionService::CreateParams::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
1167 1168 1169 1170 1171 1172 1173 |
# File 'lib/stripe/services/subscription_service.rb', line 1167 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
1157 1158 1159 |
# File 'lib/stripe/services/subscription_service.rb', line 1157 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
1159 1160 1161 |
# File 'lib/stripe/services/subscription_service.rb', line 1159 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
1161 1162 1163 |
# File 'lib/stripe/services/subscription_service.rb', line 1161 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
1163 1164 1165 |
# File 'lib/stripe/services/subscription_service.rb', line 1163 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
1165 1166 1167 |
# File 'lib/stripe/services/subscription_service.rb', line 1165 def second @second end |