Class: Stripe::SubscriptionService::CreateParams::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
997 998 999 1000 1001 1002 1003 |
# File 'lib/stripe/services/subscription_service.rb', line 997 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
987 988 989 |
# File 'lib/stripe/services/subscription_service.rb', line 987 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
989 990 991 |
# File 'lib/stripe/services/subscription_service.rb', line 989 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
991 992 993 |
# File 'lib/stripe/services/subscription_service.rb', line 991 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
993 994 995 |
# File 'lib/stripe/services/subscription_service.rb', line 993 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
995 996 997 |
# File 'lib/stripe/services/subscription_service.rb', line 995 def second @second end |