Class: Stripe::SubscriptionService::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Discount
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1134 1135 1136 1137 1138 1139 |
# File 'lib/stripe/services/subscription_service.rb', line 1134 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1126 1127 1128 |
# File 'lib/stripe/services/subscription_service.rb', line 1126 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1128 1129 1130 |
# File 'lib/stripe/services/subscription_service.rb', line 1128 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1130 1131 1132 |
# File 'lib/stripe/services/subscription_service.rb', line 1130 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1132 1133 1134 |
# File 'lib/stripe/services/subscription_service.rb', line 1132 def promotion_code @promotion_code end |