Class: Stripe::SubscriptionService::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1060
1061
1062
1063
1064
1065
# File 'lib/stripe/services/subscription_service.rb', line 1060

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1052
1053
1054
# File 'lib/stripe/services/subscription_service.rb', line 1052

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1054
1055
1056
# File 'lib/stripe/services/subscription_service.rb', line 1054

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1056
1057
1058
# File 'lib/stripe/services/subscription_service.rb', line 1056

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1058
1059
1060
# File 'lib/stripe/services/subscription_service.rb', line 1058

def promotion_code
  @promotion_code
end