Class: Stripe::SubscriptionService::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1105
1106
1107
1108
1109
1110
# File 'lib/stripe/services/subscription_service.rb', line 1105

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1097
1098
1099
# File 'lib/stripe/services/subscription_service.rb', line 1097

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1099
1100
1101
# File 'lib/stripe/services/subscription_service.rb', line 1099

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1101
1102
1103
# File 'lib/stripe/services/subscription_service.rb', line 1101

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1103
1104
1105
# File 'lib/stripe/services/subscription_service.rb', line 1103

def promotion_code
  @promotion_code
end