Class: Stripe::SubscriptionService::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Discount
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1105 1106 1107 1108 1109 1110 |
# File 'lib/stripe/services/subscription_service.rb', line 1105 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1097 1098 1099 |
# File 'lib/stripe/services/subscription_service.rb', line 1097 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1099 1100 1101 |
# File 'lib/stripe/services/subscription_service.rb', line 1099 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1101 1102 1103 |
# File 'lib/stripe/services/subscription_service.rb', line 1101 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1103 1104 1105 |
# File 'lib/stripe/services/subscription_service.rb', line 1103 def promotion_code @promotion_code end |