Class: Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1119 1120 1121 1122 1123 |
# File 'lib/stripe/services/subscription_service.rb', line 1119 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1113 1114 1115 |
# File 'lib/stripe/services/subscription_service.rb', line 1113 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1115 1116 1117 |
# File 'lib/stripe/services/subscription_service.rb', line 1115 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1117 1118 1119 |
# File 'lib/stripe/services/subscription_service.rb', line 1117 def type @type end |