Class: Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1080 1081 1082 1083 1084 |
# File 'lib/stripe/services/subscription_service.rb', line 1080 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1074 1075 1076 |
# File 'lib/stripe/services/subscription_service.rb', line 1074 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1076 1077 1078 |
# File 'lib/stripe/services/subscription_service.rb', line 1076 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1078 1079 1080 |
# File 'lib/stripe/services/subscription_service.rb', line 1078 def type @type end |