Class: Stripe::SubscriptionService::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1090
1091
1092
1093
1094
# File 'lib/stripe/services/subscription_service.rb', line 1090

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1084
1085
1086
# File 'lib/stripe/services/subscription_service.rb', line 1084

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1086
1087
1088
# File 'lib/stripe/services/subscription_service.rb', line 1086

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1088
1089
1090
# File 'lib/stripe/services/subscription_service.rb', line 1088

def type
  @type
end