Class: Stripe::SubscriptionService::CreateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



1120
1121
1122
1123
# File 'lib/stripe/services/subscription_service.rb', line 1120

def initialize(account_tax_ids: nil, issuer: nil)
  @account_tax_ids = 
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.



1116
1117
1118
# File 'lib/stripe/services/subscription_service.rb', line 1116

def 
  @account_tax_ids
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1118
1119
1120
# File 'lib/stripe/services/subscription_service.rb', line 1118

def issuer
  @issuer
end