Class: Stripe::SubscriptionService::CreateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
# File 'lib/stripe/services/subscription_service.rb', line 1290

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1272
1273
1274
# File 'lib/stripe/services/subscription_service.rb', line 1272

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1274
1275
1276
# File 'lib/stripe/services/subscription_service.rb', line 1274

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1276
1277
1278
# File 'lib/stripe/services/subscription_service.rb', line 1276

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1278
1279
1280
# File 'lib/stripe/services/subscription_service.rb', line 1278

def plan
  @plan
end

#priceObject

The ID of the price object.



1280
1281
1282
# File 'lib/stripe/services/subscription_service.rb', line 1280

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1282
1283
1284
# File 'lib/stripe/services/subscription_service.rb', line 1282

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1284
1285
1286
# File 'lib/stripe/services/subscription_service.rb', line 1284

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1286
1287
1288
# File 'lib/stripe/services/subscription_service.rb', line 1286

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



1288
1289
1290
# File 'lib/stripe/services/subscription_service.rb', line 1288

def trial
  @trial
end