Class: Stripe::SubscriptionService::CreateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/stripe/services/subscription_service.rb', line 1050

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1034
1035
1036
# File 'lib/stripe/services/subscription_service.rb', line 1034

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1036
1037
1038
# File 'lib/stripe/services/subscription_service.rb', line 1036

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1038
1039
1040
# File 'lib/stripe/services/subscription_service.rb', line 1038

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1040
1041
1042
# File 'lib/stripe/services/subscription_service.rb', line 1040

def plan
  @plan
end

#priceObject

The ID of the price object.



1042
1043
1044
# File 'lib/stripe/services/subscription_service.rb', line 1042

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1044
1045
1046
# File 'lib/stripe/services/subscription_service.rb', line 1044

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1046
1047
1048
# File 'lib/stripe/services/subscription_service.rb', line 1046

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1048
1049
1050
# File 'lib/stripe/services/subscription_service.rb', line 1048

def tax_rates
  @tax_rates
end