Class: Stripe::SubscriptionService::CreateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Item
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#trial ⇒ Object
Define options to configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
Returns a new instance of Item.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/stripe/services/subscription_service.rb', line 1205 def initialize( discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1189 1190 1191 |
# File 'lib/stripe/services/subscription_service.rb', line 1189 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1191 1192 1193 |
# File 'lib/stripe/services/subscription_service.rb', line 1191 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
1193 1194 1195 |
# File 'lib/stripe/services/subscription_service.rb', line 1193 def plan @plan end |
#price ⇒ Object
The ID of the price object.
1195 1196 1197 |
# File 'lib/stripe/services/subscription_service.rb', line 1195 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
1197 1198 1199 |
# File 'lib/stripe/services/subscription_service.rb', line 1197 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
1199 1200 1201 |
# File 'lib/stripe/services/subscription_service.rb', line 1199 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
1201 1202 1203 |
# File 'lib/stripe/services/subscription_service.rb', line 1201 def tax_rates @tax_rates end |
#trial ⇒ Object
Define options to configure the trial on the subscription item.
1203 1204 1205 |
# File 'lib/stripe/services/subscription_service.rb', line 1203 def trial @trial end |