Class: Stripe::SubscriptionService::CreateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
# File 'lib/stripe/services/subscription_service.rb', line 1442

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



1416
1417
1418
# File 'lib/stripe/services/subscription_service.rb', line 1416

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1419
1420
1421
# File 'lib/stripe/services/subscription_service.rb', line 1419

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1422
1423
1424
# File 'lib/stripe/services/subscription_service.rb', line 1422

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1425
1426
1427
# File 'lib/stripe/services/subscription_service.rb', line 1425

def plan
  @plan
end

#priceObject

The ID of the price object.



1428
1429
1430
# File 'lib/stripe/services/subscription_service.rb', line 1428

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1431
1432
1433
# File 'lib/stripe/services/subscription_service.rb', line 1431

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1434
1435
1436
# File 'lib/stripe/services/subscription_service.rb', line 1434

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1437
1438
1439
# File 'lib/stripe/services/subscription_service.rb', line 1437

def tax_rates
  @tax_rates
end

#trialObject

Define options to configure the trial on the subscription item.



1440
1441
1442
# File 'lib/stripe/services/subscription_service.rb', line 1440

def trial
  @trial
end