Class: Stripe::SubscriptionService::CreateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::Item::Discount
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
985 986 987 988 989 |
# File 'lib/stripe/services/subscription_service.rb', line 985 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
979 980 981 |
# File 'lib/stripe/services/subscription_service.rb', line 979 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
981 982 983 |
# File 'lib/stripe/services/subscription_service.rb', line 981 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
983 984 985 |
# File 'lib/stripe/services/subscription_service.rb', line 983 def promotion_code @promotion_code end |