Class: Stripe::SubscriptionService::CreateParams::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1171
1172
1173
1174
1175
1176
# File 'lib/stripe/services/subscription_service.rb', line 1171

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1163
1164
1165
# File 'lib/stripe/services/subscription_service.rb', line 1163

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1165
1166
1167
# File 'lib/stripe/services/subscription_service.rb', line 1165

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1167
1168
1169
# File 'lib/stripe/services/subscription_service.rb', line 1167

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1169
1170
1171
# File 'lib/stripe/services/subscription_service.rb', line 1169

def promotion_code
  @promotion_code
end