Class: Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, Konbini, SepaDebit, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/stripe/services/subscription_service.rb', line 1204 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @konbini = konbini @sepa_debit = sepa_debit @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
1190 1191 1192 |
# File 'lib/stripe/services/subscription_service.rb', line 1190 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
1192 1193 1194 |
# File 'lib/stripe/services/subscription_service.rb', line 1192 def bancontact @bancontact end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
1194 1195 1196 |
# File 'lib/stripe/services/subscription_service.rb', line 1194 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
1196 1197 1198 |
# File 'lib/stripe/services/subscription_service.rb', line 1196 def customer_balance @customer_balance end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
1198 1199 1200 |
# File 'lib/stripe/services/subscription_service.rb', line 1198 def konbini @konbini end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
1200 1201 1202 |
# File 'lib/stripe/services/subscription_service.rb', line 1200 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
1202 1203 1204 |
# File 'lib/stripe/services/subscription_service.rb', line 1202 def us_bank_account @us_bank_account end |