Class: Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1353
1354
1355
1356
1357
# File 'lib/stripe/services/subscription_service.rb', line 1353

def initialize(amount: nil, amount_type: nil, description: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1347
1348
1349
# File 'lib/stripe/services/subscription_service.rb', line 1347

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1349
1350
1351
# File 'lib/stripe/services/subscription_service.rb', line 1349

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1351
1352
1353
# File 'lib/stripe/services/subscription_service.rb', line 1351

def description
  @description
end