Class: Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::CreateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
1173 1174 1175 1176 1177 |
# File 'lib/stripe/services/subscription_service.rb', line 1173 def initialize(filters: nil, permissions: nil, prefetch: nil) @filters = filters @permissions = @prefetch = prefetch end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
1167 1168 1169 |
# File 'lib/stripe/services/subscription_service.rb', line 1167 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
1169 1170 1171 |
# File 'lib/stripe/services/subscription_service.rb', line 1169 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
1171 1172 1173 |
# File 'lib/stripe/services/subscription_service.rb', line 1171 def prefetch @prefetch end |