Class: Stripe::SubscriptionService::CreateParams::Prebilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(iterations: nil, update_behavior: nil) ⇒ Prebilling

Returns a new instance of Prebilling.



1696
1697
1698
1699
# File 'lib/stripe/services/subscription_service.rb', line 1696

def initialize(iterations: nil, update_behavior: nil)
  @iterations = iterations
  @update_behavior = update_behavior
end

Instance Attribute Details

#iterationsObject

This is used to determine the number of billing cycles to prebill.



1691
1692
1693
# File 'lib/stripe/services/subscription_service.rb', line 1691

def iterations
  @iterations
end

#update_behaviorObject

Whether to cancel or preserve ‘prebilling` if the subscription is updated during the prebilled period. The default value is `reset`.



1694
1695
1696
# File 'lib/stripe/services/subscription_service.rb', line 1694

def update_behavior
  @update_behavior
end