Class: Stripe::SubscriptionService::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1559
1560
1561
1562
# File 'lib/stripe/services/subscription_service.rb', line 1559

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1555
1556
1557
# File 'lib/stripe/services/subscription_service.rb', line 1555

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1557
1558
1559
# File 'lib/stripe/services/subscription_service.rb', line 1557

def destination
  @destination
end