Class: Stripe::SubscriptionService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
# File 'lib/stripe/services/subscription_service.rb', line 817

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



789
790
791
# File 'lib/stripe/services/subscription_service.rb', line 789

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



791
792
793
# File 'lib/stripe/services/subscription_service.rb', line 791

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



793
794
795
# File 'lib/stripe/services/subscription_service.rb', line 793

def created
  @created
end

#current_period_endObject

Only return subscriptions whose minimum item current_period_end falls within the given date interval.



795
796
797
# File 'lib/stripe/services/subscription_service.rb', line 795

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose maximum item current_period_start falls within the given date interval.



797
798
799
# File 'lib/stripe/services/subscription_service.rb', line 797

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



799
800
801
# File 'lib/stripe/services/subscription_service.rb', line 799

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



801
802
803
# File 'lib/stripe/services/subscription_service.rb', line 801

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



803
804
805
# File 'lib/stripe/services/subscription_service.rb', line 803

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



805
806
807
# File 'lib/stripe/services/subscription_service.rb', line 805

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



807
808
809
# File 'lib/stripe/services/subscription_service.rb', line 807

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



809
810
811
# File 'lib/stripe/services/subscription_service.rb', line 809

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



811
812
813
# File 'lib/stripe/services/subscription_service.rb', line 811

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



813
814
815
# File 'lib/stripe/services/subscription_service.rb', line 813

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



815
816
817
# File 'lib/stripe/services/subscription_service.rb', line 815

def test_clock
  @test_clock
end