Class: Stripe::SubscriptionService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
# File 'lib/stripe/services/subscription_service.rb', line 908

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



878
879
880
# File 'lib/stripe/services/subscription_service.rb', line 878

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



880
881
882
# File 'lib/stripe/services/subscription_service.rb', line 880

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



882
883
884
# File 'lib/stripe/services/subscription_service.rb', line 882

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



884
885
886
# File 'lib/stripe/services/subscription_service.rb', line 884

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



886
887
888
# File 'lib/stripe/services/subscription_service.rb', line 886

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



888
889
890
# File 'lib/stripe/services/subscription_service.rb', line 888

def customer
  @customer
end

#customer_accountObject

The ID of the account whose subscriptions will be retrieved.



890
891
892
# File 'lib/stripe/services/subscription_service.rb', line 890

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



892
893
894
# File 'lib/stripe/services/subscription_service.rb', line 892

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



894
895
896
# File 'lib/stripe/services/subscription_service.rb', line 894

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



896
897
898
# File 'lib/stripe/services/subscription_service.rb', line 896

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



898
899
900
# File 'lib/stripe/services/subscription_service.rb', line 898

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



900
901
902
# File 'lib/stripe/services/subscription_service.rb', line 900

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



902
903
904
# File 'lib/stripe/services/subscription_service.rb', line 902

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



904
905
906
# File 'lib/stripe/services/subscription_service.rb', line 904

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



906
907
908
# File 'lib/stripe/services/subscription_service.rb', line 906

def test_clock
  @test_clock
end