Class: Stripe::SubscriptionService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
# File 'lib/stripe/services/subscription_service.rb', line 768

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



740
741
742
# File 'lib/stripe/services/subscription_service.rb', line 740

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



742
743
744
# File 'lib/stripe/services/subscription_service.rb', line 742

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



744
745
746
# File 'lib/stripe/services/subscription_service.rb', line 744

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



746
747
748
# File 'lib/stripe/services/subscription_service.rb', line 746

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



748
749
750
# File 'lib/stripe/services/subscription_service.rb', line 748

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



750
751
752
# File 'lib/stripe/services/subscription_service.rb', line 750

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



752
753
754
# File 'lib/stripe/services/subscription_service.rb', line 752

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



754
755
756
# File 'lib/stripe/services/subscription_service.rb', line 754

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



756
757
758
# File 'lib/stripe/services/subscription_service.rb', line 756

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



758
759
760
# File 'lib/stripe/services/subscription_service.rb', line 758

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



760
761
762
# File 'lib/stripe/services/subscription_service.rb', line 760

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



762
763
764
# File 'lib/stripe/services/subscription_service.rb', line 762

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



764
765
766
# File 'lib/stripe/services/subscription_service.rb', line 764

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



766
767
768
# File 'lib/stripe/services/subscription_service.rb', line 766

def test_clock
  @test_clock
end