Class: Stripe::SubscriptionService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
# File 'lib/stripe/services/subscription_service.rb', line 855

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



825
826
827
# File 'lib/stripe/services/subscription_service.rb', line 825

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



827
828
829
# File 'lib/stripe/services/subscription_service.rb', line 827

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



829
830
831
# File 'lib/stripe/services/subscription_service.rb', line 829

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



831
832
833
# File 'lib/stripe/services/subscription_service.rb', line 831

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



833
834
835
# File 'lib/stripe/services/subscription_service.rb', line 833

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



835
836
837
# File 'lib/stripe/services/subscription_service.rb', line 835

def customer
  @customer
end

#customer_accountObject

Attribute for param field customer_account



837
838
839
# File 'lib/stripe/services/subscription_service.rb', line 837

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



839
840
841
# File 'lib/stripe/services/subscription_service.rb', line 839

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



841
842
843
# File 'lib/stripe/services/subscription_service.rb', line 841

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



843
844
845
# File 'lib/stripe/services/subscription_service.rb', line 843

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



845
846
847
# File 'lib/stripe/services/subscription_service.rb', line 845

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



847
848
849
# File 'lib/stripe/services/subscription_service.rb', line 847

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



849
850
851
# File 'lib/stripe/services/subscription_service.rb', line 849

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



851
852
853
# File 'lib/stripe/services/subscription_service.rb', line 851

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



853
854
855
# File 'lib/stripe/services/subscription_service.rb', line 853

def test_clock
  @test_clock
end