Class: Stripe::SubscriptionService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
# File 'lib/stripe/services/subscription_service.rb', line 890

def initialize(
  automatic_tax: nil,
  collection_method: nil,
  created: nil,
  current_period_end: nil,
  current_period_start: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  plan: nil,
  price: nil,
  starting_after: nil,
  status: nil,
  test_clock: nil
)
  @automatic_tax = automatic_tax
  @collection_method = collection_method
  @created = created
  @current_period_end = current_period_end
  @current_period_start = current_period_start
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @plan = plan
  @price = price
  @starting_after = starting_after
  @status = status
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_taxObject

Filter subscriptions by their automatic tax settings.



862
863
864
# File 'lib/stripe/services/subscription_service.rb', line 862

def automatic_tax
  @automatic_tax
end

#collection_methodObject

The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.



864
865
866
# File 'lib/stripe/services/subscription_service.rb', line 864

def collection_method
  @collection_method
end

#createdObject

Only return subscriptions that were created during the given date interval.



866
867
868
# File 'lib/stripe/services/subscription_service.rb', line 866

def created
  @created
end

#current_period_endObject

Only return subscriptions whose current_period_end falls within the given date interval.



868
869
870
# File 'lib/stripe/services/subscription_service.rb', line 868

def current_period_end
  @current_period_end
end

#current_period_startObject

Only return subscriptions whose current_period_start falls within the given date interval.



870
871
872
# File 'lib/stripe/services/subscription_service.rb', line 870

def current_period_start
  @current_period_start
end

#customerObject

The ID of the customer whose subscriptions will be retrieved.



872
873
874
# File 'lib/stripe/services/subscription_service.rb', line 872

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



874
875
876
# File 'lib/stripe/services/subscription_service.rb', line 874

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



876
877
878
# File 'lib/stripe/services/subscription_service.rb', line 876

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



878
879
880
# File 'lib/stripe/services/subscription_service.rb', line 878

def limit
  @limit
end

#planObject

The ID of the plan whose subscriptions will be retrieved.



880
881
882
# File 'lib/stripe/services/subscription_service.rb', line 880

def plan
  @plan
end

#priceObject

Filter for subscriptions that contain this recurring price ID.



882
883
884
# File 'lib/stripe/services/subscription_service.rb', line 882

def price
  @price
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



884
885
886
# File 'lib/stripe/services/subscription_service.rb', line 884

def starting_after
  @starting_after
end

#statusObject

The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.



886
887
888
# File 'lib/stripe/services/subscription_service.rb', line 886

def status
  @status
end

#test_clockObject

Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.



888
889
890
# File 'lib/stripe/services/subscription_service.rb', line 888

def test_clock
  @test_clock
end