Class: Stripe::SubscriptionService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::ListParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: AutomaticTax, Created, CurrentPeriodEnd, CurrentPeriodStart
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Filter subscriptions by their automatic tax settings.
-
#collection_method ⇒ Object
The collection method of the subscriptions to retrieve.
-
#created ⇒ Object
Only return subscriptions that were created during the given date interval.
-
#current_period_end ⇒ Object
Only return subscriptions whose current_period_end falls within the given date interval.
-
#current_period_start ⇒ Object
Only return subscriptions whose current_period_start falls within the given date interval.
-
#customer ⇒ Object
The ID of the customer whose subscriptions will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#plan ⇒ Object
The ID of the plan whose subscriptions will be retrieved.
-
#price ⇒ Object
Filter for subscriptions that contain this recurring price ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the subscriptions to retrieve.
-
#test_clock ⇒ Object
Filter for subscriptions that are associated with the specified test clock.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil) ⇒ ListParams
Returns a new instance of ListParams.
1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 |
# File 'lib/stripe/services/subscription_service.rb', line 1021 def initialize( automatic_tax: nil, collection_method: nil, created: nil, current_period_end: nil, current_period_start: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, plan: nil, price: nil, starting_after: nil, status: nil, test_clock: nil ) @automatic_tax = automatic_tax @collection_method = collection_method @created = created @current_period_end = current_period_end @current_period_start = current_period_start @customer = customer @ending_before = ending_before @expand = @limit = limit @plan = plan @price = price @starting_after = starting_after @status = status @test_clock = test_clock end |
Instance Attribute Details
#automatic_tax ⇒ Object
Filter subscriptions by their automatic tax settings.
980 981 982 |
# File 'lib/stripe/services/subscription_service.rb', line 980 def automatic_tax @automatic_tax end |
#collection_method ⇒ Object
The collection method of the subscriptions to retrieve. Either ‘charge_automatically` or `send_invoice`.
983 984 985 |
# File 'lib/stripe/services/subscription_service.rb', line 983 def collection_method @collection_method end |
#created ⇒ Object
Only return subscriptions that were created during the given date interval.
986 987 988 |
# File 'lib/stripe/services/subscription_service.rb', line 986 def created @created end |
#current_period_end ⇒ Object
Only return subscriptions whose current_period_end falls within the given date interval.
989 990 991 |
# File 'lib/stripe/services/subscription_service.rb', line 989 def current_period_end @current_period_end end |
#current_period_start ⇒ Object
Only return subscriptions whose current_period_start falls within the given date interval.
992 993 994 |
# File 'lib/stripe/services/subscription_service.rb', line 992 def current_period_start @current_period_start end |
#customer ⇒ Object
The ID of the customer whose subscriptions will be retrieved.
995 996 997 |
# File 'lib/stripe/services/subscription_service.rb', line 995 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
998 999 1000 |
# File 'lib/stripe/services/subscription_service.rb', line 998 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1001 1002 1003 |
# File 'lib/stripe/services/subscription_service.rb', line 1001 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1004 1005 1006 |
# File 'lib/stripe/services/subscription_service.rb', line 1004 def limit @limit end |
#plan ⇒ Object
The ID of the plan whose subscriptions will be retrieved.
1007 1008 1009 |
# File 'lib/stripe/services/subscription_service.rb', line 1007 def plan @plan end |
#price ⇒ Object
Filter for subscriptions that contain this recurring price ID.
1010 1011 1012 |
# File 'lib/stripe/services/subscription_service.rb', line 1010 def price @price end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1013 1014 1015 |
# File 'lib/stripe/services/subscription_service.rb', line 1013 def starting_after @starting_after end |
#status ⇒ Object
The status of the subscriptions to retrieve. Passing in a value of ‘canceled` will return all canceled subscriptions, including those belonging to deleted customers. Pass `ended` to find subscriptions that are canceled and subscriptions that are expired due to [incomplete payment](stripe.com/docs/billing/subscriptions/overview#subscription-statuses). Passing in a value of `all` will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned.
1016 1017 1018 |
# File 'lib/stripe/services/subscription_service.rb', line 1016 def status @status end |
#test_clock ⇒ Object
Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set.
1019 1020 1021 |
# File 'lib/stripe/services/subscription_service.rb', line 1019 def test_clock @test_clock end |