Class: Stripe::SubscriptionService::MigrateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::MigrateParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: BillingMode
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams
constructor
A new instance of MigrateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams
Returns a new instance of MigrateParams.
1887 1888 1889 1890 |
# File 'lib/stripe/services/subscription_service.rb', line 1887 def initialize(billing_mode: nil, expand: nil) @billing_mode = billing_mode @expand = end |
Instance Attribute Details
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
1883 1884 1885 |
# File 'lib/stripe/services/subscription_service.rb', line 1883 def billing_mode @billing_mode end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1885 1886 1887 |
# File 'lib/stripe/services/subscription_service.rb', line 1885 def @expand end |