Class: Stripe::SubscriptionService::MigrateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



1773
1774
1775
1776
# File 'lib/stripe/services/subscription_service.rb', line 1773

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1769
1770
1771
# File 'lib/stripe/services/subscription_service.rb', line 1769

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



1771
1772
1773
# File 'lib/stripe/services/subscription_service.rb', line 1771

def expand
  @expand
end