Class: Stripe::SubscriptionService::MigrateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingMode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams

Returns a new instance of MigrateParams.



1473
1474
1475
1476
# File 'lib/stripe/services/subscription_service.rb', line 1473

def initialize(billing_mode: nil, expand: nil)
  @billing_mode = billing_mode
  @expand = expand
end

Instance Attribute Details

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1469
1470
1471
# File 'lib/stripe/services/subscription_service.rb', line 1469

def billing_mode
  @billing_mode
end

#expandObject

Specifies which fields in the response should be expanded.



1471
1472
1473
# File 'lib/stripe/services/subscription_service.rb', line 1471

def expand
  @expand
end