Class: Stripe::SubscriptionService::MigrateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::MigrateParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams
constructor
A new instance of MigrateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_mode: nil, expand: nil) ⇒ MigrateParams
Returns a new instance of MigrateParams.
1696 1697 1698 1699 |
# File 'lib/stripe/services/subscription_service.rb', line 1696 def initialize(billing_mode: nil, expand: nil) @billing_mode = billing_mode @expand = end |
Instance Attribute Details
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
1692 1693 1694 |
# File 'lib/stripe/services/subscription_service.rb', line 1692 def billing_mode @billing_mode end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1694 1695 1696 |
# File 'lib/stripe/services/subscription_service.rb', line 1694 def @expand end |