Class: Stripe::SubscriptionService::ResumeParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil) ⇒ ResumeParams

Returns a new instance of ResumeParams.



1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
# File 'lib/stripe/services/subscription_service.rb', line 1729

def initialize(
  billing_cycle_anchor: nil,
  expand: nil,
  proration_behavior: nil,
  proration_date: nil
)
  @billing_cycle_anchor = billing_cycle_anchor
  @expand = expand
  @proration_behavior = proration_behavior
  @proration_date = proration_date
end

Instance Attribute Details

#billing_cycle_anchorObject

The billing cycle anchor that applies when the subscription is resumed. Either ‘now` or `unchanged`. The default is `now`. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



1721
1722
1723
# File 'lib/stripe/services/subscription_service.rb', line 1721

def billing_cycle_anchor
  @billing_cycle_anchor
end

#expandObject

Specifies which fields in the response should be expanded.



1723
1724
1725
# File 'lib/stripe/services/subscription_service.rb', line 1723

def expand
  @expand
end

#proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) resulting from the ‘billing_cycle_anchor` being `unchanged`. When the `billing_cycle_anchor` is set to `now` (default value), no prorations are generated. If no value is passed, the default is `create_prorations`.



1725
1726
1727
# File 'lib/stripe/services/subscription_service.rb', line 1725

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, prorations will be calculated as though the subscription was resumed at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](stripe.com/docs/api/invoices/create_preview) endpoint.



1727
1728
1729
# File 'lib/stripe/services/subscription_service.rb', line 1727

def proration_date
  @proration_date
end