Class: Stripe::SubscriptionService::ResumeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::ResumeParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
The billing cycle anchor that applies when the subscription is resumed.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was resumed at the given time.
Instance Method Summary collapse
-
#initialize(billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil) ⇒ ResumeParams
constructor
A new instance of ResumeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil) ⇒ ResumeParams
Returns a new instance of ResumeParams.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 |
# File 'lib/stripe/services/subscription_service.rb', line 1715 def initialize( billing_cycle_anchor: nil, expand: nil, proration_behavior: nil, proration_date: nil ) @billing_cycle_anchor = billing_cycle_anchor @expand = @proration_behavior = proration_behavior @proration_date = proration_date end |
Instance Attribute Details
#billing_cycle_anchor ⇒ Object
The billing cycle anchor that applies when the subscription is resumed. Either ‘now` or `unchanged`. The default is `now`. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
1707 1708 1709 |
# File 'lib/stripe/services/subscription_service.rb', line 1707 def billing_cycle_anchor @billing_cycle_anchor end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1709 1710 1711 |
# File 'lib/stripe/services/subscription_service.rb', line 1709 def @expand end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
1711 1712 1713 |
# File 'lib/stripe/services/subscription_service.rb', line 1711 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, the proration will be calculated as though the subscription was resumed at the given time. This can be used to apply exactly the same proration that was previewed with [upcoming invoice](stripe.com/docs/api#retrieve_customer_invoice) endpoint.
1713 1714 1715 |
# File 'lib/stripe/services/subscription_service.rb', line 1713 def proration_date @proration_date end |