Class: Stripe::SubscriptionService::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



1451
1452
1453
1454
1455
1456
# File 'lib/stripe/services/subscription_service.rb', line 1451

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1443
1444
1445
# File 'lib/stripe/services/subscription_service.rb', line 1443

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1445
1446
1447
# File 'lib/stripe/services/subscription_service.rb', line 1445

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



1447
1448
1449
# File 'lib/stripe/services/subscription_service.rb', line 1447

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).



1449
1450
1451
# File 'lib/stripe/services/subscription_service.rb', line 1449

def query
  @query
end