Class: Stripe::SubscriptionService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::SearchParams
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
1682 1683 1684 1685 1686 1687 |
# File 'lib/stripe/services/subscription_service.rb', line 1682 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1674 1675 1676 |
# File 'lib/stripe/services/subscription_service.rb', line 1674 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1676 1677 1678 |
# File 'lib/stripe/services/subscription_service.rb', line 1676 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
1678 1679 1680 |
# File 'lib/stripe/services/subscription_service.rb', line 1678 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for subscriptions](stripe.com/docs/search#query-fields-for-subscriptions).
1680 1681 1682 |
# File 'lib/stripe/services/subscription_service.rb', line 1680 def query @query end |