Class: Stripe::SubscriptionService::UpdateParams::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/stripe/services/subscription_service.rb', line 137

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



123
124
125
# File 'lib/stripe/services/subscription_service.rb', line 123

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



125
126
127
# File 'lib/stripe/services/subscription_service.rb', line 125

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the current period of the subscription.



127
128
129
# File 'lib/stripe/services/subscription_service.rb', line 127

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



129
130
131
# File 'lib/stripe/services/subscription_service.rb', line 129

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



131
132
133
# File 'lib/stripe/services/subscription_service.rb', line 131

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



133
134
135
# File 'lib/stripe/services/subscription_service.rb', line 133

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



135
136
137
# File 'lib/stripe/services/subscription_service.rb', line 135

def tax_rates
  @tax_rates
end