Class: Stripe::SubscriptionService::UpdateParams::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



198
199
200
201
# File 'lib/stripe/services/subscription_service.rb', line 198

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



193
194
195
# File 'lib/stripe/services/subscription_service.rb', line 193

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



196
197
198
# File 'lib/stripe/services/subscription_service.rb', line 196

def feedback
  @feedback
end