Class: Stripe::SubscriptionService::UpdateParams::CancellationDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::UpdateParams::CancellationDetails
- Defined in:
- lib/stripe/services/subscription_service.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
-
#feedback ⇒ Object
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
Instance Method Summary collapse
-
#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails
constructor
A new instance of CancellationDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails
Returns a new instance of CancellationDetails.
198 199 200 201 |
# File 'lib/stripe/services/subscription_service.rb', line 198 def initialize(comment: nil, feedback: nil) @comment = comment @feedback = feedback end |
Instance Attribute Details
#comment ⇒ Object
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
193 194 195 |
# File 'lib/stripe/services/subscription_service.rb', line 193 def comment @comment end |
#feedback ⇒ Object
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
196 197 198 |
# File 'lib/stripe/services/subscription_service.rb', line 196 def feedback @feedback end |