Class: Stripe::SubscriptionService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



205
206
207
208
209
210
# File 'lib/stripe/services/subscription_service.rb', line 205

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



197
198
199
# File 'lib/stripe/services/subscription_service.rb', line 197

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



199
200
201
# File 'lib/stripe/services/subscription_service.rb', line 199

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



201
202
203
# File 'lib/stripe/services/subscription_service.rb', line 201

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



203
204
205
# File 'lib/stripe/services/subscription_service.rb', line 203

def promotion_code
  @promotion_code
end