Class: Stripe::SubscriptionService::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::UpdateParams::Discount
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
245 246 247 248 249 250 |
# File 'lib/stripe/services/subscription_service.rb', line 245 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
234 235 236 |
# File 'lib/stripe/services/subscription_service.rb', line 234 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
237 238 239 |
# File 'lib/stripe/services/subscription_service.rb', line 237 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
240 241 242 |
# File 'lib/stripe/services/subscription_service.rb', line 240 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
243 244 245 |
# File 'lib/stripe/services/subscription_service.rb', line 243 def promotion_code @promotion_code end |