Class: Stripe::SubscriptionService::UpdateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/stripe/services/subscription_service.rb', line 365

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



343
344
345
# File 'lib/stripe/services/subscription_service.rb', line 343

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



345
346
347
# File 'lib/stripe/services/subscription_service.rb', line 345

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



347
348
349
# File 'lib/stripe/services/subscription_service.rb', line 347

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



349
350
351
# File 'lib/stripe/services/subscription_service.rb', line 349

def discounts
  @discounts
end

#idObject

Subscription item to update.



351
352
353
# File 'lib/stripe/services/subscription_service.rb', line 351

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



353
354
355
# File 'lib/stripe/services/subscription_service.rb', line 353

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



355
356
357
# File 'lib/stripe/services/subscription_service.rb', line 355

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



357
358
359
# File 'lib/stripe/services/subscription_service.rb', line 357

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



359
360
361
# File 'lib/stripe/services/subscription_service.rb', line 359

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



361
362
363
# File 'lib/stripe/services/subscription_service.rb', line 361

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



363
364
365
# File 'lib/stripe/services/subscription_service.rb', line 363

def tax_rates
  @tax_rates
end