Class: Stripe::SubscriptionService::UpdateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/stripe/services/subscription_service.rb', line 281

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



259
260
261
# File 'lib/stripe/services/subscription_service.rb', line 259

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



261
262
263
# File 'lib/stripe/services/subscription_service.rb', line 261

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



263
264
265
# File 'lib/stripe/services/subscription_service.rb', line 263

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



265
266
267
# File 'lib/stripe/services/subscription_service.rb', line 265

def discounts
  @discounts
end

#idObject

Subscription item to update.



267
268
269
# File 'lib/stripe/services/subscription_service.rb', line 267

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



269
270
271
# File 'lib/stripe/services/subscription_service.rb', line 269

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



271
272
273
# File 'lib/stripe/services/subscription_service.rb', line 271

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



273
274
275
# File 'lib/stripe/services/subscription_service.rb', line 273

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



275
276
277
# File 'lib/stripe/services/subscription_service.rb', line 275

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



277
278
279
# File 'lib/stripe/services/subscription_service.rb', line 277

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



279
280
281
# File 'lib/stripe/services/subscription_service.rb', line 279

def tax_rates
  @tax_rates
end