Class: Stripe::SubscriptionService::UpdateParams::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/stripe/services/subscription_service.rb', line 258

def initialize(
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



238
239
240
# File 'lib/stripe/services/subscription_service.rb', line 238

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



240
241
242
# File 'lib/stripe/services/subscription_service.rb', line 240

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



242
243
244
# File 'lib/stripe/services/subscription_service.rb', line 242

def discounts
  @discounts
end

#idObject

Subscription item to update.



244
245
246
# File 'lib/stripe/services/subscription_service.rb', line 244

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



246
247
248
# File 'lib/stripe/services/subscription_service.rb', line 246

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



248
249
250
# File 'lib/stripe/services/subscription_service.rb', line 248

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



250
251
252
# File 'lib/stripe/services/subscription_service.rb', line 250

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



252
253
254
# File 'lib/stripe/services/subscription_service.rb', line 252

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



254
255
256
# File 'lib/stripe/services/subscription_service.rb', line 254

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



256
257
258
# File 'lib/stripe/services/subscription_service.rb', line 256

def tax_rates
  @tax_rates
end