Class: Stripe::SubscriptionService::UpdateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionService::UpdateParams::Item::Discount
- Defined in:
- lib/stripe/services/subscription_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
329 330 331 332 333 334 |
# File 'lib/stripe/services/subscription_service.rb', line 329 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
318 319 320 |
# File 'lib/stripe/services/subscription_service.rb', line 318 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
321 322 323 |
# File 'lib/stripe/services/subscription_service.rb', line 321 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
324 325 326 |
# File 'lib/stripe/services/subscription_service.rb', line 324 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
327 328 329 |
# File 'lib/stripe/services/subscription_service.rb', line 327 def promotion_code @promotion_code end |