Class: Stripe::SubscriptionService::UpdateParams::PauseCollection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, resumes_at: nil) ⇒ PauseCollection

Returns a new instance of PauseCollection.



373
374
375
376
# File 'lib/stripe/services/subscription_service.rb', line 373

def initialize(behavior: nil, resumes_at: nil)
  @behavior = behavior
  @resumes_at = resumes_at
end

Instance Attribute Details

#behaviorObject

The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.



369
370
371
# File 'lib/stripe/services/subscription_service.rb', line 369

def behavior
  @behavior
end

#resumes_atObject

The time after which the subscription will resume collecting payments.



371
372
373
# File 'lib/stripe/services/subscription_service.rb', line 371

def resumes_at
  @resumes_at
end