Class: Stripe::SubscriptionService::UpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/subscription_service.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
# File 'lib/stripe/services/subscription_service.rb', line 628

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  sepa_debit: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @sepa_debit = sepa_debit
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



605
606
607
# File 'lib/stripe/services/subscription_service.rb', line 605

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



608
609
610
# File 'lib/stripe/services/subscription_service.rb', line 608

def bancontact
  @bancontact
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



611
612
613
# File 'lib/stripe/services/subscription_service.rb', line 611

def card
  @card
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



614
615
616
# File 'lib/stripe/services/subscription_service.rb', line 614

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



617
618
619
# File 'lib/stripe/services/subscription_service.rb', line 617

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



620
621
622
# File 'lib/stripe/services/subscription_service.rb', line 620

def konbini
  @konbini
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



623
624
625
# File 'lib/stripe/services/subscription_service.rb', line 623

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



626
627
628
# File 'lib/stripe/services/subscription_service.rb', line 626

def 
  @us_bank_account
end