Class: Stripe::SubscriptionUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingSchedule, BillingThresholds, CancellationDetails, Discount, InvoiceSettings, Item, PauseCollection, PaymentSettings, PendingInvoiceItemInterval, Prebilling, TransferData, TrialSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cadence: nil, billing_cycle_anchor: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, cancellation_details: nil, collection_method: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, pause_collection: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, prebilling: nil, proration_behavior: nil, proration_date: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_settings: nil) ⇒ SubscriptionUpdateParams

Returns a new instance of SubscriptionUpdateParams.



1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
# File 'lib/stripe/params/subscription_update_params.rb', line 1107

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cadence: nil,
  billing_cycle_anchor: nil,
  billing_schedules: nil,
  billing_thresholds: nil,
  cancel_at: nil,
  cancel_at_period_end: nil,
  cancellation_details: nil,
  collection_method: nil,
  days_until_due: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  invoice_settings: nil,
  items: nil,
  metadata: nil,
  off_session: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  payment_behavior: nil,
  payment_settings: nil,
  pending_invoice_item_interval: nil,
  prebilling: nil,
  proration_behavior: nil,
  proration_date: nil,
  transfer_data: nil,
  trial_end: nil,
  trial_from_plan: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cadence = billing_cadence
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules = billing_schedules
  @billing_thresholds = billing_thresholds
  @cancel_at = cancel_at
  @cancel_at_period_end = cancel_at_period_end
  @cancellation_details = cancellation_details
  @collection_method = collection_method
  @days_until_due = days_until_due
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @expand = expand
  @invoice_settings = invoice_settings
  @items = items
  @metadata = 
  @off_session = off_session
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @payment_behavior = payment_behavior
  @payment_settings = payment_settings
  @pending_invoice_item_interval = pending_invoice_item_interval
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @proration_date = proration_date
  @transfer_data = transfer_data
  @trial_end = trial_end
  @trial_from_plan = trial_from_plan
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.



1039
1040
1041
# File 'lib/stripe/params/subscription_update_params.rb', line 1039

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees documentation.



1041
1042
1043
# File 'lib/stripe/params/subscription_update_params.rb', line 1041

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.



1043
1044
1045
# File 'lib/stripe/params/subscription_update_params.rb', line 1043

def automatic_tax
  @automatic_tax
end

#billing_cadenceObject

The Billing Cadence which controls the timing of recurring invoice generation for this subscription. If unset, the subscription will bill according to its own configured schedule and create its own invoices. If set, this subscription will be billed by the cadence instead, potentially sharing invoices with the other subscriptions linked to that Cadence.



1045
1046
1047
# File 'lib/stripe/params/subscription_update_params.rb', line 1045

def billing_cadence
  @billing_cadence
end

#billing_cycle_anchorObject

Either now or unchanged. Setting the value to now resets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle documentation.



1047
1048
1049
# File 'lib/stripe/params/subscription_update_params.rb', line 1047

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedulesObject

Sets the billing schedules for the subscription.



1049
1050
1051
# File 'lib/stripe/params/subscription_update_params.rb', line 1049

def billing_schedules
  @billing_schedules
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



1051
1052
1053
# File 'lib/stripe/params/subscription_update_params.rb', line 1051

def billing_thresholds
  @billing_thresholds
end

#cancel_atObject

A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using proration_behavior. If set during a future period, this will always cause a proration for that period.



1053
1054
1055
# File 'lib/stripe/params/subscription_update_params.rb', line 1053

def cancel_at
  @cancel_at
end

#cancel_at_period_endObject

Indicate whether this subscription should cancel at the end of the current period (current_period_end).



1055
1056
1057
# File 'lib/stripe/params/subscription_update_params.rb', line 1055

def cancel_at_period_end
  @cancel_at_period_end
end

#cancellation_detailsObject

Details about why this subscription was cancelled



1057
1058
1059
# File 'lib/stripe/params/subscription_update_params.rb', line 1057

def cancellation_details
  @cancellation_details
end

#collection_methodObject

Either charge_automatically, or send_invoice. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as active. Defaults to charge_automatically.



1059
1060
1061
# File 'lib/stripe/params/subscription_update_params.rb', line 1059

def collection_method
  @collection_method
end

#days_until_dueObject

Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where collection_method is set to send_invoice.



1061
1062
1063
# File 'lib/stripe/params/subscription_update_params.rb', line 1061

def days_until_due
  @days_until_due
end

#default_payment_methodObject

ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over default_source. If neither are set, invoices will use the customer's invoice_settings.default_payment_method or default_source.



1063
1064
1065
# File 'lib/stripe/params/subscription_update_params.rb', line 1063

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If default_payment_method is also set, default_payment_method will take precedence. If neither are set, invoices will use the customer's invoice_settings.default_payment_method or default_source.



1065
1066
1067
# File 'lib/stripe/params/subscription_update_params.rb', line 1065

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any subscription item that does not have tax_rates set. Invoices created will have their default_tax_rates populated from the subscription. Pass an empty string to remove previously-defined tax rates.



1067
1068
1069
# File 'lib/stripe/params/subscription_update_params.rb', line 1067

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1069
1070
1071
# File 'lib/stripe/params/subscription_update_params.rb', line 1069

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the subscription. A populated array overwrites the existing discounts on the subscription. If not specified or empty array, it leaves the subscription's discounts unchanged. If empty string, it clears the subscription's discounts.



1071
1072
1073
# File 'lib/stripe/params/subscription_update_params.rb', line 1071

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



1073
1074
1075
# File 'lib/stripe/params/subscription_update_params.rb', line 1073

def expand
  @expand
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



1075
1076
1077
# File 'lib/stripe/params/subscription_update_params.rb', line 1075

def invoice_settings
  @invoice_settings
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



1077
1078
1079
# File 'lib/stripe/params/subscription_update_params.rb', line 1077

def items
  @items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



1079
1080
1081
# File 'lib/stripe/params/subscription_update_params.rb', line 1079

def 
  @metadata
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to false (on-session).



1081
1082
1083
# File 'lib/stripe/params/subscription_update_params.rb', line 1081

def off_session
  @off_session
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the subscription's invoices.



1083
1084
1085
# File 'lib/stripe/params/subscription_update_params.rb', line 1083

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to paused. Learn more about pausing collection.



1085
1086
1087
# File 'lib/stripe/params/subscription_update_params.rb', line 1085

def pause_collection
  @pause_collection
end

#payment_behaviorObject

Controls how Stripe handles payment when a subscription update requires payment and collection_method=charge_automatically.



1087
1088
1089
# File 'lib/stripe/params/subscription_update_params.rb', line 1087

def payment_behavior
  @payment_behavior
end

#payment_settingsObject

Payment settings to pass to invoices created by the subscription.



1089
1090
1091
# File 'lib/stripe/params/subscription_update_params.rb', line 1089

def payment_settings
  @payment_settings
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling Create an invoice for the given subscription at the specified interval.



1091
1092
1093
# File 'lib/stripe/params/subscription_update_params.rb', line 1091

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#prebillingObject

If specified, the invoicing for the given billing cycle iterations will be processed now.



1093
1094
1095
# File 'lib/stripe/params/subscription_update_params.rb', line 1093

def prebilling
  @prebilling
end

#proration_behaviorObject

Determines how to handle prorations when the billing cycle changes (e.g., when switching plans, resetting billing_cycle_anchor=now, or starting a trial), or if an item's quantity changes. The default value is create_prorations.



1095
1096
1097
# File 'lib/stripe/params/subscription_update_params.rb', line 1095

def proration_behavior
  @proration_behavior
end

#proration_dateObject

If set, prorations will be calculated as though the subscription was updated at the given time. This can be used to apply exactly the same prorations that were previewed with the create preview endpoint. proration_date can also be used to implement custom proration logic, such as prorating by day instead of by second, by providing the time that you wish to use for proration calculations.



1097
1098
1099
# File 'lib/stripe/params/subscription_update_params.rb', line 1097

def proration_date
  @proration_date
end

#transfer_dataObject

If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges. This will be unset if you POST an empty value.



1099
1100
1101
# File 'lib/stripe/params/subscription_update_params.rb', line 1099

def transfer_data
  @transfer_data
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. If set, trial_end will override the default trial period of the plan the customer is being subscribed to. The billing_cycle_anchor will be updated to the trial_end value. The special value now can be provided to end the customer's trial immediately. Can be at most two years from billing_cycle_anchor.



1101
1102
1103
# File 'lib/stripe/params/subscription_update_params.rb', line 1101

def trial_end
  @trial_end
end

#trial_from_planObject

Indicates if a plan's trial_period_days should be applied to the subscription. Setting trial_end per subscription is preferred, and this defaults to false. Setting this flag to true together with trial_end is not allowed. See Using trial periods on subscriptions to learn more.



1103
1104
1105
# File 'lib/stripe/params/subscription_update_params.rb', line 1103

def trial_from_plan
  @trial_from_plan
end

#trial_settingsObject

Settings related to subscription trials.



1105
1106
1107
# File 'lib/stripe/params/subscription_update_params.rb', line 1105

def trial_settings
  @trial_settings
end

Class Method Details

.field_encodingsObject



1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'lib/stripe/params/subscription_update_params.rb', line 1179

def self.field_encodings
  @field_encodings = {
    add_invoice_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
    items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end