Class: Stripe::SubscriptionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingSchedule, BillingThresholds, CancellationDetails, Discount, InvoiceSettings, Item, PauseCollection, PaymentSettings, PendingInvoiceItemInterval, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this subscription.
-
#billing_cycle_anchor ⇒ Object
Either ‘now` or `unchanged`.
-
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel.
-
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`).
-
#cancellation_details ⇒ Object
Details about why this subscription was cancelled.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription.
-
#default_source ⇒ Object
ID of the default payment source for the subscription.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
-
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused.
-
#payment_behavior ⇒ Object
Controls how Stripe handles payment when a subscription update requires payment and ‘collection_method=charge_automatically`.
-
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
-
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items.
-
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes.
-
#proration_date ⇒ Object
If set, prorations will be calculated as though the subscription was updated at the given time.
-
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, cancellation_details: nil, collection_method: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, pause_collection: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, proration_behavior: nil, proration_date: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_settings: nil) ⇒ SubscriptionUpdateParams
Returns a new instance of SubscriptionUpdateParams.
782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 |
# File 'lib/stripe/params/subscription_update_params.rb', line 782 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_schedules: nil, billing_thresholds: nil, cancel_at: nil, cancel_at_period_end: nil, cancellation_details: nil, collection_method: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, expand: nil, invoice_settings: nil, items: nil, metadata: nil, off_session: nil, on_behalf_of: nil, pause_collection: nil, payment_behavior: nil, payment_settings: nil, pending_invoice_item_interval: nil, proration_behavior: nil, proration_date: nil, transfer_data: nil, trial_end: nil, trial_from_plan: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_schedules = billing_schedules @billing_thresholds = billing_thresholds @cancel_at = cancel_at @cancel_at_period_end = cancel_at_period_end @cancellation_details = cancellation_details @collection_method = collection_method @days_until_due = days_until_due @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @expand = @invoice_settings = invoice_settings @items = items @metadata = @off_session = off_session @on_behalf_of = on_behalf_of @pause_collection = pause_collection @payment_behavior = payment_behavior @payment_settings = payment_settings @pending_invoice_item_interval = pending_invoice_item_interval @proration_behavior = proration_behavior @proration_date = proration_date @transfer_data = transfer_data @trial_end = trial_end @trial_from_plan = trial_from_plan @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this subscription. You may pass up to 20 items.
718 719 720 |
# File 'lib/stripe/params/subscription_update_params.rb', line 718 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
720 721 722 |
# File 'lib/stripe/params/subscription_update_params.rb', line 720 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this subscription. We recommend you only include this parameter when the existing value is being changed.
722 723 724 |
# File 'lib/stripe/params/subscription_update_params.rb', line 722 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Either ‘now` or `unchanged`. Setting the value to `now` resets the subscription’s billing cycle anchor to the current time (in UTC). For more information, see the billing cycle [documentation](docs.stripe.com/billing/subscriptions/billing-cycle).
724 725 726 |
# File 'lib/stripe/params/subscription_update_params.rb', line 724 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription.
726 727 728 |
# File 'lib/stripe/params/subscription_update_params.rb', line 726 def billing_schedules @billing_schedules end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.
728 729 730 |
# File 'lib/stripe/params/subscription_update_params.rb', line 728 def billing_thresholds @billing_thresholds end |
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period.
730 731 732 |
# File 'lib/stripe/params/subscription_update_params.rb', line 730 def cancel_at @cancel_at end |
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`.
732 733 734 |
# File 'lib/stripe/params/subscription_update_params.rb', line 732 def cancel_at_period_end @cancel_at_period_end end |
#cancellation_details ⇒ Object
Details about why this subscription was cancelled
734 735 736 |
# File 'lib/stripe/params/subscription_update_params.rb', line 734 def cancellation_details @cancellation_details end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this subscription at the end of the cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically`.
736 737 738 |
# File 'lib/stripe/params/subscription_update_params.rb', line 736 def collection_method @collection_method end |
#days_until_due ⇒ Object
Number of days a customer has to pay invoices generated by this subscription. Valid only for subscriptions where ‘collection_method` is set to `send_invoice`.
738 739 740 |
# File 'lib/stripe/params/subscription_update_params.rb', line 738 def days_until_due @days_until_due end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription. It must belong to the customer associated with the subscription. This takes precedence over ‘default_source`. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](docs.stripe.com/api/customers/object#customer_object-default_source).
740 741 742 |
# File 'lib/stripe/params/subscription_update_params.rb', line 740 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the subscription. It must belong to the customer associated with the subscription and be in a chargeable state. If ‘default_payment_method` is also set, `default_payment_method` will take precedence. If neither are set, invoices will use the customer’s [invoice_settings.default_payment_method](docs.stripe.com/api/customers/object#customer_object-invoice_settings-default_payment_method) or [default_source](docs.stripe.com/api/customers/object#customer_object-default_source).
742 743 744 |
# File 'lib/stripe/params/subscription_update_params.rb', line 742 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription. Pass an empty string to remove previously-defined tax rates.
744 745 746 |
# File 'lib/stripe/params/subscription_update_params.rb', line 744 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
746 747 748 |
# File 'lib/stripe/params/subscription_update_params.rb', line 746 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription. A populated array overwrites the existing discounts on the subscription. If not specified or empty array, it leaves the subscription’s discounts unchanged. If empty string, it clears the subscription’s discounts.
748 749 750 |
# File 'lib/stripe/params/subscription_update_params.rb', line 748 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
750 751 752 |
# File 'lib/stripe/params/subscription_update_params.rb', line 750 def @expand end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
752 753 754 |
# File 'lib/stripe/params/subscription_update_params.rb', line 752 def invoice_settings @invoice_settings end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
754 755 756 |
# File 'lib/stripe/params/subscription_update_params.rb', line 754 def items @items end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
756 757 758 |
# File 'lib/stripe/params/subscription_update_params.rb', line 756 def @metadata end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘false` (on-session).
758 759 760 |
# File 'lib/stripe/params/subscription_update_params.rb', line 758 def off_session @off_session end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
760 761 762 |
# File 'lib/stripe/params/subscription_update_params.rb', line 760 def on_behalf_of @on_behalf_of end |
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](docs.stripe.com/billing/subscriptions/pause-payment).
762 763 764 |
# File 'lib/stripe/params/subscription_update_params.rb', line 762 def pause_collection @pause_collection end |
#payment_behavior ⇒ Object
Controls how Stripe handles payment when a subscription update requires payment and ‘collection_method=charge_automatically`.
764 765 766 |
# File 'lib/stripe/params/subscription_update_params.rb', line 764 def payment_behavior @payment_behavior end |
#payment_settings ⇒ Object
Payment settings to pass to invoices created by the subscription.
766 767 768 |
# File 'lib/stripe/params/subscription_update_params.rb', line 766 def payment_settings @payment_settings end |
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](/api/invoices/create) for the given subscription at the specified interval.
768 769 770 |
# File 'lib/stripe/params/subscription_update_params.rb', line 768 def pending_invoice_item_interval @pending_invoice_item_interval end |
#proration_behavior ⇒ Object
Determines how to handle [prorations](docs.stripe.com/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`.
770 771 772 |
# File 'lib/stripe/params/subscription_update_params.rb', line 770 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If set, prorations will be calculated as though the subscription was updated at the given time. This can be used to apply exactly the same prorations that were previewed with the [create preview](stripe.com/docs/api/invoices/create_preview) endpoint. ‘proration_date` can also be used to implement custom proration logic, such as prorating by day instead of by second, by providing the time that you wish to use for proration calculations.
772 773 774 |
# File 'lib/stripe/params/subscription_update_params.rb', line 772 def proration_date @proration_date end |
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges. This will be unset if you POST an empty value.
774 775 776 |
# File 'lib/stripe/params/subscription_update_params.rb', line 774 def transfer_data @transfer_data end |
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. This will always overwrite any trials that might apply via a subscribed plan. If set, ‘trial_end` will override the default trial period of the plan the customer is being subscribed to. The `billing_cycle_anchor` will be updated to the `trial_end` value. The special value `now` can be provided to end the customer’s trial immediately. Can be at most two years from ‘billing_cycle_anchor`.
776 777 778 |
# File 'lib/stripe/params/subscription_update_params.rb', line 776 def trial_end @trial_end end |
#trial_from_plan ⇒ Object
Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `trial_end` is not allowed. See [Using trial periods on subscriptions](docs.stripe.com/billing/subscriptions/trials) to learn more.
778 779 780 |
# File 'lib/stripe/params/subscription_update_params.rb', line 778 def trial_from_plan @trial_from_plan end |
#trial_settings ⇒ Object
Settings related to subscription trials.
780 781 782 |
# File 'lib/stripe/params/subscription_update_params.rb', line 780 def trial_settings @trial_settings end |
Class Method Details
.field_encodings ⇒ Object
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/stripe/params/subscription_update_params.rb', line 850 def self.field_encodings @field_encodings = { add_invoice_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |