Class: Stripe::SubscriptionUpdateParams::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
57 58 59 60 |
# File 'lib/stripe/params/subscription_update_params.rb', line 57 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
53 54 55 |
# File 'lib/stripe/params/subscription_update_params.rb', line 53 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
55 56 57 |
# File 'lib/stripe/params/subscription_update_params.rb', line 55 def type @type end |