Class: Stripe::SubscriptionUpdateParams::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AppliesTo, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



223
224
225
226
227
# File 'lib/stripe/params/subscription_update_params.rb', line 223

def initialize(applies_to: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



217
218
219
# File 'lib/stripe/params/subscription_update_params.rb', line 217

def applies_to
  @applies_to
end

#bill_untilObject

The end date for the billing schedule.



219
220
221
# File 'lib/stripe/params/subscription_update_params.rb', line 219

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



221
222
223
# File 'lib/stripe/params/subscription_update_params.rb', line 221

def key
  @key
end