Class: Stripe::SubscriptionUpdateParams::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
175 176 177 178 |
# File 'lib/stripe/params/subscription_update_params.rb', line 175 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
171 172 173 |
# File 'lib/stripe/params/subscription_update_params.rb', line 171 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
173 174 175 |
# File 'lib/stripe/params/subscription_update_params.rb', line 173 def type @type end |