Class: Stripe::SubscriptionUpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



289
290
291
292
293
294
# File 'lib/stripe/params/subscription_update_params.rb', line 289

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



281
282
283
# File 'lib/stripe/params/subscription_update_params.rb', line 281

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



283
284
285
# File 'lib/stripe/params/subscription_update_params.rb', line 283

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



285
286
287
# File 'lib/stripe/params/subscription_update_params.rb', line 285

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



287
288
289
# File 'lib/stripe/params/subscription_update_params.rb', line 287

def promotion_code
  @promotion_code
end