Class: Stripe::SubscriptionUpdateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
285 286 287 288 289 290 291 |
# File 'lib/stripe/params/subscription_update_params.rb', line 285 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
275 276 277 |
# File 'lib/stripe/params/subscription_update_params.rb', line 275 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
277 278 279 |
# File 'lib/stripe/params/subscription_update_params.rb', line 277 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
279 280 281 |
# File 'lib/stripe/params/subscription_update_params.rb', line 279 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
281 282 283 |
# File 'lib/stripe/params/subscription_update_params.rb', line 281 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
283 284 285 |
# File 'lib/stripe/params/subscription_update_params.rb', line 283 def second @second end |