Class: Stripe::SubscriptionUpdateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: CustomField, Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/stripe/params/subscription_update_params.rb', line 280

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.



270
271
272
# File 'lib/stripe/params/subscription_update_params.rb', line 270

def 
  @account_tax_ids
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



272
273
274
# File 'lib/stripe/params/subscription_update_params.rb', line 272

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



274
275
276
# File 'lib/stripe/params/subscription_update_params.rb', line 274

def description
  @description
end

Footer to be displayed on the invoice.



276
277
278
# File 'lib/stripe/params/subscription_update_params.rb', line 276

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



278
279
280
# File 'lib/stripe/params/subscription_update_params.rb', line 278

def issuer
  @issuer
end