Class: Stripe::SubscriptionUpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/stripe/params/subscription_update_params.rb', line 590

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  current_trial: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @current_trial = current_trial
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



566
567
568
# File 'lib/stripe/params/subscription_update_params.rb', line 566

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. clear_usage has no effect if the plan has a billing meter attached.



568
569
570
# File 'lib/stripe/params/subscription_update_params.rb', line 568

def clear_usage
  @clear_usage
end

#current_trialObject

The trial offer to apply to this subscription item.



570
571
572
# File 'lib/stripe/params/subscription_update_params.rb', line 570

def current_trial
  @current_trial
end

#deletedObject

A flag that, if set to true, will delete the specified item.



572
573
574
# File 'lib/stripe/params/subscription_update_params.rb', line 572

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



574
575
576
# File 'lib/stripe/params/subscription_update_params.rb', line 574

def discounts
  @discounts
end

#idObject

Subscription item to update. If you omit id, the API adds a new subscription item rather than updating the existing one. See Changing a subscription's price.



576
577
578
# File 'lib/stripe/params/subscription_update_params.rb', line 576

def id
  @id
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



578
579
580
# File 'lib/stripe/params/subscription_update_params.rb', line 578

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



580
581
582
# File 'lib/stripe/params/subscription_update_params.rb', line 580

def plan
  @plan
end

#priceObject

The ID of the price object. One of price or price_data is required. When changing a subscription item's price, quantity is set to 1 unless a quantity parameter is provided.



582
583
584
# File 'lib/stripe/params/subscription_update_params.rb', line 582

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline. One of price or price_data is required.



584
585
586
# File 'lib/stripe/params/subscription_update_params.rb', line 584

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



586
587
588
# File 'lib/stripe/params/subscription_update_params.rb', line 586

def quantity
  @quantity
end

#tax_ratesObject

A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



588
589
590
# File 'lib/stripe/params/subscription_update_params.rb', line 588

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



618
619
620
621
622
# File 'lib/stripe/params/subscription_update_params.rb', line 618

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end