Class: Stripe::SubscriptionUpdateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#deleted ⇒ Object
A flag that, if set to
true, will delete the specified item. -
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/stripe/params/subscription_update_params.rb', line 388 def initialize( billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @clear_usage = clear_usage @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
366 367 368 |
# File 'lib/stripe/params/subscription_update_params.rb', line 366 def billing_thresholds @billing_thresholds end |
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. clear_usage has no effect if the plan has a billing meter attached.
368 369 370 |
# File 'lib/stripe/params/subscription_update_params.rb', line 368 def clear_usage @clear_usage end |
#deleted ⇒ Object
A flag that, if set to true, will delete the specified item.
370 371 372 |
# File 'lib/stripe/params/subscription_update_params.rb', line 370 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
372 373 374 |
# File 'lib/stripe/params/subscription_update_params.rb', line 372 def discounts @discounts end |
#id ⇒ Object
Subscription item to update. If you omit id, the API adds a new subscription item rather than updating the existing one. See Changing a subscription's price.
374 375 376 |
# File 'lib/stripe/params/subscription_update_params.rb', line 374 def id @id end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
376 377 378 |
# File 'lib/stripe/params/subscription_update_params.rb', line 376 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
378 379 380 |
# File 'lib/stripe/params/subscription_update_params.rb', line 378 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of price or price_data is required. When changing a subscription item's price, quantity is set to 1 unless a quantity parameter is provided.
380 381 382 |
# File 'lib/stripe/params/subscription_update_params.rb', line 380 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline. One of price or price_data is required.
382 383 384 |
# File 'lib/stripe/params/subscription_update_params.rb', line 382 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
384 385 386 |
# File 'lib/stripe/params/subscription_update_params.rb', line 384 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
386 387 388 |
# File 'lib/stripe/params/subscription_update_params.rb', line 386 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
414 415 416 417 418 |
# File 'lib/stripe/params/subscription_update_params.rb', line 414 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |