Class: Stripe::SubscriptionUpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/stripe/params/subscription_update_params.rb', line 459

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  current_trial: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @current_trial = current_trial
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



435
436
437
# File 'lib/stripe/params/subscription_update_params.rb', line 435

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



437
438
439
# File 'lib/stripe/params/subscription_update_params.rb', line 437

def clear_usage
  @clear_usage
end

#current_trialObject

The trial offer to apply to this subscription item.



439
440
441
# File 'lib/stripe/params/subscription_update_params.rb', line 439

def current_trial
  @current_trial
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



441
442
443
# File 'lib/stripe/params/subscription_update_params.rb', line 441

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



443
444
445
# File 'lib/stripe/params/subscription_update_params.rb', line 443

def discounts
  @discounts
end

#idObject

Subscription item to update.



445
446
447
# File 'lib/stripe/params/subscription_update_params.rb', line 445

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



447
448
449
# File 'lib/stripe/params/subscription_update_params.rb', line 447

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



449
450
451
# File 'lib/stripe/params/subscription_update_params.rb', line 449

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



451
452
453
# File 'lib/stripe/params/subscription_update_params.rb', line 451

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



453
454
455
# File 'lib/stripe/params/subscription_update_params.rb', line 453

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



455
456
457
# File 'lib/stripe/params/subscription_update_params.rb', line 455

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



457
458
459
# File 'lib/stripe/params/subscription_update_params.rb', line 457

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



487
488
489
490
491
# File 'lib/stripe/params/subscription_update_params.rb', line 487

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end