Class: Stripe::SubscriptionUpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/stripe/params/subscription_update_params.rb', line 559

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  current_trial: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @current_trial = current_trial
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



535
536
537
# File 'lib/stripe/params/subscription_update_params.rb', line 535

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



537
538
539
# File 'lib/stripe/params/subscription_update_params.rb', line 537

def clear_usage
  @clear_usage
end

#current_trialObject

The trial offer to apply to this subscription item.



539
540
541
# File 'lib/stripe/params/subscription_update_params.rb', line 539

def current_trial
  @current_trial
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



541
542
543
# File 'lib/stripe/params/subscription_update_params.rb', line 541

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



543
544
545
# File 'lib/stripe/params/subscription_update_params.rb', line 543

def discounts
  @discounts
end

#idObject

Subscription item to update.



545
546
547
# File 'lib/stripe/params/subscription_update_params.rb', line 545

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



547
548
549
# File 'lib/stripe/params/subscription_update_params.rb', line 547

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



549
550
551
# File 'lib/stripe/params/subscription_update_params.rb', line 549

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



551
552
553
# File 'lib/stripe/params/subscription_update_params.rb', line 551

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



553
554
555
# File 'lib/stripe/params/subscription_update_params.rb', line 553

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



555
556
557
# File 'lib/stripe/params/subscription_update_params.rb', line 555

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



557
558
559
# File 'lib/stripe/params/subscription_update_params.rb', line 557

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



587
588
589
590
591
# File 'lib/stripe/params/subscription_update_params.rb', line 587

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end