Class: Stripe::SubscriptionUpdateParams::Item

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/stripe/params/subscription_update_params.rb', line 427

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



405
406
407
# File 'lib/stripe/params/subscription_update_params.rb', line 405

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



407
408
409
# File 'lib/stripe/params/subscription_update_params.rb', line 407

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



409
410
411
# File 'lib/stripe/params/subscription_update_params.rb', line 409

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



411
412
413
# File 'lib/stripe/params/subscription_update_params.rb', line 411

def discounts
  @discounts
end

#idObject

Subscription item to update.



413
414
415
# File 'lib/stripe/params/subscription_update_params.rb', line 413

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



415
416
417
# File 'lib/stripe/params/subscription_update_params.rb', line 415

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



417
418
419
# File 'lib/stripe/params/subscription_update_params.rb', line 417

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



419
420
421
# File 'lib/stripe/params/subscription_update_params.rb', line 419

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



421
422
423
# File 'lib/stripe/params/subscription_update_params.rb', line 421

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



423
424
425
# File 'lib/stripe/params/subscription_update_params.rb', line 423

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



425
426
427
# File 'lib/stripe/params/subscription_update_params.rb', line 425

def tax_rates
  @tax_rates
end