Class: Stripe::SubscriptionUpdateParams::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: BillingThresholds, CurrentTrial, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
-
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/stripe/params/subscription_update_params.rb', line 441 def initialize( billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @clear_usage = clear_usage @current_trial = current_trial @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
417 418 419 |
# File 'lib/stripe/params/subscription_update_params.rb', line 417 def billing_thresholds @billing_thresholds end |
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.
419 420 421 |
# File 'lib/stripe/params/subscription_update_params.rb', line 419 def clear_usage @clear_usage end |
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
421 422 423 |
# File 'lib/stripe/params/subscription_update_params.rb', line 421 def current_trial @current_trial end |
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
423 424 425 |
# File 'lib/stripe/params/subscription_update_params.rb', line 423 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
425 426 427 |
# File 'lib/stripe/params/subscription_update_params.rb', line 425 def discounts @discounts end |
#id ⇒ Object
Subscription item to update.
427 428 429 |
# File 'lib/stripe/params/subscription_update_params.rb', line 427 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
429 430 431 |
# File 'lib/stripe/params/subscription_update_params.rb', line 429 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
431 432 433 |
# File 'lib/stripe/params/subscription_update_params.rb', line 431 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
433 434 435 |
# File 'lib/stripe/params/subscription_update_params.rb', line 433 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
435 436 437 |
# File 'lib/stripe/params/subscription_update_params.rb', line 435 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
437 438 439 |
# File 'lib/stripe/params/subscription_update_params.rb', line 437 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
439 440 441 |
# File 'lib/stripe/params/subscription_update_params.rb', line 439 def tax_rates @tax_rates end |