Class: Stripe::SubscriptionUpdateParams::Item::CurrentTrial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item::CurrentTrial
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
Instance Method Summary collapse
-
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
constructor
A new instance of CurrentTrial.
Methods inherited from RequestParams
Constructor Details
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
Returns a new instance of CurrentTrial.
378 379 380 381 |
# File 'lib/stripe/params/subscription_update_params.rb', line 378 def initialize(trial_end: nil, trial_offer: nil) @trial_end = trial_end @trial_offer = trial_offer end |
Instance Attribute Details
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.
374 375 376 |
# File 'lib/stripe/params/subscription_update_params.rb', line 374 def trial_end @trial_end end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
376 377 378 |
# File 'lib/stripe/params/subscription_update_params.rb', line 376 def trial_offer @trial_offer end |