Class: Stripe::SubscriptionUpdateParams::Item::CurrentTrial

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial

Returns a new instance of CurrentTrial.



326
327
328
329
# File 'lib/stripe/params/subscription_update_params.rb', line 326

def initialize(trial_end: nil, trial_offer: nil)
  @trial_end = trial_end
  @trial_offer = trial_offer
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.



322
323
324
# File 'lib/stripe/params/subscription_update_params.rb', line 322

def trial_end
  @trial_end
end

#trial_offerObject

The ID of the trial offer to apply to the subscription item.



324
325
326
# File 'lib/stripe/params/subscription_update_params.rb', line 324

def trial_offer
  @trial_offer
end