Class: Stripe::SubscriptionUpdateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item::Discount
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
377 378 379 380 381 382 |
# File 'lib/stripe/params/subscription_update_params.rb', line 377 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
369 370 371 |
# File 'lib/stripe/params/subscription_update_params.rb', line 369 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
371 372 373 |
# File 'lib/stripe/params/subscription_update_params.rb', line 371 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
373 374 375 |
# File 'lib/stripe/params/subscription_update_params.rb', line 373 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
375 376 377 |
# File 'lib/stripe/params/subscription_update_params.rb', line 375 def promotion_code @promotion_code end |