Class: Stripe::SubscriptionUpdateParams::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::Item::Discount
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/stripe/params/subscription_update_params.rb', line 464 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
454 455 456 |
# File 'lib/stripe/params/subscription_update_params.rb', line 454 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
456 457 458 |
# File 'lib/stripe/params/subscription_update_params.rb', line 456 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
458 459 460 |
# File 'lib/stripe/params/subscription_update_params.rb', line 458 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
460 461 462 |
# File 'lib/stripe/params/subscription_update_params.rb', line 460 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
462 463 464 |
# File 'lib/stripe/params/subscription_update_params.rb', line 462 def settings @settings end |