Class: Stripe::SubscriptionUpdateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



362
363
364
365
366
# File 'lib/stripe/params/subscription_update_params.rb', line 362

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



356
357
358
# File 'lib/stripe/params/subscription_update_params.rb', line 356

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



358
359
360
# File 'lib/stripe/params/subscription_update_params.rb', line 358

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



360
361
362
# File 'lib/stripe/params/subscription_update_params.rb', line 360

def type
  @type
end