Class: Stripe::SubscriptionUpdateParams::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



404
405
406
407
408
# File 'lib/stripe/params/subscription_update_params.rb', line 404

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



398
399
400
# File 'lib/stripe/params/subscription_update_params.rb', line 398

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



400
401
402
# File 'lib/stripe/params/subscription_update_params.rb', line 400

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



402
403
404
# File 'lib/stripe/params/subscription_update_params.rb', line 402

def type
  @type
end