Class: Stripe::SubscriptionUpdateParams::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



425
426
427
428
429
430
431
# File 'lib/stripe/params/subscription_update_params.rb', line 425

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



415
416
417
# File 'lib/stripe/params/subscription_update_params.rb', line 415

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



417
418
419
# File 'lib/stripe/params/subscription_update_params.rb', line 417

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



419
420
421
# File 'lib/stripe/params/subscription_update_params.rb', line 419

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



421
422
423
# File 'lib/stripe/params/subscription_update_params.rb', line 421

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



423
424
425
# File 'lib/stripe/params/subscription_update_params.rb', line 423

def second
  @second
end