Class: Stripe::SubscriptionUpdateParams::PauseCollection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(behavior: nil, resumes_at: nil) ⇒ PauseCollection

Returns a new instance of PauseCollection.



496
497
498
499
# File 'lib/stripe/params/subscription_update_params.rb', line 496

def initialize(behavior: nil, resumes_at: nil)
  @behavior = behavior
  @resumes_at = resumes_at
end

Instance Attribute Details

#behaviorObject

The payment collection behavior for this subscription while paused.



492
493
494
# File 'lib/stripe/params/subscription_update_params.rb', line 492

def behavior
  @behavior
end

#resumes_atObject

The time after which the subscription will resume collecting payments.



494
495
496
# File 'lib/stripe/params/subscription_update_params.rb', line 494

def resumes_at
  @resumes_at
end