Class: Stripe::SubscriptionUpdateParams::PauseCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PauseCollection
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
-
#resumes_at ⇒ Object
The time after which the subscription will resume collecting payments.
Instance Method Summary collapse
-
#initialize(behavior: nil, resumes_at: nil) ⇒ PauseCollection
constructor
A new instance of PauseCollection.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(behavior: nil, resumes_at: nil) ⇒ PauseCollection
Returns a new instance of PauseCollection.
344 345 346 347 |
# File 'lib/stripe/params/subscription_update_params.rb', line 344 def initialize(behavior: nil, resumes_at: nil) @behavior = behavior @resumes_at = resumes_at end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
340 341 342 |
# File 'lib/stripe/params/subscription_update_params.rb', line 340 def behavior @behavior end |
#resumes_at ⇒ Object
The time after which the subscription will resume collecting payments.
342 343 344 |
# File 'lib/stripe/params/subscription_update_params.rb', line 342 def resumes_at @resumes_at end |