Class: Stripe::SubscriptionUpdateParams::PaymentSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Instance Attribute Summary collapse
-
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
-
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent.
-
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds.
Instance Method Summary collapse
-
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
constructor
A new instance of PaymentSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil) ⇒ PaymentSettings
Returns a new instance of PaymentSettings.
822 823 824 825 826 827 828 829 830 |
# File 'lib/stripe/params/subscription_update_params.rb', line 822 def initialize( payment_method_options: nil, payment_method_types: nil, save_default_payment_method: nil ) @payment_method_options = @payment_method_types = payment_method_types @save_default_payment_method = save_default_payment_method end |
Instance Attribute Details
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to invoices created by the subscription.
816 817 818 |
# File 'lib/stripe/params/subscription_update_params.rb', line 816 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration
818 819 820 |
# File 'lib/stripe/params/subscription_update_params.rb', line 818 def payment_method_types @payment_method_types end |
#save_default_payment_method ⇒ Object
Configure whether Stripe updates ‘subscription.default_payment_method` when payment succeeds. Defaults to `off` if unspecified.
820 821 822 |
# File 'lib/stripe/params/subscription_update_params.rb', line 820 def save_default_payment_method @save_default_payment_method end |