Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'lib/stripe/params/subscription_update_params.rb', line 635 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
615 616 617 |
# File 'lib/stripe/params/subscription_update_params.rb', line 615 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
617 618 619 |
# File 'lib/stripe/params/subscription_update_params.rb', line 617 def bancontact @bancontact end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
619 620 621 |
# File 'lib/stripe/params/subscription_update_params.rb', line 619 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
621 622 623 |
# File 'lib/stripe/params/subscription_update_params.rb', line 621 def customer_balance @customer_balance end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
623 624 625 |
# File 'lib/stripe/params/subscription_update_params.rb', line 623 def konbini @konbini end |
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
625 626 627 |
# File 'lib/stripe/params/subscription_update_params.rb', line 625 def payto @payto end |
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
627 628 629 |
# File 'lib/stripe/params/subscription_update_params.rb', line 627 def pix @pix end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
629 630 631 |
# File 'lib/stripe/params/subscription_update_params.rb', line 629 def sepa_debit @sepa_debit end |
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
631 632 633 |
# File 'lib/stripe/params/subscription_update_params.rb', line 631 def upi @upi end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
633 634 635 |
# File 'lib/stripe/params/subscription_update_params.rb', line 633 def us_bank_account @us_bank_account end |