Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Bizum, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, bizum: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/stripe/params/subscription_update_params.rb', line 904

def initialize(
  acss_debit: nil,
  bancontact: nil,
  bizum: nil,
  card: nil,
  check_scan: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @bizum = bizum
  @card = card
  @check_scan = check_scan
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



878
879
880
# File 'lib/stripe/params/subscription_update_params.rb', line 878

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



880
881
882
# File 'lib/stripe/params/subscription_update_params.rb', line 880

def bancontact
  @bancontact
end

#bizumObject

This sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.



882
883
884
# File 'lib/stripe/params/subscription_update_params.rb', line 882

def bizum
  @bizum
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



884
885
886
# File 'lib/stripe/params/subscription_update_params.rb', line 884

def card
  @card
end

#check_scanObject

This sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



886
887
888
# File 'lib/stripe/params/subscription_update_params.rb', line 886

def check_scan
  @check_scan
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



888
889
890
# File 'lib/stripe/params/subscription_update_params.rb', line 888

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



890
891
892
# File 'lib/stripe/params/subscription_update_params.rb', line 890

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



892
893
894
# File 'lib/stripe/params/subscription_update_params.rb', line 892

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



894
895
896
# File 'lib/stripe/params/subscription_update_params.rb', line 894

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



896
897
898
# File 'lib/stripe/params/subscription_update_params.rb', line 896

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



898
899
900
# File 'lib/stripe/params/subscription_update_params.rb', line 898

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



900
901
902
# File 'lib/stripe/params/subscription_update_params.rb', line 900

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



902
903
904
# File 'lib/stripe/params/subscription_update_params.rb', line 902

def 
  @us_bank_account
end