Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#blik ⇒ Object
This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/stripe/params/subscription_update_params.rb', line 756 def initialize( acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @blik = blik @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
732 733 734 |
# File 'lib/stripe/params/subscription_update_params.rb', line 732 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
734 735 736 |
# File 'lib/stripe/params/subscription_update_params.rb', line 734 def bancontact @bancontact end |
#blik ⇒ Object
This sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
736 737 738 |
# File 'lib/stripe/params/subscription_update_params.rb', line 736 def blik @blik end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
738 739 740 |
# File 'lib/stripe/params/subscription_update_params.rb', line 738 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
740 741 742 |
# File 'lib/stripe/params/subscription_update_params.rb', line 740 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
742 743 744 |
# File 'lib/stripe/params/subscription_update_params.rb', line 742 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
744 745 746 |
# File 'lib/stripe/params/subscription_update_params.rb', line 744 def konbini @konbini end |
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
746 747 748 |
# File 'lib/stripe/params/subscription_update_params.rb', line 746 def payto @payto end |
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
748 749 750 |
# File 'lib/stripe/params/subscription_update_params.rb', line 748 def pix @pix end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
750 751 752 |
# File 'lib/stripe/params/subscription_update_params.rb', line 750 def sepa_debit @sepa_debit end |
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
752 753 754 |
# File 'lib/stripe/params/subscription_update_params.rb', line 752 def upi @upi end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
754 755 756 |
# File 'lib/stripe/params/subscription_update_params.rb', line 754 def us_bank_account @us_bank_account end |