Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 |
# File 'lib/stripe/params/subscription_update_params.rb', line 818 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @payto = payto @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
796 797 798 |
# File 'lib/stripe/params/subscription_update_params.rb', line 796 def acss_debit @acss_debit end |
#bancontact ⇒ Object
This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
798 799 800 |
# File 'lib/stripe/params/subscription_update_params.rb', line 798 def bancontact @bancontact end |
#card ⇒ Object
This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
800 801 802 |
# File 'lib/stripe/params/subscription_update_params.rb', line 800 def card @card end |
#customer_balance ⇒ Object
This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
802 803 804 |
# File 'lib/stripe/params/subscription_update_params.rb', line 802 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
804 805 806 |
# File 'lib/stripe/params/subscription_update_params.rb', line 804 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
806 807 808 |
# File 'lib/stripe/params/subscription_update_params.rb', line 806 def konbini @konbini end |
#payto ⇒ Object
This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
808 809 810 |
# File 'lib/stripe/params/subscription_update_params.rb', line 808 def payto @payto end |
#pix ⇒ Object
This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
810 811 812 |
# File 'lib/stripe/params/subscription_update_params.rb', line 810 def pix @pix end |
#sepa_debit ⇒ Object
This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
812 813 814 |
# File 'lib/stripe/params/subscription_update_params.rb', line 812 def sepa_debit @sepa_debit end |
#upi ⇒ Object
This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
814 815 816 |
# File 'lib/stripe/params/subscription_update_params.rb', line 814 def upi @upi end |
#us_bank_account ⇒ Object
This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
816 817 818 |
# File 'lib/stripe/params/subscription_update_params.rb', line 816 def us_bank_account @us_bank_account end |