Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
# File 'lib/stripe/params/subscription_update_params.rb', line 714

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



692
693
694
# File 'lib/stripe/params/subscription_update_params.rb', line 692

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



694
695
696
# File 'lib/stripe/params/subscription_update_params.rb', line 694

def bancontact
  @bancontact
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



696
697
698
# File 'lib/stripe/params/subscription_update_params.rb', line 696

def card
  @card
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



698
699
700
# File 'lib/stripe/params/subscription_update_params.rb', line 698

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



700
701
702
# File 'lib/stripe/params/subscription_update_params.rb', line 700

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



702
703
704
# File 'lib/stripe/params/subscription_update_params.rb', line 702

def konbini
  @konbini
end

#paytoObject

This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



704
705
706
# File 'lib/stripe/params/subscription_update_params.rb', line 704

def payto
  @payto
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



706
707
708
# File 'lib/stripe/params/subscription_update_params.rb', line 706

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



708
709
710
# File 'lib/stripe/params/subscription_update_params.rb', line 708

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



710
711
712
# File 'lib/stripe/params/subscription_update_params.rb', line 710

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



712
713
714
# File 'lib/stripe/params/subscription_update_params.rb', line 712

def 
  @us_bank_account
end