Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
# File 'lib/stripe/params/subscription_update_params.rb', line 692

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



672
673
674
# File 'lib/stripe/params/subscription_update_params.rb', line 672

def acss_debit
  @acss_debit
end

#bancontactObject

This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



674
675
676
# File 'lib/stripe/params/subscription_update_params.rb', line 674

def bancontact
  @bancontact
end

#cardObject

This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



676
677
678
# File 'lib/stripe/params/subscription_update_params.rb', line 676

def card
  @card
end

#customer_balanceObject

This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



678
679
680
# File 'lib/stripe/params/subscription_update_params.rb', line 678

def customer_balance
  @customer_balance
end

#id_bank_transferObject

This sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



680
681
682
# File 'lib/stripe/params/subscription_update_params.rb', line 680

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



682
683
684
# File 'lib/stripe/params/subscription_update_params.rb', line 682

def konbini
  @konbini
end

#pixObject

This sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



684
685
686
# File 'lib/stripe/params/subscription_update_params.rb', line 684

def pix
  @pix
end

#sepa_debitObject

This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



686
687
688
# File 'lib/stripe/params/subscription_update_params.rb', line 686

def sepa_debit
  @sepa_debit
end

#upiObject

This sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



688
689
690
# File 'lib/stripe/params/subscription_update_params.rb', line 688

def upi
  @upi
end

#us_bank_accountObject

This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



690
691
692
# File 'lib/stripe/params/subscription_update_params.rb', line 690

def 
  @us_bank_account
end