Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Blik::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Blik::MandateOptions
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#expires_after ⇒ Object
Date when the mandate expires and no further payments will be charged.
Instance Method Summary collapse
-
#initialize(expires_after: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expires_after: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
538 539 540 |
# File 'lib/stripe/params/subscription_update_params.rb', line 538 def initialize(expires_after: nil) @expires_after = expires_after end |
Instance Attribute Details
#expires_after ⇒ Object
Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.
536 537 538 |
# File 'lib/stripe/params/subscription_update_params.rb', line 536 def expires_after @expires_after end |