Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
Selected network to process this Subscription on.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
603 604 605 606 607 |
# File 'lib/stripe/params/subscription_update_params.rb', line 603 def initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) @mandate_options = @network = network @request_three_d_secure = request_three_d_secure end |
Instance Attribute Details
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
597 598 599 |
# File 'lib/stripe/params/subscription_update_params.rb', line 597 def @mandate_options end |
#network ⇒ Object
Selected network to process this Subscription on. Depends on the available networks of the card attached to the Subscription. Can be only set confirm-time.
599 600 601 |
# File 'lib/stripe/params/subscription_update_params.rb', line 599 def network @network end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
601 602 603 |
# File 'lib/stripe/params/subscription_update_params.rb', line 601 def request_three_d_secure @request_three_d_secure end |