Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
473 474 475 476 477 |
# File 'lib/stripe/params/subscription_update_params.rb', line 473 def initialize(amount: nil, amount_type: nil, description: nil) @amount = amount @amount_type = amount_type @description = description end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments, specified in the presentment currency.
467 468 469 |
# File 'lib/stripe/params/subscription_update_params.rb', line 467 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
469 470 471 |
# File 'lib/stripe/params/subscription_update_params.rb', line 469 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
471 472 473 |
# File 'lib/stripe/params/subscription_update_params.rb', line 471 def description @description end |