Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



774
775
776
777
778
779
780
781
782
783
784
# File 'lib/stripe/params/subscription_update_params.rb', line 774

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  end_date: nil,
  payment_schedule: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @end_date = end_date
  @payment_schedule = payment_schedule
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. If not provided, defaults to 40000.



766
767
768
# File 'lib/stripe/params/subscription_update_params.rb', line 766

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



768
769
770
# File 'lib/stripe/params/subscription_update_params.rb', line 768

def amount_includes_iof
  @amount_includes_iof
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled.



770
771
772
# File 'lib/stripe/params/subscription_update_params.rb', line 770

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to the subscription servicing interval.



772
773
774
# File 'lib/stripe/params/subscription_update_params.rb', line 772

def payment_schedule
  @payment_schedule
end