Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



644
645
646
647
648
649
650
651
652
653
654
# File 'lib/stripe/params/subscription_update_params.rb', line 644

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  end_date: nil,
  payment_schedule: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @end_date = end_date
  @payment_schedule = payment_schedule
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. If not provided, defaults to 40000.



636
637
638
# File 'lib/stripe/params/subscription_update_params.rb', line 636

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



638
639
640
# File 'lib/stripe/params/subscription_update_params.rb', line 638

def amount_includes_iof
  @amount_includes_iof
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled.



640
641
642
# File 'lib/stripe/params/subscription_update_params.rb', line 640

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to the subscription servicing interval.



642
643
644
# File 'lib/stripe/params/subscription_update_params.rb', line 642

def payment_schedule
  @payment_schedule
end