Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



711
712
713
714
715
716
717
718
719
720
721
# File 'lib/stripe/params/subscription_update_params.rb', line 711

def initialize(
  amount: nil,
  amount_includes_iof: nil,
  end_date: nil,
  payment_schedule: nil
)
  @amount = amount
  @amount_includes_iof = amount_includes_iof
  @end_date = end_date
  @payment_schedule = payment_schedule
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments. If not provided, defaults to 40000.



703
704
705
# File 'lib/stripe/params/subscription_update_params.rb', line 703

def amount
  @amount
end

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to ‘never`.



705
706
707
# File 'lib/stripe/params/subscription_update_params.rb', line 705

def amount_includes_iof
  @amount_includes_iof
end

#end_dateObject

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled.



707
708
709
# File 'lib/stripe/params/subscription_update_params.rb', line 707

def end_date
  @end_date
end

#payment_scheduleObject

Schedule at which the future payments will be charged. Defaults to ‘weekly`.



709
710
711
# File 'lib/stripe/params/subscription_update_params.rb', line 709

def payment_schedule
  @payment_schedule
end