Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/stripe/params/subscription_update_params.rb', line 587 def initialize( amount: nil, amount_includes_iof: nil, end_date: nil, payment_schedule: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @end_date = end_date @payment_schedule = payment_schedule end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. If not provided, defaults to 40000.
579 580 581 |
# File 'lib/stripe/params/subscription_update_params.rb', line 579 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to ‘never`.
581 582 583 |
# File 'lib/stripe/params/subscription_update_params.rb', line 581 def amount_includes_iof @amount_includes_iof end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`. If not provided, the mandate will be active until canceled.
583 584 585 |
# File 'lib/stripe/params/subscription_update_params.rb', line 583 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to ‘weekly`.
585 586 587 |
# File 'lib/stripe/params/subscription_update_params.rb', line 585 def payment_schedule @payment_schedule end |