Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



711
712
713
714
715
716
# File 'lib/stripe/params/subscription_update_params.rb', line 711

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



703
704
705
# File 'lib/stripe/params/subscription_update_params.rb', line 703

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



705
706
707
# File 'lib/stripe/params/subscription_update_params.rb', line 705

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



707
708
709
# File 'lib/stripe/params/subscription_update_params.rb', line 707

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



709
710
711
# File 'lib/stripe/params/subscription_update_params.rb', line 709

def end_date
  @end_date
end