Class: Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::WechatPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::PaymentSettings::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The app ID registered with WeChat Pay.
-
#client ⇒ Object
The client type that the end customer will pay from.
Instance Method Summary collapse
-
#initialize(app_id: nil, client: nil) ⇒ WechatPay
constructor
A new instance of WechatPay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(app_id: nil, client: nil) ⇒ WechatPay
Returns a new instance of WechatPay.
868 869 870 871 |
# File 'lib/stripe/params/subscription_update_params.rb', line 868 def initialize(app_id: nil, client: nil) @app_id = app_id @client = client end |
Instance Attribute Details
#app_id ⇒ Object
The app ID registered with WeChat Pay. Only required when client is ‘ios` or `android`.
864 865 866 |
# File 'lib/stripe/params/subscription_update_params.rb', line 864 def app_id @app_id end |
#client ⇒ Object
The client type that the end customer will pay from.
866 867 868 |
# File 'lib/stripe/params/subscription_update_params.rb', line 866 def client @client end |