Class: Stripe::SubscriptionUpdateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::SubscriptionUpdateParams::TransferData
- Defined in:
- lib/stripe/params/subscription_update_params.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
892 893 894 895 |
# File 'lib/stripe/params/subscription_update_params.rb', line 892 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
888 889 890 |
# File 'lib/stripe/params/subscription_update_params.rb', line 888 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
890 891 892 |
# File 'lib/stripe/params/subscription_update_params.rb', line 890 def destination @destination end |