Class: Stripe::SubscriptionUpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



764
765
766
767
# File 'lib/stripe/params/subscription_update_params.rb', line 764

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



760
761
762
# File 'lib/stripe/params/subscription_update_params.rb', line 760

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



762
763
764
# File 'lib/stripe/params/subscription_update_params.rb', line 762

def destination
  @destination
end