Class: Stripe::SubscriptionUpdateParams::TrialSettings::EndBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/subscription_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billing_cycle_anchor: nil, missing_payment_method: nil) ⇒ EndBehavior

Returns a new instance of EndBehavior.



845
846
847
848
# File 'lib/stripe/params/subscription_update_params.rb', line 845

def initialize(billing_cycle_anchor: nil, missing_payment_method: nil)
  @billing_cycle_anchor = billing_cycle_anchor
  @missing_payment_method = missing_payment_method
end

Instance Attribute Details

#billing_cycle_anchorObject

Indicates how the subscription’s billing cycle anchor is reset when a trial ends. Defaults to ‘now`.



841
842
843
# File 'lib/stripe/params/subscription_update_params.rb', line 841

def billing_cycle_anchor
  @billing_cycle_anchor
end

#missing_payment_methodObject

Indicates how the subscription should change when the trial ends if the user did not provide a payment method.



843
844
845
# File 'lib/stripe/params/subscription_update_params.rb', line 843

def missing_payment_method
  @missing_payment_method
end