Class: Stripe::Tax::Calculation

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/tax/calculation.rb

Overview

A Tax Calculation allows you to calculate the tax to collect from your customer.

Related guide: [Calculate tax in your custom payment flow](stripe.com/docs/tax/custom)

Defined Under Namespace

Classes: CreateParams, CustomerDetails, ListLineItemsParams, ShipFromDetails, ShippingCost, TaxBreakdown

Constant Summary collapse

OBJECT_NAME =
"tax.calculation"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_totalObject (readonly)

Total amount after taxes in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



465
466
467
# File 'lib/stripe/resources/tax/calculation.rb', line 465

def amount_total
  @amount_total
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



467
468
469
# File 'lib/stripe/resources/tax/calculation.rb', line 467

def currency
  @currency
end

#customerObject (readonly)

The ID of an existing [Customer](stripe.com/docs/api/customers/object) used for the resource.



469
470
471
# File 'lib/stripe/resources/tax/calculation.rb', line 469

def customer
  @customer
end

#customer_detailsObject (readonly)

Attribute for field customer_details



471
472
473
# File 'lib/stripe/resources/tax/calculation.rb', line 471

def customer_details
  @customer_details
end

#expires_atObject (readonly)

Timestamp of date at which the tax calculation will expire.



473
474
475
# File 'lib/stripe/resources/tax/calculation.rb', line 473

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the calculation.



475
476
477
# File 'lib/stripe/resources/tax/calculation.rb', line 475

def id
  @id
end

#line_itemsObject (readonly)

The list of items the customer is purchasing.



477
478
479
# File 'lib/stripe/resources/tax/calculation.rb', line 477

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



479
480
481
# File 'lib/stripe/resources/tax/calculation.rb', line 479

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



481
482
483
# File 'lib/stripe/resources/tax/calculation.rb', line 481

def object
  @object
end

#ship_from_detailsObject (readonly)

The details of the ship from location, such as the address.



483
484
485
# File 'lib/stripe/resources/tax/calculation.rb', line 483

def ship_from_details
  @ship_from_details
end

#shipping_costObject (readonly)

The shipping cost details for the calculation.



485
486
487
# File 'lib/stripe/resources/tax/calculation.rb', line 485

def shipping_cost
  @shipping_cost
end

#tax_amount_exclusiveObject (readonly)

The amount of tax to be collected on top of the line item prices.



487
488
489
# File 'lib/stripe/resources/tax/calculation.rb', line 487

def tax_amount_exclusive
  @tax_amount_exclusive
end

#tax_amount_inclusiveObject (readonly)

The amount of tax already included in the line item prices.



489
490
491
# File 'lib/stripe/resources/tax/calculation.rb', line 489

def tax_amount_inclusive
  @tax_amount_inclusive
end

#tax_breakdownObject (readonly)

Breakdown of individual tax amounts that add up to the total.



491
492
493
# File 'lib/stripe/resources/tax/calculation.rb', line 491

def tax_breakdown
  @tax_breakdown
end

#tax_dateObject (readonly)

Timestamp of date at which the tax rules and rates in effect applies for the calculation.



493
494
495
# File 'lib/stripe/resources/tax/calculation.rb', line 493

def tax_date
  @tax_date
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Calculates tax based on the input and returns a Tax Calculation object.



496
497
498
499
500
501
502
503
# File 'lib/stripe/resources/tax/calculation.rb', line 496

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/calculations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



534
535
536
# File 'lib/stripe/resources/tax/calculation.rb', line 534

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



525
526
527
528
529
530
531
532
# File 'lib/stripe/resources/tax/calculation.rb', line 525

def self.inner_class_types
  @inner_class_types = {
    customer_details: CustomerDetails,
    ship_from_details: ShipFromDetails,
    shipping_cost: ShippingCost,
    tax_breakdown: TaxBreakdown,
  }
end

.list_line_items(calculation, params = {}, opts = {}) ⇒ Object

Retrieves the line items of a tax calculation as a collection, if the calculation hasn’t expired.



516
517
518
519
520
521
522
523
# File 'lib/stripe/resources/tax/calculation.rb', line 516

def self.list_line_items(calculation, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/tax/calculations/%<calculation>s/line_items", { calculation: CGI.escape(calculation) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/tax/calculation.rb', line 13

def self.object_name
  "tax.calculation"
end

Instance Method Details

#list_line_items(params = {}, opts = {}) ⇒ Object

Retrieves the line items of a tax calculation as a collection, if the calculation hasn’t expired.



506
507
508
509
510
511
512
513
# File 'lib/stripe/resources/tax/calculation.rb', line 506

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/tax/calculations/%<calculation>s/line_items", { calculation: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end