Class: Stripe::Tax::Calculation

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/tax/calculation.rb

Overview

A Tax Calculation allows you to calculate the tax to collect from your customer.

Related guide: [Calculate tax in your custom payment flow](stripe.com/docs/tax/custom)

Defined Under Namespace

Classes: CreateParams, CustomerDetails, ListLineItemsParams, RetrieveParams, ShipFromDetails, ShippingCost, TaxBreakdown

Constant Summary collapse

OBJECT_NAME =
"tax.calculation"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_totalObject (readonly)

Total amount after taxes in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



374
375
376
# File 'lib/stripe/resources/tax/calculation.rb', line 374

def amount_total
  @amount_total
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



376
377
378
# File 'lib/stripe/resources/tax/calculation.rb', line 376

def currency
  @currency
end

#customerObject (readonly)

The ID of an existing [Customer](stripe.com/docs/api/customers/object) used for the resource.



378
379
380
# File 'lib/stripe/resources/tax/calculation.rb', line 378

def customer
  @customer
end

#customer_detailsObject (readonly)

Attribute for field customer_details



380
381
382
# File 'lib/stripe/resources/tax/calculation.rb', line 380

def customer_details
  @customer_details
end

#expires_atObject (readonly)

Timestamp of date at which the tax calculation will expire.



382
383
384
# File 'lib/stripe/resources/tax/calculation.rb', line 382

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the calculation.



384
385
386
# File 'lib/stripe/resources/tax/calculation.rb', line 384

def id
  @id
end

#line_itemsObject (readonly)

The list of items the customer is purchasing.



386
387
388
# File 'lib/stripe/resources/tax/calculation.rb', line 386

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



388
389
390
# File 'lib/stripe/resources/tax/calculation.rb', line 388

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



390
391
392
# File 'lib/stripe/resources/tax/calculation.rb', line 390

def object
  @object
end

#ship_from_detailsObject (readonly)

The details of the ship from location, such as the address.



392
393
394
# File 'lib/stripe/resources/tax/calculation.rb', line 392

def ship_from_details
  @ship_from_details
end

#shipping_costObject (readonly)

The shipping cost details for the calculation.



394
395
396
# File 'lib/stripe/resources/tax/calculation.rb', line 394

def shipping_cost
  @shipping_cost
end

#tax_amount_exclusiveObject (readonly)

The amount of tax to be collected on top of the line item prices.



396
397
398
# File 'lib/stripe/resources/tax/calculation.rb', line 396

def tax_amount_exclusive
  @tax_amount_exclusive
end

#tax_amount_inclusiveObject (readonly)

The amount of tax already included in the line item prices.



398
399
400
# File 'lib/stripe/resources/tax/calculation.rb', line 398

def tax_amount_inclusive
  @tax_amount_inclusive
end

#tax_breakdownObject (readonly)

Breakdown of individual tax amounts that add up to the total.



400
401
402
# File 'lib/stripe/resources/tax/calculation.rb', line 400

def tax_breakdown
  @tax_breakdown
end

#tax_dateObject (readonly)

Timestamp of date at which the tax rules and rates in effect applies for the calculation.



402
403
404
# File 'lib/stripe/resources/tax/calculation.rb', line 402

def tax_date
  @tax_date
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Calculates tax based on the input and returns a Tax Calculation object.



405
406
407
408
409
410
411
412
# File 'lib/stripe/resources/tax/calculation.rb', line 405

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/calculations",
    params: params,
    opts: opts
  )
end

.list_line_items(calculation, params = {}, opts = {}) ⇒ Object

Retrieves the line items of a tax calculation as a collection, if the calculation hasn’t expired.



425
426
427
428
429
430
431
432
# File 'lib/stripe/resources/tax/calculation.rb', line 425

def self.list_line_items(calculation, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/tax/calculations/%<calculation>s/line_items", { calculation: CGI.escape(calculation) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/tax/calculation.rb', line 13

def self.object_name
  "tax.calculation"
end

Instance Method Details

#list_line_items(params = {}, opts = {}) ⇒ Object

Retrieves the line items of a tax calculation as a collection, if the calculation hasn’t expired.



415
416
417
418
419
420
421
422
# File 'lib/stripe/resources/tax/calculation.rb', line 415

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/tax/calculations/%<calculation>s/line_items", { calculation: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end