Class: Stripe::Tax::Calculation::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/calculation.rb

Defined Under Namespace

Classes: CustomerDetails, LineItem, ShipFromDetails, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/stripe/resources/tax/calculation.rb', line 353

def initialize(
  currency: nil,
  customer: nil,
  customer_details: nil,
  expand: nil,
  line_items: nil,
  ship_from_details: nil,
  shipping_cost: nil,
  tax_date: nil
)
  @currency = currency
  @customer = customer
  @customer_details = customer_details
  @expand = expand
  @line_items = line_items
  @ship_from_details = ship_from_details
  @shipping_cost = shipping_cost
  @tax_date = tax_date
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



337
338
339
# File 'lib/stripe/resources/tax/calculation.rb', line 337

def currency
  @currency
end

#customerObject

The ID of an existing customer to use for this calculation. If provided, the customer’s address and tax IDs are copied to ‘customer_details`.



339
340
341
# File 'lib/stripe/resources/tax/calculation.rb', line 339

def customer
  @customer
end

#customer_detailsObject

Details about the customer, including address and tax IDs.



341
342
343
# File 'lib/stripe/resources/tax/calculation.rb', line 341

def customer_details
  @customer_details
end

#expandObject

Specifies which fields in the response should be expanded.



343
344
345
# File 'lib/stripe/resources/tax/calculation.rb', line 343

def expand
  @expand
end

#line_itemsObject

A list of items the customer is purchasing.



345
346
347
# File 'lib/stripe/resources/tax/calculation.rb', line 345

def line_items
  @line_items
end

#ship_from_detailsObject

Details about the address from which the goods are being shipped.



347
348
349
# File 'lib/stripe/resources/tax/calculation.rb', line 347

def ship_from_details
  @ship_from_details
end

#shipping_costObject

Shipping cost details to be used for the calculation.



349
350
351
# File 'lib/stripe/resources/tax/calculation.rb', line 349

def shipping_cost
  @shipping_cost
end

#tax_dateObject

Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.



351
352
353
# File 'lib/stripe/resources/tax/calculation.rb', line 351

def tax_date
  @tax_date
end