Class: Stripe::Tax::Calculation::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Calculation::CreateParams
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Classes: CustomerDetails, LineItem, ShipFromDetails, ShippingCost
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The ID of an existing customer to use for this calculation.
-
#customer_details ⇒ Object
Details about the customer, including address and tax IDs.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#ship_from_details ⇒ Object
Details about the address from which the goods are being shipped.
-
#shipping_cost ⇒ Object
Shipping cost details to be used for the calculation.
-
#tax_date ⇒ Object
Timestamp of date at which the tax rules and rates in effect applies for the calculation.
Instance Method Summary collapse
-
#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/stripe/resources/tax/calculation.rb', line 426 def initialize( currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil ) @currency = currency @customer = customer @customer_details = customer_details @expand = @line_items = line_items @ship_from_details = ship_from_details @shipping_cost = shipping_cost @tax_date = tax_date end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
403 404 405 |
# File 'lib/stripe/resources/tax/calculation.rb', line 403 def currency @currency end |
#customer ⇒ Object
The ID of an existing customer to use for this calculation. If provided, the customer’s address and tax IDs are copied to ‘customer_details`.
406 407 408 |
# File 'lib/stripe/resources/tax/calculation.rb', line 406 def customer @customer end |
#customer_details ⇒ Object
Details about the customer, including address and tax IDs.
409 410 411 |
# File 'lib/stripe/resources/tax/calculation.rb', line 409 def customer_details @customer_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
412 413 414 |
# File 'lib/stripe/resources/tax/calculation.rb', line 412 def @expand end |
#line_items ⇒ Object
A list of items the customer is purchasing.
415 416 417 |
# File 'lib/stripe/resources/tax/calculation.rb', line 415 def line_items @line_items end |
#ship_from_details ⇒ Object
Details about the address from which the goods are being shipped.
418 419 420 |
# File 'lib/stripe/resources/tax/calculation.rb', line 418 def ship_from_details @ship_from_details end |
#shipping_cost ⇒ Object
Shipping cost details to be used for the calculation.
421 422 423 |
# File 'lib/stripe/resources/tax/calculation.rb', line 421 def shipping_cost @shipping_cost end |
#tax_date ⇒ Object
Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.
424 425 426 |
# File 'lib/stripe/resources/tax/calculation.rb', line 424 def tax_date @tax_date end |