Class: Stripe::Tax::Calculation::CreateParams::CustomerDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Calculation::CreateParams::CustomerDetails
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s postal address (for example, home or business location).
-
#address_source ⇒ Object
The type of customer address provided.
-
#ip_address ⇒ Object
The customer’s IP address (IPv4 or IPv6).
-
#tax_ids ⇒ Object
The customer’s tax IDs.
-
#taxability_override ⇒ Object
Overrides the tax calculation result to allow you to not collect tax from your customer.
Instance Method Summary collapse
-
#initialize(address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil) ⇒ CustomerDetails
constructor
A new instance of CustomerDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil) ⇒ CustomerDetails
Returns a new instance of CustomerDetails.
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/stripe/resources/tax/calculation.rb', line 233 def initialize( address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil ) @address = address @address_source = address_source @ip_address = ip_address @tax_ids = tax_ids @taxability_override = taxability_override end |
Instance Attribute Details
#address ⇒ Object
The customer’s postal address (for example, home or business location).
223 224 225 |
# File 'lib/stripe/resources/tax/calculation.rb', line 223 def address @address end |
#address_source ⇒ Object
The type of customer address provided.
225 226 227 |
# File 'lib/stripe/resources/tax/calculation.rb', line 225 def address_source @address_source end |
#ip_address ⇒ Object
The customer’s IP address (IPv4 or IPv6).
227 228 229 |
# File 'lib/stripe/resources/tax/calculation.rb', line 227 def ip_address @ip_address end |
#tax_ids ⇒ Object
The customer’s tax IDs. Stripe Tax might consider a transaction with applicable tax IDs to be B2B, which might affect the tax calculation result. Stripe Tax doesn’t validate tax IDs for correctness.
229 230 231 |
# File 'lib/stripe/resources/tax/calculation.rb', line 229 def tax_ids @tax_ids end |
#taxability_override ⇒ Object
Overrides the tax calculation result to allow you to not collect tax from your customer. Use this if you’ve manually checked your customer’s tax exemptions. Prefer providing the customer’s ‘tax_ids` where possible, which automatically determines whether `reverse_charge` applies.
231 232 233 |
# File 'lib/stripe/resources/tax/calculation.rb', line 231 def taxability_override @taxability_override end |