Class: Stripe::Tax::Calculation::CreateParams::CustomerDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Calculation::CreateParams::CustomerDetails
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s postal address (for example, home or business location).
-
#address_source ⇒ Object
The type of customer address provided.
-
#ip_address ⇒ Object
The customer’s IP address (IPv4 or IPv6).
-
#tax_ids ⇒ Object
The customer’s tax IDs.
-
#taxability_override ⇒ Object
Overrides the tax calculation result to allow you to not collect tax from your customer.
Instance Method Summary collapse
-
#initialize(address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil) ⇒ CustomerDetails
constructor
A new instance of CustomerDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil) ⇒ CustomerDetails
Returns a new instance of CustomerDetails.
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/stripe/resources/tax/calculation.rb', line 286 def initialize( address: nil, address_source: nil, ip_address: nil, tax_ids: nil, taxability_override: nil ) @address = address @address_source = address_source @ip_address = ip_address @tax_ids = tax_ids @taxability_override = taxability_override end |
Instance Attribute Details
#address ⇒ Object
The customer’s postal address (for example, home or business location).
272 273 274 |
# File 'lib/stripe/resources/tax/calculation.rb', line 272 def address @address end |
#address_source ⇒ Object
The type of customer address provided.
275 276 277 |
# File 'lib/stripe/resources/tax/calculation.rb', line 275 def address_source @address_source end |
#ip_address ⇒ Object
The customer’s IP address (IPv4 or IPv6).
278 279 280 |
# File 'lib/stripe/resources/tax/calculation.rb', line 278 def ip_address @ip_address end |
#tax_ids ⇒ Object
The customer’s tax IDs. Stripe Tax might consider a transaction with applicable tax IDs to be B2B, which might affect the tax calculation result. Stripe Tax doesn’t validate tax IDs for correctness.
281 282 283 |
# File 'lib/stripe/resources/tax/calculation.rb', line 281 def tax_ids @tax_ids end |
#taxability_override ⇒ Object
Overrides the tax calculation result to allow you to not collect tax from your customer. Use this if you’ve manually checked your customer’s tax exemptions. Prefer providing the customer’s ‘tax_ids` where possible, which automatically determines whether `reverse_charge` applies.
284 285 286 |
# File 'lib/stripe/resources/tax/calculation.rb', line 284 def taxability_override @taxability_override end |