Class: Stripe::Tax::Calculation::ShippingCost
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Calculation::ShippingCost
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Classes: TaxBreakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The shipping amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#amount_tax ⇒ Object
readonly
The amount of tax calculated for shipping, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#shipping_rate ⇒ Object
readonly
The ID of an existing [ShippingRate](stripe.com/docs/api/shipping_rates/object).
-
#tax_behavior ⇒ Object
readonly
Specifies whether the ‘amount` includes taxes.
-
#tax_breakdown ⇒ Object
readonly
Detailed account of taxes relevant to shipping cost.
-
#tax_code ⇒ Object
readonly
The [tax code](stripe.com/docs/tax/tax-categories) ID used for shipping.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The shipping amount in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). If ‘tax_behavior=inclusive`, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.
130 131 132 |
# File 'lib/stripe/resources/tax/calculation.rb', line 130 def amount @amount end |
#amount_tax ⇒ Object (readonly)
The amount of tax calculated for shipping, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
133 134 135 |
# File 'lib/stripe/resources/tax/calculation.rb', line 133 def amount_tax @amount_tax end |
#shipping_rate ⇒ Object (readonly)
The ID of an existing [ShippingRate](stripe.com/docs/api/shipping_rates/object).
136 137 138 |
# File 'lib/stripe/resources/tax/calculation.rb', line 136 def shipping_rate @shipping_rate end |
#tax_behavior ⇒ Object (readonly)
Specifies whether the ‘amount` includes taxes. If `tax_behavior=inclusive`, then the amount includes taxes.
139 140 141 |
# File 'lib/stripe/resources/tax/calculation.rb', line 139 def tax_behavior @tax_behavior end |
#tax_breakdown ⇒ Object (readonly)
Detailed account of taxes relevant to shipping cost.
142 143 144 |
# File 'lib/stripe/resources/tax/calculation.rb', line 142 def tax_breakdown @tax_breakdown end |
#tax_code ⇒ Object (readonly)
The [tax code](stripe.com/docs/tax/tax-categories) ID used for shipping.
145 146 147 |
# File 'lib/stripe/resources/tax/calculation.rb', line 145 def tax_code @tax_code end |