Class: Stripe::Tax::Calculation::ShippingCost::TaxBreakdown

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/calculation.rb

Defined Under Namespace

Classes: Jurisdiction, TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of tax, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



112
113
114
# File 'lib/stripe/resources/tax/calculation.rb', line 112

def amount
  @amount
end

#jurisdictionObject (readonly)

Attribute for field jurisdiction



115
116
117
# File 'lib/stripe/resources/tax/calculation.rb', line 115

def jurisdiction
  @jurisdiction
end

#sourcingObject (readonly)

Indicates whether the jurisdiction was determined by the origin (merchant’s address) or destination (customer’s address).



118
119
120
# File 'lib/stripe/resources/tax/calculation.rb', line 118

def sourcing
  @sourcing
end

#tax_rate_detailsObject (readonly)

Details regarding the rate for this tax. This field will be ‘null` when the tax is not imposed, for example if the product is exempt from tax.



121
122
123
# File 'lib/stripe/resources/tax/calculation.rb', line 121

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



124
125
126
# File 'lib/stripe/resources/tax/calculation.rb', line 124

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



127
128
129
# File 'lib/stripe/resources/tax/calculation.rb', line 127

def taxable_amount
  @taxable_amount
end