Class: Stripe::Tax::Calculation::TaxBreakdown
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Calculation::TaxBreakdown
- Defined in:
- lib/stripe/resources/tax/calculation.rb
Defined Under Namespace
Classes: TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of tax, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#inclusive ⇒ Object
readonly
Specifies whether the tax amount is included in the line item amount.
-
#tax_rate_details ⇒ Object
readonly
Attribute for field tax_rate_details.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of tax, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
176 177 178 |
# File 'lib/stripe/resources/tax/calculation.rb', line 176 def amount @amount end |
#inclusive ⇒ Object (readonly)
Specifies whether the tax amount is included in the line item amount.
179 180 181 |
# File 'lib/stripe/resources/tax/calculation.rb', line 179 def inclusive @inclusive end |
#tax_rate_details ⇒ Object (readonly)
Attribute for field tax_rate_details
182 183 184 |
# File 'lib/stripe/resources/tax/calculation.rb', line 182 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. We might extend the possible values for this field to support new tax rules.
185 186 187 |
# File 'lib/stripe/resources/tax/calculation.rb', line 185 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
188 189 190 |
# File 'lib/stripe/resources/tax/calculation.rb', line 188 def taxable_amount @taxable_amount end |