Class: Stripe::Tax::CalculationLineItem::TaxBreakdown

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/calculation_line_item.rb

Defined Under Namespace

Classes: Jurisdiction, TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of tax, in the smallest currency unit.



84
85
86
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 84

def amount
  @amount
end

#jurisdictionObject (readonly)

Attribute for field jurisdiction



86
87
88
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 86

def jurisdiction
  @jurisdiction
end

#sourcingObject (readonly)

Indicates whether the jurisdiction was determined by the origin (merchant's address) or destination (customer's address).



88
89
90
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 88

def sourcing
  @sourcing
end

#tax_rate_detailsObject (readonly)

Details regarding the rate for this tax. This field will be null when the tax is not imposed, for example if the product is exempt from tax.



90
91
92
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 90

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



92
93
94
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 92

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in the smallest currency unit.



94
95
96
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 94

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



100
101
102
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 100

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



96
97
98
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 96

def self.inner_class_types
  @inner_class_types = { jurisdiction: Jurisdiction, tax_rate_details: TaxRateDetails }
end