Class: Stripe::Tax::CalculationLineItem::TaxBreakdown
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::CalculationLineItem::TaxBreakdown
- Defined in:
- lib/stripe/resources/tax/calculation_line_item.rb
Defined Under Namespace
Classes: Jurisdiction, TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of tax, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#jurisdiction ⇒ Object
readonly
Attribute for field jurisdiction.
-
#sourcing ⇒ Object
readonly
Indicates whether the jurisdiction was determined by the origin (merchant’s address) or destination (customer’s address).
-
#tax_rate_details ⇒ Object
readonly
Details regarding the rate for this tax.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of tax, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
38 39 40 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 38 def amount @amount end |
#jurisdiction ⇒ Object (readonly)
Attribute for field jurisdiction
41 42 43 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 41 def jurisdiction @jurisdiction end |
#sourcing ⇒ Object (readonly)
Indicates whether the jurisdiction was determined by the origin (merchant’s address) or destination (customer’s address).
44 45 46 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 44 def sourcing @sourcing end |
#tax_rate_details ⇒ Object (readonly)
Details regarding the rate for this tax. This field will be ‘null` when the tax is not imposed, for example if the product is exempt from tax.
47 48 49 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 47 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
50 51 52 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 50 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
53 54 55 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 53 def taxable_amount @taxable_amount end |