Class: Stripe::Tax::CalculationLineItem::TaxBreakdown
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::CalculationLineItem::TaxBreakdown
- Defined in:
- lib/stripe/resources/tax/calculation_line_item.rb
Defined Under Namespace
Classes: Jurisdiction, TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of tax, in the smallest currency unit.
-
#jurisdiction ⇒ Object
readonly
Attribute for field jurisdiction.
-
#sourcing ⇒ Object
readonly
Indicates whether the jurisdiction was determined by the origin (merchant's address) or destination (customer's address).
-
#tax_rate_details ⇒ Object
readonly
Details regarding the rate for this tax.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in the smallest currency unit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of tax, in the smallest currency unit.
50 51 52 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 50 def amount @amount end |
#jurisdiction ⇒ Object (readonly)
Attribute for field jurisdiction
52 53 54 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 52 def jurisdiction @jurisdiction end |
#sourcing ⇒ Object (readonly)
Indicates whether the jurisdiction was determined by the origin (merchant's address) or destination (customer's address).
54 55 56 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 54 def sourcing @sourcing end |
#tax_rate_details ⇒ Object (readonly)
Details regarding the rate for this tax. This field will be null when the tax is not imposed, for example if the product is exempt from tax.
56 57 58 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 56 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
58 59 60 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 58 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in the smallest currency unit.
60 61 62 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 60 def taxable_amount @taxable_amount end |
Class Method Details
.field_remappings ⇒ Object
66 67 68 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 66 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
62 63 64 |
# File 'lib/stripe/resources/tax/calculation_line_item.rb', line 62 def self.inner_class_types @inner_class_types = { jurisdiction: Jurisdiction, tax_rate_details: TaxRateDetails } end |