Class: Stripe::Tax::CalculationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/calculation_service.rb

Defined Under Namespace

Classes: CustomerDetails, LineItem, ShipFromDetails, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/stripe/services/tax/calculation_service.rb', line 202

def initialize(
  currency: nil,
  customer: nil,
  customer_details: nil,
  expand: nil,
  line_items: nil,
  ship_from_details: nil,
  shipping_cost: nil,
  tax_date: nil
)
  @currency = currency
  @customer = customer
  @customer_details = customer_details
  @expand = expand
  @line_items = line_items
  @ship_from_details = ship_from_details
  @shipping_cost = shipping_cost
  @tax_date = tax_date
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



186
187
188
# File 'lib/stripe/services/tax/calculation_service.rb', line 186

def currency
  @currency
end

#customerObject

The ID of an existing customer to use for this calculation. If provided, the customer’s address and tax IDs are copied to ‘customer_details`.



188
189
190
# File 'lib/stripe/services/tax/calculation_service.rb', line 188

def customer
  @customer
end

#customer_detailsObject

Details about the customer, including address and tax IDs.



190
191
192
# File 'lib/stripe/services/tax/calculation_service.rb', line 190

def customer_details
  @customer_details
end

#expandObject

Specifies which fields in the response should be expanded.



192
193
194
# File 'lib/stripe/services/tax/calculation_service.rb', line 192

def expand
  @expand
end

#line_itemsObject

A list of items the customer is purchasing.



194
195
196
# File 'lib/stripe/services/tax/calculation_service.rb', line 194

def line_items
  @line_items
end

#ship_from_detailsObject

Details about the address from which the goods are being shipped.



196
197
198
# File 'lib/stripe/services/tax/calculation_service.rb', line 196

def ship_from_details
  @ship_from_details
end

#shipping_costObject

Shipping cost details to be used for the calculation.



198
199
200
# File 'lib/stripe/services/tax/calculation_service.rb', line 198

def shipping_cost
  @shipping_cost
end

#tax_dateObject

Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.



200
201
202
# File 'lib/stripe/services/tax/calculation_service.rb', line 200

def tax_date
  @tax_date
end