Class: Stripe::Tax::CalculationService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::CalculationService::CreateParams
- Defined in:
- lib/stripe/services/tax/calculation_service.rb
Defined Under Namespace
Classes: CustomerDetails, LineItem, ShipFromDetails, ShippingCost
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The ID of an existing customer to use for this calculation.
-
#customer_details ⇒ Object
Details about the customer, including address and tax IDs.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#ship_from_details ⇒ Object
Details about the address from which the goods are being shipped.
-
#shipping_cost ⇒ Object
Shipping cost details to be used for the calculation.
-
#tax_date ⇒ Object
Timestamp of date at which the tax rules and rates in effect applies for the calculation.
Instance Method Summary collapse
-
#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 228 def initialize( currency: nil, customer: nil, customer_details: nil, expand: nil, line_items: nil, ship_from_details: nil, shipping_cost: nil, tax_date: nil ) @currency = currency @customer = customer @customer_details = customer_details @expand = @line_items = line_items @ship_from_details = ship_from_details @shipping_cost = shipping_cost @tax_date = tax_date end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
205 206 207 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 205 def currency @currency end |
#customer ⇒ Object
The ID of an existing customer to use for this calculation. If provided, the customer’s address and tax IDs are copied to ‘customer_details`.
208 209 210 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 208 def customer @customer end |
#customer_details ⇒ Object
Details about the customer, including address and tax IDs.
211 212 213 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 211 def customer_details @customer_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
214 215 216 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 214 def @expand end |
#line_items ⇒ Object
A list of items the customer is purchasing.
217 218 219 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 217 def line_items @line_items end |
#ship_from_details ⇒ Object
Details about the address from which the goods are being shipped.
220 221 222 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 220 def ship_from_details @ship_from_details end |
#shipping_cost ⇒ Object
Shipping cost details to be used for the calculation.
223 224 225 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 223 def shipping_cost @shipping_cost end |
#tax_date ⇒ Object
Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.
226 227 228 |
# File 'lib/stripe/services/tax/calculation_service.rb', line 226 def tax_date @tax_date end |