Class: Stripe::Tax::Form::FilingStatus::Jurisdiction
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Form::FilingStatus::Jurisdiction
- Defined in:
- lib/stripe/resources/tax/form.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#level ⇒ Object
readonly
Indicates the level of the jurisdiction where the form was filed.
-
#state ⇒ Object
readonly
[ISO 3166-2 U.S. state code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix, if any.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
41 42 43 |
# File 'lib/stripe/resources/tax/form.rb', line 41 def country @country end |
#level ⇒ Object (readonly)
Indicates the level of the jurisdiction where the form was filed.
43 44 45 |
# File 'lib/stripe/resources/tax/form.rb', line 43 def level @level end |
#state ⇒ Object (readonly)
[ISO 3166-2 U.S. state code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix, if any. For example, “NY” for New York, United States. Null for non-U.S. forms.
45 46 47 |
# File 'lib/stripe/resources/tax/form.rb', line 45 def state @state end |