Class: Stripe::Tax::Form::GbMrdp

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/tax/form.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#reporting_period_end_dateObject (readonly)

End date of the period represented by the information reported on the tax form.



57
58
59
# File 'lib/stripe/resources/tax/form.rb', line 57

def reporting_period_end_date
  @reporting_period_end_date
end

#reporting_period_start_dateObject (readonly)

Start date of the period represented by the information reported on the tax form.



59
60
61
# File 'lib/stripe/resources/tax/form.rb', line 59

def reporting_period_start_date
  @reporting_period_start_date
end