Class: Stripe::Tax::Form::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Form::ListParams
- Defined in:
- lib/stripe/resources/tax/form.rb
Defined Under Namespace
Classes: Payee
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payee ⇒ Object
The payee whose volume is represented on the tax form.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/stripe/resources/tax/form.rb', line 209 def initialize( ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil ) @ending_before = ending_before @expand = @limit = limit @payee = payee @starting_after = starting_after @type = type end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
197 198 199 |
# File 'lib/stripe/resources/tax/form.rb', line 197 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
199 200 201 |
# File 'lib/stripe/resources/tax/form.rb', line 199 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
201 202 203 |
# File 'lib/stripe/resources/tax/form.rb', line 201 def limit @limit end |
#payee ⇒ Object
The payee whose volume is represented on the tax form.
203 204 205 |
# File 'lib/stripe/resources/tax/form.rb', line 203 def payee @payee end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
205 206 207 |
# File 'lib/stripe/resources/tax/form.rb', line 205 def starting_after @starting_after end |
#type ⇒ Object
An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future tax form types. If your integration expects only one type of tax form in the response, make sure to provide a type value in the request.
207 208 209 |
# File 'lib/stripe/resources/tax/form.rb', line 207 def type @type end |