Class: Stripe::Tax::Form::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/form.rb

Defined Under Namespace

Classes: Payee

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/stripe/resources/tax/form.rb', line 139

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  payee: nil,
  starting_after: nil,
  type: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payee = payee
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



122
123
124
# File 'lib/stripe/resources/tax/form.rb', line 122

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



125
126
127
# File 'lib/stripe/resources/tax/form.rb', line 125

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



128
129
130
# File 'lib/stripe/resources/tax/form.rb', line 128

def limit
  @limit
end

#payeeObject

The payee whose volume is represented on the tax form.



131
132
133
# File 'lib/stripe/resources/tax/form.rb', line 131

def payee
  @payee
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



134
135
136
# File 'lib/stripe/resources/tax/form.rb', line 134

def starting_after
  @starting_after
end

#typeObject

An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future tax form types. If your integration expects only one type of tax form in the response, make sure to provide a type value in the request.



137
138
139
# File 'lib/stripe/resources/tax/form.rb', line 137

def type
  @type
end