Class: Stripe::Tax::Form::ListParams::Payee

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/form.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee

Returns a new instance of Payee.



115
116
117
118
119
# File 'lib/stripe/resources/tax/form.rb', line 115

def initialize(account: nil, external_reference: nil, type: nil)
  @account = 
  @external_reference = external_reference
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose forms will be retrieved.



107
108
109
# File 'lib/stripe/resources/tax/form.rb', line 107

def 
  @account
end

#external_referenceObject

The external reference to the payee whose forms will be retrieved.



110
111
112
# File 'lib/stripe/resources/tax/form.rb', line 110

def external_reference
  @external_reference
end

#typeObject

Specifies the payee type. Either ‘account` or `external_reference`.



113
114
115
# File 'lib/stripe/resources/tax/form.rb', line 113

def type
  @type
end