Class: Stripe::Tax::Form::ListParams::Payee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Form::ListParams::Payee
- Defined in:
- lib/stripe/resources/tax/form.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose forms will be retrieved.
-
#external_reference ⇒ Object
The external reference to the payee whose forms will be retrieved.
-
#type ⇒ Object
Specifies the payee type.
Instance Method Summary collapse
-
#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee
constructor
A new instance of Payee.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee
Returns a new instance of Payee.
115 116 117 118 119 |
# File 'lib/stripe/resources/tax/form.rb', line 115 def initialize(account: nil, external_reference: nil, type: nil) @account = account @external_reference = external_reference @type = type end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose forms will be retrieved.
107 108 109 |
# File 'lib/stripe/resources/tax/form.rb', line 107 def account @account end |
#external_reference ⇒ Object
The external reference to the payee whose forms will be retrieved.
110 111 112 |
# File 'lib/stripe/resources/tax/form.rb', line 110 def external_reference @external_reference end |
#type ⇒ Object
Specifies the payee type. Either ‘account` or `external_reference`.
113 114 115 |
# File 'lib/stripe/resources/tax/form.rb', line 113 def type @type end |