Class: Stripe::Tax::FormListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::FormListParams
- Defined in:
- lib/stripe/params/tax/form_list_params.rb
Defined Under Namespace
Classes: Payee
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payee ⇒ Object
The payee whose volume is represented on the tax form.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
An optional filter on the list, based on the object
typefield.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ FormListParams
constructor
A new instance of FormListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil) ⇒ FormListParams
Returns a new instance of FormListParams.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 34 def initialize( ending_before: nil, expand: nil, limit: nil, payee: nil, starting_after: nil, type: nil ) @ending_before = ending_before @expand = @limit = limit @payee = payee @starting_after = starting_after @type = type end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
22 23 24 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 22 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
24 25 26 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 24 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
26 27 28 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 26 def limit @limit end |
#payee ⇒ Object
The payee whose volume is represented on the tax form.
28 29 30 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 28 def payee @payee end |
#starting_after ⇒ Object
A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
30 31 32 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 30 def starting_after @starting_after end |
#type ⇒ Object
An optional filter on the list, based on the object type field. Without the filter, the list includes all current and future tax form types. If your integration expects only one type of tax form in the response, make sure to provide a type value in the request.
32 33 34 |
# File 'lib/stripe/params/tax/form_list_params.rb', line 32 def type @type end |