Class: Stripe::Tax::FormService::ListParams::Payee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::FormService::ListParams::Payee
- Defined in:
- lib/stripe/services/tax/form_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose forms will be retrieved.
-
#external_reference ⇒ Object
The external reference to the payee whose forms will be retrieved.
-
#type ⇒ Object
Specifies the payee type.
Instance Method Summary collapse
-
#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee
constructor
A new instance of Payee.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, external_reference: nil, type: nil) ⇒ Payee
Returns a new instance of Payee.
18 19 20 21 22 |
# File 'lib/stripe/services/tax/form_service.rb', line 18 def initialize(account: nil, external_reference: nil, type: nil) @account = account @external_reference = external_reference @type = type end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose forms will be retrieved.
10 11 12 |
# File 'lib/stripe/services/tax/form_service.rb', line 10 def account @account end |
#external_reference ⇒ Object
The external reference to the payee whose forms will be retrieved.
13 14 15 |
# File 'lib/stripe/services/tax/form_service.rb', line 13 def external_reference @external_reference end |
#type ⇒ Object
Specifies the payee type. Either ‘account` or `external_reference`.
16 17 18 |
# File 'lib/stripe/services/tax/form_service.rb', line 16 def type @type end |