Class: Stripe::Tax::LocationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::LocationCreateParams
- Defined in:
- lib/stripe/params/tax/location_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The physical address of the tax location.
-
#description ⇒ Object
Details to identify the tax location by its venue, types of events held, or available services, such as “A spacious auditorium suitable for large concerts and events.”.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
The type of tax location.
Instance Method Summary collapse
-
#initialize(address: nil, description: nil, expand: nil, type: nil) ⇒ LocationCreateParams
constructor
A new instance of LocationCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, description: nil, expand: nil, type: nil) ⇒ LocationCreateParams
Returns a new instance of LocationCreateParams.
46 47 48 49 50 51 |
# File 'lib/stripe/params/tax/location_create_params.rb', line 46 def initialize(address: nil, description: nil, expand: nil, type: nil) @address = address @description = description @expand = @type = type end |
Instance Attribute Details
#address ⇒ Object
The physical address of the tax location.
38 39 40 |
# File 'lib/stripe/params/tax/location_create_params.rb', line 38 def address @address end |
#description ⇒ Object
Details to identify the tax location by its venue, types of events held, or available services, such as “A spacious auditorium suitable for large concerts and events.”.
40 41 42 |
# File 'lib/stripe/params/tax/location_create_params.rb', line 40 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
42 43 44 |
# File 'lib/stripe/params/tax/location_create_params.rb', line 42 def @expand end |
#type ⇒ Object
The type of tax location. The only supported value is “performance”.
44 45 46 |
# File 'lib/stripe/params/tax/location_create_params.rb', line 44 def type @type end |