Class: Stripe::Tax::Registration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Tax::Registration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/tax/registration.rb
Overview
A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.
Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.
Related guide: Using the Registrations API
Defined Under Namespace
Classes: CountryOptions
Constant Summary collapse
- OBJECT_NAME =
"tax.registration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active_from ⇒ Object
readonly
Time at which the registration becomes active.
-
#country ⇒ Object
readonly
Two-letter country code (ISO 3166-1 alpha-2).
-
#country_options ⇒ Object
readonly
Attribute for field country_options.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#expires_at ⇒ Object
readonly
If set, the registration stops being active at this time.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#object ⇒ Object
readonly
String representing the object's type.
-
#status ⇒ Object
readonly
The status of the registration.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active_from ⇒ Object (readonly)
Time at which the registration becomes active. Measured in seconds since the Unix epoch.
2781 2782 2783 |
# File 'lib/stripe/resources/tax/registration.rb', line 2781 def active_from @active_from end |
#country ⇒ Object (readonly)
Two-letter country code (ISO 3166-1 alpha-2).
2783 2784 2785 |
# File 'lib/stripe/resources/tax/registration.rb', line 2783 def country @country end |
#country_options ⇒ Object (readonly)
Attribute for field country_options
2785 2786 2787 |
# File 'lib/stripe/resources/tax/registration.rb', line 2785 def @country_options end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2787 2788 2789 |
# File 'lib/stripe/resources/tax/registration.rb', line 2787 def created @created end |
#expires_at ⇒ Object (readonly)
If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.
2789 2790 2791 |
# File 'lib/stripe/resources/tax/registration.rb', line 2789 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2791 2792 2793 |
# File 'lib/stripe/resources/tax/registration.rb', line 2791 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
2793 2794 2795 |
# File 'lib/stripe/resources/tax/registration.rb', line 2793 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
2795 2796 2797 |
# File 'lib/stripe/resources/tax/registration.rb', line 2795 def object @object end |
#status ⇒ Object (readonly)
The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at.
2797 2798 2799 |
# File 'lib/stripe/resources/tax/registration.rb', line 2797 def status @status end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
2800 2801 2802 2803 2804 2805 2806 2807 |
# File 'lib/stripe/resources/tax/registration.rb', line 2800 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/tax/registrations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
2835 2836 2837 |
# File 'lib/stripe/resources/tax/registration.rb', line 2835 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2831 2832 2833 |
# File 'lib/stripe/resources/tax/registration.rb', line 2831 def self.inner_class_types @inner_class_types = { country_options: CountryOptions } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
2810 2811 2812 2813 2814 2815 2816 2817 |
# File 'lib/stripe/resources/tax/registration.rb', line 2810 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/tax/registrations", params: params, opts: opts ) end |
.object_name ⇒ Object
17 18 19 |
# File 'lib/stripe/resources/tax/registration.rb', line 17 def self.object_name "tax.registration" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.
2822 2823 2824 2825 2826 2827 2828 2829 |
# File 'lib/stripe/resources/tax/registration.rb', line 2822 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |