Class: Stripe::Tax::Registration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/tax/registration.rb

Overview

A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.

Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.

Related guide: Using the Registrations API

Defined Under Namespace

Classes: CountryOptions

Constant Summary collapse

OBJECT_NAME =
"tax.registration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#active_fromObject (readonly)

Time at which the registration becomes active. Measured in seconds since the Unix epoch.



2797
2798
2799
# File 'lib/stripe/resources/tax/registration.rb', line 2797

def active_from
  @active_from
end

#countryObject (readonly)

Two-letter country code (ISO 3166-1 alpha-2).



2799
2800
2801
# File 'lib/stripe/resources/tax/registration.rb', line 2799

def country
  @country
end

#country_optionsObject (readonly)

Attribute for field country_options



2801
2802
2803
# File 'lib/stripe/resources/tax/registration.rb', line 2801

def country_options
  @country_options
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2803
2804
2805
# File 'lib/stripe/resources/tax/registration.rb', line 2803

def created
  @created
end

#expires_atObject (readonly)

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.



2805
2806
2807
# File 'lib/stripe/resources/tax/registration.rb', line 2805

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



2807
2808
2809
# File 'lib/stripe/resources/tax/registration.rb', line 2807

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



2809
2810
2811
# File 'lib/stripe/resources/tax/registration.rb', line 2809

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



2811
2812
2813
# File 'lib/stripe/resources/tax/registration.rb', line 2811

def object
  @object
end

#statusObject (readonly)

The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at.



2813
2814
2815
# File 'lib/stripe/resources/tax/registration.rb', line 2813

def status
  @status
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Tax Registration object.



2816
2817
2818
2819
2820
2821
2822
2823
# File 'lib/stripe/resources/tax/registration.rb', line 2816

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2851
2852
2853
# File 'lib/stripe/resources/tax/registration.rb', line 2851

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2847
2848
2849
# File 'lib/stripe/resources/tax/registration.rb', line 2847

def self.inner_class_types
  @inner_class_types = { country_options: CountryOptions }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Tax Registration objects.



2826
2827
2828
2829
2830
2831
2832
2833
# File 'lib/stripe/resources/tax/registration.rb', line 2826

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/tax/registration.rb', line 17

def self.object_name
  "tax.registration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates an existing Tax Registration object.

A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.



2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/stripe/resources/tax/registration.rb', line 2838

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end