Class: Stripe::Tax::Registration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Tax::Registration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/tax/registration.rb
Overview
A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.
Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.
Related guide: Using the Registrations API
Defined Under Namespace
Classes: CountryOptions
Constant Summary collapse
- OBJECT_NAME =
"tax.registration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active_from ⇒ Object
readonly
Time at which the registration becomes active.
-
#country ⇒ Object
readonly
Two-letter country code (ISO 3166-1 alpha-2).
-
#country_options ⇒ Object
readonly
Attribute for field country_options.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#expires_at ⇒ Object
readonly
If set, the registration stops being active at this time.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#object ⇒ Object
readonly
String representing the object's type.
-
#status ⇒ Object
readonly
The status of the registration.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active_from ⇒ Object (readonly)
Time at which the registration becomes active. Measured in seconds since the Unix epoch.
2392 2393 2394 |
# File 'lib/stripe/resources/tax/registration.rb', line 2392 def active_from @active_from end |
#country ⇒ Object (readonly)
Two-letter country code (ISO 3166-1 alpha-2).
2394 2395 2396 |
# File 'lib/stripe/resources/tax/registration.rb', line 2394 def country @country end |
#country_options ⇒ Object (readonly)
Attribute for field country_options
2396 2397 2398 |
# File 'lib/stripe/resources/tax/registration.rb', line 2396 def @country_options end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2398 2399 2400 |
# File 'lib/stripe/resources/tax/registration.rb', line 2398 def created @created end |
#expires_at ⇒ Object (readonly)
If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.
2400 2401 2402 |
# File 'lib/stripe/resources/tax/registration.rb', line 2400 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2402 2403 2404 |
# File 'lib/stripe/resources/tax/registration.rb', line 2402 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
2404 2405 2406 |
# File 'lib/stripe/resources/tax/registration.rb', line 2404 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
2406 2407 2408 |
# File 'lib/stripe/resources/tax/registration.rb', line 2406 def object @object end |
#status ⇒ Object (readonly)
The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at.
2408 2409 2410 |
# File 'lib/stripe/resources/tax/registration.rb', line 2408 def status @status end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/stripe/resources/tax/registration.rb', line 2411 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/tax/registrations", params: params, opts: opts ) end |
.field_remappings ⇒ Object
2446 2447 2448 |
# File 'lib/stripe/resources/tax/registration.rb', line 2446 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2442 2443 2444 |
# File 'lib/stripe/resources/tax/registration.rb', line 2442 def self.inner_class_types @inner_class_types = { country_options: CountryOptions } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/stripe/resources/tax/registration.rb', line 2421 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/tax/registrations", params: params, opts: opts ) end |
.object_name ⇒ Object
17 18 19 |
# File 'lib/stripe/resources/tax/registration.rb', line 17 def self.object_name "tax.registration" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.
2433 2434 2435 2436 2437 2438 2439 2440 |
# File 'lib/stripe/resources/tax/registration.rb', line 2433 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |