Class: Stripe::Tax::Registration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/tax/registration.rb

Overview

A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.

Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.

Related guide: Using the Registrations API

Defined Under Namespace

Classes: CountryOptions

Constant Summary collapse

OBJECT_NAME =
"tax.registration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#active_fromObject (readonly)

Time at which the registration becomes active. Measured in seconds since the Unix epoch.



2248
2249
2250
# File 'lib/stripe/resources/tax/registration.rb', line 2248

def active_from
  @active_from
end

#countryObject (readonly)

Two-letter country code (ISO 3166-1 alpha-2).



2250
2251
2252
# File 'lib/stripe/resources/tax/registration.rb', line 2250

def country
  @country
end

#country_optionsObject (readonly)

Attribute for field country_options



2252
2253
2254
# File 'lib/stripe/resources/tax/registration.rb', line 2252

def country_options
  @country_options
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2254
2255
2256
# File 'lib/stripe/resources/tax/registration.rb', line 2254

def created
  @created
end

#expires_atObject (readonly)

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.



2256
2257
2258
# File 'lib/stripe/resources/tax/registration.rb', line 2256

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



2258
2259
2260
# File 'lib/stripe/resources/tax/registration.rb', line 2258

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



2260
2261
2262
# File 'lib/stripe/resources/tax/registration.rb', line 2260

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



2262
2263
2264
# File 'lib/stripe/resources/tax/registration.rb', line 2262

def object
  @object
end

#statusObject (readonly)

The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at.



2264
2265
2266
# File 'lib/stripe/resources/tax/registration.rb', line 2264

def status
  @status
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Tax Registration object.



2267
2268
2269
2270
2271
2272
2273
2274
# File 'lib/stripe/resources/tax/registration.rb', line 2267

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2302
2303
2304
# File 'lib/stripe/resources/tax/registration.rb', line 2302

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2298
2299
2300
# File 'lib/stripe/resources/tax/registration.rb', line 2298

def self.inner_class_types
  @inner_class_types = { country_options: CountryOptions }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Tax Registration objects.



2277
2278
2279
2280
2281
2282
2283
2284
# File 'lib/stripe/resources/tax/registration.rb', line 2277

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/tax/registration.rb', line 17

def self.object_name
  "tax.registration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates an existing Tax Registration object.

A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.



2289
2290
2291
2292
2293
2294
2295
2296
# File 'lib/stripe/resources/tax/registration.rb', line 2289

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end