Class: Stripe::Tax::Registration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/tax/registration.rb

Overview

A Tax ‘Registration` lets us know that your business is registered to collect tax on payments within a region, enabling you to [automatically collect tax](docs.stripe.com/tax).

Stripe doesn’t register on your behalf with the relevant authorities when you create a Tax ‘Registration` object. For more information on how to register to collect tax, see [our guide](docs.stripe.com/tax/registering).

Related guide: [Using the Registrations API](docs.stripe.com/tax/registrations-api)

Defined Under Namespace

Classes: CountryOptions

Constant Summary collapse

OBJECT_NAME =
"tax.registration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#active_fromObject (readonly)

Time at which the registration becomes active. Measured in seconds since the Unix epoch.



2328
2329
2330
# File 'lib/stripe/resources/tax/registration.rb', line 2328

def active_from
  @active_from
end

#countryObject (readonly)

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2330
2331
2332
# File 'lib/stripe/resources/tax/registration.rb', line 2330

def country
  @country
end

#country_optionsObject (readonly)

Attribute for field country_options



2332
2333
2334
# File 'lib/stripe/resources/tax/registration.rb', line 2332

def country_options
  @country_options
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2334
2335
2336
# File 'lib/stripe/resources/tax/registration.rb', line 2334

def created
  @created
end

#expires_atObject (readonly)

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.



2336
2337
2338
# File 'lib/stripe/resources/tax/registration.rb', line 2336

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



2338
2339
2340
# File 'lib/stripe/resources/tax/registration.rb', line 2338

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2340
2341
2342
# File 'lib/stripe/resources/tax/registration.rb', line 2340

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2342
2343
2344
# File 'lib/stripe/resources/tax/registration.rb', line 2342

def object
  @object
end

#statusObject (readonly)

The status of the registration. This field is present for convenience and can be deduced from ‘active_from` and `expires_at`.



2344
2345
2346
# File 'lib/stripe/resources/tax/registration.rb', line 2344

def status
  @status
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Tax Registration object.



2347
2348
2349
2350
2351
2352
2353
2354
# File 'lib/stripe/resources/tax/registration.rb', line 2347

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2382
2383
2384
# File 'lib/stripe/resources/tax/registration.rb', line 2382

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2378
2379
2380
# File 'lib/stripe/resources/tax/registration.rb', line 2378

def self.inner_class_types
  @inner_class_types = { country_options: CountryOptions }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Tax Registration objects.



2357
2358
2359
2360
2361
2362
2363
2364
# File 'lib/stripe/resources/tax/registration.rb', line 2357

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/tax/registration.rb', line 17

def self.object_name
  "tax.registration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates an existing Tax Registration object.

A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.



2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/stripe/resources/tax/registration.rb', line 2369

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end