Class: Stripe::Tax::Registration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Tax::Registration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/tax/registration.rb
Overview
A Tax ‘Registration` lets us know that your business is registered to collect tax on payments within a region, enabling you to [automatically collect tax](stripe.com/docs/tax).
Stripe doesn’t register on your behalf with the relevant authorities when you create a Tax ‘Registration` object. For more information on how to register to collect tax, see [our guide](stripe.com/docs/tax/registering).
Related guide: [Using the Registrations API](stripe.com/docs/tax/registrations-api)
Defined Under Namespace
Classes: CountryOptions
Constant Summary collapse
- OBJECT_NAME =
"tax.registration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active_from ⇒ Object
readonly
Time at which the registration becomes active.
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#country_options ⇒ Object
readonly
Attribute for field country_options.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#expires_at ⇒ Object
readonly
If set, the registration stops being active at this time.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The status of the registration.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active_from ⇒ Object (readonly)
Time at which the registration becomes active. Measured in seconds since the Unix epoch.
382 383 384 |
# File 'lib/stripe/resources/tax/registration.rb', line 382 def active_from @active_from end |
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
384 385 386 |
# File 'lib/stripe/resources/tax/registration.rb', line 384 def country @country end |
#country_options ⇒ Object (readonly)
Attribute for field country_options
386 387 388 |
# File 'lib/stripe/resources/tax/registration.rb', line 386 def @country_options end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
388 389 390 |
# File 'lib/stripe/resources/tax/registration.rb', line 388 def created @created end |
#expires_at ⇒ Object (readonly)
If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch.
390 391 392 |
# File 'lib/stripe/resources/tax/registration.rb', line 390 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
392 393 394 |
# File 'lib/stripe/resources/tax/registration.rb', line 392 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
394 395 396 |
# File 'lib/stripe/resources/tax/registration.rb', line 394 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
396 397 398 |
# File 'lib/stripe/resources/tax/registration.rb', line 396 def object @object end |
#status ⇒ Object (readonly)
The status of the registration. This field is present for convenience and can be deduced from ‘active_from` and `expires_at`.
398 399 400 |
# File 'lib/stripe/resources/tax/registration.rb', line 398 def status @status end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
401 402 403 404 405 406 407 408 |
# File 'lib/stripe/resources/tax/registration.rb', line 401 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/tax/registrations", params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
411 412 413 414 415 416 417 418 |
# File 'lib/stripe/resources/tax/registration.rb', line 411 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/tax/registrations", params: filters, opts: opts ) end |
.object_name ⇒ Object
17 18 19 |
# File 'lib/stripe/resources/tax/registration.rb', line 17 def self.object_name "tax.registration" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.
423 424 425 426 427 428 429 430 |
# File 'lib/stripe/resources/tax/registration.rb', line 423 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |