Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Attribute for field ae.
-
#al ⇒ Object
readonly
Attribute for field al.
-
#am ⇒ Object
readonly
Attribute for field am.
-
#ao ⇒ Object
readonly
Attribute for field ao.
-
#at ⇒ Object
readonly
Attribute for field at.
-
#au ⇒ Object
readonly
Attribute for field au.
-
#aw ⇒ Object
readonly
Attribute for field aw.
-
#az ⇒ Object
readonly
Attribute for field az.
-
#ba ⇒ Object
readonly
Attribute for field ba.
-
#bb ⇒ Object
readonly
Attribute for field bb.
-
#bd ⇒ Object
readonly
Attribute for field bd.
-
#be ⇒ Object
readonly
Attribute for field be.
-
#bf ⇒ Object
readonly
Attribute for field bf.
-
#bg ⇒ Object
readonly
Attribute for field bg.
-
#bh ⇒ Object
readonly
Attribute for field bh.
-
#bj ⇒ Object
readonly
Attribute for field bj.
-
#bs ⇒ Object
readonly
Attribute for field bs.
-
#by ⇒ Object
readonly
Attribute for field by.
-
#ca ⇒ Object
readonly
Attribute for field ca.
-
#cd ⇒ Object
readonly
Attribute for field cd.
-
#ch ⇒ Object
readonly
Attribute for field ch.
-
#cl ⇒ Object
readonly
Attribute for field cl.
-
#cm ⇒ Object
readonly
Attribute for field cm.
-
#co ⇒ Object
readonly
Attribute for field co.
-
#cr ⇒ Object
readonly
Attribute for field cr.
-
#cv ⇒ Object
readonly
Attribute for field cv.
-
#cy ⇒ Object
readonly
Attribute for field cy.
-
#cz ⇒ Object
readonly
Attribute for field cz.
-
#de ⇒ Object
readonly
Attribute for field de.
-
#dk ⇒ Object
readonly
Attribute for field dk.
-
#ec ⇒ Object
readonly
Attribute for field ec.
-
#ee ⇒ Object
readonly
Attribute for field ee.
-
#eg ⇒ Object
readonly
Attribute for field eg.
-
#es ⇒ Object
readonly
Attribute for field es.
-
#et ⇒ Object
readonly
Attribute for field et.
-
#fi ⇒ Object
readonly
Attribute for field fi.
-
#fr ⇒ Object
readonly
Attribute for field fr.
-
#gb ⇒ Object
readonly
Attribute for field gb.
-
#ge ⇒ Object
readonly
Attribute for field ge.
-
#gn ⇒ Object
readonly
Attribute for field gn.
-
#gr ⇒ Object
readonly
Attribute for field gr.
-
#hr ⇒ Object
readonly
Attribute for field hr.
-
#hu ⇒ Object
readonly
Attribute for field hu.
-
#id ⇒ Object
readonly
Attribute for field id.
-
#ie ⇒ Object
readonly
Attribute for field ie.
-
#in ⇒ Object
readonly
Attribute for field in.
-
#is ⇒ Object
readonly
Attribute for field is.
-
#it ⇒ Object
readonly
Attribute for field it.
-
#jp ⇒ Object
readonly
Attribute for field jp.
-
#ke ⇒ Object
readonly
Attribute for field ke.
-
#kg ⇒ Object
readonly
Attribute for field kg.
-
#kh ⇒ Object
readonly
Attribute for field kh.
-
#kr ⇒ Object
readonly
Attribute for field kr.
-
#kz ⇒ Object
readonly
Attribute for field kz.
-
#la ⇒ Object
readonly
Attribute for field la.
-
#lk ⇒ Object
readonly
Attribute for field lk.
-
#lt ⇒ Object
readonly
Attribute for field lt.
-
#lu ⇒ Object
readonly
Attribute for field lu.
-
#lv ⇒ Object
readonly
Attribute for field lv.
-
#ma ⇒ Object
readonly
Attribute for field ma.
-
#md ⇒ Object
readonly
Attribute for field md.
-
#me ⇒ Object
readonly
Attribute for field me.
-
#mk ⇒ Object
readonly
Attribute for field mk.
-
#mr ⇒ Object
readonly
Attribute for field mr.
-
#mt ⇒ Object
readonly
Attribute for field mt.
-
#mx ⇒ Object
readonly
Attribute for field mx.
-
#my ⇒ Object
readonly
Attribute for field my.
-
#ng ⇒ Object
readonly
Attribute for field ng.
-
#nl ⇒ Object
readonly
Attribute for field nl.
-
#no ⇒ Object
readonly
Attribute for field no.
-
#np ⇒ Object
readonly
Attribute for field np.
-
#nz ⇒ Object
readonly
Attribute for field nz.
-
#om ⇒ Object
readonly
Attribute for field om.
-
#pe ⇒ Object
readonly
Attribute for field pe.
-
#ph ⇒ Object
readonly
Attribute for field ph.
-
#pl ⇒ Object
readonly
Attribute for field pl.
-
#pt ⇒ Object
readonly
Attribute for field pt.
-
#ro ⇒ Object
readonly
Attribute for field ro.
-
#rs ⇒ Object
readonly
Attribute for field rs.
-
#ru ⇒ Object
readonly
Attribute for field ru.
-
#sa ⇒ Object
readonly
Attribute for field sa.
-
#se ⇒ Object
readonly
Attribute for field se.
-
#sg ⇒ Object
readonly
Attribute for field sg.
-
#si ⇒ Object
readonly
Attribute for field si.
-
#sk ⇒ Object
readonly
Attribute for field sk.
-
#sn ⇒ Object
readonly
Attribute for field sn.
-
#sr ⇒ Object
readonly
Attribute for field sr.
-
#th ⇒ Object
readonly
Attribute for field th.
-
#tj ⇒ Object
readonly
Attribute for field tj.
-
#tr ⇒ Object
readonly
Attribute for field tr.
-
#tw ⇒ Object
readonly
Attribute for field tw.
-
#tz ⇒ Object
readonly
Attribute for field tz.
-
#ua ⇒ Object
readonly
Attribute for field ua.
-
#ug ⇒ Object
readonly
Attribute for field ug.
-
#us ⇒ Object
readonly
Attribute for field us.
-
#uy ⇒ Object
readonly
Attribute for field uy.
-
#uz ⇒ Object
readonly
Attribute for field uz.
-
#vn ⇒ Object
readonly
Attribute for field vn.
-
#za ⇒ Object
readonly
Attribute for field za.
-
#zm ⇒ Object
readonly
Attribute for field zm.
-
#zw ⇒ Object
readonly
Attribute for field zw.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Attribute for field ae
2468 2469 2470 |
# File 'lib/stripe/resources/tax/registration.rb', line 2468 def ae @ae end |
#al ⇒ Object (readonly)
Attribute for field al
2470 2471 2472 |
# File 'lib/stripe/resources/tax/registration.rb', line 2470 def al @al end |
#am ⇒ Object (readonly)
Attribute for field am
2472 2473 2474 |
# File 'lib/stripe/resources/tax/registration.rb', line 2472 def am @am end |
#ao ⇒ Object (readonly)
Attribute for field ao
2474 2475 2476 |
# File 'lib/stripe/resources/tax/registration.rb', line 2474 def ao @ao end |
#at ⇒ Object (readonly)
Attribute for field at
2476 2477 2478 |
# File 'lib/stripe/resources/tax/registration.rb', line 2476 def at @at end |
#au ⇒ Object (readonly)
Attribute for field au
2478 2479 2480 |
# File 'lib/stripe/resources/tax/registration.rb', line 2478 def au @au end |
#aw ⇒ Object (readonly)
Attribute for field aw
2480 2481 2482 |
# File 'lib/stripe/resources/tax/registration.rb', line 2480 def aw @aw end |
#az ⇒ Object (readonly)
Attribute for field az
2482 2483 2484 |
# File 'lib/stripe/resources/tax/registration.rb', line 2482 def az @az end |
#ba ⇒ Object (readonly)
Attribute for field ba
2484 2485 2486 |
# File 'lib/stripe/resources/tax/registration.rb', line 2484 def ba @ba end |
#bb ⇒ Object (readonly)
Attribute for field bb
2486 2487 2488 |
# File 'lib/stripe/resources/tax/registration.rb', line 2486 def bb @bb end |
#bd ⇒ Object (readonly)
Attribute for field bd
2488 2489 2490 |
# File 'lib/stripe/resources/tax/registration.rb', line 2488 def bd @bd end |
#be ⇒ Object (readonly)
Attribute for field be
2490 2491 2492 |
# File 'lib/stripe/resources/tax/registration.rb', line 2490 def be @be end |
#bf ⇒ Object (readonly)
Attribute for field bf
2492 2493 2494 |
# File 'lib/stripe/resources/tax/registration.rb', line 2492 def bf @bf end |
#bg ⇒ Object (readonly)
Attribute for field bg
2494 2495 2496 |
# File 'lib/stripe/resources/tax/registration.rb', line 2494 def bg @bg end |
#bh ⇒ Object (readonly)
Attribute for field bh
2496 2497 2498 |
# File 'lib/stripe/resources/tax/registration.rb', line 2496 def bh @bh end |
#bj ⇒ Object (readonly)
Attribute for field bj
2498 2499 2500 |
# File 'lib/stripe/resources/tax/registration.rb', line 2498 def bj @bj end |
#bs ⇒ Object (readonly)
Attribute for field bs
2500 2501 2502 |
# File 'lib/stripe/resources/tax/registration.rb', line 2500 def bs @bs end |
#by ⇒ Object (readonly)
Attribute for field by
2502 2503 2504 |
# File 'lib/stripe/resources/tax/registration.rb', line 2502 def by @by end |
#ca ⇒ Object (readonly)
Attribute for field ca
2504 2505 2506 |
# File 'lib/stripe/resources/tax/registration.rb', line 2504 def ca @ca end |
#cd ⇒ Object (readonly)
Attribute for field cd
2506 2507 2508 |
# File 'lib/stripe/resources/tax/registration.rb', line 2506 def cd @cd end |
#ch ⇒ Object (readonly)
Attribute for field ch
2508 2509 2510 |
# File 'lib/stripe/resources/tax/registration.rb', line 2508 def ch @ch end |
#cl ⇒ Object (readonly)
Attribute for field cl
2510 2511 2512 |
# File 'lib/stripe/resources/tax/registration.rb', line 2510 def cl @cl end |
#cm ⇒ Object (readonly)
Attribute for field cm
2512 2513 2514 |
# File 'lib/stripe/resources/tax/registration.rb', line 2512 def cm @cm end |
#co ⇒ Object (readonly)
Attribute for field co
2514 2515 2516 |
# File 'lib/stripe/resources/tax/registration.rb', line 2514 def co @co end |
#cr ⇒ Object (readonly)
Attribute for field cr
2516 2517 2518 |
# File 'lib/stripe/resources/tax/registration.rb', line 2516 def cr @cr end |
#cv ⇒ Object (readonly)
Attribute for field cv
2518 2519 2520 |
# File 'lib/stripe/resources/tax/registration.rb', line 2518 def cv @cv end |
#cy ⇒ Object (readonly)
Attribute for field cy
2520 2521 2522 |
# File 'lib/stripe/resources/tax/registration.rb', line 2520 def cy @cy end |
#cz ⇒ Object (readonly)
Attribute for field cz
2522 2523 2524 |
# File 'lib/stripe/resources/tax/registration.rb', line 2522 def cz @cz end |
#de ⇒ Object (readonly)
Attribute for field de
2524 2525 2526 |
# File 'lib/stripe/resources/tax/registration.rb', line 2524 def de @de end |
#dk ⇒ Object (readonly)
Attribute for field dk
2526 2527 2528 |
# File 'lib/stripe/resources/tax/registration.rb', line 2526 def dk @dk end |
#ec ⇒ Object (readonly)
Attribute for field ec
2528 2529 2530 |
# File 'lib/stripe/resources/tax/registration.rb', line 2528 def ec @ec end |
#ee ⇒ Object (readonly)
Attribute for field ee
2530 2531 2532 |
# File 'lib/stripe/resources/tax/registration.rb', line 2530 def ee @ee end |
#eg ⇒ Object (readonly)
Attribute for field eg
2532 2533 2534 |
# File 'lib/stripe/resources/tax/registration.rb', line 2532 def eg @eg end |
#es ⇒ Object (readonly)
Attribute for field es
2534 2535 2536 |
# File 'lib/stripe/resources/tax/registration.rb', line 2534 def es @es end |
#et ⇒ Object (readonly)
Attribute for field et
2536 2537 2538 |
# File 'lib/stripe/resources/tax/registration.rb', line 2536 def et @et end |
#fi ⇒ Object (readonly)
Attribute for field fi
2538 2539 2540 |
# File 'lib/stripe/resources/tax/registration.rb', line 2538 def fi @fi end |
#fr ⇒ Object (readonly)
Attribute for field fr
2540 2541 2542 |
# File 'lib/stripe/resources/tax/registration.rb', line 2540 def fr @fr end |
#gb ⇒ Object (readonly)
Attribute for field gb
2542 2543 2544 |
# File 'lib/stripe/resources/tax/registration.rb', line 2542 def gb @gb end |
#ge ⇒ Object (readonly)
Attribute for field ge
2544 2545 2546 |
# File 'lib/stripe/resources/tax/registration.rb', line 2544 def ge @ge end |
#gn ⇒ Object (readonly)
Attribute for field gn
2546 2547 2548 |
# File 'lib/stripe/resources/tax/registration.rb', line 2546 def gn @gn end |
#gr ⇒ Object (readonly)
Attribute for field gr
2548 2549 2550 |
# File 'lib/stripe/resources/tax/registration.rb', line 2548 def gr @gr end |
#hr ⇒ Object (readonly)
Attribute for field hr
2550 2551 2552 |
# File 'lib/stripe/resources/tax/registration.rb', line 2550 def hr @hr end |
#hu ⇒ Object (readonly)
Attribute for field hu
2552 2553 2554 |
# File 'lib/stripe/resources/tax/registration.rb', line 2552 def hu @hu end |
#id ⇒ Object (readonly)
Attribute for field id
2554 2555 2556 |
# File 'lib/stripe/resources/tax/registration.rb', line 2554 def id @id end |
#ie ⇒ Object (readonly)
Attribute for field ie
2556 2557 2558 |
# File 'lib/stripe/resources/tax/registration.rb', line 2556 def ie @ie end |
#in ⇒ Object (readonly)
Attribute for field in
2558 2559 2560 |
# File 'lib/stripe/resources/tax/registration.rb', line 2558 def in @in end |
#is ⇒ Object (readonly)
Attribute for field is
2560 2561 2562 |
# File 'lib/stripe/resources/tax/registration.rb', line 2560 def is @is end |
#it ⇒ Object (readonly)
Attribute for field it
2562 2563 2564 |
# File 'lib/stripe/resources/tax/registration.rb', line 2562 def it @it end |
#jp ⇒ Object (readonly)
Attribute for field jp
2564 2565 2566 |
# File 'lib/stripe/resources/tax/registration.rb', line 2564 def jp @jp end |
#ke ⇒ Object (readonly)
Attribute for field ke
2566 2567 2568 |
# File 'lib/stripe/resources/tax/registration.rb', line 2566 def ke @ke end |
#kg ⇒ Object (readonly)
Attribute for field kg
2568 2569 2570 |
# File 'lib/stripe/resources/tax/registration.rb', line 2568 def kg @kg end |
#kh ⇒ Object (readonly)
Attribute for field kh
2570 2571 2572 |
# File 'lib/stripe/resources/tax/registration.rb', line 2570 def kh @kh end |
#kr ⇒ Object (readonly)
Attribute for field kr
2572 2573 2574 |
# File 'lib/stripe/resources/tax/registration.rb', line 2572 def kr @kr end |
#kz ⇒ Object (readonly)
Attribute for field kz
2574 2575 2576 |
# File 'lib/stripe/resources/tax/registration.rb', line 2574 def kz @kz end |
#la ⇒ Object (readonly)
Attribute for field la
2576 2577 2578 |
# File 'lib/stripe/resources/tax/registration.rb', line 2576 def la @la end |
#lk ⇒ Object (readonly)
Attribute for field lk
2578 2579 2580 |
# File 'lib/stripe/resources/tax/registration.rb', line 2578 def lk @lk end |
#lt ⇒ Object (readonly)
Attribute for field lt
2580 2581 2582 |
# File 'lib/stripe/resources/tax/registration.rb', line 2580 def lt @lt end |
#lu ⇒ Object (readonly)
Attribute for field lu
2582 2583 2584 |
# File 'lib/stripe/resources/tax/registration.rb', line 2582 def lu @lu end |
#lv ⇒ Object (readonly)
Attribute for field lv
2584 2585 2586 |
# File 'lib/stripe/resources/tax/registration.rb', line 2584 def lv @lv end |
#ma ⇒ Object (readonly)
Attribute for field ma
2586 2587 2588 |
# File 'lib/stripe/resources/tax/registration.rb', line 2586 def ma @ma end |
#md ⇒ Object (readonly)
Attribute for field md
2588 2589 2590 |
# File 'lib/stripe/resources/tax/registration.rb', line 2588 def md @md end |
#me ⇒ Object (readonly)
Attribute for field me
2590 2591 2592 |
# File 'lib/stripe/resources/tax/registration.rb', line 2590 def me @me end |
#mk ⇒ Object (readonly)
Attribute for field mk
2592 2593 2594 |
# File 'lib/stripe/resources/tax/registration.rb', line 2592 def mk @mk end |
#mr ⇒ Object (readonly)
Attribute for field mr
2594 2595 2596 |
# File 'lib/stripe/resources/tax/registration.rb', line 2594 def mr @mr end |
#mt ⇒ Object (readonly)
Attribute for field mt
2596 2597 2598 |
# File 'lib/stripe/resources/tax/registration.rb', line 2596 def mt @mt end |
#mx ⇒ Object (readonly)
Attribute for field mx
2598 2599 2600 |
# File 'lib/stripe/resources/tax/registration.rb', line 2598 def mx @mx end |
#my ⇒ Object (readonly)
Attribute for field my
2600 2601 2602 |
# File 'lib/stripe/resources/tax/registration.rb', line 2600 def my @my end |
#ng ⇒ Object (readonly)
Attribute for field ng
2602 2603 2604 |
# File 'lib/stripe/resources/tax/registration.rb', line 2602 def ng @ng end |
#nl ⇒ Object (readonly)
Attribute for field nl
2604 2605 2606 |
# File 'lib/stripe/resources/tax/registration.rb', line 2604 def nl @nl end |
#no ⇒ Object (readonly)
Attribute for field no
2606 2607 2608 |
# File 'lib/stripe/resources/tax/registration.rb', line 2606 def no @no end |
#np ⇒ Object (readonly)
Attribute for field np
2608 2609 2610 |
# File 'lib/stripe/resources/tax/registration.rb', line 2608 def np @np end |
#nz ⇒ Object (readonly)
Attribute for field nz
2610 2611 2612 |
# File 'lib/stripe/resources/tax/registration.rb', line 2610 def nz @nz end |
#om ⇒ Object (readonly)
Attribute for field om
2612 2613 2614 |
# File 'lib/stripe/resources/tax/registration.rb', line 2612 def om @om end |
#pe ⇒ Object (readonly)
Attribute for field pe
2614 2615 2616 |
# File 'lib/stripe/resources/tax/registration.rb', line 2614 def pe @pe end |
#ph ⇒ Object (readonly)
Attribute for field ph
2616 2617 2618 |
# File 'lib/stripe/resources/tax/registration.rb', line 2616 def ph @ph end |
#pl ⇒ Object (readonly)
Attribute for field pl
2618 2619 2620 |
# File 'lib/stripe/resources/tax/registration.rb', line 2618 def pl @pl end |
#pt ⇒ Object (readonly)
Attribute for field pt
2620 2621 2622 |
# File 'lib/stripe/resources/tax/registration.rb', line 2620 def pt @pt end |
#ro ⇒ Object (readonly)
Attribute for field ro
2622 2623 2624 |
# File 'lib/stripe/resources/tax/registration.rb', line 2622 def ro @ro end |
#rs ⇒ Object (readonly)
Attribute for field rs
2624 2625 2626 |
# File 'lib/stripe/resources/tax/registration.rb', line 2624 def rs @rs end |
#ru ⇒ Object (readonly)
Attribute for field ru
2626 2627 2628 |
# File 'lib/stripe/resources/tax/registration.rb', line 2626 def ru @ru end |
#sa ⇒ Object (readonly)
Attribute for field sa
2628 2629 2630 |
# File 'lib/stripe/resources/tax/registration.rb', line 2628 def sa @sa end |
#se ⇒ Object (readonly)
Attribute for field se
2630 2631 2632 |
# File 'lib/stripe/resources/tax/registration.rb', line 2630 def se @se end |
#sg ⇒ Object (readonly)
Attribute for field sg
2632 2633 2634 |
# File 'lib/stripe/resources/tax/registration.rb', line 2632 def sg @sg end |
#si ⇒ Object (readonly)
Attribute for field si
2634 2635 2636 |
# File 'lib/stripe/resources/tax/registration.rb', line 2634 def si @si end |
#sk ⇒ Object (readonly)
Attribute for field sk
2636 2637 2638 |
# File 'lib/stripe/resources/tax/registration.rb', line 2636 def sk @sk end |
#sn ⇒ Object (readonly)
Attribute for field sn
2638 2639 2640 |
# File 'lib/stripe/resources/tax/registration.rb', line 2638 def sn @sn end |
#sr ⇒ Object (readonly)
Attribute for field sr
2640 2641 2642 |
# File 'lib/stripe/resources/tax/registration.rb', line 2640 def sr @sr end |
#th ⇒ Object (readonly)
Attribute for field th
2642 2643 2644 |
# File 'lib/stripe/resources/tax/registration.rb', line 2642 def th @th end |
#tj ⇒ Object (readonly)
Attribute for field tj
2644 2645 2646 |
# File 'lib/stripe/resources/tax/registration.rb', line 2644 def tj @tj end |
#tr ⇒ Object (readonly)
Attribute for field tr
2646 2647 2648 |
# File 'lib/stripe/resources/tax/registration.rb', line 2646 def tr @tr end |
#tw ⇒ Object (readonly)
Attribute for field tw
2648 2649 2650 |
# File 'lib/stripe/resources/tax/registration.rb', line 2648 def tw @tw end |
#tz ⇒ Object (readonly)
Attribute for field tz
2650 2651 2652 |
# File 'lib/stripe/resources/tax/registration.rb', line 2650 def tz @tz end |
#ua ⇒ Object (readonly)
Attribute for field ua
2652 2653 2654 |
# File 'lib/stripe/resources/tax/registration.rb', line 2652 def ua @ua end |
#ug ⇒ Object (readonly)
Attribute for field ug
2654 2655 2656 |
# File 'lib/stripe/resources/tax/registration.rb', line 2654 def ug @ug end |
#us ⇒ Object (readonly)
Attribute for field us
2656 2657 2658 |
# File 'lib/stripe/resources/tax/registration.rb', line 2656 def us @us end |
#uy ⇒ Object (readonly)
Attribute for field uy
2658 2659 2660 |
# File 'lib/stripe/resources/tax/registration.rb', line 2658 def uy @uy end |
#uz ⇒ Object (readonly)
Attribute for field uz
2660 2661 2662 |
# File 'lib/stripe/resources/tax/registration.rb', line 2660 def uz @uz end |
#vn ⇒ Object (readonly)
Attribute for field vn
2662 2663 2664 |
# File 'lib/stripe/resources/tax/registration.rb', line 2662 def vn @vn end |
#za ⇒ Object (readonly)
Attribute for field za
2664 2665 2666 |
# File 'lib/stripe/resources/tax/registration.rb', line 2664 def za @za end |
#zm ⇒ Object (readonly)
Attribute for field zm
2666 2667 2668 |
# File 'lib/stripe/resources/tax/registration.rb', line 2666 def zm @zm end |
#zw ⇒ Object (readonly)
Attribute for field zw
2668 2669 2670 |
# File 'lib/stripe/resources/tax/registration.rb', line 2668 def zw @zw end |
Class Method Details
.field_remappings ⇒ Object
2776 2777 2778 |
# File 'lib/stripe/resources/tax/registration.rb', line 2776 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 |
# File 'lib/stripe/resources/tax/registration.rb', line 2670 def self.inner_class_types @inner_class_types = { ae: Ae, al: Al, am: Am, ao: Ao, at: At, au: Au, aw: Aw, az: Az, ba: Ba, bb: Bb, bd: Bd, be: Be, bf: Bf, bg: Bg, bh: Bh, bj: Bj, bs: Bs, by: By, ca: Ca, cd: Cd, ch: Ch, cl: Cl, cm: Cm, co: Co, cr: Cr, cv: Cv, cy: Cy, cz: Cz, de: De, dk: Dk, ec: Ec, ee: Ee, eg: Eg, es: Es, et: Et, fi: Fi, fr: Fr, gb: Gb, ge: Ge, gn: Gn, gr: Gr, hr: Hr, hu: Hu, id: Id, ie: Ie, in: In, is: Is, it: It, jp: Jp, ke: Ke, kg: Kg, kh: Kh, kr: Kr, kz: Kz, la: La, lk: Lk, lt: Lt, lu: Lu, lv: Lv, ma: Ma, md: Md, me: Me, mk: Mk, mr: Mr, mt: Mt, mx: Mx, my: My, ng: Ng, nl: Nl, no: No, np: Np, nz: Nz, om: Om, pe: Pe, ph: Ph, pl: Pl, pt: Pt, ro: Ro, rs: Rs, ru: Ru, sa: Sa, se: Se, sg: Sg, si: Si, sk: Sk, sn: Sn, sr: Sr, th: Th, tj: Tj, tr: Tr, tw: Tw, tz: Tz, ua: Ua, ug: Ug, us: Us, uy: Uy, uz: Uz, vn: Vn, za: Za, zm: Zm, zw: Zw, } end |