Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



2484
2485
2486
# File 'lib/stripe/resources/tax/registration.rb', line 2484

def ae
  @ae
end

#alObject (readonly)

Attribute for field al



2486
2487
2488
# File 'lib/stripe/resources/tax/registration.rb', line 2486

def al
  @al
end

#amObject (readonly)

Attribute for field am



2488
2489
2490
# File 'lib/stripe/resources/tax/registration.rb', line 2488

def am
  @am
end

#aoObject (readonly)

Attribute for field ao



2490
2491
2492
# File 'lib/stripe/resources/tax/registration.rb', line 2490

def ao
  @ao
end

#atObject (readonly)

Attribute for field at



2492
2493
2494
# File 'lib/stripe/resources/tax/registration.rb', line 2492

def at
  @at
end

#auObject (readonly)

Attribute for field au



2494
2495
2496
# File 'lib/stripe/resources/tax/registration.rb', line 2494

def au
  @au
end

#awObject (readonly)

Attribute for field aw



2496
2497
2498
# File 'lib/stripe/resources/tax/registration.rb', line 2496

def aw
  @aw
end

#azObject (readonly)

Attribute for field az



2498
2499
2500
# File 'lib/stripe/resources/tax/registration.rb', line 2498

def az
  @az
end

#baObject (readonly)

Attribute for field ba



2500
2501
2502
# File 'lib/stripe/resources/tax/registration.rb', line 2500

def ba
  @ba
end

#bbObject (readonly)

Attribute for field bb



2502
2503
2504
# File 'lib/stripe/resources/tax/registration.rb', line 2502

def bb
  @bb
end

#bdObject (readonly)

Attribute for field bd



2504
2505
2506
# File 'lib/stripe/resources/tax/registration.rb', line 2504

def bd
  @bd
end

#beObject (readonly)

Attribute for field be



2506
2507
2508
# File 'lib/stripe/resources/tax/registration.rb', line 2506

def be
  @be
end

#bfObject (readonly)

Attribute for field bf



2508
2509
2510
# File 'lib/stripe/resources/tax/registration.rb', line 2508

def bf
  @bf
end

#bgObject (readonly)

Attribute for field bg



2510
2511
2512
# File 'lib/stripe/resources/tax/registration.rb', line 2510

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



2512
2513
2514
# File 'lib/stripe/resources/tax/registration.rb', line 2512

def bh
  @bh
end

#bjObject (readonly)

Attribute for field bj



2514
2515
2516
# File 'lib/stripe/resources/tax/registration.rb', line 2514

def bj
  @bj
end

#bsObject (readonly)

Attribute for field bs



2516
2517
2518
# File 'lib/stripe/resources/tax/registration.rb', line 2516

def bs
  @bs
end

#byObject (readonly)

Attribute for field by



2518
2519
2520
# File 'lib/stripe/resources/tax/registration.rb', line 2518

def by
  @by
end

#caObject (readonly)

Attribute for field ca



2520
2521
2522
# File 'lib/stripe/resources/tax/registration.rb', line 2520

def ca
  @ca
end

#cdObject (readonly)

Attribute for field cd



2522
2523
2524
# File 'lib/stripe/resources/tax/registration.rb', line 2522

def cd
  @cd
end

#chObject (readonly)

Attribute for field ch



2524
2525
2526
# File 'lib/stripe/resources/tax/registration.rb', line 2524

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



2526
2527
2528
# File 'lib/stripe/resources/tax/registration.rb', line 2526

def cl
  @cl
end

#cmObject (readonly)

Attribute for field cm



2528
2529
2530
# File 'lib/stripe/resources/tax/registration.rb', line 2528

def cm
  @cm
end

#coObject (readonly)

Attribute for field co



2530
2531
2532
# File 'lib/stripe/resources/tax/registration.rb', line 2530

def co
  @co
end

#crObject (readonly)

Attribute for field cr



2532
2533
2534
# File 'lib/stripe/resources/tax/registration.rb', line 2532

def cr
  @cr
end

#cvObject (readonly)

Attribute for field cv



2534
2535
2536
# File 'lib/stripe/resources/tax/registration.rb', line 2534

def cv
  @cv
end

#cyObject (readonly)

Attribute for field cy



2536
2537
2538
# File 'lib/stripe/resources/tax/registration.rb', line 2536

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



2538
2539
2540
# File 'lib/stripe/resources/tax/registration.rb', line 2538

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



2540
2541
2542
# File 'lib/stripe/resources/tax/registration.rb', line 2540

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



2542
2543
2544
# File 'lib/stripe/resources/tax/registration.rb', line 2542

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



2544
2545
2546
# File 'lib/stripe/resources/tax/registration.rb', line 2544

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



2546
2547
2548
# File 'lib/stripe/resources/tax/registration.rb', line 2546

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



2548
2549
2550
# File 'lib/stripe/resources/tax/registration.rb', line 2548

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



2550
2551
2552
# File 'lib/stripe/resources/tax/registration.rb', line 2550

def es
  @es
end

#etObject (readonly)

Attribute for field et



2552
2553
2554
# File 'lib/stripe/resources/tax/registration.rb', line 2552

def et
  @et
end

#fiObject (readonly)

Attribute for field fi



2554
2555
2556
# File 'lib/stripe/resources/tax/registration.rb', line 2554

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



2556
2557
2558
# File 'lib/stripe/resources/tax/registration.rb', line 2556

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



2558
2559
2560
# File 'lib/stripe/resources/tax/registration.rb', line 2558

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



2560
2561
2562
# File 'lib/stripe/resources/tax/registration.rb', line 2560

def ge
  @ge
end

#gnObject (readonly)

Attribute for field gn



2562
2563
2564
# File 'lib/stripe/resources/tax/registration.rb', line 2562

def gn
  @gn
end

#grObject (readonly)

Attribute for field gr



2564
2565
2566
# File 'lib/stripe/resources/tax/registration.rb', line 2564

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



2566
2567
2568
# File 'lib/stripe/resources/tax/registration.rb', line 2566

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



2568
2569
2570
# File 'lib/stripe/resources/tax/registration.rb', line 2568

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



2570
2571
2572
# File 'lib/stripe/resources/tax/registration.rb', line 2570

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



2572
2573
2574
# File 'lib/stripe/resources/tax/registration.rb', line 2572

def ie
  @ie
end

#inObject (readonly)

Attribute for field in



2574
2575
2576
# File 'lib/stripe/resources/tax/registration.rb', line 2574

def in
  @in
end

#isObject (readonly)

Attribute for field is



2576
2577
2578
# File 'lib/stripe/resources/tax/registration.rb', line 2576

def is
  @is
end

#itObject (readonly)

Attribute for field it



2578
2579
2580
# File 'lib/stripe/resources/tax/registration.rb', line 2578

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



2580
2581
2582
# File 'lib/stripe/resources/tax/registration.rb', line 2580

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



2582
2583
2584
# File 'lib/stripe/resources/tax/registration.rb', line 2582

def ke
  @ke
end

#kgObject (readonly)

Attribute for field kg



2584
2585
2586
# File 'lib/stripe/resources/tax/registration.rb', line 2584

def kg
  @kg
end

#khObject (readonly)

Attribute for field kh



2586
2587
2588
# File 'lib/stripe/resources/tax/registration.rb', line 2586

def kh
  @kh
end

#krObject (readonly)

Attribute for field kr



2588
2589
2590
# File 'lib/stripe/resources/tax/registration.rb', line 2588

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



2590
2591
2592
# File 'lib/stripe/resources/tax/registration.rb', line 2590

def kz
  @kz
end

#laObject (readonly)

Attribute for field la



2592
2593
2594
# File 'lib/stripe/resources/tax/registration.rb', line 2592

def la
  @la
end

#lkObject (readonly)

Attribute for field lk



2594
2595
2596
# File 'lib/stripe/resources/tax/registration.rb', line 2594

def lk
  @lk
end

#ltObject (readonly)

Attribute for field lt



2596
2597
2598
# File 'lib/stripe/resources/tax/registration.rb', line 2596

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



2598
2599
2600
# File 'lib/stripe/resources/tax/registration.rb', line 2598

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



2600
2601
2602
# File 'lib/stripe/resources/tax/registration.rb', line 2600

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



2602
2603
2604
# File 'lib/stripe/resources/tax/registration.rb', line 2602

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



2604
2605
2606
# File 'lib/stripe/resources/tax/registration.rb', line 2604

def md
  @md
end

#meObject (readonly)

Attribute for field me



2606
2607
2608
# File 'lib/stripe/resources/tax/registration.rb', line 2606

def me
  @me
end

#mkObject (readonly)

Attribute for field mk



2608
2609
2610
# File 'lib/stripe/resources/tax/registration.rb', line 2608

def mk
  @mk
end

#mrObject (readonly)

Attribute for field mr



2610
2611
2612
# File 'lib/stripe/resources/tax/registration.rb', line 2610

def mr
  @mr
end

#mtObject (readonly)

Attribute for field mt



2612
2613
2614
# File 'lib/stripe/resources/tax/registration.rb', line 2612

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



2614
2615
2616
# File 'lib/stripe/resources/tax/registration.rb', line 2614

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



2616
2617
2618
# File 'lib/stripe/resources/tax/registration.rb', line 2616

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



2618
2619
2620
# File 'lib/stripe/resources/tax/registration.rb', line 2618

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



2620
2621
2622
# File 'lib/stripe/resources/tax/registration.rb', line 2620

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



2622
2623
2624
# File 'lib/stripe/resources/tax/registration.rb', line 2622

def no
  @no
end

#npObject (readonly)

Attribute for field np



2624
2625
2626
# File 'lib/stripe/resources/tax/registration.rb', line 2624

def np
  @np
end

#nzObject (readonly)

Attribute for field nz



2626
2627
2628
# File 'lib/stripe/resources/tax/registration.rb', line 2626

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



2628
2629
2630
# File 'lib/stripe/resources/tax/registration.rb', line 2628

def om
  @om
end

#peObject (readonly)

Attribute for field pe



2630
2631
2632
# File 'lib/stripe/resources/tax/registration.rb', line 2630

def pe
  @pe
end

#phObject (readonly)

Attribute for field ph



2632
2633
2634
# File 'lib/stripe/resources/tax/registration.rb', line 2632

def ph
  @ph
end

#plObject (readonly)

Attribute for field pl



2634
2635
2636
# File 'lib/stripe/resources/tax/registration.rb', line 2634

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



2636
2637
2638
# File 'lib/stripe/resources/tax/registration.rb', line 2636

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



2638
2639
2640
# File 'lib/stripe/resources/tax/registration.rb', line 2638

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



2640
2641
2642
# File 'lib/stripe/resources/tax/registration.rb', line 2640

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



2642
2643
2644
# File 'lib/stripe/resources/tax/registration.rb', line 2642

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



2644
2645
2646
# File 'lib/stripe/resources/tax/registration.rb', line 2644

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



2646
2647
2648
# File 'lib/stripe/resources/tax/registration.rb', line 2646

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



2648
2649
2650
# File 'lib/stripe/resources/tax/registration.rb', line 2648

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



2650
2651
2652
# File 'lib/stripe/resources/tax/registration.rb', line 2650

def si
  @si
end

#skObject (readonly)

Attribute for field sk



2652
2653
2654
# File 'lib/stripe/resources/tax/registration.rb', line 2652

def sk
  @sk
end

#snObject (readonly)

Attribute for field sn



2654
2655
2656
# File 'lib/stripe/resources/tax/registration.rb', line 2654

def sn
  @sn
end

#srObject (readonly)

Attribute for field sr



2656
2657
2658
# File 'lib/stripe/resources/tax/registration.rb', line 2656

def sr
  @sr
end

#thObject (readonly)

Attribute for field th



2658
2659
2660
# File 'lib/stripe/resources/tax/registration.rb', line 2658

def th
  @th
end

#tjObject (readonly)

Attribute for field tj



2660
2661
2662
# File 'lib/stripe/resources/tax/registration.rb', line 2660

def tj
  @tj
end

#trObject (readonly)

Attribute for field tr



2662
2663
2664
# File 'lib/stripe/resources/tax/registration.rb', line 2662

def tr
  @tr
end

#twObject (readonly)

Attribute for field tw



2664
2665
2666
# File 'lib/stripe/resources/tax/registration.rb', line 2664

def tw
  @tw
end

#tzObject (readonly)

Attribute for field tz



2666
2667
2668
# File 'lib/stripe/resources/tax/registration.rb', line 2666

def tz
  @tz
end

#uaObject (readonly)

Attribute for field ua



2668
2669
2670
# File 'lib/stripe/resources/tax/registration.rb', line 2668

def ua
  @ua
end

#ugObject (readonly)

Attribute for field ug



2670
2671
2672
# File 'lib/stripe/resources/tax/registration.rb', line 2670

def ug
  @ug
end

#usObject (readonly)

Attribute for field us



2672
2673
2674
# File 'lib/stripe/resources/tax/registration.rb', line 2672

def us
  @us
end

#uyObject (readonly)

Attribute for field uy



2674
2675
2676
# File 'lib/stripe/resources/tax/registration.rb', line 2674

def uy
  @uy
end

#uzObject (readonly)

Attribute for field uz



2676
2677
2678
# File 'lib/stripe/resources/tax/registration.rb', line 2676

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



2678
2679
2680
# File 'lib/stripe/resources/tax/registration.rb', line 2678

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



2680
2681
2682
# File 'lib/stripe/resources/tax/registration.rb', line 2680

def za
  @za
end

#zmObject (readonly)

Attribute for field zm



2682
2683
2684
# File 'lib/stripe/resources/tax/registration.rb', line 2682

def zm
  @zm
end

#zwObject (readonly)

Attribute for field zw



2684
2685
2686
# File 'lib/stripe/resources/tax/registration.rb', line 2684

def zw
  @zw
end

Class Method Details

.field_remappingsObject



2792
2793
2794
# File 'lib/stripe/resources/tax/registration.rb', line 2792

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
# File 'lib/stripe/resources/tax/registration.rb', line 2686

def self.inner_class_types
  @inner_class_types = {
    ae: Ae,
    al: Al,
    am: Am,
    ao: Ao,
    at: At,
    au: Au,
    aw: Aw,
    az: Az,
    ba: Ba,
    bb: Bb,
    bd: Bd,
    be: Be,
    bf: Bf,
    bg: Bg,
    bh: Bh,
    bj: Bj,
    bs: Bs,
    by: By,
    ca: Ca,
    cd: Cd,
    ch: Ch,
    cl: Cl,
    cm: Cm,
    co: Co,
    cr: Cr,
    cv: Cv,
    cy: Cy,
    cz: Cz,
    de: De,
    dk: Dk,
    ec: Ec,
    ee: Ee,
    eg: Eg,
    es: Es,
    et: Et,
    fi: Fi,
    fr: Fr,
    gb: Gb,
    ge: Ge,
    gn: Gn,
    gr: Gr,
    hr: Hr,
    hu: Hu,
    id: Id,
    ie: Ie,
    in: In,
    is: Is,
    it: It,
    jp: Jp,
    ke: Ke,
    kg: Kg,
    kh: Kh,
    kr: Kr,
    kz: Kz,
    la: La,
    lk: Lk,
    lt: Lt,
    lu: Lu,
    lv: Lv,
    ma: Ma,
    md: Md,
    me: Me,
    mk: Mk,
    mr: Mr,
    mt: Mt,
    mx: Mx,
    my: My,
    ng: Ng,
    nl: Nl,
    no: No,
    np: Np,
    nz: Nz,
    om: Om,
    pe: Pe,
    ph: Ph,
    pl: Pl,
    pt: Pt,
    ro: Ro,
    rs: Rs,
    ru: Ru,
    sa: Sa,
    se: Se,
    sg: Sg,
    si: Si,
    sk: Sk,
    sn: Sn,
    sr: Sr,
    th: Th,
    tj: Tj,
    tr: Tr,
    tw: Tw,
    tz: Tz,
    ua: Ua,
    ug: Ug,
    us: Us,
    uy: Uy,
    uz: Uz,
    vn: Vn,
    za: Za,
    zm: Zm,
    zw: Zw,
  }
end