Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



2079
2080
2081
# File 'lib/stripe/resources/tax/registration.rb', line 2079

def ae
  @ae
end

#alObject (readonly)

Attribute for field al



2081
2082
2083
# File 'lib/stripe/resources/tax/registration.rb', line 2081

def al
  @al
end

#amObject (readonly)

Attribute for field am



2083
2084
2085
# File 'lib/stripe/resources/tax/registration.rb', line 2083

def am
  @am
end

#aoObject (readonly)

Attribute for field ao



2085
2086
2087
# File 'lib/stripe/resources/tax/registration.rb', line 2085

def ao
  @ao
end

#atObject (readonly)

Attribute for field at



2087
2088
2089
# File 'lib/stripe/resources/tax/registration.rb', line 2087

def at
  @at
end

#auObject (readonly)

Attribute for field au



2089
2090
2091
# File 'lib/stripe/resources/tax/registration.rb', line 2089

def au
  @au
end

#awObject (readonly)

Attribute for field aw



2091
2092
2093
# File 'lib/stripe/resources/tax/registration.rb', line 2091

def aw
  @aw
end

#azObject (readonly)

Attribute for field az



2093
2094
2095
# File 'lib/stripe/resources/tax/registration.rb', line 2093

def az
  @az
end

#baObject (readonly)

Attribute for field ba



2095
2096
2097
# File 'lib/stripe/resources/tax/registration.rb', line 2095

def ba
  @ba
end

#bbObject (readonly)

Attribute for field bb



2097
2098
2099
# File 'lib/stripe/resources/tax/registration.rb', line 2097

def bb
  @bb
end

#bdObject (readonly)

Attribute for field bd



2099
2100
2101
# File 'lib/stripe/resources/tax/registration.rb', line 2099

def bd
  @bd
end

#beObject (readonly)

Attribute for field be



2101
2102
2103
# File 'lib/stripe/resources/tax/registration.rb', line 2101

def be
  @be
end

#bfObject (readonly)

Attribute for field bf



2103
2104
2105
# File 'lib/stripe/resources/tax/registration.rb', line 2103

def bf
  @bf
end

#bgObject (readonly)

Attribute for field bg



2105
2106
2107
# File 'lib/stripe/resources/tax/registration.rb', line 2105

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



2107
2108
2109
# File 'lib/stripe/resources/tax/registration.rb', line 2107

def bh
  @bh
end

#bjObject (readonly)

Attribute for field bj



2109
2110
2111
# File 'lib/stripe/resources/tax/registration.rb', line 2109

def bj
  @bj
end

#bsObject (readonly)

Attribute for field bs



2111
2112
2113
# File 'lib/stripe/resources/tax/registration.rb', line 2111

def bs
  @bs
end

#byObject (readonly)

Attribute for field by



2113
2114
2115
# File 'lib/stripe/resources/tax/registration.rb', line 2113

def by
  @by
end

#caObject (readonly)

Attribute for field ca



2115
2116
2117
# File 'lib/stripe/resources/tax/registration.rb', line 2115

def ca
  @ca
end

#cdObject (readonly)

Attribute for field cd



2117
2118
2119
# File 'lib/stripe/resources/tax/registration.rb', line 2117

def cd
  @cd
end

#chObject (readonly)

Attribute for field ch



2119
2120
2121
# File 'lib/stripe/resources/tax/registration.rb', line 2119

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



2121
2122
2123
# File 'lib/stripe/resources/tax/registration.rb', line 2121

def cl
  @cl
end

#cmObject (readonly)

Attribute for field cm



2123
2124
2125
# File 'lib/stripe/resources/tax/registration.rb', line 2123

def cm
  @cm
end

#coObject (readonly)

Attribute for field co



2125
2126
2127
# File 'lib/stripe/resources/tax/registration.rb', line 2125

def co
  @co
end

#crObject (readonly)

Attribute for field cr



2127
2128
2129
# File 'lib/stripe/resources/tax/registration.rb', line 2127

def cr
  @cr
end

#cvObject (readonly)

Attribute for field cv



2129
2130
2131
# File 'lib/stripe/resources/tax/registration.rb', line 2129

def cv
  @cv
end

#cyObject (readonly)

Attribute for field cy



2131
2132
2133
# File 'lib/stripe/resources/tax/registration.rb', line 2131

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



2133
2134
2135
# File 'lib/stripe/resources/tax/registration.rb', line 2133

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



2135
2136
2137
# File 'lib/stripe/resources/tax/registration.rb', line 2135

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



2137
2138
2139
# File 'lib/stripe/resources/tax/registration.rb', line 2137

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



2139
2140
2141
# File 'lib/stripe/resources/tax/registration.rb', line 2139

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



2141
2142
2143
# File 'lib/stripe/resources/tax/registration.rb', line 2141

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



2143
2144
2145
# File 'lib/stripe/resources/tax/registration.rb', line 2143

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



2145
2146
2147
# File 'lib/stripe/resources/tax/registration.rb', line 2145

def es
  @es
end

#etObject (readonly)

Attribute for field et



2147
2148
2149
# File 'lib/stripe/resources/tax/registration.rb', line 2147

def et
  @et
end

#fiObject (readonly)

Attribute for field fi



2149
2150
2151
# File 'lib/stripe/resources/tax/registration.rb', line 2149

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



2151
2152
2153
# File 'lib/stripe/resources/tax/registration.rb', line 2151

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



2153
2154
2155
# File 'lib/stripe/resources/tax/registration.rb', line 2153

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



2155
2156
2157
# File 'lib/stripe/resources/tax/registration.rb', line 2155

def ge
  @ge
end

#gnObject (readonly)

Attribute for field gn



2157
2158
2159
# File 'lib/stripe/resources/tax/registration.rb', line 2157

def gn
  @gn
end

#grObject (readonly)

Attribute for field gr



2159
2160
2161
# File 'lib/stripe/resources/tax/registration.rb', line 2159

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



2161
2162
2163
# File 'lib/stripe/resources/tax/registration.rb', line 2161

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



2163
2164
2165
# File 'lib/stripe/resources/tax/registration.rb', line 2163

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



2165
2166
2167
# File 'lib/stripe/resources/tax/registration.rb', line 2165

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



2167
2168
2169
# File 'lib/stripe/resources/tax/registration.rb', line 2167

def ie
  @ie
end

#inObject (readonly)

Attribute for field in



2169
2170
2171
# File 'lib/stripe/resources/tax/registration.rb', line 2169

def in
  @in
end

#isObject (readonly)

Attribute for field is



2171
2172
2173
# File 'lib/stripe/resources/tax/registration.rb', line 2171

def is
  @is
end

#itObject (readonly)

Attribute for field it



2173
2174
2175
# File 'lib/stripe/resources/tax/registration.rb', line 2173

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



2175
2176
2177
# File 'lib/stripe/resources/tax/registration.rb', line 2175

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



2177
2178
2179
# File 'lib/stripe/resources/tax/registration.rb', line 2177

def ke
  @ke
end

#kgObject (readonly)

Attribute for field kg



2179
2180
2181
# File 'lib/stripe/resources/tax/registration.rb', line 2179

def kg
  @kg
end

#khObject (readonly)

Attribute for field kh



2181
2182
2183
# File 'lib/stripe/resources/tax/registration.rb', line 2181

def kh
  @kh
end

#krObject (readonly)

Attribute for field kr



2183
2184
2185
# File 'lib/stripe/resources/tax/registration.rb', line 2183

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



2185
2186
2187
# File 'lib/stripe/resources/tax/registration.rb', line 2185

def kz
  @kz
end

#laObject (readonly)

Attribute for field la



2187
2188
2189
# File 'lib/stripe/resources/tax/registration.rb', line 2187

def la
  @la
end

#lkObject (readonly)

Attribute for field lk



2189
2190
2191
# File 'lib/stripe/resources/tax/registration.rb', line 2189

def lk
  @lk
end

#ltObject (readonly)

Attribute for field lt



2191
2192
2193
# File 'lib/stripe/resources/tax/registration.rb', line 2191

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



2193
2194
2195
# File 'lib/stripe/resources/tax/registration.rb', line 2193

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



2195
2196
2197
# File 'lib/stripe/resources/tax/registration.rb', line 2195

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



2197
2198
2199
# File 'lib/stripe/resources/tax/registration.rb', line 2197

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



2199
2200
2201
# File 'lib/stripe/resources/tax/registration.rb', line 2199

def md
  @md
end

#meObject (readonly)

Attribute for field me



2201
2202
2203
# File 'lib/stripe/resources/tax/registration.rb', line 2201

def me
  @me
end

#mkObject (readonly)

Attribute for field mk



2203
2204
2205
# File 'lib/stripe/resources/tax/registration.rb', line 2203

def mk
  @mk
end

#mrObject (readonly)

Attribute for field mr



2205
2206
2207
# File 'lib/stripe/resources/tax/registration.rb', line 2205

def mr
  @mr
end

#mtObject (readonly)

Attribute for field mt



2207
2208
2209
# File 'lib/stripe/resources/tax/registration.rb', line 2207

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



2209
2210
2211
# File 'lib/stripe/resources/tax/registration.rb', line 2209

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



2211
2212
2213
# File 'lib/stripe/resources/tax/registration.rb', line 2211

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



2213
2214
2215
# File 'lib/stripe/resources/tax/registration.rb', line 2213

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



2215
2216
2217
# File 'lib/stripe/resources/tax/registration.rb', line 2215

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



2217
2218
2219
# File 'lib/stripe/resources/tax/registration.rb', line 2217

def no
  @no
end

#npObject (readonly)

Attribute for field np



2219
2220
2221
# File 'lib/stripe/resources/tax/registration.rb', line 2219

def np
  @np
end

#nzObject (readonly)

Attribute for field nz



2221
2222
2223
# File 'lib/stripe/resources/tax/registration.rb', line 2221

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



2223
2224
2225
# File 'lib/stripe/resources/tax/registration.rb', line 2223

def om
  @om
end

#peObject (readonly)

Attribute for field pe



2225
2226
2227
# File 'lib/stripe/resources/tax/registration.rb', line 2225

def pe
  @pe
end

#phObject (readonly)

Attribute for field ph



2227
2228
2229
# File 'lib/stripe/resources/tax/registration.rb', line 2227

def ph
  @ph
end

#plObject (readonly)

Attribute for field pl



2229
2230
2231
# File 'lib/stripe/resources/tax/registration.rb', line 2229

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



2231
2232
2233
# File 'lib/stripe/resources/tax/registration.rb', line 2231

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



2233
2234
2235
# File 'lib/stripe/resources/tax/registration.rb', line 2233

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



2235
2236
2237
# File 'lib/stripe/resources/tax/registration.rb', line 2235

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



2237
2238
2239
# File 'lib/stripe/resources/tax/registration.rb', line 2237

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



2239
2240
2241
# File 'lib/stripe/resources/tax/registration.rb', line 2239

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



2241
2242
2243
# File 'lib/stripe/resources/tax/registration.rb', line 2241

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



2243
2244
2245
# File 'lib/stripe/resources/tax/registration.rb', line 2243

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



2245
2246
2247
# File 'lib/stripe/resources/tax/registration.rb', line 2245

def si
  @si
end

#skObject (readonly)

Attribute for field sk



2247
2248
2249
# File 'lib/stripe/resources/tax/registration.rb', line 2247

def sk
  @sk
end

#snObject (readonly)

Attribute for field sn



2249
2250
2251
# File 'lib/stripe/resources/tax/registration.rb', line 2249

def sn
  @sn
end

#srObject (readonly)

Attribute for field sr



2251
2252
2253
# File 'lib/stripe/resources/tax/registration.rb', line 2251

def sr
  @sr
end

#thObject (readonly)

Attribute for field th



2253
2254
2255
# File 'lib/stripe/resources/tax/registration.rb', line 2253

def th
  @th
end

#tjObject (readonly)

Attribute for field tj



2255
2256
2257
# File 'lib/stripe/resources/tax/registration.rb', line 2255

def tj
  @tj
end

#trObject (readonly)

Attribute for field tr



2257
2258
2259
# File 'lib/stripe/resources/tax/registration.rb', line 2257

def tr
  @tr
end

#twObject (readonly)

Attribute for field tw



2259
2260
2261
# File 'lib/stripe/resources/tax/registration.rb', line 2259

def tw
  @tw
end

#tzObject (readonly)

Attribute for field tz



2261
2262
2263
# File 'lib/stripe/resources/tax/registration.rb', line 2261

def tz
  @tz
end

#uaObject (readonly)

Attribute for field ua



2263
2264
2265
# File 'lib/stripe/resources/tax/registration.rb', line 2263

def ua
  @ua
end

#ugObject (readonly)

Attribute for field ug



2265
2266
2267
# File 'lib/stripe/resources/tax/registration.rb', line 2265

def ug
  @ug
end

#usObject (readonly)

Attribute for field us



2267
2268
2269
# File 'lib/stripe/resources/tax/registration.rb', line 2267

def us
  @us
end

#uyObject (readonly)

Attribute for field uy



2269
2270
2271
# File 'lib/stripe/resources/tax/registration.rb', line 2269

def uy
  @uy
end

#uzObject (readonly)

Attribute for field uz



2271
2272
2273
# File 'lib/stripe/resources/tax/registration.rb', line 2271

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



2273
2274
2275
# File 'lib/stripe/resources/tax/registration.rb', line 2273

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



2275
2276
2277
# File 'lib/stripe/resources/tax/registration.rb', line 2275

def za
  @za
end

#zmObject (readonly)

Attribute for field zm



2277
2278
2279
# File 'lib/stripe/resources/tax/registration.rb', line 2277

def zm
  @zm
end

#zwObject (readonly)

Attribute for field zw



2279
2280
2281
# File 'lib/stripe/resources/tax/registration.rb', line 2279

def zw
  @zw
end

Class Method Details

.field_remappingsObject



2387
2388
2389
# File 'lib/stripe/resources/tax/registration.rb', line 2387

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/stripe/resources/tax/registration.rb', line 2281

def self.inner_class_types
  @inner_class_types = {
    ae: Ae,
    al: Al,
    am: Am,
    ao: Ao,
    at: At,
    au: Au,
    aw: Aw,
    az: Az,
    ba: Ba,
    bb: Bb,
    bd: Bd,
    be: Be,
    bf: Bf,
    bg: Bg,
    bh: Bh,
    bj: Bj,
    bs: Bs,
    by: By,
    ca: Ca,
    cd: Cd,
    ch: Ch,
    cl: Cl,
    cm: Cm,
    co: Co,
    cr: Cr,
    cv: Cv,
    cy: Cy,
    cz: Cz,
    de: De,
    dk: Dk,
    ec: Ec,
    ee: Ee,
    eg: Eg,
    es: Es,
    et: Et,
    fi: Fi,
    fr: Fr,
    gb: Gb,
    ge: Ge,
    gn: Gn,
    gr: Gr,
    hr: Hr,
    hu: Hu,
    id: Id,
    ie: Ie,
    in: In,
    is: Is,
    it: It,
    jp: Jp,
    ke: Ke,
    kg: Kg,
    kh: Kh,
    kr: Kr,
    kz: Kz,
    la: La,
    lk: Lk,
    lt: Lt,
    lu: Lu,
    lv: Lv,
    ma: Ma,
    md: Md,
    me: Me,
    mk: Mk,
    mr: Mr,
    mt: Mt,
    mx: Mx,
    my: My,
    ng: Ng,
    nl: Nl,
    no: No,
    np: Np,
    nz: Nz,
    om: Om,
    pe: Pe,
    ph: Ph,
    pl: Pl,
    pt: Pt,
    ro: Ro,
    rs: Rs,
    ru: Ru,
    sa: Sa,
    se: Se,
    sg: Sg,
    si: Si,
    sk: Sk,
    sn: Sn,
    sr: Sr,
    th: Th,
    tj: Tj,
    tr: Tr,
    tw: Tw,
    tz: Tz,
    ua: Ua,
    ug: Ug,
    us: Us,
    uy: Uy,
    uz: Uz,
    vn: Vn,
    za: Za,
    zm: Zm,
    zw: Zw,
  }
end