Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Attribute for field ae.
-
#al ⇒ Object
readonly
Attribute for field al.
-
#am ⇒ Object
readonly
Attribute for field am.
-
#ao ⇒ Object
readonly
Attribute for field ao.
-
#at ⇒ Object
readonly
Attribute for field at.
-
#au ⇒ Object
readonly
Attribute for field au.
-
#aw ⇒ Object
readonly
Attribute for field aw.
-
#az ⇒ Object
readonly
Attribute for field az.
-
#ba ⇒ Object
readonly
Attribute for field ba.
-
#bb ⇒ Object
readonly
Attribute for field bb.
-
#bd ⇒ Object
readonly
Attribute for field bd.
-
#be ⇒ Object
readonly
Attribute for field be.
-
#bf ⇒ Object
readonly
Attribute for field bf.
-
#bg ⇒ Object
readonly
Attribute for field bg.
-
#bh ⇒ Object
readonly
Attribute for field bh.
-
#bj ⇒ Object
readonly
Attribute for field bj.
-
#bs ⇒ Object
readonly
Attribute for field bs.
-
#by ⇒ Object
readonly
Attribute for field by.
-
#ca ⇒ Object
readonly
Attribute for field ca.
-
#cd ⇒ Object
readonly
Attribute for field cd.
-
#ch ⇒ Object
readonly
Attribute for field ch.
-
#cl ⇒ Object
readonly
Attribute for field cl.
-
#cm ⇒ Object
readonly
Attribute for field cm.
-
#co ⇒ Object
readonly
Attribute for field co.
-
#cr ⇒ Object
readonly
Attribute for field cr.
-
#cv ⇒ Object
readonly
Attribute for field cv.
-
#cy ⇒ Object
readonly
Attribute for field cy.
-
#cz ⇒ Object
readonly
Attribute for field cz.
-
#de ⇒ Object
readonly
Attribute for field de.
-
#dk ⇒ Object
readonly
Attribute for field dk.
-
#ec ⇒ Object
readonly
Attribute for field ec.
-
#ee ⇒ Object
readonly
Attribute for field ee.
-
#eg ⇒ Object
readonly
Attribute for field eg.
-
#es ⇒ Object
readonly
Attribute for field es.
-
#et ⇒ Object
readonly
Attribute for field et.
-
#fi ⇒ Object
readonly
Attribute for field fi.
-
#fr ⇒ Object
readonly
Attribute for field fr.
-
#gb ⇒ Object
readonly
Attribute for field gb.
-
#ge ⇒ Object
readonly
Attribute for field ge.
-
#gn ⇒ Object
readonly
Attribute for field gn.
-
#gr ⇒ Object
readonly
Attribute for field gr.
-
#hr ⇒ Object
readonly
Attribute for field hr.
-
#hu ⇒ Object
readonly
Attribute for field hu.
-
#id ⇒ Object
readonly
Attribute for field id.
-
#ie ⇒ Object
readonly
Attribute for field ie.
-
#in ⇒ Object
readonly
Attribute for field in.
-
#is ⇒ Object
readonly
Attribute for field is.
-
#it ⇒ Object
readonly
Attribute for field it.
-
#jp ⇒ Object
readonly
Attribute for field jp.
-
#ke ⇒ Object
readonly
Attribute for field ke.
-
#kg ⇒ Object
readonly
Attribute for field kg.
-
#kh ⇒ Object
readonly
Attribute for field kh.
-
#kr ⇒ Object
readonly
Attribute for field kr.
-
#kz ⇒ Object
readonly
Attribute for field kz.
-
#la ⇒ Object
readonly
Attribute for field la.
-
#lk ⇒ Object
readonly
Attribute for field lk.
-
#lt ⇒ Object
readonly
Attribute for field lt.
-
#lu ⇒ Object
readonly
Attribute for field lu.
-
#lv ⇒ Object
readonly
Attribute for field lv.
-
#ma ⇒ Object
readonly
Attribute for field ma.
-
#md ⇒ Object
readonly
Attribute for field md.
-
#me ⇒ Object
readonly
Attribute for field me.
-
#mk ⇒ Object
readonly
Attribute for field mk.
-
#mr ⇒ Object
readonly
Attribute for field mr.
-
#mt ⇒ Object
readonly
Attribute for field mt.
-
#mx ⇒ Object
readonly
Attribute for field mx.
-
#my ⇒ Object
readonly
Attribute for field my.
-
#ng ⇒ Object
readonly
Attribute for field ng.
-
#nl ⇒ Object
readonly
Attribute for field nl.
-
#no ⇒ Object
readonly
Attribute for field no.
-
#np ⇒ Object
readonly
Attribute for field np.
-
#nz ⇒ Object
readonly
Attribute for field nz.
-
#om ⇒ Object
readonly
Attribute for field om.
-
#pe ⇒ Object
readonly
Attribute for field pe.
-
#ph ⇒ Object
readonly
Attribute for field ph.
-
#pl ⇒ Object
readonly
Attribute for field pl.
-
#pt ⇒ Object
readonly
Attribute for field pt.
-
#ro ⇒ Object
readonly
Attribute for field ro.
-
#rs ⇒ Object
readonly
Attribute for field rs.
-
#ru ⇒ Object
readonly
Attribute for field ru.
-
#sa ⇒ Object
readonly
Attribute for field sa.
-
#se ⇒ Object
readonly
Attribute for field se.
-
#sg ⇒ Object
readonly
Attribute for field sg.
-
#si ⇒ Object
readonly
Attribute for field si.
-
#sk ⇒ Object
readonly
Attribute for field sk.
-
#sn ⇒ Object
readonly
Attribute for field sn.
-
#sr ⇒ Object
readonly
Attribute for field sr.
-
#th ⇒ Object
readonly
Attribute for field th.
-
#tj ⇒ Object
readonly
Attribute for field tj.
-
#tr ⇒ Object
readonly
Attribute for field tr.
-
#tw ⇒ Object
readonly
Attribute for field tw.
-
#tz ⇒ Object
readonly
Attribute for field tz.
-
#ua ⇒ Object
readonly
Attribute for field ua.
-
#ug ⇒ Object
readonly
Attribute for field ug.
-
#us ⇒ Object
readonly
Attribute for field us.
-
#uy ⇒ Object
readonly
Attribute for field uy.
-
#uz ⇒ Object
readonly
Attribute for field uz.
-
#vn ⇒ Object
readonly
Attribute for field vn.
-
#za ⇒ Object
readonly
Attribute for field za.
-
#zm ⇒ Object
readonly
Attribute for field zm.
-
#zw ⇒ Object
readonly
Attribute for field zw.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Attribute for field ae
2031 2032 2033 |
# File 'lib/stripe/resources/tax/registration.rb', line 2031 def ae @ae end |
#al ⇒ Object (readonly)
Attribute for field al
2033 2034 2035 |
# File 'lib/stripe/resources/tax/registration.rb', line 2033 def al @al end |
#am ⇒ Object (readonly)
Attribute for field am
2035 2036 2037 |
# File 'lib/stripe/resources/tax/registration.rb', line 2035 def am @am end |
#ao ⇒ Object (readonly)
Attribute for field ao
2037 2038 2039 |
# File 'lib/stripe/resources/tax/registration.rb', line 2037 def ao @ao end |
#at ⇒ Object (readonly)
Attribute for field at
2039 2040 2041 |
# File 'lib/stripe/resources/tax/registration.rb', line 2039 def at @at end |
#au ⇒ Object (readonly)
Attribute for field au
2041 2042 2043 |
# File 'lib/stripe/resources/tax/registration.rb', line 2041 def au @au end |
#aw ⇒ Object (readonly)
Attribute for field aw
2043 2044 2045 |
# File 'lib/stripe/resources/tax/registration.rb', line 2043 def aw @aw end |
#az ⇒ Object (readonly)
Attribute for field az
2045 2046 2047 |
# File 'lib/stripe/resources/tax/registration.rb', line 2045 def az @az end |
#ba ⇒ Object (readonly)
Attribute for field ba
2047 2048 2049 |
# File 'lib/stripe/resources/tax/registration.rb', line 2047 def ba @ba end |
#bb ⇒ Object (readonly)
Attribute for field bb
2049 2050 2051 |
# File 'lib/stripe/resources/tax/registration.rb', line 2049 def bb @bb end |
#bd ⇒ Object (readonly)
Attribute for field bd
2051 2052 2053 |
# File 'lib/stripe/resources/tax/registration.rb', line 2051 def bd @bd end |
#be ⇒ Object (readonly)
Attribute for field be
2053 2054 2055 |
# File 'lib/stripe/resources/tax/registration.rb', line 2053 def be @be end |
#bf ⇒ Object (readonly)
Attribute for field bf
2055 2056 2057 |
# File 'lib/stripe/resources/tax/registration.rb', line 2055 def bf @bf end |
#bg ⇒ Object (readonly)
Attribute for field bg
2057 2058 2059 |
# File 'lib/stripe/resources/tax/registration.rb', line 2057 def bg @bg end |
#bh ⇒ Object (readonly)
Attribute for field bh
2059 2060 2061 |
# File 'lib/stripe/resources/tax/registration.rb', line 2059 def bh @bh end |
#bj ⇒ Object (readonly)
Attribute for field bj
2061 2062 2063 |
# File 'lib/stripe/resources/tax/registration.rb', line 2061 def bj @bj end |
#bs ⇒ Object (readonly)
Attribute for field bs
2063 2064 2065 |
# File 'lib/stripe/resources/tax/registration.rb', line 2063 def bs @bs end |
#by ⇒ Object (readonly)
Attribute for field by
2065 2066 2067 |
# File 'lib/stripe/resources/tax/registration.rb', line 2065 def by @by end |
#ca ⇒ Object (readonly)
Attribute for field ca
2067 2068 2069 |
# File 'lib/stripe/resources/tax/registration.rb', line 2067 def ca @ca end |
#cd ⇒ Object (readonly)
Attribute for field cd
2069 2070 2071 |
# File 'lib/stripe/resources/tax/registration.rb', line 2069 def cd @cd end |
#ch ⇒ Object (readonly)
Attribute for field ch
2071 2072 2073 |
# File 'lib/stripe/resources/tax/registration.rb', line 2071 def ch @ch end |
#cl ⇒ Object (readonly)
Attribute for field cl
2073 2074 2075 |
# File 'lib/stripe/resources/tax/registration.rb', line 2073 def cl @cl end |
#cm ⇒ Object (readonly)
Attribute for field cm
2075 2076 2077 |
# File 'lib/stripe/resources/tax/registration.rb', line 2075 def cm @cm end |
#co ⇒ Object (readonly)
Attribute for field co
2077 2078 2079 |
# File 'lib/stripe/resources/tax/registration.rb', line 2077 def co @co end |
#cr ⇒ Object (readonly)
Attribute for field cr
2079 2080 2081 |
# File 'lib/stripe/resources/tax/registration.rb', line 2079 def cr @cr end |
#cv ⇒ Object (readonly)
Attribute for field cv
2081 2082 2083 |
# File 'lib/stripe/resources/tax/registration.rb', line 2081 def cv @cv end |
#cy ⇒ Object (readonly)
Attribute for field cy
2083 2084 2085 |
# File 'lib/stripe/resources/tax/registration.rb', line 2083 def cy @cy end |
#cz ⇒ Object (readonly)
Attribute for field cz
2085 2086 2087 |
# File 'lib/stripe/resources/tax/registration.rb', line 2085 def cz @cz end |
#de ⇒ Object (readonly)
Attribute for field de
2087 2088 2089 |
# File 'lib/stripe/resources/tax/registration.rb', line 2087 def de @de end |
#dk ⇒ Object (readonly)
Attribute for field dk
2089 2090 2091 |
# File 'lib/stripe/resources/tax/registration.rb', line 2089 def dk @dk end |
#ec ⇒ Object (readonly)
Attribute for field ec
2091 2092 2093 |
# File 'lib/stripe/resources/tax/registration.rb', line 2091 def ec @ec end |
#ee ⇒ Object (readonly)
Attribute for field ee
2093 2094 2095 |
# File 'lib/stripe/resources/tax/registration.rb', line 2093 def ee @ee end |
#eg ⇒ Object (readonly)
Attribute for field eg
2095 2096 2097 |
# File 'lib/stripe/resources/tax/registration.rb', line 2095 def eg @eg end |
#es ⇒ Object (readonly)
Attribute for field es
2097 2098 2099 |
# File 'lib/stripe/resources/tax/registration.rb', line 2097 def es @es end |
#et ⇒ Object (readonly)
Attribute for field et
2099 2100 2101 |
# File 'lib/stripe/resources/tax/registration.rb', line 2099 def et @et end |
#fi ⇒ Object (readonly)
Attribute for field fi
2101 2102 2103 |
# File 'lib/stripe/resources/tax/registration.rb', line 2101 def fi @fi end |
#fr ⇒ Object (readonly)
Attribute for field fr
2103 2104 2105 |
# File 'lib/stripe/resources/tax/registration.rb', line 2103 def fr @fr end |
#gb ⇒ Object (readonly)
Attribute for field gb
2105 2106 2107 |
# File 'lib/stripe/resources/tax/registration.rb', line 2105 def gb @gb end |
#ge ⇒ Object (readonly)
Attribute for field ge
2107 2108 2109 |
# File 'lib/stripe/resources/tax/registration.rb', line 2107 def ge @ge end |
#gn ⇒ Object (readonly)
Attribute for field gn
2109 2110 2111 |
# File 'lib/stripe/resources/tax/registration.rb', line 2109 def gn @gn end |
#gr ⇒ Object (readonly)
Attribute for field gr
2111 2112 2113 |
# File 'lib/stripe/resources/tax/registration.rb', line 2111 def gr @gr end |
#hr ⇒ Object (readonly)
Attribute for field hr
2113 2114 2115 |
# File 'lib/stripe/resources/tax/registration.rb', line 2113 def hr @hr end |
#hu ⇒ Object (readonly)
Attribute for field hu
2115 2116 2117 |
# File 'lib/stripe/resources/tax/registration.rb', line 2115 def hu @hu end |
#id ⇒ Object (readonly)
Attribute for field id
2117 2118 2119 |
# File 'lib/stripe/resources/tax/registration.rb', line 2117 def id @id end |
#ie ⇒ Object (readonly)
Attribute for field ie
2119 2120 2121 |
# File 'lib/stripe/resources/tax/registration.rb', line 2119 def ie @ie end |
#in ⇒ Object (readonly)
Attribute for field in
2121 2122 2123 |
# File 'lib/stripe/resources/tax/registration.rb', line 2121 def in @in end |
#is ⇒ Object (readonly)
Attribute for field is
2123 2124 2125 |
# File 'lib/stripe/resources/tax/registration.rb', line 2123 def is @is end |
#it ⇒ Object (readonly)
Attribute for field it
2125 2126 2127 |
# File 'lib/stripe/resources/tax/registration.rb', line 2125 def it @it end |
#jp ⇒ Object (readonly)
Attribute for field jp
2127 2128 2129 |
# File 'lib/stripe/resources/tax/registration.rb', line 2127 def jp @jp end |
#ke ⇒ Object (readonly)
Attribute for field ke
2129 2130 2131 |
# File 'lib/stripe/resources/tax/registration.rb', line 2129 def ke @ke end |
#kg ⇒ Object (readonly)
Attribute for field kg
2131 2132 2133 |
# File 'lib/stripe/resources/tax/registration.rb', line 2131 def kg @kg end |
#kh ⇒ Object (readonly)
Attribute for field kh
2133 2134 2135 |
# File 'lib/stripe/resources/tax/registration.rb', line 2133 def kh @kh end |
#kr ⇒ Object (readonly)
Attribute for field kr
2135 2136 2137 |
# File 'lib/stripe/resources/tax/registration.rb', line 2135 def kr @kr end |
#kz ⇒ Object (readonly)
Attribute for field kz
2137 2138 2139 |
# File 'lib/stripe/resources/tax/registration.rb', line 2137 def kz @kz end |
#la ⇒ Object (readonly)
Attribute for field la
2139 2140 2141 |
# File 'lib/stripe/resources/tax/registration.rb', line 2139 def la @la end |
#lk ⇒ Object (readonly)
Attribute for field lk
2141 2142 2143 |
# File 'lib/stripe/resources/tax/registration.rb', line 2141 def lk @lk end |
#lt ⇒ Object (readonly)
Attribute for field lt
2143 2144 2145 |
# File 'lib/stripe/resources/tax/registration.rb', line 2143 def lt @lt end |
#lu ⇒ Object (readonly)
Attribute for field lu
2145 2146 2147 |
# File 'lib/stripe/resources/tax/registration.rb', line 2145 def lu @lu end |
#lv ⇒ Object (readonly)
Attribute for field lv
2147 2148 2149 |
# File 'lib/stripe/resources/tax/registration.rb', line 2147 def lv @lv end |
#ma ⇒ Object (readonly)
Attribute for field ma
2149 2150 2151 |
# File 'lib/stripe/resources/tax/registration.rb', line 2149 def ma @ma end |
#md ⇒ Object (readonly)
Attribute for field md
2151 2152 2153 |
# File 'lib/stripe/resources/tax/registration.rb', line 2151 def md @md end |
#me ⇒ Object (readonly)
Attribute for field me
2153 2154 2155 |
# File 'lib/stripe/resources/tax/registration.rb', line 2153 def me @me end |
#mk ⇒ Object (readonly)
Attribute for field mk
2155 2156 2157 |
# File 'lib/stripe/resources/tax/registration.rb', line 2155 def mk @mk end |
#mr ⇒ Object (readonly)
Attribute for field mr
2157 2158 2159 |
# File 'lib/stripe/resources/tax/registration.rb', line 2157 def mr @mr end |
#mt ⇒ Object (readonly)
Attribute for field mt
2159 2160 2161 |
# File 'lib/stripe/resources/tax/registration.rb', line 2159 def mt @mt end |
#mx ⇒ Object (readonly)
Attribute for field mx
2161 2162 2163 |
# File 'lib/stripe/resources/tax/registration.rb', line 2161 def mx @mx end |
#my ⇒ Object (readonly)
Attribute for field my
2163 2164 2165 |
# File 'lib/stripe/resources/tax/registration.rb', line 2163 def my @my end |
#ng ⇒ Object (readonly)
Attribute for field ng
2165 2166 2167 |
# File 'lib/stripe/resources/tax/registration.rb', line 2165 def ng @ng end |
#nl ⇒ Object (readonly)
Attribute for field nl
2167 2168 2169 |
# File 'lib/stripe/resources/tax/registration.rb', line 2167 def nl @nl end |
#no ⇒ Object (readonly)
Attribute for field no
2169 2170 2171 |
# File 'lib/stripe/resources/tax/registration.rb', line 2169 def no @no end |
#np ⇒ Object (readonly)
Attribute for field np
2171 2172 2173 |
# File 'lib/stripe/resources/tax/registration.rb', line 2171 def np @np end |
#nz ⇒ Object (readonly)
Attribute for field nz
2173 2174 2175 |
# File 'lib/stripe/resources/tax/registration.rb', line 2173 def nz @nz end |
#om ⇒ Object (readonly)
Attribute for field om
2175 2176 2177 |
# File 'lib/stripe/resources/tax/registration.rb', line 2175 def om @om end |
#pe ⇒ Object (readonly)
Attribute for field pe
2177 2178 2179 |
# File 'lib/stripe/resources/tax/registration.rb', line 2177 def pe @pe end |
#ph ⇒ Object (readonly)
Attribute for field ph
2179 2180 2181 |
# File 'lib/stripe/resources/tax/registration.rb', line 2179 def ph @ph end |
#pl ⇒ Object (readonly)
Attribute for field pl
2181 2182 2183 |
# File 'lib/stripe/resources/tax/registration.rb', line 2181 def pl @pl end |
#pt ⇒ Object (readonly)
Attribute for field pt
2183 2184 2185 |
# File 'lib/stripe/resources/tax/registration.rb', line 2183 def pt @pt end |
#ro ⇒ Object (readonly)
Attribute for field ro
2185 2186 2187 |
# File 'lib/stripe/resources/tax/registration.rb', line 2185 def ro @ro end |
#rs ⇒ Object (readonly)
Attribute for field rs
2187 2188 2189 |
# File 'lib/stripe/resources/tax/registration.rb', line 2187 def rs @rs end |
#ru ⇒ Object (readonly)
Attribute for field ru
2189 2190 2191 |
# File 'lib/stripe/resources/tax/registration.rb', line 2189 def ru @ru end |
#sa ⇒ Object (readonly)
Attribute for field sa
2191 2192 2193 |
# File 'lib/stripe/resources/tax/registration.rb', line 2191 def sa @sa end |
#se ⇒ Object (readonly)
Attribute for field se
2193 2194 2195 |
# File 'lib/stripe/resources/tax/registration.rb', line 2193 def se @se end |
#sg ⇒ Object (readonly)
Attribute for field sg
2195 2196 2197 |
# File 'lib/stripe/resources/tax/registration.rb', line 2195 def sg @sg end |
#si ⇒ Object (readonly)
Attribute for field si
2197 2198 2199 |
# File 'lib/stripe/resources/tax/registration.rb', line 2197 def si @si end |
#sk ⇒ Object (readonly)
Attribute for field sk
2199 2200 2201 |
# File 'lib/stripe/resources/tax/registration.rb', line 2199 def sk @sk end |
#sn ⇒ Object (readonly)
Attribute for field sn
2201 2202 2203 |
# File 'lib/stripe/resources/tax/registration.rb', line 2201 def sn @sn end |
#sr ⇒ Object (readonly)
Attribute for field sr
2203 2204 2205 |
# File 'lib/stripe/resources/tax/registration.rb', line 2203 def sr @sr end |
#th ⇒ Object (readonly)
Attribute for field th
2205 2206 2207 |
# File 'lib/stripe/resources/tax/registration.rb', line 2205 def th @th end |
#tj ⇒ Object (readonly)
Attribute for field tj
2207 2208 2209 |
# File 'lib/stripe/resources/tax/registration.rb', line 2207 def tj @tj end |
#tr ⇒ Object (readonly)
Attribute for field tr
2209 2210 2211 |
# File 'lib/stripe/resources/tax/registration.rb', line 2209 def tr @tr end |
#tw ⇒ Object (readonly)
Attribute for field tw
2211 2212 2213 |
# File 'lib/stripe/resources/tax/registration.rb', line 2211 def tw @tw end |
#tz ⇒ Object (readonly)
Attribute for field tz
2213 2214 2215 |
# File 'lib/stripe/resources/tax/registration.rb', line 2213 def tz @tz end |
#ua ⇒ Object (readonly)
Attribute for field ua
2215 2216 2217 |
# File 'lib/stripe/resources/tax/registration.rb', line 2215 def ua @ua end |
#ug ⇒ Object (readonly)
Attribute for field ug
2217 2218 2219 |
# File 'lib/stripe/resources/tax/registration.rb', line 2217 def ug @ug end |
#us ⇒ Object (readonly)
Attribute for field us
2219 2220 2221 |
# File 'lib/stripe/resources/tax/registration.rb', line 2219 def us @us end |
#uy ⇒ Object (readonly)
Attribute for field uy
2221 2222 2223 |
# File 'lib/stripe/resources/tax/registration.rb', line 2221 def uy @uy end |
#uz ⇒ Object (readonly)
Attribute for field uz
2223 2224 2225 |
# File 'lib/stripe/resources/tax/registration.rb', line 2223 def uz @uz end |
#vn ⇒ Object (readonly)
Attribute for field vn
2225 2226 2227 |
# File 'lib/stripe/resources/tax/registration.rb', line 2225 def vn @vn end |
#za ⇒ Object (readonly)
Attribute for field za
2227 2228 2229 |
# File 'lib/stripe/resources/tax/registration.rb', line 2227 def za @za end |
#zm ⇒ Object (readonly)
Attribute for field zm
2229 2230 2231 |
# File 'lib/stripe/resources/tax/registration.rb', line 2229 def zm @zm end |
#zw ⇒ Object (readonly)
Attribute for field zw
2231 2232 2233 |
# File 'lib/stripe/resources/tax/registration.rb', line 2231 def zw @zw end |
Class Method Details
.field_remappings ⇒ Object
2339 2340 2341 |
# File 'lib/stripe/resources/tax/registration.rb', line 2339 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 |
# File 'lib/stripe/resources/tax/registration.rb', line 2233 def self.inner_class_types @inner_class_types = { ae: Ae, al: Al, am: Am, ao: Ao, at: At, au: Au, aw: Aw, az: Az, ba: Ba, bb: Bb, bd: Bd, be: Be, bf: Bf, bg: Bg, bh: Bh, bj: Bj, bs: Bs, by: By, ca: Ca, cd: Cd, ch: Ch, cl: Cl, cm: Cm, co: Co, cr: Cr, cv: Cv, cy: Cy, cz: Cz, de: De, dk: Dk, ec: Ec, ee: Ee, eg: Eg, es: Es, et: Et, fi: Fi, fr: Fr, gb: Gb, ge: Ge, gn: Gn, gr: Gr, hr: Hr, hu: Hu, id: Id, ie: Ie, in: In, is: Is, it: It, jp: Jp, ke: Ke, kg: Kg, kh: Kh, kr: Kr, kz: Kz, la: La, lk: Lk, lt: Lt, lu: Lu, lv: Lv, ma: Ma, md: Md, me: Me, mk: Mk, mr: Mr, mt: Mt, mx: Mx, my: My, ng: Ng, nl: Nl, no: No, np: Np, nz: Nz, om: Om, pe: Pe, ph: Ph, pl: Pl, pt: Pt, ro: Ro, rs: Rs, ru: Ru, sa: Sa, se: Se, sg: Sg, si: Si, sk: Sk, sn: Sn, sr: Sr, th: Th, tj: Tj, tr: Tr, tw: Tw, tz: Tz, ua: Ua, ug: Ug, us: Us, uy: Uy, uz: Uz, vn: Vn, za: Za, zm: Zm, zw: Zw, } end |