Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



2018
2019
2020
# File 'lib/stripe/resources/tax/registration.rb', line 2018

def ae
  @ae
end

#alObject (readonly)

Attribute for field al



2020
2021
2022
# File 'lib/stripe/resources/tax/registration.rb', line 2020

def al
  @al
end

#amObject (readonly)

Attribute for field am



2022
2023
2024
# File 'lib/stripe/resources/tax/registration.rb', line 2022

def am
  @am
end

#aoObject (readonly)

Attribute for field ao



2024
2025
2026
# File 'lib/stripe/resources/tax/registration.rb', line 2024

def ao
  @ao
end

#atObject (readonly)

Attribute for field at



2026
2027
2028
# File 'lib/stripe/resources/tax/registration.rb', line 2026

def at
  @at
end

#auObject (readonly)

Attribute for field au



2028
2029
2030
# File 'lib/stripe/resources/tax/registration.rb', line 2028

def au
  @au
end

#awObject (readonly)

Attribute for field aw



2030
2031
2032
# File 'lib/stripe/resources/tax/registration.rb', line 2030

def aw
  @aw
end

#azObject (readonly)

Attribute for field az



2032
2033
2034
# File 'lib/stripe/resources/tax/registration.rb', line 2032

def az
  @az
end

#baObject (readonly)

Attribute for field ba



2034
2035
2036
# File 'lib/stripe/resources/tax/registration.rb', line 2034

def ba
  @ba
end

#bbObject (readonly)

Attribute for field bb



2036
2037
2038
# File 'lib/stripe/resources/tax/registration.rb', line 2036

def bb
  @bb
end

#bdObject (readonly)

Attribute for field bd



2038
2039
2040
# File 'lib/stripe/resources/tax/registration.rb', line 2038

def bd
  @bd
end

#beObject (readonly)

Attribute for field be



2040
2041
2042
# File 'lib/stripe/resources/tax/registration.rb', line 2040

def be
  @be
end

#bfObject (readonly)

Attribute for field bf



2042
2043
2044
# File 'lib/stripe/resources/tax/registration.rb', line 2042

def bf
  @bf
end

#bgObject (readonly)

Attribute for field bg



2044
2045
2046
# File 'lib/stripe/resources/tax/registration.rb', line 2044

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



2046
2047
2048
# File 'lib/stripe/resources/tax/registration.rb', line 2046

def bh
  @bh
end

#bjObject (readonly)

Attribute for field bj



2048
2049
2050
# File 'lib/stripe/resources/tax/registration.rb', line 2048

def bj
  @bj
end

#bsObject (readonly)

Attribute for field bs



2050
2051
2052
# File 'lib/stripe/resources/tax/registration.rb', line 2050

def bs
  @bs
end

#byObject (readonly)

Attribute for field by



2052
2053
2054
# File 'lib/stripe/resources/tax/registration.rb', line 2052

def by
  @by
end

#caObject (readonly)

Attribute for field ca



2054
2055
2056
# File 'lib/stripe/resources/tax/registration.rb', line 2054

def ca
  @ca
end

#cdObject (readonly)

Attribute for field cd



2056
2057
2058
# File 'lib/stripe/resources/tax/registration.rb', line 2056

def cd
  @cd
end

#chObject (readonly)

Attribute for field ch



2058
2059
2060
# File 'lib/stripe/resources/tax/registration.rb', line 2058

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



2060
2061
2062
# File 'lib/stripe/resources/tax/registration.rb', line 2060

def cl
  @cl
end

#cmObject (readonly)

Attribute for field cm



2062
2063
2064
# File 'lib/stripe/resources/tax/registration.rb', line 2062

def cm
  @cm
end

#coObject (readonly)

Attribute for field co



2064
2065
2066
# File 'lib/stripe/resources/tax/registration.rb', line 2064

def co
  @co
end

#crObject (readonly)

Attribute for field cr



2066
2067
2068
# File 'lib/stripe/resources/tax/registration.rb', line 2066

def cr
  @cr
end

#cvObject (readonly)

Attribute for field cv



2068
2069
2070
# File 'lib/stripe/resources/tax/registration.rb', line 2068

def cv
  @cv
end

#cyObject (readonly)

Attribute for field cy



2070
2071
2072
# File 'lib/stripe/resources/tax/registration.rb', line 2070

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



2072
2073
2074
# File 'lib/stripe/resources/tax/registration.rb', line 2072

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



2074
2075
2076
# File 'lib/stripe/resources/tax/registration.rb', line 2074

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



2076
2077
2078
# File 'lib/stripe/resources/tax/registration.rb', line 2076

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



2078
2079
2080
# File 'lib/stripe/resources/tax/registration.rb', line 2078

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



2080
2081
2082
# File 'lib/stripe/resources/tax/registration.rb', line 2080

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



2082
2083
2084
# File 'lib/stripe/resources/tax/registration.rb', line 2082

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



2084
2085
2086
# File 'lib/stripe/resources/tax/registration.rb', line 2084

def es
  @es
end

#etObject (readonly)

Attribute for field et



2086
2087
2088
# File 'lib/stripe/resources/tax/registration.rb', line 2086

def et
  @et
end

#fiObject (readonly)

Attribute for field fi



2088
2089
2090
# File 'lib/stripe/resources/tax/registration.rb', line 2088

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



2090
2091
2092
# File 'lib/stripe/resources/tax/registration.rb', line 2090

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



2092
2093
2094
# File 'lib/stripe/resources/tax/registration.rb', line 2092

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



2094
2095
2096
# File 'lib/stripe/resources/tax/registration.rb', line 2094

def ge
  @ge
end

#gnObject (readonly)

Attribute for field gn



2096
2097
2098
# File 'lib/stripe/resources/tax/registration.rb', line 2096

def gn
  @gn
end

#grObject (readonly)

Attribute for field gr



2098
2099
2100
# File 'lib/stripe/resources/tax/registration.rb', line 2098

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



2100
2101
2102
# File 'lib/stripe/resources/tax/registration.rb', line 2100

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



2102
2103
2104
# File 'lib/stripe/resources/tax/registration.rb', line 2102

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



2104
2105
2106
# File 'lib/stripe/resources/tax/registration.rb', line 2104

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



2106
2107
2108
# File 'lib/stripe/resources/tax/registration.rb', line 2106

def ie
  @ie
end

#inObject (readonly)

Attribute for field in



2108
2109
2110
# File 'lib/stripe/resources/tax/registration.rb', line 2108

def in
  @in
end

#isObject (readonly)

Attribute for field is



2110
2111
2112
# File 'lib/stripe/resources/tax/registration.rb', line 2110

def is
  @is
end

#itObject (readonly)

Attribute for field it



2112
2113
2114
# File 'lib/stripe/resources/tax/registration.rb', line 2112

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



2114
2115
2116
# File 'lib/stripe/resources/tax/registration.rb', line 2114

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



2116
2117
2118
# File 'lib/stripe/resources/tax/registration.rb', line 2116

def ke
  @ke
end

#kgObject (readonly)

Attribute for field kg



2118
2119
2120
# File 'lib/stripe/resources/tax/registration.rb', line 2118

def kg
  @kg
end

#khObject (readonly)

Attribute for field kh



2120
2121
2122
# File 'lib/stripe/resources/tax/registration.rb', line 2120

def kh
  @kh
end

#krObject (readonly)

Attribute for field kr



2122
2123
2124
# File 'lib/stripe/resources/tax/registration.rb', line 2122

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



2124
2125
2126
# File 'lib/stripe/resources/tax/registration.rb', line 2124

def kz
  @kz
end

#laObject (readonly)

Attribute for field la



2126
2127
2128
# File 'lib/stripe/resources/tax/registration.rb', line 2126

def la
  @la
end

#ltObject (readonly)

Attribute for field lt



2128
2129
2130
# File 'lib/stripe/resources/tax/registration.rb', line 2128

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



2130
2131
2132
# File 'lib/stripe/resources/tax/registration.rb', line 2130

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



2132
2133
2134
# File 'lib/stripe/resources/tax/registration.rb', line 2132

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



2134
2135
2136
# File 'lib/stripe/resources/tax/registration.rb', line 2134

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



2136
2137
2138
# File 'lib/stripe/resources/tax/registration.rb', line 2136

def md
  @md
end

#meObject (readonly)

Attribute for field me



2138
2139
2140
# File 'lib/stripe/resources/tax/registration.rb', line 2138

def me
  @me
end

#mkObject (readonly)

Attribute for field mk



2140
2141
2142
# File 'lib/stripe/resources/tax/registration.rb', line 2140

def mk
  @mk
end

#mrObject (readonly)

Attribute for field mr



2142
2143
2144
# File 'lib/stripe/resources/tax/registration.rb', line 2142

def mr
  @mr
end

#mtObject (readonly)

Attribute for field mt



2144
2145
2146
# File 'lib/stripe/resources/tax/registration.rb', line 2144

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



2146
2147
2148
# File 'lib/stripe/resources/tax/registration.rb', line 2146

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



2148
2149
2150
# File 'lib/stripe/resources/tax/registration.rb', line 2148

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



2150
2151
2152
# File 'lib/stripe/resources/tax/registration.rb', line 2150

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



2152
2153
2154
# File 'lib/stripe/resources/tax/registration.rb', line 2152

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



2154
2155
2156
# File 'lib/stripe/resources/tax/registration.rb', line 2154

def no
  @no
end

#npObject (readonly)

Attribute for field np



2156
2157
2158
# File 'lib/stripe/resources/tax/registration.rb', line 2156

def np
  @np
end

#nzObject (readonly)

Attribute for field nz



2158
2159
2160
# File 'lib/stripe/resources/tax/registration.rb', line 2158

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



2160
2161
2162
# File 'lib/stripe/resources/tax/registration.rb', line 2160

def om
  @om
end

#peObject (readonly)

Attribute for field pe



2162
2163
2164
# File 'lib/stripe/resources/tax/registration.rb', line 2162

def pe
  @pe
end

#phObject (readonly)

Attribute for field ph



2164
2165
2166
# File 'lib/stripe/resources/tax/registration.rb', line 2164

def ph
  @ph
end

#plObject (readonly)

Attribute for field pl



2166
2167
2168
# File 'lib/stripe/resources/tax/registration.rb', line 2166

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



2168
2169
2170
# File 'lib/stripe/resources/tax/registration.rb', line 2168

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



2170
2171
2172
# File 'lib/stripe/resources/tax/registration.rb', line 2170

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



2172
2173
2174
# File 'lib/stripe/resources/tax/registration.rb', line 2172

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



2174
2175
2176
# File 'lib/stripe/resources/tax/registration.rb', line 2174

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



2176
2177
2178
# File 'lib/stripe/resources/tax/registration.rb', line 2176

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



2178
2179
2180
# File 'lib/stripe/resources/tax/registration.rb', line 2178

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



2180
2181
2182
# File 'lib/stripe/resources/tax/registration.rb', line 2180

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



2182
2183
2184
# File 'lib/stripe/resources/tax/registration.rb', line 2182

def si
  @si
end

#skObject (readonly)

Attribute for field sk



2184
2185
2186
# File 'lib/stripe/resources/tax/registration.rb', line 2184

def sk
  @sk
end

#snObject (readonly)

Attribute for field sn



2186
2187
2188
# File 'lib/stripe/resources/tax/registration.rb', line 2186

def sn
  @sn
end

#srObject (readonly)

Attribute for field sr



2188
2189
2190
# File 'lib/stripe/resources/tax/registration.rb', line 2188

def sr
  @sr
end

#thObject (readonly)

Attribute for field th



2190
2191
2192
# File 'lib/stripe/resources/tax/registration.rb', line 2190

def th
  @th
end

#tjObject (readonly)

Attribute for field tj



2192
2193
2194
# File 'lib/stripe/resources/tax/registration.rb', line 2192

def tj
  @tj
end

#trObject (readonly)

Attribute for field tr



2194
2195
2196
# File 'lib/stripe/resources/tax/registration.rb', line 2194

def tr
  @tr
end

#twObject (readonly)

Attribute for field tw



2196
2197
2198
# File 'lib/stripe/resources/tax/registration.rb', line 2196

def tw
  @tw
end

#tzObject (readonly)

Attribute for field tz



2198
2199
2200
# File 'lib/stripe/resources/tax/registration.rb', line 2198

def tz
  @tz
end

#uaObject (readonly)

Attribute for field ua



2200
2201
2202
# File 'lib/stripe/resources/tax/registration.rb', line 2200

def ua
  @ua
end

#ugObject (readonly)

Attribute for field ug



2202
2203
2204
# File 'lib/stripe/resources/tax/registration.rb', line 2202

def ug
  @ug
end

#usObject (readonly)

Attribute for field us



2204
2205
2206
# File 'lib/stripe/resources/tax/registration.rb', line 2204

def us
  @us
end

#uyObject (readonly)

Attribute for field uy



2206
2207
2208
# File 'lib/stripe/resources/tax/registration.rb', line 2206

def uy
  @uy
end

#uzObject (readonly)

Attribute for field uz



2208
2209
2210
# File 'lib/stripe/resources/tax/registration.rb', line 2208

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



2210
2211
2212
# File 'lib/stripe/resources/tax/registration.rb', line 2210

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



2212
2213
2214
# File 'lib/stripe/resources/tax/registration.rb', line 2212

def za
  @za
end

#zmObject (readonly)

Attribute for field zm



2214
2215
2216
# File 'lib/stripe/resources/tax/registration.rb', line 2214

def zm
  @zm
end

#zwObject (readonly)

Attribute for field zw



2216
2217
2218
# File 'lib/stripe/resources/tax/registration.rb', line 2216

def zw
  @zw
end

Class Method Details

.field_remappingsObject



2323
2324
2325
# File 'lib/stripe/resources/tax/registration.rb', line 2323

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
# File 'lib/stripe/resources/tax/registration.rb', line 2218

def self.inner_class_types
  @inner_class_types = {
    ae: Ae,
    al: Al,
    am: Am,
    ao: Ao,
    at: At,
    au: Au,
    aw: Aw,
    az: Az,
    ba: Ba,
    bb: Bb,
    bd: Bd,
    be: Be,
    bf: Bf,
    bg: Bg,
    bh: Bh,
    bj: Bj,
    bs: Bs,
    by: By,
    ca: Ca,
    cd: Cd,
    ch: Ch,
    cl: Cl,
    cm: Cm,
    co: Co,
    cr: Cr,
    cv: Cv,
    cy: Cy,
    cz: Cz,
    de: De,
    dk: Dk,
    ec: Ec,
    ee: Ee,
    eg: Eg,
    es: Es,
    et: Et,
    fi: Fi,
    fr: Fr,
    gb: Gb,
    ge: Ge,
    gn: Gn,
    gr: Gr,
    hr: Hr,
    hu: Hu,
    id: Id,
    ie: Ie,
    in: In,
    is: Is,
    it: It,
    jp: Jp,
    ke: Ke,
    kg: Kg,
    kh: Kh,
    kr: Kr,
    kz: Kz,
    la: La,
    lt: Lt,
    lu: Lu,
    lv: Lv,
    ma: Ma,
    md: Md,
    me: Me,
    mk: Mk,
    mr: Mr,
    mt: Mt,
    mx: Mx,
    my: My,
    ng: Ng,
    nl: Nl,
    no: No,
    np: Np,
    nz: Nz,
    om: Om,
    pe: Pe,
    ph: Ph,
    pl: Pl,
    pt: Pt,
    ro: Ro,
    rs: Rs,
    ru: Ru,
    sa: Sa,
    se: Se,
    sg: Sg,
    si: Si,
    sk: Sk,
    sn: Sn,
    sr: Sr,
    th: Th,
    tj: Tj,
    tr: Tr,
    tw: Tw,
    tz: Tz,
    ua: Ua,
    ug: Ug,
    us: Us,
    uy: Uy,
    uz: Uz,
    vn: Vn,
    za: Za,
    zm: Zm,
    zw: Zw,
  }
end