Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



761
762
763
# File 'lib/stripe/resources/tax/registration.rb', line 761

def ae
  @ae
end

#alObject (readonly)

Attribute for field al



763
764
765
# File 'lib/stripe/resources/tax/registration.rb', line 763

def al
  @al
end

#amObject (readonly)

Attribute for field am



765
766
767
# File 'lib/stripe/resources/tax/registration.rb', line 765

def am
  @am
end

#aoObject (readonly)

Attribute for field ao



767
768
769
# File 'lib/stripe/resources/tax/registration.rb', line 767

def ao
  @ao
end

#atObject (readonly)

Attribute for field at



769
770
771
# File 'lib/stripe/resources/tax/registration.rb', line 769

def at
  @at
end

#auObject (readonly)

Attribute for field au



771
772
773
# File 'lib/stripe/resources/tax/registration.rb', line 771

def au
  @au
end

#awObject (readonly)

Attribute for field aw



773
774
775
# File 'lib/stripe/resources/tax/registration.rb', line 773

def aw
  @aw
end

#azObject (readonly)

Attribute for field az



775
776
777
# File 'lib/stripe/resources/tax/registration.rb', line 775

def az
  @az
end

#baObject (readonly)

Attribute for field ba



777
778
779
# File 'lib/stripe/resources/tax/registration.rb', line 777

def ba
  @ba
end

#bbObject (readonly)

Attribute for field bb



779
780
781
# File 'lib/stripe/resources/tax/registration.rb', line 779

def bb
  @bb
end

#bdObject (readonly)

Attribute for field bd



781
782
783
# File 'lib/stripe/resources/tax/registration.rb', line 781

def bd
  @bd
end

#beObject (readonly)

Attribute for field be



783
784
785
# File 'lib/stripe/resources/tax/registration.rb', line 783

def be
  @be
end

#bfObject (readonly)

Attribute for field bf



785
786
787
# File 'lib/stripe/resources/tax/registration.rb', line 785

def bf
  @bf
end

#bgObject (readonly)

Attribute for field bg



787
788
789
# File 'lib/stripe/resources/tax/registration.rb', line 787

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



789
790
791
# File 'lib/stripe/resources/tax/registration.rb', line 789

def bh
  @bh
end

#bjObject (readonly)

Attribute for field bj



791
792
793
# File 'lib/stripe/resources/tax/registration.rb', line 791

def bj
  @bj
end

#bsObject (readonly)

Attribute for field bs



793
794
795
# File 'lib/stripe/resources/tax/registration.rb', line 793

def bs
  @bs
end

#byObject (readonly)

Attribute for field by



795
796
797
# File 'lib/stripe/resources/tax/registration.rb', line 795

def by
  @by
end

#caObject (readonly)

Attribute for field ca



797
798
799
# File 'lib/stripe/resources/tax/registration.rb', line 797

def ca
  @ca
end

#cdObject (readonly)

Attribute for field cd



799
800
801
# File 'lib/stripe/resources/tax/registration.rb', line 799

def cd
  @cd
end

#chObject (readonly)

Attribute for field ch



801
802
803
# File 'lib/stripe/resources/tax/registration.rb', line 801

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



803
804
805
# File 'lib/stripe/resources/tax/registration.rb', line 803

def cl
  @cl
end

#cmObject (readonly)

Attribute for field cm



805
806
807
# File 'lib/stripe/resources/tax/registration.rb', line 805

def cm
  @cm
end

#coObject (readonly)

Attribute for field co



807
808
809
# File 'lib/stripe/resources/tax/registration.rb', line 807

def co
  @co
end

#crObject (readonly)

Attribute for field cr



809
810
811
# File 'lib/stripe/resources/tax/registration.rb', line 809

def cr
  @cr
end

#cvObject (readonly)

Attribute for field cv



811
812
813
# File 'lib/stripe/resources/tax/registration.rb', line 811

def cv
  @cv
end

#cyObject (readonly)

Attribute for field cy



813
814
815
# File 'lib/stripe/resources/tax/registration.rb', line 813

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



815
816
817
# File 'lib/stripe/resources/tax/registration.rb', line 815

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



817
818
819
# File 'lib/stripe/resources/tax/registration.rb', line 817

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



819
820
821
# File 'lib/stripe/resources/tax/registration.rb', line 819

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



821
822
823
# File 'lib/stripe/resources/tax/registration.rb', line 821

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



823
824
825
# File 'lib/stripe/resources/tax/registration.rb', line 823

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



825
826
827
# File 'lib/stripe/resources/tax/registration.rb', line 825

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



827
828
829
# File 'lib/stripe/resources/tax/registration.rb', line 827

def es
  @es
end

#etObject (readonly)

Attribute for field et



829
830
831
# File 'lib/stripe/resources/tax/registration.rb', line 829

def et
  @et
end

#fiObject (readonly)

Attribute for field fi



831
832
833
# File 'lib/stripe/resources/tax/registration.rb', line 831

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



833
834
835
# File 'lib/stripe/resources/tax/registration.rb', line 833

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



835
836
837
# File 'lib/stripe/resources/tax/registration.rb', line 835

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



837
838
839
# File 'lib/stripe/resources/tax/registration.rb', line 837

def ge
  @ge
end

#gnObject (readonly)

Attribute for field gn



839
840
841
# File 'lib/stripe/resources/tax/registration.rb', line 839

def gn
  @gn
end

#grObject (readonly)

Attribute for field gr



841
842
843
# File 'lib/stripe/resources/tax/registration.rb', line 841

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



843
844
845
# File 'lib/stripe/resources/tax/registration.rb', line 843

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



845
846
847
# File 'lib/stripe/resources/tax/registration.rb', line 845

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



847
848
849
# File 'lib/stripe/resources/tax/registration.rb', line 847

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



849
850
851
# File 'lib/stripe/resources/tax/registration.rb', line 849

def ie
  @ie
end

#inObject (readonly)

Attribute for field in



851
852
853
# File 'lib/stripe/resources/tax/registration.rb', line 851

def in
  @in
end

#isObject (readonly)

Attribute for field is



853
854
855
# File 'lib/stripe/resources/tax/registration.rb', line 853

def is
  @is
end

#itObject (readonly)

Attribute for field it



855
856
857
# File 'lib/stripe/resources/tax/registration.rb', line 855

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



857
858
859
# File 'lib/stripe/resources/tax/registration.rb', line 857

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



859
860
861
# File 'lib/stripe/resources/tax/registration.rb', line 859

def ke
  @ke
end

#kgObject (readonly)

Attribute for field kg



861
862
863
# File 'lib/stripe/resources/tax/registration.rb', line 861

def kg
  @kg
end

#khObject (readonly)

Attribute for field kh



863
864
865
# File 'lib/stripe/resources/tax/registration.rb', line 863

def kh
  @kh
end

#krObject (readonly)

Attribute for field kr



865
866
867
# File 'lib/stripe/resources/tax/registration.rb', line 865

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



867
868
869
# File 'lib/stripe/resources/tax/registration.rb', line 867

def kz
  @kz
end

#laObject (readonly)

Attribute for field la



869
870
871
# File 'lib/stripe/resources/tax/registration.rb', line 869

def la
  @la
end

#ltObject (readonly)

Attribute for field lt



871
872
873
# File 'lib/stripe/resources/tax/registration.rb', line 871

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



873
874
875
# File 'lib/stripe/resources/tax/registration.rb', line 873

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



875
876
877
# File 'lib/stripe/resources/tax/registration.rb', line 875

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



877
878
879
# File 'lib/stripe/resources/tax/registration.rb', line 877

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



879
880
881
# File 'lib/stripe/resources/tax/registration.rb', line 879

def md
  @md
end

#meObject (readonly)

Attribute for field me



881
882
883
# File 'lib/stripe/resources/tax/registration.rb', line 881

def me
  @me
end

#mkObject (readonly)

Attribute for field mk



883
884
885
# File 'lib/stripe/resources/tax/registration.rb', line 883

def mk
  @mk
end

#mrObject (readonly)

Attribute for field mr



885
886
887
# File 'lib/stripe/resources/tax/registration.rb', line 885

def mr
  @mr
end

#mtObject (readonly)

Attribute for field mt



887
888
889
# File 'lib/stripe/resources/tax/registration.rb', line 887

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



889
890
891
# File 'lib/stripe/resources/tax/registration.rb', line 889

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



891
892
893
# File 'lib/stripe/resources/tax/registration.rb', line 891

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



893
894
895
# File 'lib/stripe/resources/tax/registration.rb', line 893

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



895
896
897
# File 'lib/stripe/resources/tax/registration.rb', line 895

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



897
898
899
# File 'lib/stripe/resources/tax/registration.rb', line 897

def no
  @no
end

#npObject (readonly)

Attribute for field np



899
900
901
# File 'lib/stripe/resources/tax/registration.rb', line 899

def np
  @np
end

#nzObject (readonly)

Attribute for field nz



901
902
903
# File 'lib/stripe/resources/tax/registration.rb', line 901

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



903
904
905
# File 'lib/stripe/resources/tax/registration.rb', line 903

def om
  @om
end

#peObject (readonly)

Attribute for field pe



905
906
907
# File 'lib/stripe/resources/tax/registration.rb', line 905

def pe
  @pe
end

#phObject (readonly)

Attribute for field ph



907
908
909
# File 'lib/stripe/resources/tax/registration.rb', line 907

def ph
  @ph
end

#plObject (readonly)

Attribute for field pl



909
910
911
# File 'lib/stripe/resources/tax/registration.rb', line 909

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



911
912
913
# File 'lib/stripe/resources/tax/registration.rb', line 911

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



913
914
915
# File 'lib/stripe/resources/tax/registration.rb', line 913

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



915
916
917
# File 'lib/stripe/resources/tax/registration.rb', line 915

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



917
918
919
# File 'lib/stripe/resources/tax/registration.rb', line 917

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



919
920
921
# File 'lib/stripe/resources/tax/registration.rb', line 919

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



921
922
923
# File 'lib/stripe/resources/tax/registration.rb', line 921

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



923
924
925
# File 'lib/stripe/resources/tax/registration.rb', line 923

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



925
926
927
# File 'lib/stripe/resources/tax/registration.rb', line 925

def si
  @si
end

#skObject (readonly)

Attribute for field sk



927
928
929
# File 'lib/stripe/resources/tax/registration.rb', line 927

def sk
  @sk
end

#snObject (readonly)

Attribute for field sn



929
930
931
# File 'lib/stripe/resources/tax/registration.rb', line 929

def sn
  @sn
end

#srObject (readonly)

Attribute for field sr



931
932
933
# File 'lib/stripe/resources/tax/registration.rb', line 931

def sr
  @sr
end

#thObject (readonly)

Attribute for field th



933
934
935
# File 'lib/stripe/resources/tax/registration.rb', line 933

def th
  @th
end

#tjObject (readonly)

Attribute for field tj



935
936
937
# File 'lib/stripe/resources/tax/registration.rb', line 935

def tj
  @tj
end

#trObject (readonly)

Attribute for field tr



937
938
939
# File 'lib/stripe/resources/tax/registration.rb', line 937

def tr
  @tr
end

#tzObject (readonly)

Attribute for field tz



939
940
941
# File 'lib/stripe/resources/tax/registration.rb', line 939

def tz
  @tz
end

#uaObject (readonly)

Attribute for field ua



941
942
943
# File 'lib/stripe/resources/tax/registration.rb', line 941

def ua
  @ua
end

#ugObject (readonly)

Attribute for field ug



943
944
945
# File 'lib/stripe/resources/tax/registration.rb', line 943

def ug
  @ug
end

#usObject (readonly)

Attribute for field us



945
946
947
# File 'lib/stripe/resources/tax/registration.rb', line 945

def us
  @us
end

#uyObject (readonly)

Attribute for field uy



947
948
949
# File 'lib/stripe/resources/tax/registration.rb', line 947

def uy
  @uy
end

#uzObject (readonly)

Attribute for field uz



949
950
951
# File 'lib/stripe/resources/tax/registration.rb', line 949

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



951
952
953
# File 'lib/stripe/resources/tax/registration.rb', line 951

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



953
954
955
# File 'lib/stripe/resources/tax/registration.rb', line 953

def za
  @za
end

#zmObject (readonly)

Attribute for field zm



955
956
957
# File 'lib/stripe/resources/tax/registration.rb', line 955

def zm
  @zm
end

#zwObject (readonly)

Attribute for field zw



957
958
959
# File 'lib/stripe/resources/tax/registration.rb', line 957

def zw
  @zw
end