Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Attribute for field ae.
-
#al ⇒ Object
readonly
Attribute for field al.
-
#am ⇒ Object
readonly
Attribute for field am.
-
#ao ⇒ Object
readonly
Attribute for field ao.
-
#at ⇒ Object
readonly
Attribute for field at.
-
#au ⇒ Object
readonly
Attribute for field au.
-
#aw ⇒ Object
readonly
Attribute for field aw.
-
#az ⇒ Object
readonly
Attribute for field az.
-
#ba ⇒ Object
readonly
Attribute for field ba.
-
#bb ⇒ Object
readonly
Attribute for field bb.
-
#bd ⇒ Object
readonly
Attribute for field bd.
-
#be ⇒ Object
readonly
Attribute for field be.
-
#bf ⇒ Object
readonly
Attribute for field bf.
-
#bg ⇒ Object
readonly
Attribute for field bg.
-
#bh ⇒ Object
readonly
Attribute for field bh.
-
#bj ⇒ Object
readonly
Attribute for field bj.
-
#bs ⇒ Object
readonly
Attribute for field bs.
-
#by ⇒ Object
readonly
Attribute for field by.
-
#ca ⇒ Object
readonly
Attribute for field ca.
-
#cd ⇒ Object
readonly
Attribute for field cd.
-
#ch ⇒ Object
readonly
Attribute for field ch.
-
#cl ⇒ Object
readonly
Attribute for field cl.
-
#cm ⇒ Object
readonly
Attribute for field cm.
-
#co ⇒ Object
readonly
Attribute for field co.
-
#cr ⇒ Object
readonly
Attribute for field cr.
-
#cv ⇒ Object
readonly
Attribute for field cv.
-
#cy ⇒ Object
readonly
Attribute for field cy.
-
#cz ⇒ Object
readonly
Attribute for field cz.
-
#de ⇒ Object
readonly
Attribute for field de.
-
#dk ⇒ Object
readonly
Attribute for field dk.
-
#ec ⇒ Object
readonly
Attribute for field ec.
-
#ee ⇒ Object
readonly
Attribute for field ee.
-
#eg ⇒ Object
readonly
Attribute for field eg.
-
#es ⇒ Object
readonly
Attribute for field es.
-
#et ⇒ Object
readonly
Attribute for field et.
-
#fi ⇒ Object
readonly
Attribute for field fi.
-
#fr ⇒ Object
readonly
Attribute for field fr.
-
#gb ⇒ Object
readonly
Attribute for field gb.
-
#ge ⇒ Object
readonly
Attribute for field ge.
-
#gn ⇒ Object
readonly
Attribute for field gn.
-
#gr ⇒ Object
readonly
Attribute for field gr.
-
#hr ⇒ Object
readonly
Attribute for field hr.
-
#hu ⇒ Object
readonly
Attribute for field hu.
-
#id ⇒ Object
readonly
Attribute for field id.
-
#ie ⇒ Object
readonly
Attribute for field ie.
-
#in ⇒ Object
readonly
Attribute for field in.
-
#is ⇒ Object
readonly
Attribute for field is.
-
#it ⇒ Object
readonly
Attribute for field it.
-
#jp ⇒ Object
readonly
Attribute for field jp.
-
#ke ⇒ Object
readonly
Attribute for field ke.
-
#kg ⇒ Object
readonly
Attribute for field kg.
-
#kh ⇒ Object
readonly
Attribute for field kh.
-
#kr ⇒ Object
readonly
Attribute for field kr.
-
#kz ⇒ Object
readonly
Attribute for field kz.
-
#la ⇒ Object
readonly
Attribute for field la.
-
#lt ⇒ Object
readonly
Attribute for field lt.
-
#lu ⇒ Object
readonly
Attribute for field lu.
-
#lv ⇒ Object
readonly
Attribute for field lv.
-
#ma ⇒ Object
readonly
Attribute for field ma.
-
#md ⇒ Object
readonly
Attribute for field md.
-
#me ⇒ Object
readonly
Attribute for field me.
-
#mk ⇒ Object
readonly
Attribute for field mk.
-
#mr ⇒ Object
readonly
Attribute for field mr.
-
#mt ⇒ Object
readonly
Attribute for field mt.
-
#mx ⇒ Object
readonly
Attribute for field mx.
-
#my ⇒ Object
readonly
Attribute for field my.
-
#ng ⇒ Object
readonly
Attribute for field ng.
-
#nl ⇒ Object
readonly
Attribute for field nl.
-
#no ⇒ Object
readonly
Attribute for field no.
-
#np ⇒ Object
readonly
Attribute for field np.
-
#nz ⇒ Object
readonly
Attribute for field nz.
-
#om ⇒ Object
readonly
Attribute for field om.
-
#pe ⇒ Object
readonly
Attribute for field pe.
-
#ph ⇒ Object
readonly
Attribute for field ph.
-
#pl ⇒ Object
readonly
Attribute for field pl.
-
#pt ⇒ Object
readonly
Attribute for field pt.
-
#ro ⇒ Object
readonly
Attribute for field ro.
-
#rs ⇒ Object
readonly
Attribute for field rs.
-
#ru ⇒ Object
readonly
Attribute for field ru.
-
#sa ⇒ Object
readonly
Attribute for field sa.
-
#se ⇒ Object
readonly
Attribute for field se.
-
#sg ⇒ Object
readonly
Attribute for field sg.
-
#si ⇒ Object
readonly
Attribute for field si.
-
#sk ⇒ Object
readonly
Attribute for field sk.
-
#sn ⇒ Object
readonly
Attribute for field sn.
-
#sr ⇒ Object
readonly
Attribute for field sr.
-
#th ⇒ Object
readonly
Attribute for field th.
-
#tj ⇒ Object
readonly
Attribute for field tj.
-
#tr ⇒ Object
readonly
Attribute for field tr.
-
#tz ⇒ Object
readonly
Attribute for field tz.
-
#ua ⇒ Object
readonly
Attribute for field ua.
-
#ug ⇒ Object
readonly
Attribute for field ug.
-
#us ⇒ Object
readonly
Attribute for field us.
-
#uy ⇒ Object
readonly
Attribute for field uy.
-
#uz ⇒ Object
readonly
Attribute for field uz.
-
#vn ⇒ Object
readonly
Attribute for field vn.
-
#za ⇒ Object
readonly
Attribute for field za.
-
#zm ⇒ Object
readonly
Attribute for field zm.
-
#zw ⇒ Object
readonly
Attribute for field zw.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Attribute for field ae
1877 1878 1879 |
# File 'lib/stripe/resources/tax/registration.rb', line 1877 def ae @ae end |
#al ⇒ Object (readonly)
Attribute for field al
1879 1880 1881 |
# File 'lib/stripe/resources/tax/registration.rb', line 1879 def al @al end |
#am ⇒ Object (readonly)
Attribute for field am
1881 1882 1883 |
# File 'lib/stripe/resources/tax/registration.rb', line 1881 def am @am end |
#ao ⇒ Object (readonly)
Attribute for field ao
1883 1884 1885 |
# File 'lib/stripe/resources/tax/registration.rb', line 1883 def ao @ao end |
#at ⇒ Object (readonly)
Attribute for field at
1885 1886 1887 |
# File 'lib/stripe/resources/tax/registration.rb', line 1885 def at @at end |
#au ⇒ Object (readonly)
Attribute for field au
1887 1888 1889 |
# File 'lib/stripe/resources/tax/registration.rb', line 1887 def au @au end |
#aw ⇒ Object (readonly)
Attribute for field aw
1889 1890 1891 |
# File 'lib/stripe/resources/tax/registration.rb', line 1889 def aw @aw end |
#az ⇒ Object (readonly)
Attribute for field az
1891 1892 1893 |
# File 'lib/stripe/resources/tax/registration.rb', line 1891 def az @az end |
#ba ⇒ Object (readonly)
Attribute for field ba
1893 1894 1895 |
# File 'lib/stripe/resources/tax/registration.rb', line 1893 def ba @ba end |
#bb ⇒ Object (readonly)
Attribute for field bb
1895 1896 1897 |
# File 'lib/stripe/resources/tax/registration.rb', line 1895 def bb @bb end |
#bd ⇒ Object (readonly)
Attribute for field bd
1897 1898 1899 |
# File 'lib/stripe/resources/tax/registration.rb', line 1897 def bd @bd end |
#be ⇒ Object (readonly)
Attribute for field be
1899 1900 1901 |
# File 'lib/stripe/resources/tax/registration.rb', line 1899 def be @be end |
#bf ⇒ Object (readonly)
Attribute for field bf
1901 1902 1903 |
# File 'lib/stripe/resources/tax/registration.rb', line 1901 def bf @bf end |
#bg ⇒ Object (readonly)
Attribute for field bg
1903 1904 1905 |
# File 'lib/stripe/resources/tax/registration.rb', line 1903 def bg @bg end |
#bh ⇒ Object (readonly)
Attribute for field bh
1905 1906 1907 |
# File 'lib/stripe/resources/tax/registration.rb', line 1905 def bh @bh end |
#bj ⇒ Object (readonly)
Attribute for field bj
1907 1908 1909 |
# File 'lib/stripe/resources/tax/registration.rb', line 1907 def bj @bj end |
#bs ⇒ Object (readonly)
Attribute for field bs
1909 1910 1911 |
# File 'lib/stripe/resources/tax/registration.rb', line 1909 def bs @bs end |
#by ⇒ Object (readonly)
Attribute for field by
1911 1912 1913 |
# File 'lib/stripe/resources/tax/registration.rb', line 1911 def by @by end |
#ca ⇒ Object (readonly)
Attribute for field ca
1913 1914 1915 |
# File 'lib/stripe/resources/tax/registration.rb', line 1913 def ca @ca end |
#cd ⇒ Object (readonly)
Attribute for field cd
1915 1916 1917 |
# File 'lib/stripe/resources/tax/registration.rb', line 1915 def cd @cd end |
#ch ⇒ Object (readonly)
Attribute for field ch
1917 1918 1919 |
# File 'lib/stripe/resources/tax/registration.rb', line 1917 def ch @ch end |
#cl ⇒ Object (readonly)
Attribute for field cl
1919 1920 1921 |
# File 'lib/stripe/resources/tax/registration.rb', line 1919 def cl @cl end |
#cm ⇒ Object (readonly)
Attribute for field cm
1921 1922 1923 |
# File 'lib/stripe/resources/tax/registration.rb', line 1921 def cm @cm end |
#co ⇒ Object (readonly)
Attribute for field co
1923 1924 1925 |
# File 'lib/stripe/resources/tax/registration.rb', line 1923 def co @co end |
#cr ⇒ Object (readonly)
Attribute for field cr
1925 1926 1927 |
# File 'lib/stripe/resources/tax/registration.rb', line 1925 def cr @cr end |
#cv ⇒ Object (readonly)
Attribute for field cv
1927 1928 1929 |
# File 'lib/stripe/resources/tax/registration.rb', line 1927 def cv @cv end |
#cy ⇒ Object (readonly)
Attribute for field cy
1929 1930 1931 |
# File 'lib/stripe/resources/tax/registration.rb', line 1929 def cy @cy end |
#cz ⇒ Object (readonly)
Attribute for field cz
1931 1932 1933 |
# File 'lib/stripe/resources/tax/registration.rb', line 1931 def cz @cz end |
#de ⇒ Object (readonly)
Attribute for field de
1933 1934 1935 |
# File 'lib/stripe/resources/tax/registration.rb', line 1933 def de @de end |
#dk ⇒ Object (readonly)
Attribute for field dk
1935 1936 1937 |
# File 'lib/stripe/resources/tax/registration.rb', line 1935 def dk @dk end |
#ec ⇒ Object (readonly)
Attribute for field ec
1937 1938 1939 |
# File 'lib/stripe/resources/tax/registration.rb', line 1937 def ec @ec end |
#ee ⇒ Object (readonly)
Attribute for field ee
1939 1940 1941 |
# File 'lib/stripe/resources/tax/registration.rb', line 1939 def ee @ee end |
#eg ⇒ Object (readonly)
Attribute for field eg
1941 1942 1943 |
# File 'lib/stripe/resources/tax/registration.rb', line 1941 def eg @eg end |
#es ⇒ Object (readonly)
Attribute for field es
1943 1944 1945 |
# File 'lib/stripe/resources/tax/registration.rb', line 1943 def es @es end |
#et ⇒ Object (readonly)
Attribute for field et
1945 1946 1947 |
# File 'lib/stripe/resources/tax/registration.rb', line 1945 def et @et end |
#fi ⇒ Object (readonly)
Attribute for field fi
1947 1948 1949 |
# File 'lib/stripe/resources/tax/registration.rb', line 1947 def fi @fi end |
#fr ⇒ Object (readonly)
Attribute for field fr
1949 1950 1951 |
# File 'lib/stripe/resources/tax/registration.rb', line 1949 def fr @fr end |
#gb ⇒ Object (readonly)
Attribute for field gb
1951 1952 1953 |
# File 'lib/stripe/resources/tax/registration.rb', line 1951 def gb @gb end |
#ge ⇒ Object (readonly)
Attribute for field ge
1953 1954 1955 |
# File 'lib/stripe/resources/tax/registration.rb', line 1953 def ge @ge end |
#gn ⇒ Object (readonly)
Attribute for field gn
1955 1956 1957 |
# File 'lib/stripe/resources/tax/registration.rb', line 1955 def gn @gn end |
#gr ⇒ Object (readonly)
Attribute for field gr
1957 1958 1959 |
# File 'lib/stripe/resources/tax/registration.rb', line 1957 def gr @gr end |
#hr ⇒ Object (readonly)
Attribute for field hr
1959 1960 1961 |
# File 'lib/stripe/resources/tax/registration.rb', line 1959 def hr @hr end |
#hu ⇒ Object (readonly)
Attribute for field hu
1961 1962 1963 |
# File 'lib/stripe/resources/tax/registration.rb', line 1961 def hu @hu end |
#id ⇒ Object (readonly)
Attribute for field id
1963 1964 1965 |
# File 'lib/stripe/resources/tax/registration.rb', line 1963 def id @id end |
#ie ⇒ Object (readonly)
Attribute for field ie
1965 1966 1967 |
# File 'lib/stripe/resources/tax/registration.rb', line 1965 def ie @ie end |
#in ⇒ Object (readonly)
Attribute for field in
1967 1968 1969 |
# File 'lib/stripe/resources/tax/registration.rb', line 1967 def in @in end |
#is ⇒ Object (readonly)
Attribute for field is
1969 1970 1971 |
# File 'lib/stripe/resources/tax/registration.rb', line 1969 def is @is end |
#it ⇒ Object (readonly)
Attribute for field it
1971 1972 1973 |
# File 'lib/stripe/resources/tax/registration.rb', line 1971 def it @it end |
#jp ⇒ Object (readonly)
Attribute for field jp
1973 1974 1975 |
# File 'lib/stripe/resources/tax/registration.rb', line 1973 def jp @jp end |
#ke ⇒ Object (readonly)
Attribute for field ke
1975 1976 1977 |
# File 'lib/stripe/resources/tax/registration.rb', line 1975 def ke @ke end |
#kg ⇒ Object (readonly)
Attribute for field kg
1977 1978 1979 |
# File 'lib/stripe/resources/tax/registration.rb', line 1977 def kg @kg end |
#kh ⇒ Object (readonly)
Attribute for field kh
1979 1980 1981 |
# File 'lib/stripe/resources/tax/registration.rb', line 1979 def kh @kh end |
#kr ⇒ Object (readonly)
Attribute for field kr
1981 1982 1983 |
# File 'lib/stripe/resources/tax/registration.rb', line 1981 def kr @kr end |
#kz ⇒ Object (readonly)
Attribute for field kz
1983 1984 1985 |
# File 'lib/stripe/resources/tax/registration.rb', line 1983 def kz @kz end |
#la ⇒ Object (readonly)
Attribute for field la
1985 1986 1987 |
# File 'lib/stripe/resources/tax/registration.rb', line 1985 def la @la end |
#lt ⇒ Object (readonly)
Attribute for field lt
1987 1988 1989 |
# File 'lib/stripe/resources/tax/registration.rb', line 1987 def lt @lt end |
#lu ⇒ Object (readonly)
Attribute for field lu
1989 1990 1991 |
# File 'lib/stripe/resources/tax/registration.rb', line 1989 def lu @lu end |
#lv ⇒ Object (readonly)
Attribute for field lv
1991 1992 1993 |
# File 'lib/stripe/resources/tax/registration.rb', line 1991 def lv @lv end |
#ma ⇒ Object (readonly)
Attribute for field ma
1993 1994 1995 |
# File 'lib/stripe/resources/tax/registration.rb', line 1993 def ma @ma end |
#md ⇒ Object (readonly)
Attribute for field md
1995 1996 1997 |
# File 'lib/stripe/resources/tax/registration.rb', line 1995 def md @md end |
#me ⇒ Object (readonly)
Attribute for field me
1997 1998 1999 |
# File 'lib/stripe/resources/tax/registration.rb', line 1997 def me @me end |
#mk ⇒ Object (readonly)
Attribute for field mk
1999 2000 2001 |
# File 'lib/stripe/resources/tax/registration.rb', line 1999 def mk @mk end |
#mr ⇒ Object (readonly)
Attribute for field mr
2001 2002 2003 |
# File 'lib/stripe/resources/tax/registration.rb', line 2001 def mr @mr end |
#mt ⇒ Object (readonly)
Attribute for field mt
2003 2004 2005 |
# File 'lib/stripe/resources/tax/registration.rb', line 2003 def mt @mt end |
#mx ⇒ Object (readonly)
Attribute for field mx
2005 2006 2007 |
# File 'lib/stripe/resources/tax/registration.rb', line 2005 def mx @mx end |
#my ⇒ Object (readonly)
Attribute for field my
2007 2008 2009 |
# File 'lib/stripe/resources/tax/registration.rb', line 2007 def my @my end |
#ng ⇒ Object (readonly)
Attribute for field ng
2009 2010 2011 |
# File 'lib/stripe/resources/tax/registration.rb', line 2009 def ng @ng end |
#nl ⇒ Object (readonly)
Attribute for field nl
2011 2012 2013 |
# File 'lib/stripe/resources/tax/registration.rb', line 2011 def nl @nl end |
#no ⇒ Object (readonly)
Attribute for field no
2013 2014 2015 |
# File 'lib/stripe/resources/tax/registration.rb', line 2013 def no @no end |
#np ⇒ Object (readonly)
Attribute for field np
2015 2016 2017 |
# File 'lib/stripe/resources/tax/registration.rb', line 2015 def np @np end |
#nz ⇒ Object (readonly)
Attribute for field nz
2017 2018 2019 |
# File 'lib/stripe/resources/tax/registration.rb', line 2017 def nz @nz end |
#om ⇒ Object (readonly)
Attribute for field om
2019 2020 2021 |
# File 'lib/stripe/resources/tax/registration.rb', line 2019 def om @om end |
#pe ⇒ Object (readonly)
Attribute for field pe
2021 2022 2023 |
# File 'lib/stripe/resources/tax/registration.rb', line 2021 def pe @pe end |
#ph ⇒ Object (readonly)
Attribute for field ph
2023 2024 2025 |
# File 'lib/stripe/resources/tax/registration.rb', line 2023 def ph @ph end |
#pl ⇒ Object (readonly)
Attribute for field pl
2025 2026 2027 |
# File 'lib/stripe/resources/tax/registration.rb', line 2025 def pl @pl end |
#pt ⇒ Object (readonly)
Attribute for field pt
2027 2028 2029 |
# File 'lib/stripe/resources/tax/registration.rb', line 2027 def pt @pt end |
#ro ⇒ Object (readonly)
Attribute for field ro
2029 2030 2031 |
# File 'lib/stripe/resources/tax/registration.rb', line 2029 def ro @ro end |
#rs ⇒ Object (readonly)
Attribute for field rs
2031 2032 2033 |
# File 'lib/stripe/resources/tax/registration.rb', line 2031 def rs @rs end |
#ru ⇒ Object (readonly)
Attribute for field ru
2033 2034 2035 |
# File 'lib/stripe/resources/tax/registration.rb', line 2033 def ru @ru end |
#sa ⇒ Object (readonly)
Attribute for field sa
2035 2036 2037 |
# File 'lib/stripe/resources/tax/registration.rb', line 2035 def sa @sa end |
#se ⇒ Object (readonly)
Attribute for field se
2037 2038 2039 |
# File 'lib/stripe/resources/tax/registration.rb', line 2037 def se @se end |
#sg ⇒ Object (readonly)
Attribute for field sg
2039 2040 2041 |
# File 'lib/stripe/resources/tax/registration.rb', line 2039 def sg @sg end |
#si ⇒ Object (readonly)
Attribute for field si
2041 2042 2043 |
# File 'lib/stripe/resources/tax/registration.rb', line 2041 def si @si end |
#sk ⇒ Object (readonly)
Attribute for field sk
2043 2044 2045 |
# File 'lib/stripe/resources/tax/registration.rb', line 2043 def sk @sk end |
#sn ⇒ Object (readonly)
Attribute for field sn
2045 2046 2047 |
# File 'lib/stripe/resources/tax/registration.rb', line 2045 def sn @sn end |
#sr ⇒ Object (readonly)
Attribute for field sr
2047 2048 2049 |
# File 'lib/stripe/resources/tax/registration.rb', line 2047 def sr @sr end |
#th ⇒ Object (readonly)
Attribute for field th
2049 2050 2051 |
# File 'lib/stripe/resources/tax/registration.rb', line 2049 def th @th end |
#tj ⇒ Object (readonly)
Attribute for field tj
2051 2052 2053 |
# File 'lib/stripe/resources/tax/registration.rb', line 2051 def tj @tj end |
#tr ⇒ Object (readonly)
Attribute for field tr
2053 2054 2055 |
# File 'lib/stripe/resources/tax/registration.rb', line 2053 def tr @tr end |
#tz ⇒ Object (readonly)
Attribute for field tz
2055 2056 2057 |
# File 'lib/stripe/resources/tax/registration.rb', line 2055 def tz @tz end |
#ua ⇒ Object (readonly)
Attribute for field ua
2057 2058 2059 |
# File 'lib/stripe/resources/tax/registration.rb', line 2057 def ua @ua end |
#ug ⇒ Object (readonly)
Attribute for field ug
2059 2060 2061 |
# File 'lib/stripe/resources/tax/registration.rb', line 2059 def ug @ug end |
#us ⇒ Object (readonly)
Attribute for field us
2061 2062 2063 |
# File 'lib/stripe/resources/tax/registration.rb', line 2061 def us @us end |
#uy ⇒ Object (readonly)
Attribute for field uy
2063 2064 2065 |
# File 'lib/stripe/resources/tax/registration.rb', line 2063 def uy @uy end |
#uz ⇒ Object (readonly)
Attribute for field uz
2065 2066 2067 |
# File 'lib/stripe/resources/tax/registration.rb', line 2065 def uz @uz end |
#vn ⇒ Object (readonly)
Attribute for field vn
2067 2068 2069 |
# File 'lib/stripe/resources/tax/registration.rb', line 2067 def vn @vn end |
#za ⇒ Object (readonly)
Attribute for field za
2069 2070 2071 |
# File 'lib/stripe/resources/tax/registration.rb', line 2069 def za @za end |
#zm ⇒ Object (readonly)
Attribute for field zm
2071 2072 2073 |
# File 'lib/stripe/resources/tax/registration.rb', line 2071 def zm @zm end |
#zw ⇒ Object (readonly)
Attribute for field zw
2073 2074 2075 |
# File 'lib/stripe/resources/tax/registration.rb', line 2073 def zw @zw end |
Class Method Details
.field_remappings ⇒ Object
2179 2180 2181 |
# File 'lib/stripe/resources/tax/registration.rb', line 2179 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 |
# File 'lib/stripe/resources/tax/registration.rb', line 2075 def self.inner_class_types @inner_class_types = { ae: Ae, al: Al, am: Am, ao: Ao, at: At, au: Au, aw: Aw, az: Az, ba: Ba, bb: Bb, bd: Bd, be: Be, bf: Bf, bg: Bg, bh: Bh, bj: Bj, bs: Bs, by: By, ca: Ca, cd: Cd, ch: Ch, cl: Cl, cm: Cm, co: Co, cr: Cr, cv: Cv, cy: Cy, cz: Cz, de: De, dk: Dk, ec: Ec, ee: Ee, eg: Eg, es: Es, et: Et, fi: Fi, fr: Fr, gb: Gb, ge: Ge, gn: Gn, gr: Gr, hr: Hr, hu: Hu, id: Id, ie: Ie, in: In, is: Is, it: It, jp: Jp, ke: Ke, kg: Kg, kh: Kh, kr: Kr, kz: Kz, la: La, lt: Lt, lu: Lu, lv: Lv, ma: Ma, md: Md, me: Me, mk: Mk, mr: Mr, mt: Mt, mx: Mx, my: My, ng: Ng, nl: Nl, no: No, np: Np, nz: Nz, om: Om, pe: Pe, ph: Ph, pl: Pl, pt: Pt, ro: Ro, rs: Rs, ru: Ru, sa: Sa, se: Se, sg: Sg, si: Si, sk: Sk, sn: Sn, sr: Sr, th: Th, tj: Tj, tr: Tr, tz: Tz, ua: Ua, ug: Ug, us: Us, uy: Uy, uz: Uz, vn: Vn, za: Za, zm: Zm, zw: Zw, } end |