Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Attribute for field ae.
-
#al ⇒ Object
readonly
Attribute for field al.
-
#am ⇒ Object
readonly
Attribute for field am.
-
#ao ⇒ Object
readonly
Attribute for field ao.
-
#at ⇒ Object
readonly
Attribute for field at.
-
#au ⇒ Object
readonly
Attribute for field au.
-
#aw ⇒ Object
readonly
Attribute for field aw.
-
#az ⇒ Object
readonly
Attribute for field az.
-
#ba ⇒ Object
readonly
Attribute for field ba.
-
#bb ⇒ Object
readonly
Attribute for field bb.
-
#bd ⇒ Object
readonly
Attribute for field bd.
-
#be ⇒ Object
readonly
Attribute for field be.
-
#bf ⇒ Object
readonly
Attribute for field bf.
-
#bg ⇒ Object
readonly
Attribute for field bg.
-
#bh ⇒ Object
readonly
Attribute for field bh.
-
#bj ⇒ Object
readonly
Attribute for field bj.
-
#bs ⇒ Object
readonly
Attribute for field bs.
-
#by ⇒ Object
readonly
Attribute for field by.
-
#ca ⇒ Object
readonly
Attribute for field ca.
-
#cd ⇒ Object
readonly
Attribute for field cd.
-
#ch ⇒ Object
readonly
Attribute for field ch.
-
#cl ⇒ Object
readonly
Attribute for field cl.
-
#cm ⇒ Object
readonly
Attribute for field cm.
-
#co ⇒ Object
readonly
Attribute for field co.
-
#cr ⇒ Object
readonly
Attribute for field cr.
-
#cv ⇒ Object
readonly
Attribute for field cv.
-
#cy ⇒ Object
readonly
Attribute for field cy.
-
#cz ⇒ Object
readonly
Attribute for field cz.
-
#de ⇒ Object
readonly
Attribute for field de.
-
#dk ⇒ Object
readonly
Attribute for field dk.
-
#ec ⇒ Object
readonly
Attribute for field ec.
-
#ee ⇒ Object
readonly
Attribute for field ee.
-
#eg ⇒ Object
readonly
Attribute for field eg.
-
#es ⇒ Object
readonly
Attribute for field es.
-
#et ⇒ Object
readonly
Attribute for field et.
-
#fi ⇒ Object
readonly
Attribute for field fi.
-
#fr ⇒ Object
readonly
Attribute for field fr.
-
#gb ⇒ Object
readonly
Attribute for field gb.
-
#ge ⇒ Object
readonly
Attribute for field ge.
-
#gn ⇒ Object
readonly
Attribute for field gn.
-
#gr ⇒ Object
readonly
Attribute for field gr.
-
#hr ⇒ Object
readonly
Attribute for field hr.
-
#hu ⇒ Object
readonly
Attribute for field hu.
-
#id ⇒ Object
readonly
Attribute for field id.
-
#ie ⇒ Object
readonly
Attribute for field ie.
-
#in ⇒ Object
readonly
Attribute for field in.
-
#is ⇒ Object
readonly
Attribute for field is.
-
#it ⇒ Object
readonly
Attribute for field it.
-
#jp ⇒ Object
readonly
Attribute for field jp.
-
#ke ⇒ Object
readonly
Attribute for field ke.
-
#kg ⇒ Object
readonly
Attribute for field kg.
-
#kh ⇒ Object
readonly
Attribute for field kh.
-
#kr ⇒ Object
readonly
Attribute for field kr.
-
#kz ⇒ Object
readonly
Attribute for field kz.
-
#la ⇒ Object
readonly
Attribute for field la.
-
#lt ⇒ Object
readonly
Attribute for field lt.
-
#lu ⇒ Object
readonly
Attribute for field lu.
-
#lv ⇒ Object
readonly
Attribute for field lv.
-
#ma ⇒ Object
readonly
Attribute for field ma.
-
#md ⇒ Object
readonly
Attribute for field md.
-
#me ⇒ Object
readonly
Attribute for field me.
-
#mk ⇒ Object
readonly
Attribute for field mk.
-
#mr ⇒ Object
readonly
Attribute for field mr.
-
#mt ⇒ Object
readonly
Attribute for field mt.
-
#mx ⇒ Object
readonly
Attribute for field mx.
-
#my ⇒ Object
readonly
Attribute for field my.
-
#ng ⇒ Object
readonly
Attribute for field ng.
-
#nl ⇒ Object
readonly
Attribute for field nl.
-
#no ⇒ Object
readonly
Attribute for field no.
-
#np ⇒ Object
readonly
Attribute for field np.
-
#nz ⇒ Object
readonly
Attribute for field nz.
-
#om ⇒ Object
readonly
Attribute for field om.
-
#pe ⇒ Object
readonly
Attribute for field pe.
-
#ph ⇒ Object
readonly
Attribute for field ph.
-
#pl ⇒ Object
readonly
Attribute for field pl.
-
#pt ⇒ Object
readonly
Attribute for field pt.
-
#ro ⇒ Object
readonly
Attribute for field ro.
-
#rs ⇒ Object
readonly
Attribute for field rs.
-
#ru ⇒ Object
readonly
Attribute for field ru.
-
#sa ⇒ Object
readonly
Attribute for field sa.
-
#se ⇒ Object
readonly
Attribute for field se.
-
#sg ⇒ Object
readonly
Attribute for field sg.
-
#si ⇒ Object
readonly
Attribute for field si.
-
#sk ⇒ Object
readonly
Attribute for field sk.
-
#sn ⇒ Object
readonly
Attribute for field sn.
-
#sr ⇒ Object
readonly
Attribute for field sr.
-
#th ⇒ Object
readonly
Attribute for field th.
-
#tj ⇒ Object
readonly
Attribute for field tj.
-
#tr ⇒ Object
readonly
Attribute for field tr.
-
#tz ⇒ Object
readonly
Attribute for field tz.
-
#ua ⇒ Object
readonly
Attribute for field ua.
-
#ug ⇒ Object
readonly
Attribute for field ug.
-
#us ⇒ Object
readonly
Attribute for field us.
-
#uy ⇒ Object
readonly
Attribute for field uy.
-
#uz ⇒ Object
readonly
Attribute for field uz.
-
#vn ⇒ Object
readonly
Attribute for field vn.
-
#za ⇒ Object
readonly
Attribute for field za.
-
#zm ⇒ Object
readonly
Attribute for field zm.
-
#zw ⇒ Object
readonly
Attribute for field zw.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Attribute for field ae
761 762 763 |
# File 'lib/stripe/resources/tax/registration.rb', line 761 def ae @ae end |
#al ⇒ Object (readonly)
Attribute for field al
763 764 765 |
# File 'lib/stripe/resources/tax/registration.rb', line 763 def al @al end |
#am ⇒ Object (readonly)
Attribute for field am
765 766 767 |
# File 'lib/stripe/resources/tax/registration.rb', line 765 def am @am end |
#ao ⇒ Object (readonly)
Attribute for field ao
767 768 769 |
# File 'lib/stripe/resources/tax/registration.rb', line 767 def ao @ao end |
#at ⇒ Object (readonly)
Attribute for field at
769 770 771 |
# File 'lib/stripe/resources/tax/registration.rb', line 769 def at @at end |
#au ⇒ Object (readonly)
Attribute for field au
771 772 773 |
# File 'lib/stripe/resources/tax/registration.rb', line 771 def au @au end |
#aw ⇒ Object (readonly)
Attribute for field aw
773 774 775 |
# File 'lib/stripe/resources/tax/registration.rb', line 773 def aw @aw end |
#az ⇒ Object (readonly)
Attribute for field az
775 776 777 |
# File 'lib/stripe/resources/tax/registration.rb', line 775 def az @az end |
#ba ⇒ Object (readonly)
Attribute for field ba
777 778 779 |
# File 'lib/stripe/resources/tax/registration.rb', line 777 def ba @ba end |
#bb ⇒ Object (readonly)
Attribute for field bb
779 780 781 |
# File 'lib/stripe/resources/tax/registration.rb', line 779 def bb @bb end |
#bd ⇒ Object (readonly)
Attribute for field bd
781 782 783 |
# File 'lib/stripe/resources/tax/registration.rb', line 781 def bd @bd end |
#be ⇒ Object (readonly)
Attribute for field be
783 784 785 |
# File 'lib/stripe/resources/tax/registration.rb', line 783 def be @be end |
#bf ⇒ Object (readonly)
Attribute for field bf
785 786 787 |
# File 'lib/stripe/resources/tax/registration.rb', line 785 def bf @bf end |
#bg ⇒ Object (readonly)
Attribute for field bg
787 788 789 |
# File 'lib/stripe/resources/tax/registration.rb', line 787 def bg @bg end |
#bh ⇒ Object (readonly)
Attribute for field bh
789 790 791 |
# File 'lib/stripe/resources/tax/registration.rb', line 789 def bh @bh end |
#bj ⇒ Object (readonly)
Attribute for field bj
791 792 793 |
# File 'lib/stripe/resources/tax/registration.rb', line 791 def bj @bj end |
#bs ⇒ Object (readonly)
Attribute for field bs
793 794 795 |
# File 'lib/stripe/resources/tax/registration.rb', line 793 def bs @bs end |
#by ⇒ Object (readonly)
Attribute for field by
795 796 797 |
# File 'lib/stripe/resources/tax/registration.rb', line 795 def by @by end |
#ca ⇒ Object (readonly)
Attribute for field ca
797 798 799 |
# File 'lib/stripe/resources/tax/registration.rb', line 797 def ca @ca end |
#cd ⇒ Object (readonly)
Attribute for field cd
799 800 801 |
# File 'lib/stripe/resources/tax/registration.rb', line 799 def cd @cd end |
#ch ⇒ Object (readonly)
Attribute for field ch
801 802 803 |
# File 'lib/stripe/resources/tax/registration.rb', line 801 def ch @ch end |
#cl ⇒ Object (readonly)
Attribute for field cl
803 804 805 |
# File 'lib/stripe/resources/tax/registration.rb', line 803 def cl @cl end |
#cm ⇒ Object (readonly)
Attribute for field cm
805 806 807 |
# File 'lib/stripe/resources/tax/registration.rb', line 805 def cm @cm end |
#co ⇒ Object (readonly)
Attribute for field co
807 808 809 |
# File 'lib/stripe/resources/tax/registration.rb', line 807 def co @co end |
#cr ⇒ Object (readonly)
Attribute for field cr
809 810 811 |
# File 'lib/stripe/resources/tax/registration.rb', line 809 def cr @cr end |
#cv ⇒ Object (readonly)
Attribute for field cv
811 812 813 |
# File 'lib/stripe/resources/tax/registration.rb', line 811 def cv @cv end |
#cy ⇒ Object (readonly)
Attribute for field cy
813 814 815 |
# File 'lib/stripe/resources/tax/registration.rb', line 813 def cy @cy end |
#cz ⇒ Object (readonly)
Attribute for field cz
815 816 817 |
# File 'lib/stripe/resources/tax/registration.rb', line 815 def cz @cz end |
#de ⇒ Object (readonly)
Attribute for field de
817 818 819 |
# File 'lib/stripe/resources/tax/registration.rb', line 817 def de @de end |
#dk ⇒ Object (readonly)
Attribute for field dk
819 820 821 |
# File 'lib/stripe/resources/tax/registration.rb', line 819 def dk @dk end |
#ec ⇒ Object (readonly)
Attribute for field ec
821 822 823 |
# File 'lib/stripe/resources/tax/registration.rb', line 821 def ec @ec end |
#ee ⇒ Object (readonly)
Attribute for field ee
823 824 825 |
# File 'lib/stripe/resources/tax/registration.rb', line 823 def ee @ee end |
#eg ⇒ Object (readonly)
Attribute for field eg
825 826 827 |
# File 'lib/stripe/resources/tax/registration.rb', line 825 def eg @eg end |
#es ⇒ Object (readonly)
Attribute for field es
827 828 829 |
# File 'lib/stripe/resources/tax/registration.rb', line 827 def es @es end |
#et ⇒ Object (readonly)
Attribute for field et
829 830 831 |
# File 'lib/stripe/resources/tax/registration.rb', line 829 def et @et end |
#fi ⇒ Object (readonly)
Attribute for field fi
831 832 833 |
# File 'lib/stripe/resources/tax/registration.rb', line 831 def fi @fi end |
#fr ⇒ Object (readonly)
Attribute for field fr
833 834 835 |
# File 'lib/stripe/resources/tax/registration.rb', line 833 def fr @fr end |
#gb ⇒ Object (readonly)
Attribute for field gb
835 836 837 |
# File 'lib/stripe/resources/tax/registration.rb', line 835 def gb @gb end |
#ge ⇒ Object (readonly)
Attribute for field ge
837 838 839 |
# File 'lib/stripe/resources/tax/registration.rb', line 837 def ge @ge end |
#gn ⇒ Object (readonly)
Attribute for field gn
839 840 841 |
# File 'lib/stripe/resources/tax/registration.rb', line 839 def gn @gn end |
#gr ⇒ Object (readonly)
Attribute for field gr
841 842 843 |
# File 'lib/stripe/resources/tax/registration.rb', line 841 def gr @gr end |
#hr ⇒ Object (readonly)
Attribute for field hr
843 844 845 |
# File 'lib/stripe/resources/tax/registration.rb', line 843 def hr @hr end |
#hu ⇒ Object (readonly)
Attribute for field hu
845 846 847 |
# File 'lib/stripe/resources/tax/registration.rb', line 845 def hu @hu end |
#id ⇒ Object (readonly)
Attribute for field id
847 848 849 |
# File 'lib/stripe/resources/tax/registration.rb', line 847 def id @id end |
#ie ⇒ Object (readonly)
Attribute for field ie
849 850 851 |
# File 'lib/stripe/resources/tax/registration.rb', line 849 def ie @ie end |
#in ⇒ Object (readonly)
Attribute for field in
851 852 853 |
# File 'lib/stripe/resources/tax/registration.rb', line 851 def in @in end |
#is ⇒ Object (readonly)
Attribute for field is
853 854 855 |
# File 'lib/stripe/resources/tax/registration.rb', line 853 def is @is end |
#it ⇒ Object (readonly)
Attribute for field it
855 856 857 |
# File 'lib/stripe/resources/tax/registration.rb', line 855 def it @it end |
#jp ⇒ Object (readonly)
Attribute for field jp
857 858 859 |
# File 'lib/stripe/resources/tax/registration.rb', line 857 def jp @jp end |
#ke ⇒ Object (readonly)
Attribute for field ke
859 860 861 |
# File 'lib/stripe/resources/tax/registration.rb', line 859 def ke @ke end |
#kg ⇒ Object (readonly)
Attribute for field kg
861 862 863 |
# File 'lib/stripe/resources/tax/registration.rb', line 861 def kg @kg end |
#kh ⇒ Object (readonly)
Attribute for field kh
863 864 865 |
# File 'lib/stripe/resources/tax/registration.rb', line 863 def kh @kh end |
#kr ⇒ Object (readonly)
Attribute for field kr
865 866 867 |
# File 'lib/stripe/resources/tax/registration.rb', line 865 def kr @kr end |
#kz ⇒ Object (readonly)
Attribute for field kz
867 868 869 |
# File 'lib/stripe/resources/tax/registration.rb', line 867 def kz @kz end |
#la ⇒ Object (readonly)
Attribute for field la
869 870 871 |
# File 'lib/stripe/resources/tax/registration.rb', line 869 def la @la end |
#lt ⇒ Object (readonly)
Attribute for field lt
871 872 873 |
# File 'lib/stripe/resources/tax/registration.rb', line 871 def lt @lt end |
#lu ⇒ Object (readonly)
Attribute for field lu
873 874 875 |
# File 'lib/stripe/resources/tax/registration.rb', line 873 def lu @lu end |
#lv ⇒ Object (readonly)
Attribute for field lv
875 876 877 |
# File 'lib/stripe/resources/tax/registration.rb', line 875 def lv @lv end |
#ma ⇒ Object (readonly)
Attribute for field ma
877 878 879 |
# File 'lib/stripe/resources/tax/registration.rb', line 877 def ma @ma end |
#md ⇒ Object (readonly)
Attribute for field md
879 880 881 |
# File 'lib/stripe/resources/tax/registration.rb', line 879 def md @md end |
#me ⇒ Object (readonly)
Attribute for field me
881 882 883 |
# File 'lib/stripe/resources/tax/registration.rb', line 881 def me @me end |
#mk ⇒ Object (readonly)
Attribute for field mk
883 884 885 |
# File 'lib/stripe/resources/tax/registration.rb', line 883 def mk @mk end |
#mr ⇒ Object (readonly)
Attribute for field mr
885 886 887 |
# File 'lib/stripe/resources/tax/registration.rb', line 885 def mr @mr end |
#mt ⇒ Object (readonly)
Attribute for field mt
887 888 889 |
# File 'lib/stripe/resources/tax/registration.rb', line 887 def mt @mt end |
#mx ⇒ Object (readonly)
Attribute for field mx
889 890 891 |
# File 'lib/stripe/resources/tax/registration.rb', line 889 def mx @mx end |
#my ⇒ Object (readonly)
Attribute for field my
891 892 893 |
# File 'lib/stripe/resources/tax/registration.rb', line 891 def my @my end |
#ng ⇒ Object (readonly)
Attribute for field ng
893 894 895 |
# File 'lib/stripe/resources/tax/registration.rb', line 893 def ng @ng end |
#nl ⇒ Object (readonly)
Attribute for field nl
895 896 897 |
# File 'lib/stripe/resources/tax/registration.rb', line 895 def nl @nl end |
#no ⇒ Object (readonly)
Attribute for field no
897 898 899 |
# File 'lib/stripe/resources/tax/registration.rb', line 897 def no @no end |
#np ⇒ Object (readonly)
Attribute for field np
899 900 901 |
# File 'lib/stripe/resources/tax/registration.rb', line 899 def np @np end |
#nz ⇒ Object (readonly)
Attribute for field nz
901 902 903 |
# File 'lib/stripe/resources/tax/registration.rb', line 901 def nz @nz end |
#om ⇒ Object (readonly)
Attribute for field om
903 904 905 |
# File 'lib/stripe/resources/tax/registration.rb', line 903 def om @om end |
#pe ⇒ Object (readonly)
Attribute for field pe
905 906 907 |
# File 'lib/stripe/resources/tax/registration.rb', line 905 def pe @pe end |
#ph ⇒ Object (readonly)
Attribute for field ph
907 908 909 |
# File 'lib/stripe/resources/tax/registration.rb', line 907 def ph @ph end |
#pl ⇒ Object (readonly)
Attribute for field pl
909 910 911 |
# File 'lib/stripe/resources/tax/registration.rb', line 909 def pl @pl end |
#pt ⇒ Object (readonly)
Attribute for field pt
911 912 913 |
# File 'lib/stripe/resources/tax/registration.rb', line 911 def pt @pt end |
#ro ⇒ Object (readonly)
Attribute for field ro
913 914 915 |
# File 'lib/stripe/resources/tax/registration.rb', line 913 def ro @ro end |
#rs ⇒ Object (readonly)
Attribute for field rs
915 916 917 |
# File 'lib/stripe/resources/tax/registration.rb', line 915 def rs @rs end |
#ru ⇒ Object (readonly)
Attribute for field ru
917 918 919 |
# File 'lib/stripe/resources/tax/registration.rb', line 917 def ru @ru end |
#sa ⇒ Object (readonly)
Attribute for field sa
919 920 921 |
# File 'lib/stripe/resources/tax/registration.rb', line 919 def sa @sa end |
#se ⇒ Object (readonly)
Attribute for field se
921 922 923 |
# File 'lib/stripe/resources/tax/registration.rb', line 921 def se @se end |
#sg ⇒ Object (readonly)
Attribute for field sg
923 924 925 |
# File 'lib/stripe/resources/tax/registration.rb', line 923 def sg @sg end |
#si ⇒ Object (readonly)
Attribute for field si
925 926 927 |
# File 'lib/stripe/resources/tax/registration.rb', line 925 def si @si end |
#sk ⇒ Object (readonly)
Attribute for field sk
927 928 929 |
# File 'lib/stripe/resources/tax/registration.rb', line 927 def sk @sk end |
#sn ⇒ Object (readonly)
Attribute for field sn
929 930 931 |
# File 'lib/stripe/resources/tax/registration.rb', line 929 def sn @sn end |
#sr ⇒ Object (readonly)
Attribute for field sr
931 932 933 |
# File 'lib/stripe/resources/tax/registration.rb', line 931 def sr @sr end |
#th ⇒ Object (readonly)
Attribute for field th
933 934 935 |
# File 'lib/stripe/resources/tax/registration.rb', line 933 def th @th end |
#tj ⇒ Object (readonly)
Attribute for field tj
935 936 937 |
# File 'lib/stripe/resources/tax/registration.rb', line 935 def tj @tj end |
#tr ⇒ Object (readonly)
Attribute for field tr
937 938 939 |
# File 'lib/stripe/resources/tax/registration.rb', line 937 def tr @tr end |
#tz ⇒ Object (readonly)
Attribute for field tz
939 940 941 |
# File 'lib/stripe/resources/tax/registration.rb', line 939 def tz @tz end |
#ua ⇒ Object (readonly)
Attribute for field ua
941 942 943 |
# File 'lib/stripe/resources/tax/registration.rb', line 941 def ua @ua end |
#ug ⇒ Object (readonly)
Attribute for field ug
943 944 945 |
# File 'lib/stripe/resources/tax/registration.rb', line 943 def ug @ug end |
#us ⇒ Object (readonly)
Attribute for field us
945 946 947 |
# File 'lib/stripe/resources/tax/registration.rb', line 945 def us @us end |
#uy ⇒ Object (readonly)
Attribute for field uy
947 948 949 |
# File 'lib/stripe/resources/tax/registration.rb', line 947 def uy @uy end |
#uz ⇒ Object (readonly)
Attribute for field uz
949 950 951 |
# File 'lib/stripe/resources/tax/registration.rb', line 949 def uz @uz end |
#vn ⇒ Object (readonly)
Attribute for field vn
951 952 953 |
# File 'lib/stripe/resources/tax/registration.rb', line 951 def vn @vn end |
#za ⇒ Object (readonly)
Attribute for field za
953 954 955 |
# File 'lib/stripe/resources/tax/registration.rb', line 953 def za @za end |
#zm ⇒ Object (readonly)
Attribute for field zm
955 956 957 |
# File 'lib/stripe/resources/tax/registration.rb', line 955 def zm @zm end |
#zw ⇒ Object (readonly)
Attribute for field zw
957 958 959 |
# File 'lib/stripe/resources/tax/registration.rb', line 957 def zw @zw end |