Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



708
709
710
# File 'lib/stripe/resources/tax/registration.rb', line 708

def ae
  @ae
end

#alObject (readonly)

Attribute for field al



710
711
712
# File 'lib/stripe/resources/tax/registration.rb', line 710

def al
  @al
end

#amObject (readonly)

Attribute for field am



712
713
714
# File 'lib/stripe/resources/tax/registration.rb', line 712

def am
  @am
end

#aoObject (readonly)

Attribute for field ao



714
715
716
# File 'lib/stripe/resources/tax/registration.rb', line 714

def ao
  @ao
end

#atObject (readonly)

Attribute for field at



716
717
718
# File 'lib/stripe/resources/tax/registration.rb', line 716

def at
  @at
end

#auObject (readonly)

Attribute for field au



718
719
720
# File 'lib/stripe/resources/tax/registration.rb', line 718

def au
  @au
end

#awObject (readonly)

Attribute for field aw



720
721
722
# File 'lib/stripe/resources/tax/registration.rb', line 720

def aw
  @aw
end

#azObject (readonly)

Attribute for field az



722
723
724
# File 'lib/stripe/resources/tax/registration.rb', line 722

def az
  @az
end

#baObject (readonly)

Attribute for field ba



724
725
726
# File 'lib/stripe/resources/tax/registration.rb', line 724

def ba
  @ba
end

#bbObject (readonly)

Attribute for field bb



726
727
728
# File 'lib/stripe/resources/tax/registration.rb', line 726

def bb
  @bb
end

#bdObject (readonly)

Attribute for field bd



728
729
730
# File 'lib/stripe/resources/tax/registration.rb', line 728

def bd
  @bd
end

#beObject (readonly)

Attribute for field be



730
731
732
# File 'lib/stripe/resources/tax/registration.rb', line 730

def be
  @be
end

#bfObject (readonly)

Attribute for field bf



732
733
734
# File 'lib/stripe/resources/tax/registration.rb', line 732

def bf
  @bf
end

#bgObject (readonly)

Attribute for field bg



734
735
736
# File 'lib/stripe/resources/tax/registration.rb', line 734

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



736
737
738
# File 'lib/stripe/resources/tax/registration.rb', line 736

def bh
  @bh
end

#bjObject (readonly)

Attribute for field bj



738
739
740
# File 'lib/stripe/resources/tax/registration.rb', line 738

def bj
  @bj
end

#bsObject (readonly)

Attribute for field bs



740
741
742
# File 'lib/stripe/resources/tax/registration.rb', line 740

def bs
  @bs
end

#byObject (readonly)

Attribute for field by



742
743
744
# File 'lib/stripe/resources/tax/registration.rb', line 742

def by
  @by
end

#caObject (readonly)

Attribute for field ca



744
745
746
# File 'lib/stripe/resources/tax/registration.rb', line 744

def ca
  @ca
end

#cdObject (readonly)

Attribute for field cd



746
747
748
# File 'lib/stripe/resources/tax/registration.rb', line 746

def cd
  @cd
end

#chObject (readonly)

Attribute for field ch



748
749
750
# File 'lib/stripe/resources/tax/registration.rb', line 748

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



750
751
752
# File 'lib/stripe/resources/tax/registration.rb', line 750

def cl
  @cl
end

#cmObject (readonly)

Attribute for field cm



752
753
754
# File 'lib/stripe/resources/tax/registration.rb', line 752

def cm
  @cm
end

#coObject (readonly)

Attribute for field co



754
755
756
# File 'lib/stripe/resources/tax/registration.rb', line 754

def co
  @co
end

#crObject (readonly)

Attribute for field cr



756
757
758
# File 'lib/stripe/resources/tax/registration.rb', line 756

def cr
  @cr
end

#cvObject (readonly)

Attribute for field cv



758
759
760
# File 'lib/stripe/resources/tax/registration.rb', line 758

def cv
  @cv
end

#cyObject (readonly)

Attribute for field cy



760
761
762
# File 'lib/stripe/resources/tax/registration.rb', line 760

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



762
763
764
# File 'lib/stripe/resources/tax/registration.rb', line 762

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



764
765
766
# File 'lib/stripe/resources/tax/registration.rb', line 764

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



766
767
768
# File 'lib/stripe/resources/tax/registration.rb', line 766

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



768
769
770
# File 'lib/stripe/resources/tax/registration.rb', line 768

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



770
771
772
# File 'lib/stripe/resources/tax/registration.rb', line 770

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



772
773
774
# File 'lib/stripe/resources/tax/registration.rb', line 772

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



774
775
776
# File 'lib/stripe/resources/tax/registration.rb', line 774

def es
  @es
end

#etObject (readonly)

Attribute for field et



776
777
778
# File 'lib/stripe/resources/tax/registration.rb', line 776

def et
  @et
end

#fiObject (readonly)

Attribute for field fi



778
779
780
# File 'lib/stripe/resources/tax/registration.rb', line 778

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



780
781
782
# File 'lib/stripe/resources/tax/registration.rb', line 780

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



782
783
784
# File 'lib/stripe/resources/tax/registration.rb', line 782

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



784
785
786
# File 'lib/stripe/resources/tax/registration.rb', line 784

def ge
  @ge
end

#gnObject (readonly)

Attribute for field gn



786
787
788
# File 'lib/stripe/resources/tax/registration.rb', line 786

def gn
  @gn
end

#grObject (readonly)

Attribute for field gr



788
789
790
# File 'lib/stripe/resources/tax/registration.rb', line 788

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



790
791
792
# File 'lib/stripe/resources/tax/registration.rb', line 790

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



792
793
794
# File 'lib/stripe/resources/tax/registration.rb', line 792

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



794
795
796
# File 'lib/stripe/resources/tax/registration.rb', line 794

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



796
797
798
# File 'lib/stripe/resources/tax/registration.rb', line 796

def ie
  @ie
end

#inObject (readonly)

Attribute for field in



798
799
800
# File 'lib/stripe/resources/tax/registration.rb', line 798

def in
  @in
end

#isObject (readonly)

Attribute for field is



800
801
802
# File 'lib/stripe/resources/tax/registration.rb', line 800

def is
  @is
end

#itObject (readonly)

Attribute for field it



802
803
804
# File 'lib/stripe/resources/tax/registration.rb', line 802

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



804
805
806
# File 'lib/stripe/resources/tax/registration.rb', line 804

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



806
807
808
# File 'lib/stripe/resources/tax/registration.rb', line 806

def ke
  @ke
end

#kgObject (readonly)

Attribute for field kg



808
809
810
# File 'lib/stripe/resources/tax/registration.rb', line 808

def kg
  @kg
end

#khObject (readonly)

Attribute for field kh



810
811
812
# File 'lib/stripe/resources/tax/registration.rb', line 810

def kh
  @kh
end

#krObject (readonly)

Attribute for field kr



812
813
814
# File 'lib/stripe/resources/tax/registration.rb', line 812

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



814
815
816
# File 'lib/stripe/resources/tax/registration.rb', line 814

def kz
  @kz
end

#laObject (readonly)

Attribute for field la



816
817
818
# File 'lib/stripe/resources/tax/registration.rb', line 816

def la
  @la
end

#ltObject (readonly)

Attribute for field lt



818
819
820
# File 'lib/stripe/resources/tax/registration.rb', line 818

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



820
821
822
# File 'lib/stripe/resources/tax/registration.rb', line 820

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



822
823
824
# File 'lib/stripe/resources/tax/registration.rb', line 822

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



824
825
826
# File 'lib/stripe/resources/tax/registration.rb', line 824

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



826
827
828
# File 'lib/stripe/resources/tax/registration.rb', line 826

def md
  @md
end

#meObject (readonly)

Attribute for field me



828
829
830
# File 'lib/stripe/resources/tax/registration.rb', line 828

def me
  @me
end

#mkObject (readonly)

Attribute for field mk



830
831
832
# File 'lib/stripe/resources/tax/registration.rb', line 830

def mk
  @mk
end

#mrObject (readonly)

Attribute for field mr



832
833
834
# File 'lib/stripe/resources/tax/registration.rb', line 832

def mr
  @mr
end

#mtObject (readonly)

Attribute for field mt



834
835
836
# File 'lib/stripe/resources/tax/registration.rb', line 834

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



836
837
838
# File 'lib/stripe/resources/tax/registration.rb', line 836

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



838
839
840
# File 'lib/stripe/resources/tax/registration.rb', line 838

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



840
841
842
# File 'lib/stripe/resources/tax/registration.rb', line 840

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



842
843
844
# File 'lib/stripe/resources/tax/registration.rb', line 842

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



844
845
846
# File 'lib/stripe/resources/tax/registration.rb', line 844

def no
  @no
end

#npObject (readonly)

Attribute for field np



846
847
848
# File 'lib/stripe/resources/tax/registration.rb', line 846

def np
  @np
end

#nzObject (readonly)

Attribute for field nz



848
849
850
# File 'lib/stripe/resources/tax/registration.rb', line 848

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



850
851
852
# File 'lib/stripe/resources/tax/registration.rb', line 850

def om
  @om
end

#peObject (readonly)

Attribute for field pe



852
853
854
# File 'lib/stripe/resources/tax/registration.rb', line 852

def pe
  @pe
end

#phObject (readonly)

Attribute for field ph



854
855
856
# File 'lib/stripe/resources/tax/registration.rb', line 854

def ph
  @ph
end

#plObject (readonly)

Attribute for field pl



856
857
858
# File 'lib/stripe/resources/tax/registration.rb', line 856

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



858
859
860
# File 'lib/stripe/resources/tax/registration.rb', line 858

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



860
861
862
# File 'lib/stripe/resources/tax/registration.rb', line 860

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



862
863
864
# File 'lib/stripe/resources/tax/registration.rb', line 862

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



864
865
866
# File 'lib/stripe/resources/tax/registration.rb', line 864

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



866
867
868
# File 'lib/stripe/resources/tax/registration.rb', line 866

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



868
869
870
# File 'lib/stripe/resources/tax/registration.rb', line 868

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



870
871
872
# File 'lib/stripe/resources/tax/registration.rb', line 870

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



872
873
874
# File 'lib/stripe/resources/tax/registration.rb', line 872

def si
  @si
end

#skObject (readonly)

Attribute for field sk



874
875
876
# File 'lib/stripe/resources/tax/registration.rb', line 874

def sk
  @sk
end

#snObject (readonly)

Attribute for field sn



876
877
878
# File 'lib/stripe/resources/tax/registration.rb', line 876

def sn
  @sn
end

#srObject (readonly)

Attribute for field sr



878
879
880
# File 'lib/stripe/resources/tax/registration.rb', line 878

def sr
  @sr
end

#thObject (readonly)

Attribute for field th



880
881
882
# File 'lib/stripe/resources/tax/registration.rb', line 880

def th
  @th
end

#tjObject (readonly)

Attribute for field tj



882
883
884
# File 'lib/stripe/resources/tax/registration.rb', line 882

def tj
  @tj
end

#trObject (readonly)

Attribute for field tr



884
885
886
# File 'lib/stripe/resources/tax/registration.rb', line 884

def tr
  @tr
end

#tzObject (readonly)

Attribute for field tz



886
887
888
# File 'lib/stripe/resources/tax/registration.rb', line 886

def tz
  @tz
end

#ugObject (readonly)

Attribute for field ug



888
889
890
# File 'lib/stripe/resources/tax/registration.rb', line 888

def ug
  @ug
end

#usObject (readonly)

Attribute for field us



890
891
892
# File 'lib/stripe/resources/tax/registration.rb', line 890

def us
  @us
end

#uyObject (readonly)

Attribute for field uy



892
893
894
# File 'lib/stripe/resources/tax/registration.rb', line 892

def uy
  @uy
end

#uzObject (readonly)

Attribute for field uz



894
895
896
# File 'lib/stripe/resources/tax/registration.rb', line 894

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



896
897
898
# File 'lib/stripe/resources/tax/registration.rb', line 896

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



898
899
900
# File 'lib/stripe/resources/tax/registration.rb', line 898

def za
  @za
end

#zmObject (readonly)

Attribute for field zm



900
901
902
# File 'lib/stripe/resources/tax/registration.rb', line 900

def zm
  @zm
end

#zwObject (readonly)

Attribute for field zw



902
903
904
# File 'lib/stripe/resources/tax/registration.rb', line 902

def zw
  @zw
end