Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



693
694
695
# File 'lib/stripe/resources/tax/registration.rb', line 693

def ae
  @ae
end

#alObject (readonly)

Attribute for field al



695
696
697
# File 'lib/stripe/resources/tax/registration.rb', line 695

def al
  @al
end

#amObject (readonly)

Attribute for field am



697
698
699
# File 'lib/stripe/resources/tax/registration.rb', line 697

def am
  @am
end

#aoObject (readonly)

Attribute for field ao



699
700
701
# File 'lib/stripe/resources/tax/registration.rb', line 699

def ao
  @ao
end

#atObject (readonly)

Attribute for field at



701
702
703
# File 'lib/stripe/resources/tax/registration.rb', line 701

def at
  @at
end

#auObject (readonly)

Attribute for field au



703
704
705
# File 'lib/stripe/resources/tax/registration.rb', line 703

def au
  @au
end

#awObject (readonly)

Attribute for field aw



705
706
707
# File 'lib/stripe/resources/tax/registration.rb', line 705

def aw
  @aw
end

#azObject (readonly)

Attribute for field az



707
708
709
# File 'lib/stripe/resources/tax/registration.rb', line 707

def az
  @az
end

#baObject (readonly)

Attribute for field ba



709
710
711
# File 'lib/stripe/resources/tax/registration.rb', line 709

def ba
  @ba
end

#bbObject (readonly)

Attribute for field bb



711
712
713
# File 'lib/stripe/resources/tax/registration.rb', line 711

def bb
  @bb
end

#bdObject (readonly)

Attribute for field bd



713
714
715
# File 'lib/stripe/resources/tax/registration.rb', line 713

def bd
  @bd
end

#beObject (readonly)

Attribute for field be



715
716
717
# File 'lib/stripe/resources/tax/registration.rb', line 715

def be
  @be
end

#bgObject (readonly)

Attribute for field bg



717
718
719
# File 'lib/stripe/resources/tax/registration.rb', line 717

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



719
720
721
# File 'lib/stripe/resources/tax/registration.rb', line 719

def bh
  @bh
end

#bjObject (readonly)

Attribute for field bj



721
722
723
# File 'lib/stripe/resources/tax/registration.rb', line 721

def bj
  @bj
end

#bsObject (readonly)

Attribute for field bs



723
724
725
# File 'lib/stripe/resources/tax/registration.rb', line 723

def bs
  @bs
end

#byObject (readonly)

Attribute for field by



725
726
727
# File 'lib/stripe/resources/tax/registration.rb', line 725

def by
  @by
end

#caObject (readonly)

Attribute for field ca



727
728
729
# File 'lib/stripe/resources/tax/registration.rb', line 727

def ca
  @ca
end

#cdObject (readonly)

Attribute for field cd



729
730
731
# File 'lib/stripe/resources/tax/registration.rb', line 729

def cd
  @cd
end

#chObject (readonly)

Attribute for field ch



731
732
733
# File 'lib/stripe/resources/tax/registration.rb', line 731

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



733
734
735
# File 'lib/stripe/resources/tax/registration.rb', line 733

def cl
  @cl
end

#coObject (readonly)

Attribute for field co



735
736
737
# File 'lib/stripe/resources/tax/registration.rb', line 735

def co
  @co
end

#crObject (readonly)

Attribute for field cr



737
738
739
# File 'lib/stripe/resources/tax/registration.rb', line 737

def cr
  @cr
end

#cyObject (readonly)

Attribute for field cy



739
740
741
# File 'lib/stripe/resources/tax/registration.rb', line 739

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



741
742
743
# File 'lib/stripe/resources/tax/registration.rb', line 741

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



743
744
745
# File 'lib/stripe/resources/tax/registration.rb', line 743

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



745
746
747
# File 'lib/stripe/resources/tax/registration.rb', line 745

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



747
748
749
# File 'lib/stripe/resources/tax/registration.rb', line 747

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



749
750
751
# File 'lib/stripe/resources/tax/registration.rb', line 749

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



751
752
753
# File 'lib/stripe/resources/tax/registration.rb', line 751

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



753
754
755
# File 'lib/stripe/resources/tax/registration.rb', line 753

def es
  @es
end

#etObject (readonly)

Attribute for field et



755
756
757
# File 'lib/stripe/resources/tax/registration.rb', line 755

def et
  @et
end

#fiObject (readonly)

Attribute for field fi



757
758
759
# File 'lib/stripe/resources/tax/registration.rb', line 757

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



759
760
761
# File 'lib/stripe/resources/tax/registration.rb', line 759

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



761
762
763
# File 'lib/stripe/resources/tax/registration.rb', line 761

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



763
764
765
# File 'lib/stripe/resources/tax/registration.rb', line 763

def ge
  @ge
end

#gnObject (readonly)

Attribute for field gn



765
766
767
# File 'lib/stripe/resources/tax/registration.rb', line 765

def gn
  @gn
end

#grObject (readonly)

Attribute for field gr



767
768
769
# File 'lib/stripe/resources/tax/registration.rb', line 767

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



769
770
771
# File 'lib/stripe/resources/tax/registration.rb', line 769

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



771
772
773
# File 'lib/stripe/resources/tax/registration.rb', line 771

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



773
774
775
# File 'lib/stripe/resources/tax/registration.rb', line 773

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



775
776
777
# File 'lib/stripe/resources/tax/registration.rb', line 775

def ie
  @ie
end

#inObject (readonly)

Attribute for field in



777
778
779
# File 'lib/stripe/resources/tax/registration.rb', line 777

def in
  @in
end

#isObject (readonly)

Attribute for field is



779
780
781
# File 'lib/stripe/resources/tax/registration.rb', line 779

def is
  @is
end

#itObject (readonly)

Attribute for field it



781
782
783
# File 'lib/stripe/resources/tax/registration.rb', line 781

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



783
784
785
# File 'lib/stripe/resources/tax/registration.rb', line 783

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



785
786
787
# File 'lib/stripe/resources/tax/registration.rb', line 785

def ke
  @ke
end

#kgObject (readonly)

Attribute for field kg



787
788
789
# File 'lib/stripe/resources/tax/registration.rb', line 787

def kg
  @kg
end

#khObject (readonly)

Attribute for field kh



789
790
791
# File 'lib/stripe/resources/tax/registration.rb', line 789

def kh
  @kh
end

#krObject (readonly)

Attribute for field kr



791
792
793
# File 'lib/stripe/resources/tax/registration.rb', line 791

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



793
794
795
# File 'lib/stripe/resources/tax/registration.rb', line 793

def kz
  @kz
end

#laObject (readonly)

Attribute for field la



795
796
797
# File 'lib/stripe/resources/tax/registration.rb', line 795

def la
  @la
end

#ltObject (readonly)

Attribute for field lt



797
798
799
# File 'lib/stripe/resources/tax/registration.rb', line 797

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



799
800
801
# File 'lib/stripe/resources/tax/registration.rb', line 799

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



801
802
803
# File 'lib/stripe/resources/tax/registration.rb', line 801

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



803
804
805
# File 'lib/stripe/resources/tax/registration.rb', line 803

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



805
806
807
# File 'lib/stripe/resources/tax/registration.rb', line 805

def md
  @md
end

#meObject (readonly)

Attribute for field me



807
808
809
# File 'lib/stripe/resources/tax/registration.rb', line 807

def me
  @me
end

#mkObject (readonly)

Attribute for field mk



809
810
811
# File 'lib/stripe/resources/tax/registration.rb', line 809

def mk
  @mk
end

#mrObject (readonly)

Attribute for field mr



811
812
813
# File 'lib/stripe/resources/tax/registration.rb', line 811

def mr
  @mr
end

#mtObject (readonly)

Attribute for field mt



813
814
815
# File 'lib/stripe/resources/tax/registration.rb', line 813

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



815
816
817
# File 'lib/stripe/resources/tax/registration.rb', line 815

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



817
818
819
# File 'lib/stripe/resources/tax/registration.rb', line 817

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



819
820
821
# File 'lib/stripe/resources/tax/registration.rb', line 819

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



821
822
823
# File 'lib/stripe/resources/tax/registration.rb', line 821

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



823
824
825
# File 'lib/stripe/resources/tax/registration.rb', line 823

def no
  @no
end

#npObject (readonly)

Attribute for field np



825
826
827
# File 'lib/stripe/resources/tax/registration.rb', line 825

def np
  @np
end

#nzObject (readonly)

Attribute for field nz



827
828
829
# File 'lib/stripe/resources/tax/registration.rb', line 827

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



829
830
831
# File 'lib/stripe/resources/tax/registration.rb', line 829

def om
  @om
end

#peObject (readonly)

Attribute for field pe



831
832
833
# File 'lib/stripe/resources/tax/registration.rb', line 831

def pe
  @pe
end

#phObject (readonly)

Attribute for field ph



833
834
835
# File 'lib/stripe/resources/tax/registration.rb', line 833

def ph
  @ph
end

#plObject (readonly)

Attribute for field pl



835
836
837
# File 'lib/stripe/resources/tax/registration.rb', line 835

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



837
838
839
# File 'lib/stripe/resources/tax/registration.rb', line 837

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



839
840
841
# File 'lib/stripe/resources/tax/registration.rb', line 839

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



841
842
843
# File 'lib/stripe/resources/tax/registration.rb', line 841

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



843
844
845
# File 'lib/stripe/resources/tax/registration.rb', line 843

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



845
846
847
# File 'lib/stripe/resources/tax/registration.rb', line 845

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



847
848
849
# File 'lib/stripe/resources/tax/registration.rb', line 847

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



849
850
851
# File 'lib/stripe/resources/tax/registration.rb', line 849

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



851
852
853
# File 'lib/stripe/resources/tax/registration.rb', line 851

def si
  @si
end

#skObject (readonly)

Attribute for field sk



853
854
855
# File 'lib/stripe/resources/tax/registration.rb', line 853

def sk
  @sk
end

#snObject (readonly)

Attribute for field sn



855
856
857
# File 'lib/stripe/resources/tax/registration.rb', line 855

def sn
  @sn
end

#srObject (readonly)

Attribute for field sr



857
858
859
# File 'lib/stripe/resources/tax/registration.rb', line 857

def sr
  @sr
end

#thObject (readonly)

Attribute for field th



859
860
861
# File 'lib/stripe/resources/tax/registration.rb', line 859

def th
  @th
end

#tjObject (readonly)

Attribute for field tj



861
862
863
# File 'lib/stripe/resources/tax/registration.rb', line 861

def tj
  @tj
end

#trObject (readonly)

Attribute for field tr



863
864
865
# File 'lib/stripe/resources/tax/registration.rb', line 863

def tr
  @tr
end

#tzObject (readonly)

Attribute for field tz



865
866
867
# File 'lib/stripe/resources/tax/registration.rb', line 865

def tz
  @tz
end

#ugObject (readonly)

Attribute for field ug



867
868
869
# File 'lib/stripe/resources/tax/registration.rb', line 867

def ug
  @ug
end

#usObject (readonly)

Attribute for field us



869
870
871
# File 'lib/stripe/resources/tax/registration.rb', line 869

def us
  @us
end

#uyObject (readonly)

Attribute for field uy



871
872
873
# File 'lib/stripe/resources/tax/registration.rb', line 871

def uy
  @uy
end

#uzObject (readonly)

Attribute for field uz



873
874
875
# File 'lib/stripe/resources/tax/registration.rb', line 873

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



875
876
877
# File 'lib/stripe/resources/tax/registration.rb', line 875

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



877
878
879
# File 'lib/stripe/resources/tax/registration.rb', line 877

def za
  @za
end

#zmObject (readonly)

Attribute for field zm



879
880
881
# File 'lib/stripe/resources/tax/registration.rb', line 879

def zm
  @zm
end

#zwObject (readonly)

Attribute for field zw



881
882
883
# File 'lib/stripe/resources/tax/registration.rb', line 881

def zw
  @zw
end