Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Ba, Bb, Be, Bg, Bh, Bs, By, Ca, Cd, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kh, Kr, Kz, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Attribute for field ae.
-
#al ⇒ Object
readonly
Attribute for field al.
-
#am ⇒ Object
readonly
Attribute for field am.
-
#ao ⇒ Object
readonly
Attribute for field ao.
-
#at ⇒ Object
readonly
Attribute for field at.
-
#au ⇒ Object
readonly
Attribute for field au.
-
#ba ⇒ Object
readonly
Attribute for field ba.
-
#bb ⇒ Object
readonly
Attribute for field bb.
-
#be ⇒ Object
readonly
Attribute for field be.
-
#bg ⇒ Object
readonly
Attribute for field bg.
-
#bh ⇒ Object
readonly
Attribute for field bh.
-
#bs ⇒ Object
readonly
Attribute for field bs.
-
#by ⇒ Object
readonly
Attribute for field by.
-
#ca ⇒ Object
readonly
Attribute for field ca.
-
#cd ⇒ Object
readonly
Attribute for field cd.
-
#ch ⇒ Object
readonly
Attribute for field ch.
-
#cl ⇒ Object
readonly
Attribute for field cl.
-
#co ⇒ Object
readonly
Attribute for field co.
-
#cr ⇒ Object
readonly
Attribute for field cr.
-
#cy ⇒ Object
readonly
Attribute for field cy.
-
#cz ⇒ Object
readonly
Attribute for field cz.
-
#de ⇒ Object
readonly
Attribute for field de.
-
#dk ⇒ Object
readonly
Attribute for field dk.
-
#ec ⇒ Object
readonly
Attribute for field ec.
-
#ee ⇒ Object
readonly
Attribute for field ee.
-
#eg ⇒ Object
readonly
Attribute for field eg.
-
#es ⇒ Object
readonly
Attribute for field es.
-
#fi ⇒ Object
readonly
Attribute for field fi.
-
#fr ⇒ Object
readonly
Attribute for field fr.
-
#gb ⇒ Object
readonly
Attribute for field gb.
-
#ge ⇒ Object
readonly
Attribute for field ge.
-
#gn ⇒ Object
readonly
Attribute for field gn.
-
#gr ⇒ Object
readonly
Attribute for field gr.
-
#hr ⇒ Object
readonly
Attribute for field hr.
-
#hu ⇒ Object
readonly
Attribute for field hu.
-
#id ⇒ Object
readonly
Attribute for field id.
-
#ie ⇒ Object
readonly
Attribute for field ie.
-
#in ⇒ Object
readonly
Attribute for field in.
-
#is ⇒ Object
readonly
Attribute for field is.
-
#it ⇒ Object
readonly
Attribute for field it.
-
#jp ⇒ Object
readonly
Attribute for field jp.
-
#ke ⇒ Object
readonly
Attribute for field ke.
-
#kh ⇒ Object
readonly
Attribute for field kh.
-
#kr ⇒ Object
readonly
Attribute for field kr.
-
#kz ⇒ Object
readonly
Attribute for field kz.
-
#lt ⇒ Object
readonly
Attribute for field lt.
-
#lu ⇒ Object
readonly
Attribute for field lu.
-
#lv ⇒ Object
readonly
Attribute for field lv.
-
#ma ⇒ Object
readonly
Attribute for field ma.
-
#md ⇒ Object
readonly
Attribute for field md.
-
#me ⇒ Object
readonly
Attribute for field me.
-
#mk ⇒ Object
readonly
Attribute for field mk.
-
#mr ⇒ Object
readonly
Attribute for field mr.
-
#mt ⇒ Object
readonly
Attribute for field mt.
-
#mx ⇒ Object
readonly
Attribute for field mx.
-
#my ⇒ Object
readonly
Attribute for field my.
-
#ng ⇒ Object
readonly
Attribute for field ng.
-
#nl ⇒ Object
readonly
Attribute for field nl.
-
#no ⇒ Object
readonly
Attribute for field no.
-
#np ⇒ Object
readonly
Attribute for field np.
-
#nz ⇒ Object
readonly
Attribute for field nz.
-
#om ⇒ Object
readonly
Attribute for field om.
-
#pe ⇒ Object
readonly
Attribute for field pe.
-
#pl ⇒ Object
readonly
Attribute for field pl.
-
#pt ⇒ Object
readonly
Attribute for field pt.
-
#ro ⇒ Object
readonly
Attribute for field ro.
-
#rs ⇒ Object
readonly
Attribute for field rs.
-
#ru ⇒ Object
readonly
Attribute for field ru.
-
#sa ⇒ Object
readonly
Attribute for field sa.
-
#se ⇒ Object
readonly
Attribute for field se.
-
#sg ⇒ Object
readonly
Attribute for field sg.
-
#si ⇒ Object
readonly
Attribute for field si.
-
#sk ⇒ Object
readonly
Attribute for field sk.
-
#sn ⇒ Object
readonly
Attribute for field sn.
-
#sr ⇒ Object
readonly
Attribute for field sr.
-
#th ⇒ Object
readonly
Attribute for field th.
-
#tj ⇒ Object
readonly
Attribute for field tj.
-
#tr ⇒ Object
readonly
Attribute for field tr.
-
#tz ⇒ Object
readonly
Attribute for field tz.
-
#ug ⇒ Object
readonly
Attribute for field ug.
-
#us ⇒ Object
readonly
Attribute for field us.
-
#uy ⇒ Object
readonly
Attribute for field uy.
-
#uz ⇒ Object
readonly
Attribute for field uz.
-
#vn ⇒ Object
readonly
Attribute for field vn.
-
#za ⇒ Object
readonly
Attribute for field za.
-
#zm ⇒ Object
readonly
Attribute for field zm.
-
#zw ⇒ Object
readonly
Attribute for field zw.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Attribute for field ae
653 654 655 |
# File 'lib/stripe/resources/tax/registration.rb', line 653 def ae @ae end |
#al ⇒ Object (readonly)
Attribute for field al
655 656 657 |
# File 'lib/stripe/resources/tax/registration.rb', line 655 def al @al end |
#am ⇒ Object (readonly)
Attribute for field am
657 658 659 |
# File 'lib/stripe/resources/tax/registration.rb', line 657 def am @am end |
#ao ⇒ Object (readonly)
Attribute for field ao
659 660 661 |
# File 'lib/stripe/resources/tax/registration.rb', line 659 def ao @ao end |
#at ⇒ Object (readonly)
Attribute for field at
661 662 663 |
# File 'lib/stripe/resources/tax/registration.rb', line 661 def at @at end |
#au ⇒ Object (readonly)
Attribute for field au
663 664 665 |
# File 'lib/stripe/resources/tax/registration.rb', line 663 def au @au end |
#ba ⇒ Object (readonly)
Attribute for field ba
665 666 667 |
# File 'lib/stripe/resources/tax/registration.rb', line 665 def ba @ba end |
#bb ⇒ Object (readonly)
Attribute for field bb
667 668 669 |
# File 'lib/stripe/resources/tax/registration.rb', line 667 def bb @bb end |
#be ⇒ Object (readonly)
Attribute for field be
669 670 671 |
# File 'lib/stripe/resources/tax/registration.rb', line 669 def be @be end |
#bg ⇒ Object (readonly)
Attribute for field bg
671 672 673 |
# File 'lib/stripe/resources/tax/registration.rb', line 671 def bg @bg end |
#bh ⇒ Object (readonly)
Attribute for field bh
673 674 675 |
# File 'lib/stripe/resources/tax/registration.rb', line 673 def bh @bh end |
#bs ⇒ Object (readonly)
Attribute for field bs
675 676 677 |
# File 'lib/stripe/resources/tax/registration.rb', line 675 def bs @bs end |
#by ⇒ Object (readonly)
Attribute for field by
677 678 679 |
# File 'lib/stripe/resources/tax/registration.rb', line 677 def by @by end |
#ca ⇒ Object (readonly)
Attribute for field ca
679 680 681 |
# File 'lib/stripe/resources/tax/registration.rb', line 679 def ca @ca end |
#cd ⇒ Object (readonly)
Attribute for field cd
681 682 683 |
# File 'lib/stripe/resources/tax/registration.rb', line 681 def cd @cd end |
#ch ⇒ Object (readonly)
Attribute for field ch
683 684 685 |
# File 'lib/stripe/resources/tax/registration.rb', line 683 def ch @ch end |
#cl ⇒ Object (readonly)
Attribute for field cl
685 686 687 |
# File 'lib/stripe/resources/tax/registration.rb', line 685 def cl @cl end |
#co ⇒ Object (readonly)
Attribute for field co
687 688 689 |
# File 'lib/stripe/resources/tax/registration.rb', line 687 def co @co end |
#cr ⇒ Object (readonly)
Attribute for field cr
689 690 691 |
# File 'lib/stripe/resources/tax/registration.rb', line 689 def cr @cr end |
#cy ⇒ Object (readonly)
Attribute for field cy
691 692 693 |
# File 'lib/stripe/resources/tax/registration.rb', line 691 def cy @cy end |
#cz ⇒ Object (readonly)
Attribute for field cz
693 694 695 |
# File 'lib/stripe/resources/tax/registration.rb', line 693 def cz @cz end |
#de ⇒ Object (readonly)
Attribute for field de
695 696 697 |
# File 'lib/stripe/resources/tax/registration.rb', line 695 def de @de end |
#dk ⇒ Object (readonly)
Attribute for field dk
697 698 699 |
# File 'lib/stripe/resources/tax/registration.rb', line 697 def dk @dk end |
#ec ⇒ Object (readonly)
Attribute for field ec
699 700 701 |
# File 'lib/stripe/resources/tax/registration.rb', line 699 def ec @ec end |
#ee ⇒ Object (readonly)
Attribute for field ee
701 702 703 |
# File 'lib/stripe/resources/tax/registration.rb', line 701 def ee @ee end |
#eg ⇒ Object (readonly)
Attribute for field eg
703 704 705 |
# File 'lib/stripe/resources/tax/registration.rb', line 703 def eg @eg end |
#es ⇒ Object (readonly)
Attribute for field es
705 706 707 |
# File 'lib/stripe/resources/tax/registration.rb', line 705 def es @es end |
#fi ⇒ Object (readonly)
Attribute for field fi
707 708 709 |
# File 'lib/stripe/resources/tax/registration.rb', line 707 def fi @fi end |
#fr ⇒ Object (readonly)
Attribute for field fr
709 710 711 |
# File 'lib/stripe/resources/tax/registration.rb', line 709 def fr @fr end |
#gb ⇒ Object (readonly)
Attribute for field gb
711 712 713 |
# File 'lib/stripe/resources/tax/registration.rb', line 711 def gb @gb end |
#ge ⇒ Object (readonly)
Attribute for field ge
713 714 715 |
# File 'lib/stripe/resources/tax/registration.rb', line 713 def ge @ge end |
#gn ⇒ Object (readonly)
Attribute for field gn
715 716 717 |
# File 'lib/stripe/resources/tax/registration.rb', line 715 def gn @gn end |
#gr ⇒ Object (readonly)
Attribute for field gr
717 718 719 |
# File 'lib/stripe/resources/tax/registration.rb', line 717 def gr @gr end |
#hr ⇒ Object (readonly)
Attribute for field hr
719 720 721 |
# File 'lib/stripe/resources/tax/registration.rb', line 719 def hr @hr end |
#hu ⇒ Object (readonly)
Attribute for field hu
721 722 723 |
# File 'lib/stripe/resources/tax/registration.rb', line 721 def hu @hu end |
#id ⇒ Object (readonly)
Attribute for field id
723 724 725 |
# File 'lib/stripe/resources/tax/registration.rb', line 723 def id @id end |
#ie ⇒ Object (readonly)
Attribute for field ie
725 726 727 |
# File 'lib/stripe/resources/tax/registration.rb', line 725 def ie @ie end |
#in ⇒ Object (readonly)
Attribute for field in
727 728 729 |
# File 'lib/stripe/resources/tax/registration.rb', line 727 def in @in end |
#is ⇒ Object (readonly)
Attribute for field is
729 730 731 |
# File 'lib/stripe/resources/tax/registration.rb', line 729 def is @is end |
#it ⇒ Object (readonly)
Attribute for field it
731 732 733 |
# File 'lib/stripe/resources/tax/registration.rb', line 731 def it @it end |
#jp ⇒ Object (readonly)
Attribute for field jp
733 734 735 |
# File 'lib/stripe/resources/tax/registration.rb', line 733 def jp @jp end |
#ke ⇒ Object (readonly)
Attribute for field ke
735 736 737 |
# File 'lib/stripe/resources/tax/registration.rb', line 735 def ke @ke end |
#kh ⇒ Object (readonly)
Attribute for field kh
737 738 739 |
# File 'lib/stripe/resources/tax/registration.rb', line 737 def kh @kh end |
#kr ⇒ Object (readonly)
Attribute for field kr
739 740 741 |
# File 'lib/stripe/resources/tax/registration.rb', line 739 def kr @kr end |
#kz ⇒ Object (readonly)
Attribute for field kz
741 742 743 |
# File 'lib/stripe/resources/tax/registration.rb', line 741 def kz @kz end |
#lt ⇒ Object (readonly)
Attribute for field lt
743 744 745 |
# File 'lib/stripe/resources/tax/registration.rb', line 743 def lt @lt end |
#lu ⇒ Object (readonly)
Attribute for field lu
745 746 747 |
# File 'lib/stripe/resources/tax/registration.rb', line 745 def lu @lu end |
#lv ⇒ Object (readonly)
Attribute for field lv
747 748 749 |
# File 'lib/stripe/resources/tax/registration.rb', line 747 def lv @lv end |
#ma ⇒ Object (readonly)
Attribute for field ma
749 750 751 |
# File 'lib/stripe/resources/tax/registration.rb', line 749 def ma @ma end |
#md ⇒ Object (readonly)
Attribute for field md
751 752 753 |
# File 'lib/stripe/resources/tax/registration.rb', line 751 def md @md end |
#me ⇒ Object (readonly)
Attribute for field me
753 754 755 |
# File 'lib/stripe/resources/tax/registration.rb', line 753 def me @me end |
#mk ⇒ Object (readonly)
Attribute for field mk
755 756 757 |
# File 'lib/stripe/resources/tax/registration.rb', line 755 def mk @mk end |
#mr ⇒ Object (readonly)
Attribute for field mr
757 758 759 |
# File 'lib/stripe/resources/tax/registration.rb', line 757 def mr @mr end |
#mt ⇒ Object (readonly)
Attribute for field mt
759 760 761 |
# File 'lib/stripe/resources/tax/registration.rb', line 759 def mt @mt end |
#mx ⇒ Object (readonly)
Attribute for field mx
761 762 763 |
# File 'lib/stripe/resources/tax/registration.rb', line 761 def mx @mx end |
#my ⇒ Object (readonly)
Attribute for field my
763 764 765 |
# File 'lib/stripe/resources/tax/registration.rb', line 763 def my @my end |
#ng ⇒ Object (readonly)
Attribute for field ng
765 766 767 |
# File 'lib/stripe/resources/tax/registration.rb', line 765 def ng @ng end |
#nl ⇒ Object (readonly)
Attribute for field nl
767 768 769 |
# File 'lib/stripe/resources/tax/registration.rb', line 767 def nl @nl end |
#no ⇒ Object (readonly)
Attribute for field no
769 770 771 |
# File 'lib/stripe/resources/tax/registration.rb', line 769 def no @no end |
#np ⇒ Object (readonly)
Attribute for field np
771 772 773 |
# File 'lib/stripe/resources/tax/registration.rb', line 771 def np @np end |
#nz ⇒ Object (readonly)
Attribute for field nz
773 774 775 |
# File 'lib/stripe/resources/tax/registration.rb', line 773 def nz @nz end |
#om ⇒ Object (readonly)
Attribute for field om
775 776 777 |
# File 'lib/stripe/resources/tax/registration.rb', line 775 def om @om end |
#pe ⇒ Object (readonly)
Attribute for field pe
777 778 779 |
# File 'lib/stripe/resources/tax/registration.rb', line 777 def pe @pe end |
#pl ⇒ Object (readonly)
Attribute for field pl
779 780 781 |
# File 'lib/stripe/resources/tax/registration.rb', line 779 def pl @pl end |
#pt ⇒ Object (readonly)
Attribute for field pt
781 782 783 |
# File 'lib/stripe/resources/tax/registration.rb', line 781 def pt @pt end |
#ro ⇒ Object (readonly)
Attribute for field ro
783 784 785 |
# File 'lib/stripe/resources/tax/registration.rb', line 783 def ro @ro end |
#rs ⇒ Object (readonly)
Attribute for field rs
785 786 787 |
# File 'lib/stripe/resources/tax/registration.rb', line 785 def rs @rs end |
#ru ⇒ Object (readonly)
Attribute for field ru
787 788 789 |
# File 'lib/stripe/resources/tax/registration.rb', line 787 def ru @ru end |
#sa ⇒ Object (readonly)
Attribute for field sa
789 790 791 |
# File 'lib/stripe/resources/tax/registration.rb', line 789 def sa @sa end |
#se ⇒ Object (readonly)
Attribute for field se
791 792 793 |
# File 'lib/stripe/resources/tax/registration.rb', line 791 def se @se end |
#sg ⇒ Object (readonly)
Attribute for field sg
793 794 795 |
# File 'lib/stripe/resources/tax/registration.rb', line 793 def sg @sg end |
#si ⇒ Object (readonly)
Attribute for field si
795 796 797 |
# File 'lib/stripe/resources/tax/registration.rb', line 795 def si @si end |
#sk ⇒ Object (readonly)
Attribute for field sk
797 798 799 |
# File 'lib/stripe/resources/tax/registration.rb', line 797 def sk @sk end |
#sn ⇒ Object (readonly)
Attribute for field sn
799 800 801 |
# File 'lib/stripe/resources/tax/registration.rb', line 799 def sn @sn end |
#sr ⇒ Object (readonly)
Attribute for field sr
801 802 803 |
# File 'lib/stripe/resources/tax/registration.rb', line 801 def sr @sr end |
#th ⇒ Object (readonly)
Attribute for field th
803 804 805 |
# File 'lib/stripe/resources/tax/registration.rb', line 803 def th @th end |
#tj ⇒ Object (readonly)
Attribute for field tj
805 806 807 |
# File 'lib/stripe/resources/tax/registration.rb', line 805 def tj @tj end |
#tr ⇒ Object (readonly)
Attribute for field tr
807 808 809 |
# File 'lib/stripe/resources/tax/registration.rb', line 807 def tr @tr end |
#tz ⇒ Object (readonly)
Attribute for field tz
809 810 811 |
# File 'lib/stripe/resources/tax/registration.rb', line 809 def tz @tz end |
#ug ⇒ Object (readonly)
Attribute for field ug
811 812 813 |
# File 'lib/stripe/resources/tax/registration.rb', line 811 def ug @ug end |
#us ⇒ Object (readonly)
Attribute for field us
813 814 815 |
# File 'lib/stripe/resources/tax/registration.rb', line 813 def us @us end |
#uy ⇒ Object (readonly)
Attribute for field uy
815 816 817 |
# File 'lib/stripe/resources/tax/registration.rb', line 815 def uy @uy end |
#uz ⇒ Object (readonly)
Attribute for field uz
817 818 819 |
# File 'lib/stripe/resources/tax/registration.rb', line 817 def uz @uz end |
#vn ⇒ Object (readonly)
Attribute for field vn
819 820 821 |
# File 'lib/stripe/resources/tax/registration.rb', line 819 def vn @vn end |
#za ⇒ Object (readonly)
Attribute for field za
821 822 823 |
# File 'lib/stripe/resources/tax/registration.rb', line 821 def za @za end |
#zm ⇒ Object (readonly)
Attribute for field zm
823 824 825 |
# File 'lib/stripe/resources/tax/registration.rb', line 823 def zm @zm end |
#zw ⇒ Object (readonly)
Attribute for field zw
825 826 827 |
# File 'lib/stripe/resources/tax/registration.rb', line 825 def zw @zw end |