Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, At, Au, Be, Bg, Bh, By, Ca, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kr, Kz, Lt, Lu, Lv, Ma, Md, Mt, Mx, My, Ng, Nl, No, Nz, Om, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Th, Tr, Tz, Us, Uz, Vn, Za

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Attribute for field ae



576
577
578
# File 'lib/stripe/resources/tax/registration.rb', line 576

def ae
  @ae
end

#atObject (readonly)

Attribute for field at



579
580
581
# File 'lib/stripe/resources/tax/registration.rb', line 579

def at
  @at
end

#auObject (readonly)

Attribute for field au



582
583
584
# File 'lib/stripe/resources/tax/registration.rb', line 582

def au
  @au
end

#beObject (readonly)

Attribute for field be



585
586
587
# File 'lib/stripe/resources/tax/registration.rb', line 585

def be
  @be
end

#bgObject (readonly)

Attribute for field bg



588
589
590
# File 'lib/stripe/resources/tax/registration.rb', line 588

def bg
  @bg
end

#bhObject (readonly)

Attribute for field bh



591
592
593
# File 'lib/stripe/resources/tax/registration.rb', line 591

def bh
  @bh
end

#byObject (readonly)

Attribute for field by



594
595
596
# File 'lib/stripe/resources/tax/registration.rb', line 594

def by
  @by
end

#caObject (readonly)

Attribute for field ca



597
598
599
# File 'lib/stripe/resources/tax/registration.rb', line 597

def ca
  @ca
end

#chObject (readonly)

Attribute for field ch



600
601
602
# File 'lib/stripe/resources/tax/registration.rb', line 600

def ch
  @ch
end

#clObject (readonly)

Attribute for field cl



603
604
605
# File 'lib/stripe/resources/tax/registration.rb', line 603

def cl
  @cl
end

#coObject (readonly)

Attribute for field co



606
607
608
# File 'lib/stripe/resources/tax/registration.rb', line 606

def co
  @co
end

#crObject (readonly)

Attribute for field cr



609
610
611
# File 'lib/stripe/resources/tax/registration.rb', line 609

def cr
  @cr
end

#cyObject (readonly)

Attribute for field cy



612
613
614
# File 'lib/stripe/resources/tax/registration.rb', line 612

def cy
  @cy
end

#czObject (readonly)

Attribute for field cz



615
616
617
# File 'lib/stripe/resources/tax/registration.rb', line 615

def cz
  @cz
end

#deObject (readonly)

Attribute for field de



618
619
620
# File 'lib/stripe/resources/tax/registration.rb', line 618

def de
  @de
end

#dkObject (readonly)

Attribute for field dk



621
622
623
# File 'lib/stripe/resources/tax/registration.rb', line 621

def dk
  @dk
end

#ecObject (readonly)

Attribute for field ec



624
625
626
# File 'lib/stripe/resources/tax/registration.rb', line 624

def ec
  @ec
end

#eeObject (readonly)

Attribute for field ee



627
628
629
# File 'lib/stripe/resources/tax/registration.rb', line 627

def ee
  @ee
end

#egObject (readonly)

Attribute for field eg



630
631
632
# File 'lib/stripe/resources/tax/registration.rb', line 630

def eg
  @eg
end

#esObject (readonly)

Attribute for field es



633
634
635
# File 'lib/stripe/resources/tax/registration.rb', line 633

def es
  @es
end

#fiObject (readonly)

Attribute for field fi



636
637
638
# File 'lib/stripe/resources/tax/registration.rb', line 636

def fi
  @fi
end

#frObject (readonly)

Attribute for field fr



639
640
641
# File 'lib/stripe/resources/tax/registration.rb', line 639

def fr
  @fr
end

#gbObject (readonly)

Attribute for field gb



642
643
644
# File 'lib/stripe/resources/tax/registration.rb', line 642

def gb
  @gb
end

#geObject (readonly)

Attribute for field ge



645
646
647
# File 'lib/stripe/resources/tax/registration.rb', line 645

def ge
  @ge
end

#grObject (readonly)

Attribute for field gr



648
649
650
# File 'lib/stripe/resources/tax/registration.rb', line 648

def gr
  @gr
end

#hrObject (readonly)

Attribute for field hr



651
652
653
# File 'lib/stripe/resources/tax/registration.rb', line 651

def hr
  @hr
end

#huObject (readonly)

Attribute for field hu



654
655
656
# File 'lib/stripe/resources/tax/registration.rb', line 654

def hu
  @hu
end

#idObject (readonly)

Attribute for field id



657
658
659
# File 'lib/stripe/resources/tax/registration.rb', line 657

def id
  @id
end

#ieObject (readonly)

Attribute for field ie



660
661
662
# File 'lib/stripe/resources/tax/registration.rb', line 660

def ie
  @ie
end

#isObject (readonly)

Attribute for field is



663
664
665
# File 'lib/stripe/resources/tax/registration.rb', line 663

def is
  @is
end

#itObject (readonly)

Attribute for field it



666
667
668
# File 'lib/stripe/resources/tax/registration.rb', line 666

def it
  @it
end

#jpObject (readonly)

Attribute for field jp



669
670
671
# File 'lib/stripe/resources/tax/registration.rb', line 669

def jp
  @jp
end

#keObject (readonly)

Attribute for field ke



672
673
674
# File 'lib/stripe/resources/tax/registration.rb', line 672

def ke
  @ke
end

#krObject (readonly)

Attribute for field kr



675
676
677
# File 'lib/stripe/resources/tax/registration.rb', line 675

def kr
  @kr
end

#kzObject (readonly)

Attribute for field kz



678
679
680
# File 'lib/stripe/resources/tax/registration.rb', line 678

def kz
  @kz
end

#ltObject (readonly)

Attribute for field lt



681
682
683
# File 'lib/stripe/resources/tax/registration.rb', line 681

def lt
  @lt
end

#luObject (readonly)

Attribute for field lu



684
685
686
# File 'lib/stripe/resources/tax/registration.rb', line 684

def lu
  @lu
end

#lvObject (readonly)

Attribute for field lv



687
688
689
# File 'lib/stripe/resources/tax/registration.rb', line 687

def lv
  @lv
end

#maObject (readonly)

Attribute for field ma



690
691
692
# File 'lib/stripe/resources/tax/registration.rb', line 690

def ma
  @ma
end

#mdObject (readonly)

Attribute for field md



693
694
695
# File 'lib/stripe/resources/tax/registration.rb', line 693

def md
  @md
end

#mtObject (readonly)

Attribute for field mt



696
697
698
# File 'lib/stripe/resources/tax/registration.rb', line 696

def mt
  @mt
end

#mxObject (readonly)

Attribute for field mx



699
700
701
# File 'lib/stripe/resources/tax/registration.rb', line 699

def mx
  @mx
end

#myObject (readonly)

Attribute for field my



702
703
704
# File 'lib/stripe/resources/tax/registration.rb', line 702

def my
  @my
end

#ngObject (readonly)

Attribute for field ng



705
706
707
# File 'lib/stripe/resources/tax/registration.rb', line 705

def ng
  @ng
end

#nlObject (readonly)

Attribute for field nl



708
709
710
# File 'lib/stripe/resources/tax/registration.rb', line 708

def nl
  @nl
end

#noObject (readonly)

Attribute for field no



711
712
713
# File 'lib/stripe/resources/tax/registration.rb', line 711

def no
  @no
end

#nzObject (readonly)

Attribute for field nz



714
715
716
# File 'lib/stripe/resources/tax/registration.rb', line 714

def nz
  @nz
end

#omObject (readonly)

Attribute for field om



717
718
719
# File 'lib/stripe/resources/tax/registration.rb', line 717

def om
  @om
end

#plObject (readonly)

Attribute for field pl



720
721
722
# File 'lib/stripe/resources/tax/registration.rb', line 720

def pl
  @pl
end

#ptObject (readonly)

Attribute for field pt



723
724
725
# File 'lib/stripe/resources/tax/registration.rb', line 723

def pt
  @pt
end

#roObject (readonly)

Attribute for field ro



726
727
728
# File 'lib/stripe/resources/tax/registration.rb', line 726

def ro
  @ro
end

#rsObject (readonly)

Attribute for field rs



729
730
731
# File 'lib/stripe/resources/tax/registration.rb', line 729

def rs
  @rs
end

#ruObject (readonly)

Attribute for field ru



732
733
734
# File 'lib/stripe/resources/tax/registration.rb', line 732

def ru
  @ru
end

#saObject (readonly)

Attribute for field sa



735
736
737
# File 'lib/stripe/resources/tax/registration.rb', line 735

def sa
  @sa
end

#seObject (readonly)

Attribute for field se



738
739
740
# File 'lib/stripe/resources/tax/registration.rb', line 738

def se
  @se
end

#sgObject (readonly)

Attribute for field sg



741
742
743
# File 'lib/stripe/resources/tax/registration.rb', line 741

def sg
  @sg
end

#siObject (readonly)

Attribute for field si



744
745
746
# File 'lib/stripe/resources/tax/registration.rb', line 744

def si
  @si
end

#skObject (readonly)

Attribute for field sk



747
748
749
# File 'lib/stripe/resources/tax/registration.rb', line 747

def sk
  @sk
end

#thObject (readonly)

Attribute for field th



750
751
752
# File 'lib/stripe/resources/tax/registration.rb', line 750

def th
  @th
end

#trObject (readonly)

Attribute for field tr



753
754
755
# File 'lib/stripe/resources/tax/registration.rb', line 753

def tr
  @tr
end

#tzObject (readonly)

Attribute for field tz



756
757
758
# File 'lib/stripe/resources/tax/registration.rb', line 756

def tz
  @tz
end

#usObject (readonly)

Attribute for field us



759
760
761
# File 'lib/stripe/resources/tax/registration.rb', line 759

def us
  @us
end

#uzObject (readonly)

Attribute for field uz



762
763
764
# File 'lib/stripe/resources/tax/registration.rb', line 762

def uz
  @uz
end

#vnObject (readonly)

Attribute for field vn



765
766
767
# File 'lib/stripe/resources/tax/registration.rb', line 765

def vn
  @vn
end

#zaObject (readonly)

Attribute for field za



768
769
770
# File 'lib/stripe/resources/tax/registration.rb', line 768

def za
  @za
end