Class: Stripe::Tax::Registration::CountryOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, At, Au, Be, Bg, Bh, By, Ca, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kr, Kz, Lt, Lu, Lv, Ma, Md, Mt, Mx, My, Ng, Nl, No, Nz, Om, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Th, Tr, Tz, Us, Uz, Vn, Za

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#aeObject (readonly)

Returns the value of attribute ae.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ae
  @ae
end

#atObject (readonly)

Returns the value of attribute at.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def at
  @at
end

#auObject (readonly)

Returns the value of attribute au.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def au
  @au
end

#beObject (readonly)

Returns the value of attribute be.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def be
  @be
end

#bgObject (readonly)

Returns the value of attribute bg.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def bg
  @bg
end

#bhObject (readonly)

Returns the value of attribute bh.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def bh
  @bh
end

#byObject (readonly)

Returns the value of attribute by.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def by
  @by
end

#caObject (readonly)

Returns the value of attribute ca.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ca
  @ca
end

#chObject (readonly)

Returns the value of attribute ch.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ch
  @ch
end

#clObject (readonly)

Returns the value of attribute cl.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def cl
  @cl
end

#coObject (readonly)

Returns the value of attribute co.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def co
  @co
end

#crObject (readonly)

Returns the value of attribute cr.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def cr
  @cr
end

#cyObject (readonly)

Returns the value of attribute cy.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def cy
  @cy
end

#czObject (readonly)

Returns the value of attribute cz.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def cz
  @cz
end

#deObject (readonly)

Returns the value of attribute de.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def de
  @de
end

#dkObject (readonly)

Returns the value of attribute dk.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def dk
  @dk
end

#ecObject (readonly)

Returns the value of attribute ec.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ec
  @ec
end

#eeObject (readonly)

Returns the value of attribute ee.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ee
  @ee
end

#egObject (readonly)

Returns the value of attribute eg.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def eg
  @eg
end

#esObject (readonly)

Returns the value of attribute es.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def es
  @es
end

#fiObject (readonly)

Returns the value of attribute fi.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def fi
  @fi
end

#frObject (readonly)

Returns the value of attribute fr.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def fr
  @fr
end

#gbObject (readonly)

Returns the value of attribute gb.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def gb
  @gb
end

#geObject (readonly)

Returns the value of attribute ge.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ge
  @ge
end

#grObject (readonly)

Returns the value of attribute gr.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def gr
  @gr
end

#hrObject (readonly)

Returns the value of attribute hr.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def hr
  @hr
end

#huObject (readonly)

Returns the value of attribute hu.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def hu
  @hu
end

#idObject (readonly)

Returns the value of attribute id.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def id
  @id
end

#ieObject (readonly)

Returns the value of attribute ie.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ie
  @ie
end

#isObject (readonly)

Returns the value of attribute is.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def is
  @is
end

#itObject (readonly)

Returns the value of attribute it.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def it
  @it
end

#jpObject (readonly)

Returns the value of attribute jp.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def jp
  @jp
end

#keObject (readonly)

Returns the value of attribute ke.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ke
  @ke
end

#krObject (readonly)

Returns the value of attribute kr.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def kr
  @kr
end

#kzObject (readonly)

Returns the value of attribute kz.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def kz
  @kz
end

#ltObject (readonly)

Returns the value of attribute lt.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def lt
  @lt
end

#luObject (readonly)

Returns the value of attribute lu.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def lu
  @lu
end

#lvObject (readonly)

Returns the value of attribute lv.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def lv
  @lv
end

#maObject (readonly)

Returns the value of attribute ma.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ma
  @ma
end

#mdObject (readonly)

Returns the value of attribute md.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def md
  @md
end

#mtObject (readonly)

Returns the value of attribute mt.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def mt
  @mt
end

#mxObject (readonly)

Returns the value of attribute mx.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def mx
  @mx
end

#myObject (readonly)

Returns the value of attribute my.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def my
  @my
end

#ngObject (readonly)

Returns the value of attribute ng.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ng
  @ng
end

#nlObject (readonly)

Returns the value of attribute nl.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def nl
  @nl
end

#noObject (readonly)

Returns the value of attribute no.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def no
  @no
end

#nzObject (readonly)

Returns the value of attribute nz.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def nz
  @nz
end

#omObject (readonly)

Returns the value of attribute om.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def om
  @om
end

#plObject (readonly)

Returns the value of attribute pl.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def pl
  @pl
end

#ptObject (readonly)

Returns the value of attribute pt.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def pt
  @pt
end

#roObject (readonly)

Returns the value of attribute ro.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ro
  @ro
end

#rsObject (readonly)

Returns the value of attribute rs.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def rs
  @rs
end

#ruObject (readonly)

Returns the value of attribute ru.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def ru
  @ru
end

#saObject (readonly)

Returns the value of attribute sa.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def sa
  @sa
end

#seObject (readonly)

Returns the value of attribute se.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def se
  @se
end

#sgObject (readonly)

Returns the value of attribute sg.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def sg
  @sg
end

#siObject (readonly)

Returns the value of attribute si.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def si
  @si
end

#skObject (readonly)

Returns the value of attribute sk.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def sk
  @sk
end

#thObject (readonly)

Returns the value of attribute th.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def th
  @th
end

#trObject (readonly)

Returns the value of attribute tr.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def tr
  @tr
end

#tzObject (readonly)

Returns the value of attribute tz.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def tz
  @tz
end

#usObject (readonly)

Returns the value of attribute us.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def us
  @us
end

#uzObject (readonly)

Returns the value of attribute uz.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def uz
  @uz
end

#vnObject (readonly)

Returns the value of attribute vn.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def vn
  @vn
end

#zaObject (readonly)

Returns the value of attribute za.



379
380
381
# File 'lib/stripe/resources/tax/registration.rb', line 379

def za
  @za
end