Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, At, Au, Be, Bg, Bh, By, Ca, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kr, Kz, Lt, Lu, Lv, Ma, Md, Mt, Mx, My, Ng, Nl, No, Nz, Om, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Th, Tr, Tz, Us, Uz, Vn, Za
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Returns the value of attribute ae.
-
#at ⇒ Object
readonly
Returns the value of attribute at.
-
#au ⇒ Object
readonly
Returns the value of attribute au.
-
#be ⇒ Object
readonly
Returns the value of attribute be.
-
#bg ⇒ Object
readonly
Returns the value of attribute bg.
-
#bh ⇒ Object
readonly
Returns the value of attribute bh.
-
#by ⇒ Object
readonly
Returns the value of attribute by.
-
#ca ⇒ Object
readonly
Returns the value of attribute ca.
-
#ch ⇒ Object
readonly
Returns the value of attribute ch.
-
#cl ⇒ Object
readonly
Returns the value of attribute cl.
-
#co ⇒ Object
readonly
Returns the value of attribute co.
-
#cr ⇒ Object
readonly
Returns the value of attribute cr.
-
#cy ⇒ Object
readonly
Returns the value of attribute cy.
-
#cz ⇒ Object
readonly
Returns the value of attribute cz.
-
#de ⇒ Object
readonly
Returns the value of attribute de.
-
#dk ⇒ Object
readonly
Returns the value of attribute dk.
-
#ec ⇒ Object
readonly
Returns the value of attribute ec.
-
#ee ⇒ Object
readonly
Returns the value of attribute ee.
-
#eg ⇒ Object
readonly
Returns the value of attribute eg.
-
#es ⇒ Object
readonly
Returns the value of attribute es.
-
#fi ⇒ Object
readonly
Returns the value of attribute fi.
-
#fr ⇒ Object
readonly
Returns the value of attribute fr.
-
#gb ⇒ Object
readonly
Returns the value of attribute gb.
-
#ge ⇒ Object
readonly
Returns the value of attribute ge.
-
#gr ⇒ Object
readonly
Returns the value of attribute gr.
-
#hr ⇒ Object
readonly
Returns the value of attribute hr.
-
#hu ⇒ Object
readonly
Returns the value of attribute hu.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#ie ⇒ Object
readonly
Returns the value of attribute ie.
-
#is ⇒ Object
readonly
Returns the value of attribute is.
-
#it ⇒ Object
readonly
Returns the value of attribute it.
-
#jp ⇒ Object
readonly
Returns the value of attribute jp.
-
#ke ⇒ Object
readonly
Returns the value of attribute ke.
-
#kr ⇒ Object
readonly
Returns the value of attribute kr.
-
#kz ⇒ Object
readonly
Returns the value of attribute kz.
-
#lt ⇒ Object
readonly
Returns the value of attribute lt.
-
#lu ⇒ Object
readonly
Returns the value of attribute lu.
-
#lv ⇒ Object
readonly
Returns the value of attribute lv.
-
#ma ⇒ Object
readonly
Returns the value of attribute ma.
-
#md ⇒ Object
readonly
Returns the value of attribute md.
-
#mt ⇒ Object
readonly
Returns the value of attribute mt.
-
#mx ⇒ Object
readonly
Returns the value of attribute mx.
-
#my ⇒ Object
readonly
Returns the value of attribute my.
-
#ng ⇒ Object
readonly
Returns the value of attribute ng.
-
#nl ⇒ Object
readonly
Returns the value of attribute nl.
-
#no ⇒ Object
readonly
Returns the value of attribute no.
-
#nz ⇒ Object
readonly
Returns the value of attribute nz.
-
#om ⇒ Object
readonly
Returns the value of attribute om.
-
#pl ⇒ Object
readonly
Returns the value of attribute pl.
-
#pt ⇒ Object
readonly
Returns the value of attribute pt.
-
#ro ⇒ Object
readonly
Returns the value of attribute ro.
-
#rs ⇒ Object
readonly
Returns the value of attribute rs.
-
#ru ⇒ Object
readonly
Returns the value of attribute ru.
-
#sa ⇒ Object
readonly
Returns the value of attribute sa.
-
#se ⇒ Object
readonly
Returns the value of attribute se.
-
#sg ⇒ Object
readonly
Returns the value of attribute sg.
-
#si ⇒ Object
readonly
Returns the value of attribute si.
-
#sk ⇒ Object
readonly
Returns the value of attribute sk.
-
#th ⇒ Object
readonly
Returns the value of attribute th.
-
#tr ⇒ Object
readonly
Returns the value of attribute tr.
-
#tz ⇒ Object
readonly
Returns the value of attribute tz.
-
#us ⇒ Object
readonly
Returns the value of attribute us.
-
#uz ⇒ Object
readonly
Returns the value of attribute uz.
-
#vn ⇒ Object
readonly
Returns the value of attribute vn.
-
#za ⇒ Object
readonly
Returns the value of attribute za.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Returns the value of attribute ae.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ae @ae end |
#at ⇒ Object (readonly)
Returns the value of attribute at.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def at @at end |
#au ⇒ Object (readonly)
Returns the value of attribute au.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def au @au end |
#be ⇒ Object (readonly)
Returns the value of attribute be.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def be @be end |
#bg ⇒ Object (readonly)
Returns the value of attribute bg.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def bg @bg end |
#bh ⇒ Object (readonly)
Returns the value of attribute bh.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def bh @bh end |
#by ⇒ Object (readonly)
Returns the value of attribute by.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def by @by end |
#ca ⇒ Object (readonly)
Returns the value of attribute ca.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ca @ca end |
#ch ⇒ Object (readonly)
Returns the value of attribute ch.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ch @ch end |
#cl ⇒ Object (readonly)
Returns the value of attribute cl.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def cl @cl end |
#co ⇒ Object (readonly)
Returns the value of attribute co.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def co @co end |
#cr ⇒ Object (readonly)
Returns the value of attribute cr.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def cr @cr end |
#cy ⇒ Object (readonly)
Returns the value of attribute cy.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def cy @cy end |
#cz ⇒ Object (readonly)
Returns the value of attribute cz.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def cz @cz end |
#de ⇒ Object (readonly)
Returns the value of attribute de.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def de @de end |
#dk ⇒ Object (readonly)
Returns the value of attribute dk.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def dk @dk end |
#ec ⇒ Object (readonly)
Returns the value of attribute ec.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ec @ec end |
#ee ⇒ Object (readonly)
Returns the value of attribute ee.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ee @ee end |
#eg ⇒ Object (readonly)
Returns the value of attribute eg.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def eg @eg end |
#es ⇒ Object (readonly)
Returns the value of attribute es.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def es @es end |
#fi ⇒ Object (readonly)
Returns the value of attribute fi.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def fi @fi end |
#fr ⇒ Object (readonly)
Returns the value of attribute fr.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def fr @fr end |
#gb ⇒ Object (readonly)
Returns the value of attribute gb.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def gb @gb end |
#ge ⇒ Object (readonly)
Returns the value of attribute ge.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ge @ge end |
#gr ⇒ Object (readonly)
Returns the value of attribute gr.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def gr @gr end |
#hr ⇒ Object (readonly)
Returns the value of attribute hr.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def hr @hr end |
#hu ⇒ Object (readonly)
Returns the value of attribute hu.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def hu @hu end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def id @id end |
#ie ⇒ Object (readonly)
Returns the value of attribute ie.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ie @ie end |
#is ⇒ Object (readonly)
Returns the value of attribute is.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def is @is end |
#it ⇒ Object (readonly)
Returns the value of attribute it.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def it @it end |
#jp ⇒ Object (readonly)
Returns the value of attribute jp.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def jp @jp end |
#ke ⇒ Object (readonly)
Returns the value of attribute ke.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ke @ke end |
#kr ⇒ Object (readonly)
Returns the value of attribute kr.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def kr @kr end |
#kz ⇒ Object (readonly)
Returns the value of attribute kz.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def kz @kz end |
#lt ⇒ Object (readonly)
Returns the value of attribute lt.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def lt @lt end |
#lu ⇒ Object (readonly)
Returns the value of attribute lu.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def lu @lu end |
#lv ⇒ Object (readonly)
Returns the value of attribute lv.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def lv @lv end |
#ma ⇒ Object (readonly)
Returns the value of attribute ma.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ma @ma end |
#md ⇒ Object (readonly)
Returns the value of attribute md.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def md @md end |
#mt ⇒ Object (readonly)
Returns the value of attribute mt.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def mt @mt end |
#mx ⇒ Object (readonly)
Returns the value of attribute mx.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def mx @mx end |
#my ⇒ Object (readonly)
Returns the value of attribute my.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def my @my end |
#ng ⇒ Object (readonly)
Returns the value of attribute ng.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ng @ng end |
#nl ⇒ Object (readonly)
Returns the value of attribute nl.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def nl @nl end |
#no ⇒ Object (readonly)
Returns the value of attribute no.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def no @no end |
#nz ⇒ Object (readonly)
Returns the value of attribute nz.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def nz @nz end |
#om ⇒ Object (readonly)
Returns the value of attribute om.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def om @om end |
#pl ⇒ Object (readonly)
Returns the value of attribute pl.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def pl @pl end |
#pt ⇒ Object (readonly)
Returns the value of attribute pt.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def pt @pt end |
#ro ⇒ Object (readonly)
Returns the value of attribute ro.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ro @ro end |
#rs ⇒ Object (readonly)
Returns the value of attribute rs.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def rs @rs end |
#ru ⇒ Object (readonly)
Returns the value of attribute ru.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def ru @ru end |
#sa ⇒ Object (readonly)
Returns the value of attribute sa.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def sa @sa end |
#se ⇒ Object (readonly)
Returns the value of attribute se.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def se @se end |
#sg ⇒ Object (readonly)
Returns the value of attribute sg.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def sg @sg end |
#si ⇒ Object (readonly)
Returns the value of attribute si.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def si @si end |
#sk ⇒ Object (readonly)
Returns the value of attribute sk.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def sk @sk end |
#th ⇒ Object (readonly)
Returns the value of attribute th.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def th @th end |
#tr ⇒ Object (readonly)
Returns the value of attribute tr.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def tr @tr end |
#tz ⇒ Object (readonly)
Returns the value of attribute tz.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def tz @tz end |
#us ⇒ Object (readonly)
Returns the value of attribute us.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def us @us end |
#uz ⇒ Object (readonly)
Returns the value of attribute uz.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def uz @uz end |
#vn ⇒ Object (readonly)
Returns the value of attribute vn.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def vn @vn end |
#za ⇒ Object (readonly)
Returns the value of attribute za.
379 380 381 |
# File 'lib/stripe/resources/tax/registration.rb', line 379 def za @za end |