Class: Stripe::Tax::Registration::CountryOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Tax::Registration::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ae ⇒ Object
readonly
Attribute for field ae.
-
#al ⇒ Object
readonly
Attribute for field al.
-
#am ⇒ Object
readonly
Attribute for field am.
-
#ao ⇒ Object
readonly
Attribute for field ao.
-
#at ⇒ Object
readonly
Attribute for field at.
-
#au ⇒ Object
readonly
Attribute for field au.
-
#aw ⇒ Object
readonly
Attribute for field aw.
-
#az ⇒ Object
readonly
Attribute for field az.
-
#ba ⇒ Object
readonly
Attribute for field ba.
-
#bb ⇒ Object
readonly
Attribute for field bb.
-
#bd ⇒ Object
readonly
Attribute for field bd.
-
#be ⇒ Object
readonly
Attribute for field be.
-
#bf ⇒ Object
readonly
Attribute for field bf.
-
#bg ⇒ Object
readonly
Attribute for field bg.
-
#bh ⇒ Object
readonly
Attribute for field bh.
-
#bj ⇒ Object
readonly
Attribute for field bj.
-
#bs ⇒ Object
readonly
Attribute for field bs.
-
#by ⇒ Object
readonly
Attribute for field by.
-
#ca ⇒ Object
readonly
Attribute for field ca.
-
#cd ⇒ Object
readonly
Attribute for field cd.
-
#ch ⇒ Object
readonly
Attribute for field ch.
-
#cl ⇒ Object
readonly
Attribute for field cl.
-
#cm ⇒ Object
readonly
Attribute for field cm.
-
#co ⇒ Object
readonly
Attribute for field co.
-
#cr ⇒ Object
readonly
Attribute for field cr.
-
#cv ⇒ Object
readonly
Attribute for field cv.
-
#cy ⇒ Object
readonly
Attribute for field cy.
-
#cz ⇒ Object
readonly
Attribute for field cz.
-
#de ⇒ Object
readonly
Attribute for field de.
-
#dk ⇒ Object
readonly
Attribute for field dk.
-
#ec ⇒ Object
readonly
Attribute for field ec.
-
#ee ⇒ Object
readonly
Attribute for field ee.
-
#eg ⇒ Object
readonly
Attribute for field eg.
-
#es ⇒ Object
readonly
Attribute for field es.
-
#et ⇒ Object
readonly
Attribute for field et.
-
#fi ⇒ Object
readonly
Attribute for field fi.
-
#fr ⇒ Object
readonly
Attribute for field fr.
-
#gb ⇒ Object
readonly
Attribute for field gb.
-
#ge ⇒ Object
readonly
Attribute for field ge.
-
#gn ⇒ Object
readonly
Attribute for field gn.
-
#gr ⇒ Object
readonly
Attribute for field gr.
-
#hr ⇒ Object
readonly
Attribute for field hr.
-
#hu ⇒ Object
readonly
Attribute for field hu.
-
#id ⇒ Object
readonly
Attribute for field id.
-
#ie ⇒ Object
readonly
Attribute for field ie.
-
#in ⇒ Object
readonly
Attribute for field in.
-
#is ⇒ Object
readonly
Attribute for field is.
-
#it ⇒ Object
readonly
Attribute for field it.
-
#jp ⇒ Object
readonly
Attribute for field jp.
-
#ke ⇒ Object
readonly
Attribute for field ke.
-
#kg ⇒ Object
readonly
Attribute for field kg.
-
#kh ⇒ Object
readonly
Attribute for field kh.
-
#kr ⇒ Object
readonly
Attribute for field kr.
-
#kz ⇒ Object
readonly
Attribute for field kz.
-
#la ⇒ Object
readonly
Attribute for field la.
-
#lk ⇒ Object
readonly
Attribute for field lk.
-
#lt ⇒ Object
readonly
Attribute for field lt.
-
#lu ⇒ Object
readonly
Attribute for field lu.
-
#lv ⇒ Object
readonly
Attribute for field lv.
-
#ma ⇒ Object
readonly
Attribute for field ma.
-
#md ⇒ Object
readonly
Attribute for field md.
-
#me ⇒ Object
readonly
Attribute for field me.
-
#mk ⇒ Object
readonly
Attribute for field mk.
-
#mr ⇒ Object
readonly
Attribute for field mr.
-
#mt ⇒ Object
readonly
Attribute for field mt.
-
#mx ⇒ Object
readonly
Attribute for field mx.
-
#my ⇒ Object
readonly
Attribute for field my.
-
#ng ⇒ Object
readonly
Attribute for field ng.
-
#nl ⇒ Object
readonly
Attribute for field nl.
-
#no ⇒ Object
readonly
Attribute for field no.
-
#np ⇒ Object
readonly
Attribute for field np.
-
#nz ⇒ Object
readonly
Attribute for field nz.
-
#om ⇒ Object
readonly
Attribute for field om.
-
#pe ⇒ Object
readonly
Attribute for field pe.
-
#ph ⇒ Object
readonly
Attribute for field ph.
-
#pl ⇒ Object
readonly
Attribute for field pl.
-
#pt ⇒ Object
readonly
Attribute for field pt.
-
#ro ⇒ Object
readonly
Attribute for field ro.
-
#rs ⇒ Object
readonly
Attribute for field rs.
-
#ru ⇒ Object
readonly
Attribute for field ru.
-
#sa ⇒ Object
readonly
Attribute for field sa.
-
#se ⇒ Object
readonly
Attribute for field se.
-
#sg ⇒ Object
readonly
Attribute for field sg.
-
#si ⇒ Object
readonly
Attribute for field si.
-
#sk ⇒ Object
readonly
Attribute for field sk.
-
#sn ⇒ Object
readonly
Attribute for field sn.
-
#sr ⇒ Object
readonly
Attribute for field sr.
-
#th ⇒ Object
readonly
Attribute for field th.
-
#tj ⇒ Object
readonly
Attribute for field tj.
-
#tr ⇒ Object
readonly
Attribute for field tr.
-
#tw ⇒ Object
readonly
Attribute for field tw.
-
#tz ⇒ Object
readonly
Attribute for field tz.
-
#ua ⇒ Object
readonly
Attribute for field ua.
-
#ug ⇒ Object
readonly
Attribute for field ug.
-
#us ⇒ Object
readonly
Attribute for field us.
-
#uy ⇒ Object
readonly
Attribute for field uy.
-
#uz ⇒ Object
readonly
Attribute for field uz.
-
#vn ⇒ Object
readonly
Attribute for field vn.
-
#za ⇒ Object
readonly
Attribute for field za.
-
#zm ⇒ Object
readonly
Attribute for field zm.
-
#zw ⇒ Object
readonly
Attribute for field zw.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ae ⇒ Object (readonly)
Attribute for field ae
2340 2341 2342 |
# File 'lib/stripe/resources/tax/registration.rb', line 2340 def ae @ae end |
#al ⇒ Object (readonly)
Attribute for field al
2342 2343 2344 |
# File 'lib/stripe/resources/tax/registration.rb', line 2342 def al @al end |
#am ⇒ Object (readonly)
Attribute for field am
2344 2345 2346 |
# File 'lib/stripe/resources/tax/registration.rb', line 2344 def am @am end |
#ao ⇒ Object (readonly)
Attribute for field ao
2346 2347 2348 |
# File 'lib/stripe/resources/tax/registration.rb', line 2346 def ao @ao end |
#at ⇒ Object (readonly)
Attribute for field at
2348 2349 2350 |
# File 'lib/stripe/resources/tax/registration.rb', line 2348 def at @at end |
#au ⇒ Object (readonly)
Attribute for field au
2350 2351 2352 |
# File 'lib/stripe/resources/tax/registration.rb', line 2350 def au @au end |
#aw ⇒ Object (readonly)
Attribute for field aw
2352 2353 2354 |
# File 'lib/stripe/resources/tax/registration.rb', line 2352 def aw @aw end |
#az ⇒ Object (readonly)
Attribute for field az
2354 2355 2356 |
# File 'lib/stripe/resources/tax/registration.rb', line 2354 def az @az end |
#ba ⇒ Object (readonly)
Attribute for field ba
2356 2357 2358 |
# File 'lib/stripe/resources/tax/registration.rb', line 2356 def ba @ba end |
#bb ⇒ Object (readonly)
Attribute for field bb
2358 2359 2360 |
# File 'lib/stripe/resources/tax/registration.rb', line 2358 def bb @bb end |
#bd ⇒ Object (readonly)
Attribute for field bd
2360 2361 2362 |
# File 'lib/stripe/resources/tax/registration.rb', line 2360 def bd @bd end |
#be ⇒ Object (readonly)
Attribute for field be
2362 2363 2364 |
# File 'lib/stripe/resources/tax/registration.rb', line 2362 def be @be end |
#bf ⇒ Object (readonly)
Attribute for field bf
2364 2365 2366 |
# File 'lib/stripe/resources/tax/registration.rb', line 2364 def bf @bf end |
#bg ⇒ Object (readonly)
Attribute for field bg
2366 2367 2368 |
# File 'lib/stripe/resources/tax/registration.rb', line 2366 def bg @bg end |
#bh ⇒ Object (readonly)
Attribute for field bh
2368 2369 2370 |
# File 'lib/stripe/resources/tax/registration.rb', line 2368 def bh @bh end |
#bj ⇒ Object (readonly)
Attribute for field bj
2370 2371 2372 |
# File 'lib/stripe/resources/tax/registration.rb', line 2370 def bj @bj end |
#bs ⇒ Object (readonly)
Attribute for field bs
2372 2373 2374 |
# File 'lib/stripe/resources/tax/registration.rb', line 2372 def bs @bs end |
#by ⇒ Object (readonly)
Attribute for field by
2374 2375 2376 |
# File 'lib/stripe/resources/tax/registration.rb', line 2374 def by @by end |
#ca ⇒ Object (readonly)
Attribute for field ca
2376 2377 2378 |
# File 'lib/stripe/resources/tax/registration.rb', line 2376 def ca @ca end |
#cd ⇒ Object (readonly)
Attribute for field cd
2378 2379 2380 |
# File 'lib/stripe/resources/tax/registration.rb', line 2378 def cd @cd end |
#ch ⇒ Object (readonly)
Attribute for field ch
2380 2381 2382 |
# File 'lib/stripe/resources/tax/registration.rb', line 2380 def ch @ch end |
#cl ⇒ Object (readonly)
Attribute for field cl
2382 2383 2384 |
# File 'lib/stripe/resources/tax/registration.rb', line 2382 def cl @cl end |
#cm ⇒ Object (readonly)
Attribute for field cm
2384 2385 2386 |
# File 'lib/stripe/resources/tax/registration.rb', line 2384 def cm @cm end |
#co ⇒ Object (readonly)
Attribute for field co
2386 2387 2388 |
# File 'lib/stripe/resources/tax/registration.rb', line 2386 def co @co end |
#cr ⇒ Object (readonly)
Attribute for field cr
2388 2389 2390 |
# File 'lib/stripe/resources/tax/registration.rb', line 2388 def cr @cr end |
#cv ⇒ Object (readonly)
Attribute for field cv
2390 2391 2392 |
# File 'lib/stripe/resources/tax/registration.rb', line 2390 def cv @cv end |
#cy ⇒ Object (readonly)
Attribute for field cy
2392 2393 2394 |
# File 'lib/stripe/resources/tax/registration.rb', line 2392 def cy @cy end |
#cz ⇒ Object (readonly)
Attribute for field cz
2394 2395 2396 |
# File 'lib/stripe/resources/tax/registration.rb', line 2394 def cz @cz end |
#de ⇒ Object (readonly)
Attribute for field de
2396 2397 2398 |
# File 'lib/stripe/resources/tax/registration.rb', line 2396 def de @de end |
#dk ⇒ Object (readonly)
Attribute for field dk
2398 2399 2400 |
# File 'lib/stripe/resources/tax/registration.rb', line 2398 def dk @dk end |
#ec ⇒ Object (readonly)
Attribute for field ec
2400 2401 2402 |
# File 'lib/stripe/resources/tax/registration.rb', line 2400 def ec @ec end |
#ee ⇒ Object (readonly)
Attribute for field ee
2402 2403 2404 |
# File 'lib/stripe/resources/tax/registration.rb', line 2402 def ee @ee end |
#eg ⇒ Object (readonly)
Attribute for field eg
2404 2405 2406 |
# File 'lib/stripe/resources/tax/registration.rb', line 2404 def eg @eg end |
#es ⇒ Object (readonly)
Attribute for field es
2406 2407 2408 |
# File 'lib/stripe/resources/tax/registration.rb', line 2406 def es @es end |
#et ⇒ Object (readonly)
Attribute for field et
2408 2409 2410 |
# File 'lib/stripe/resources/tax/registration.rb', line 2408 def et @et end |
#fi ⇒ Object (readonly)
Attribute for field fi
2410 2411 2412 |
# File 'lib/stripe/resources/tax/registration.rb', line 2410 def fi @fi end |
#fr ⇒ Object (readonly)
Attribute for field fr
2412 2413 2414 |
# File 'lib/stripe/resources/tax/registration.rb', line 2412 def fr @fr end |
#gb ⇒ Object (readonly)
Attribute for field gb
2414 2415 2416 |
# File 'lib/stripe/resources/tax/registration.rb', line 2414 def gb @gb end |
#ge ⇒ Object (readonly)
Attribute for field ge
2416 2417 2418 |
# File 'lib/stripe/resources/tax/registration.rb', line 2416 def ge @ge end |
#gn ⇒ Object (readonly)
Attribute for field gn
2418 2419 2420 |
# File 'lib/stripe/resources/tax/registration.rb', line 2418 def gn @gn end |
#gr ⇒ Object (readonly)
Attribute for field gr
2420 2421 2422 |
# File 'lib/stripe/resources/tax/registration.rb', line 2420 def gr @gr end |
#hr ⇒ Object (readonly)
Attribute for field hr
2422 2423 2424 |
# File 'lib/stripe/resources/tax/registration.rb', line 2422 def hr @hr end |
#hu ⇒ Object (readonly)
Attribute for field hu
2424 2425 2426 |
# File 'lib/stripe/resources/tax/registration.rb', line 2424 def hu @hu end |
#id ⇒ Object (readonly)
Attribute for field id
2426 2427 2428 |
# File 'lib/stripe/resources/tax/registration.rb', line 2426 def id @id end |
#ie ⇒ Object (readonly)
Attribute for field ie
2428 2429 2430 |
# File 'lib/stripe/resources/tax/registration.rb', line 2428 def ie @ie end |
#in ⇒ Object (readonly)
Attribute for field in
2430 2431 2432 |
# File 'lib/stripe/resources/tax/registration.rb', line 2430 def in @in end |
#is ⇒ Object (readonly)
Attribute for field is
2432 2433 2434 |
# File 'lib/stripe/resources/tax/registration.rb', line 2432 def is @is end |
#it ⇒ Object (readonly)
Attribute for field it
2434 2435 2436 |
# File 'lib/stripe/resources/tax/registration.rb', line 2434 def it @it end |
#jp ⇒ Object (readonly)
Attribute for field jp
2436 2437 2438 |
# File 'lib/stripe/resources/tax/registration.rb', line 2436 def jp @jp end |
#ke ⇒ Object (readonly)
Attribute for field ke
2438 2439 2440 |
# File 'lib/stripe/resources/tax/registration.rb', line 2438 def ke @ke end |
#kg ⇒ Object (readonly)
Attribute for field kg
2440 2441 2442 |
# File 'lib/stripe/resources/tax/registration.rb', line 2440 def kg @kg end |
#kh ⇒ Object (readonly)
Attribute for field kh
2442 2443 2444 |
# File 'lib/stripe/resources/tax/registration.rb', line 2442 def kh @kh end |
#kr ⇒ Object (readonly)
Attribute for field kr
2444 2445 2446 |
# File 'lib/stripe/resources/tax/registration.rb', line 2444 def kr @kr end |
#kz ⇒ Object (readonly)
Attribute for field kz
2446 2447 2448 |
# File 'lib/stripe/resources/tax/registration.rb', line 2446 def kz @kz end |
#la ⇒ Object (readonly)
Attribute for field la
2448 2449 2450 |
# File 'lib/stripe/resources/tax/registration.rb', line 2448 def la @la end |
#lk ⇒ Object (readonly)
Attribute for field lk
2450 2451 2452 |
# File 'lib/stripe/resources/tax/registration.rb', line 2450 def lk @lk end |
#lt ⇒ Object (readonly)
Attribute for field lt
2452 2453 2454 |
# File 'lib/stripe/resources/tax/registration.rb', line 2452 def lt @lt end |
#lu ⇒ Object (readonly)
Attribute for field lu
2454 2455 2456 |
# File 'lib/stripe/resources/tax/registration.rb', line 2454 def lu @lu end |
#lv ⇒ Object (readonly)
Attribute for field lv
2456 2457 2458 |
# File 'lib/stripe/resources/tax/registration.rb', line 2456 def lv @lv end |
#ma ⇒ Object (readonly)
Attribute for field ma
2458 2459 2460 |
# File 'lib/stripe/resources/tax/registration.rb', line 2458 def ma @ma end |
#md ⇒ Object (readonly)
Attribute for field md
2460 2461 2462 |
# File 'lib/stripe/resources/tax/registration.rb', line 2460 def md @md end |
#me ⇒ Object (readonly)
Attribute for field me
2462 2463 2464 |
# File 'lib/stripe/resources/tax/registration.rb', line 2462 def me @me end |
#mk ⇒ Object (readonly)
Attribute for field mk
2464 2465 2466 |
# File 'lib/stripe/resources/tax/registration.rb', line 2464 def mk @mk end |
#mr ⇒ Object (readonly)
Attribute for field mr
2466 2467 2468 |
# File 'lib/stripe/resources/tax/registration.rb', line 2466 def mr @mr end |
#mt ⇒ Object (readonly)
Attribute for field mt
2468 2469 2470 |
# File 'lib/stripe/resources/tax/registration.rb', line 2468 def mt @mt end |
#mx ⇒ Object (readonly)
Attribute for field mx
2470 2471 2472 |
# File 'lib/stripe/resources/tax/registration.rb', line 2470 def mx @mx end |
#my ⇒ Object (readonly)
Attribute for field my
2472 2473 2474 |
# File 'lib/stripe/resources/tax/registration.rb', line 2472 def my @my end |
#ng ⇒ Object (readonly)
Attribute for field ng
2474 2475 2476 |
# File 'lib/stripe/resources/tax/registration.rb', line 2474 def ng @ng end |
#nl ⇒ Object (readonly)
Attribute for field nl
2476 2477 2478 |
# File 'lib/stripe/resources/tax/registration.rb', line 2476 def nl @nl end |
#no ⇒ Object (readonly)
Attribute for field no
2478 2479 2480 |
# File 'lib/stripe/resources/tax/registration.rb', line 2478 def no @no end |
#np ⇒ Object (readonly)
Attribute for field np
2480 2481 2482 |
# File 'lib/stripe/resources/tax/registration.rb', line 2480 def np @np end |
#nz ⇒ Object (readonly)
Attribute for field nz
2482 2483 2484 |
# File 'lib/stripe/resources/tax/registration.rb', line 2482 def nz @nz end |
#om ⇒ Object (readonly)
Attribute for field om
2484 2485 2486 |
# File 'lib/stripe/resources/tax/registration.rb', line 2484 def om @om end |
#pe ⇒ Object (readonly)
Attribute for field pe
2486 2487 2488 |
# File 'lib/stripe/resources/tax/registration.rb', line 2486 def pe @pe end |
#ph ⇒ Object (readonly)
Attribute for field ph
2488 2489 2490 |
# File 'lib/stripe/resources/tax/registration.rb', line 2488 def ph @ph end |
#pl ⇒ Object (readonly)
Attribute for field pl
2490 2491 2492 |
# File 'lib/stripe/resources/tax/registration.rb', line 2490 def pl @pl end |
#pt ⇒ Object (readonly)
Attribute for field pt
2492 2493 2494 |
# File 'lib/stripe/resources/tax/registration.rb', line 2492 def pt @pt end |
#ro ⇒ Object (readonly)
Attribute for field ro
2494 2495 2496 |
# File 'lib/stripe/resources/tax/registration.rb', line 2494 def ro @ro end |
#rs ⇒ Object (readonly)
Attribute for field rs
2496 2497 2498 |
# File 'lib/stripe/resources/tax/registration.rb', line 2496 def rs @rs end |
#ru ⇒ Object (readonly)
Attribute for field ru
2498 2499 2500 |
# File 'lib/stripe/resources/tax/registration.rb', line 2498 def ru @ru end |
#sa ⇒ Object (readonly)
Attribute for field sa
2500 2501 2502 |
# File 'lib/stripe/resources/tax/registration.rb', line 2500 def sa @sa end |
#se ⇒ Object (readonly)
Attribute for field se
2502 2503 2504 |
# File 'lib/stripe/resources/tax/registration.rb', line 2502 def se @se end |
#sg ⇒ Object (readonly)
Attribute for field sg
2504 2505 2506 |
# File 'lib/stripe/resources/tax/registration.rb', line 2504 def sg @sg end |
#si ⇒ Object (readonly)
Attribute for field si
2506 2507 2508 |
# File 'lib/stripe/resources/tax/registration.rb', line 2506 def si @si end |
#sk ⇒ Object (readonly)
Attribute for field sk
2508 2509 2510 |
# File 'lib/stripe/resources/tax/registration.rb', line 2508 def sk @sk end |
#sn ⇒ Object (readonly)
Attribute for field sn
2510 2511 2512 |
# File 'lib/stripe/resources/tax/registration.rb', line 2510 def sn @sn end |
#sr ⇒ Object (readonly)
Attribute for field sr
2512 2513 2514 |
# File 'lib/stripe/resources/tax/registration.rb', line 2512 def sr @sr end |
#th ⇒ Object (readonly)
Attribute for field th
2514 2515 2516 |
# File 'lib/stripe/resources/tax/registration.rb', line 2514 def th @th end |
#tj ⇒ Object (readonly)
Attribute for field tj
2516 2517 2518 |
# File 'lib/stripe/resources/tax/registration.rb', line 2516 def tj @tj end |
#tr ⇒ Object (readonly)
Attribute for field tr
2518 2519 2520 |
# File 'lib/stripe/resources/tax/registration.rb', line 2518 def tr @tr end |
#tw ⇒ Object (readonly)
Attribute for field tw
2520 2521 2522 |
# File 'lib/stripe/resources/tax/registration.rb', line 2520 def tw @tw end |
#tz ⇒ Object (readonly)
Attribute for field tz
2522 2523 2524 |
# File 'lib/stripe/resources/tax/registration.rb', line 2522 def tz @tz end |
#ua ⇒ Object (readonly)
Attribute for field ua
2524 2525 2526 |
# File 'lib/stripe/resources/tax/registration.rb', line 2524 def ua @ua end |
#ug ⇒ Object (readonly)
Attribute for field ug
2526 2527 2528 |
# File 'lib/stripe/resources/tax/registration.rb', line 2526 def ug @ug end |
#us ⇒ Object (readonly)
Attribute for field us
2528 2529 2530 |
# File 'lib/stripe/resources/tax/registration.rb', line 2528 def us @us end |
#uy ⇒ Object (readonly)
Attribute for field uy
2530 2531 2532 |
# File 'lib/stripe/resources/tax/registration.rb', line 2530 def uy @uy end |
#uz ⇒ Object (readonly)
Attribute for field uz
2532 2533 2534 |
# File 'lib/stripe/resources/tax/registration.rb', line 2532 def uz @uz end |
#vn ⇒ Object (readonly)
Attribute for field vn
2534 2535 2536 |
# File 'lib/stripe/resources/tax/registration.rb', line 2534 def vn @vn end |
#za ⇒ Object (readonly)
Attribute for field za
2536 2537 2538 |
# File 'lib/stripe/resources/tax/registration.rb', line 2536 def za @za end |
#zm ⇒ Object (readonly)
Attribute for field zm
2538 2539 2540 |
# File 'lib/stripe/resources/tax/registration.rb', line 2538 def zm @zm end |
#zw ⇒ Object (readonly)
Attribute for field zw
2540 2541 2542 |
# File 'lib/stripe/resources/tax/registration.rb', line 2540 def zw @zw end |
Class Method Details
.field_remappings ⇒ Object
2648 2649 2650 |
# File 'lib/stripe/resources/tax/registration.rb', line 2648 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 |
# File 'lib/stripe/resources/tax/registration.rb', line 2542 def self.inner_class_types @inner_class_types = { ae: Ae, al: Al, am: Am, ao: Ao, at: At, au: Au, aw: Aw, az: Az, ba: Ba, bb: Bb, bd: Bd, be: Be, bf: Bf, bg: Bg, bh: Bh, bj: Bj, bs: Bs, by: By, ca: Ca, cd: Cd, ch: Ch, cl: Cl, cm: Cm, co: Co, cr: Cr, cv: Cv, cy: Cy, cz: Cz, de: De, dk: Dk, ec: Ec, ee: Ee, eg: Eg, es: Es, et: Et, fi: Fi, fr: Fr, gb: Gb, ge: Ge, gn: Gn, gr: Gr, hr: Hr, hu: Hu, id: Id, ie: Ie, in: In, is: Is, it: It, jp: Jp, ke: Ke, kg: Kg, kh: Kh, kr: Kr, kz: Kz, la: La, lk: Lk, lt: Lt, lu: Lu, lv: Lv, ma: Ma, md: Md, me: Me, mk: Mk, mr: Mr, mt: Mt, mx: Mx, my: My, ng: Ng, nl: Nl, no: No, np: Np, nz: Nz, om: Om, pe: Pe, ph: Ph, pl: Pl, pt: Pt, ro: Ro, rs: Rs, ru: Ru, sa: Sa, se: Se, sg: Sg, si: Si, sk: Sk, sn: Sn, sr: Sr, th: Th, tj: Tj, tr: Tr, tw: Tw, tz: Tz, ua: Ua, ug: Ug, us: Us, uy: Uy, uz: Uz, vn: Vn, za: Za, zm: Zm, zw: Zw, } end |