Class: Stripe::Tax::Registration::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: CountryOptions
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the Tax Registration becomes active.
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
4208 4209 4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 |
# File 'lib/stripe/resources/tax/registration.rb', line 4208 def initialize( active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil ) @active_from = active_from @country = country @country_options = @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
4198 4199 4200 |
# File 'lib/stripe/resources/tax/registration.rb', line 4198 def active_from @active_from end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
4200 4201 4202 |
# File 'lib/stripe/resources/tax/registration.rb', line 4200 def country @country end |
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
4202 4203 4204 |
# File 'lib/stripe/resources/tax/registration.rb', line 4202 def @country_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4204 4205 4206 |
# File 'lib/stripe/resources/tax/registration.rb', line 4204 def @expand end |
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
4206 4207 4208 |
# File 'lib/stripe/resources/tax/registration.rb', line 4206 def expires_at @expires_at end |