Class: Stripe::Tax::Registration::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
# File 'lib/stripe/resources/tax/registration.rb', line 2606

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2596
2597
2598
# File 'lib/stripe/resources/tax/registration.rb', line 2596

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2598
2599
2600
# File 'lib/stripe/resources/tax/registration.rb', line 2598

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2600
2601
2602
# File 'lib/stripe/resources/tax/registration.rb', line 2600

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2602
2603
2604
# File 'lib/stripe/resources/tax/registration.rb', line 2602

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2604
2605
2606
# File 'lib/stripe/resources/tax/registration.rb', line 2604

def expires_at
  @expires_at
end