Class: Stripe::Tax::Registration::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2586
2587
2588
2589
2590
2591
2592
2593
2594
2595
2596
2597
2598
# File 'lib/stripe/resources/tax/registration.rb', line 2586

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2576
2577
2578
# File 'lib/stripe/resources/tax/registration.rb', line 2576

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2578
2579
2580
# File 'lib/stripe/resources/tax/registration.rb', line 2578

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2580
2581
2582
# File 'lib/stripe/resources/tax/registration.rb', line 2580

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2582
2583
2584
# File 'lib/stripe/resources/tax/registration.rb', line 2582

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2584
2585
2586
# File 'lib/stripe/resources/tax/registration.rb', line 2584

def expires_at
  @expires_at
end