Class: Stripe::Tax::Registration::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/stripe/resources/tax/registration.rb', line 2366

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2356
2357
2358
# File 'lib/stripe/resources/tax/registration.rb', line 2356

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2358
2359
2360
# File 'lib/stripe/resources/tax/registration.rb', line 2358

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2360
2361
2362
# File 'lib/stripe/resources/tax/registration.rb', line 2360

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2362
2363
2364
# File 'lib/stripe/resources/tax/registration.rb', line 2362

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2364
2365
2366
# File 'lib/stripe/resources/tax/registration.rb', line 2364

def expires_at
  @expires_at
end