Class: Stripe::Tax::Registration::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
# File 'lib/stripe/resources/tax/registration.rb', line 2526

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2516
2517
2518
# File 'lib/stripe/resources/tax/registration.rb', line 2516

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2518
2519
2520
# File 'lib/stripe/resources/tax/registration.rb', line 2518

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2520
2521
2522
# File 'lib/stripe/resources/tax/registration.rb', line 2520

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2522
2523
2524
# File 'lib/stripe/resources/tax/registration.rb', line 2522

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2524
2525
2526
# File 'lib/stripe/resources/tax/registration.rb', line 2524

def expires_at
  @expires_at
end