Class: Stripe::Tax::Registration::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: CountryOptions
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the Tax Registration becomes active.
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/stripe/resources/tax/registration.rb', line 2346 def initialize( active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil ) @active_from = active_from @country = country @country_options = @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
2336 2337 2338 |
# File 'lib/stripe/resources/tax/registration.rb', line 2336 def active_from @active_from end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2338 2339 2340 |
# File 'lib/stripe/resources/tax/registration.rb', line 2338 def country @country end |
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
2340 2341 2342 |
# File 'lib/stripe/resources/tax/registration.rb', line 2340 def @country_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2342 2343 2344 |
# File 'lib/stripe/resources/tax/registration.rb', line 2342 def @expand end |
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
2344 2345 2346 |
# File 'lib/stripe/resources/tax/registration.rb', line 2344 def expires_at @expires_at end |