Class: Stripe::Tax::Registration::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/stripe/resources/tax/registration.rb', line 2128

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2114
2115
2116
# File 'lib/stripe/resources/tax/registration.rb', line 2114

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2117
2118
2119
# File 'lib/stripe/resources/tax/registration.rb', line 2117

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2120
2121
2122
# File 'lib/stripe/resources/tax/registration.rb', line 2120

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2123
2124
2125
# File 'lib/stripe/resources/tax/registration.rb', line 2123

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2126
2127
2128
# File 'lib/stripe/resources/tax/registration.rb', line 2126

def expires_at
  @expires_at
end