Class: Stripe::Tax::Registration::CreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#al ⇒ Object
Options for the registration in AL.
-
#am ⇒ Object
Options for the registration in AM.
-
#ao ⇒ Object
Options for the registration in AO.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#aw ⇒ Object
Options for the registration in AW.
-
#az ⇒ Object
Options for the registration in AZ.
-
#ba ⇒ Object
Options for the registration in BA.
-
#bb ⇒ Object
Options for the registration in BB.
-
#bd ⇒ Object
Options for the registration in BD.
-
#be ⇒ Object
Options for the registration in BE.
-
#bf ⇒ Object
Options for the registration in BF.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#bj ⇒ Object
Options for the registration in BJ.
-
#bs ⇒ Object
Options for the registration in BS.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#cd ⇒ Object
Options for the registration in CD.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#cm ⇒ Object
Options for the registration in CM.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cv ⇒ Object
Options for the registration in CV.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#et ⇒ Object
Options for the registration in ET.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gn ⇒ Object
Options for the registration in GN.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#in ⇒ Object
Options for the registration in IN.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kg ⇒ Object
Options for the registration in KG.
-
#kh ⇒ Object
Options for the registration in KH.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#la ⇒ Object
Options for the registration in LA.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#me ⇒ Object
Options for the registration in ME.
-
#mk ⇒ Object
Options for the registration in MK.
-
#mr ⇒ Object
Options for the registration in MR.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#np ⇒ Object
Options for the registration in NP.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pe ⇒ Object
Options for the registration in PE.
-
#ph ⇒ Object
Options for the registration in PH.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#sn ⇒ Object
Options for the registration in SN.
-
#sr ⇒ Object
Options for the registration in SR.
-
#th ⇒ Object
Options for the registration in TH.
-
#tj ⇒ Object
Options for the registration in TJ.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#ua ⇒ Object
Options for the registration in UA.
-
#ug ⇒ Object
Options for the registration in UG.
-
#us ⇒ Object
Options for the registration in US.
-
#uy ⇒ Object
Options for the registration in UY.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
-
#zm ⇒ Object
Options for the registration in ZM.
-
#zw ⇒ Object
Options for the registration in ZW.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/stripe/resources/tax/registration.rb', line 2771 def initialize( ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil ) @ae = ae @al = al @am = am @ao = ao @at = at @au = au @aw = aw @az = az @ba = ba @bb = bb @bd = bd @be = be @bf = bf @bg = bg @bh = bh @bj = bj @bs = bs @by = by @ca = ca @cd = cd @ch = ch @cl = cl @cm = cm @co = co @cr = cr @cv = cv @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @et = et @fi = fi @fr = fr @gb = gb @ge = ge @gn = gn @gr = gr @hr = hr @hu = hu @id = id @ie = ie @in = in_ @is = is @it = it @jp = jp @ke = ke @kg = kg @kh = kh @kr = kr @kz = kz @la = la @lt = lt @lu = lu @lv = lv @ma = ma @md = md @me = me @mk = mk @mr = mr @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @np = np @nz = nz @om = om @pe = pe @ph = ph @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @sn = sn @sr = sr @th = th @tj = tj @tr = tr @tz = tz @ua = ua @ug = ug @us = us @uy = uy @uz = uz @vn = vn @za = za @zm = zm @zw = zw end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
2573 2574 2575 |
# File 'lib/stripe/resources/tax/registration.rb', line 2573 def ae @ae end |
#al ⇒ Object
Options for the registration in AL.
2575 2576 2577 |
# File 'lib/stripe/resources/tax/registration.rb', line 2575 def al @al end |
#am ⇒ Object
Options for the registration in AM.
2577 2578 2579 |
# File 'lib/stripe/resources/tax/registration.rb', line 2577 def am @am end |
#ao ⇒ Object
Options for the registration in AO.
2579 2580 2581 |
# File 'lib/stripe/resources/tax/registration.rb', line 2579 def ao @ao end |
#at ⇒ Object
Options for the registration in AT.
2581 2582 2583 |
# File 'lib/stripe/resources/tax/registration.rb', line 2581 def at @at end |
#au ⇒ Object
Options for the registration in AU.
2583 2584 2585 |
# File 'lib/stripe/resources/tax/registration.rb', line 2583 def au @au end |
#aw ⇒ Object
Options for the registration in AW.
2585 2586 2587 |
# File 'lib/stripe/resources/tax/registration.rb', line 2585 def aw @aw end |
#az ⇒ Object
Options for the registration in AZ.
2587 2588 2589 |
# File 'lib/stripe/resources/tax/registration.rb', line 2587 def az @az end |
#ba ⇒ Object
Options for the registration in BA.
2589 2590 2591 |
# File 'lib/stripe/resources/tax/registration.rb', line 2589 def ba @ba end |
#bb ⇒ Object
Options for the registration in BB.
2591 2592 2593 |
# File 'lib/stripe/resources/tax/registration.rb', line 2591 def bb @bb end |
#bd ⇒ Object
Options for the registration in BD.
2593 2594 2595 |
# File 'lib/stripe/resources/tax/registration.rb', line 2593 def bd @bd end |
#be ⇒ Object
Options for the registration in BE.
2595 2596 2597 |
# File 'lib/stripe/resources/tax/registration.rb', line 2595 def be @be end |
#bf ⇒ Object
Options for the registration in BF.
2597 2598 2599 |
# File 'lib/stripe/resources/tax/registration.rb', line 2597 def bf @bf end |
#bg ⇒ Object
Options for the registration in BG.
2599 2600 2601 |
# File 'lib/stripe/resources/tax/registration.rb', line 2599 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
2601 2602 2603 |
# File 'lib/stripe/resources/tax/registration.rb', line 2601 def bh @bh end |
#bj ⇒ Object
Options for the registration in BJ.
2603 2604 2605 |
# File 'lib/stripe/resources/tax/registration.rb', line 2603 def bj @bj end |
#bs ⇒ Object
Options for the registration in BS.
2605 2606 2607 |
# File 'lib/stripe/resources/tax/registration.rb', line 2605 def bs @bs end |
#by ⇒ Object
Options for the registration in BY.
2607 2608 2609 |
# File 'lib/stripe/resources/tax/registration.rb', line 2607 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
2609 2610 2611 |
# File 'lib/stripe/resources/tax/registration.rb', line 2609 def ca @ca end |
#cd ⇒ Object
Options for the registration in CD.
2611 2612 2613 |
# File 'lib/stripe/resources/tax/registration.rb', line 2611 def cd @cd end |
#ch ⇒ Object
Options for the registration in CH.
2613 2614 2615 |
# File 'lib/stripe/resources/tax/registration.rb', line 2613 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
2615 2616 2617 |
# File 'lib/stripe/resources/tax/registration.rb', line 2615 def cl @cl end |
#cm ⇒ Object
Options for the registration in CM.
2617 2618 2619 |
# File 'lib/stripe/resources/tax/registration.rb', line 2617 def cm @cm end |
#co ⇒ Object
Options for the registration in CO.
2619 2620 2621 |
# File 'lib/stripe/resources/tax/registration.rb', line 2619 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
2621 2622 2623 |
# File 'lib/stripe/resources/tax/registration.rb', line 2621 def cr @cr end |
#cv ⇒ Object
Options for the registration in CV.
2623 2624 2625 |
# File 'lib/stripe/resources/tax/registration.rb', line 2623 def cv @cv end |
#cy ⇒ Object
Options for the registration in CY.
2625 2626 2627 |
# File 'lib/stripe/resources/tax/registration.rb', line 2625 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
2627 2628 2629 |
# File 'lib/stripe/resources/tax/registration.rb', line 2627 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
2629 2630 2631 |
# File 'lib/stripe/resources/tax/registration.rb', line 2629 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
2631 2632 2633 |
# File 'lib/stripe/resources/tax/registration.rb', line 2631 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
2633 2634 2635 |
# File 'lib/stripe/resources/tax/registration.rb', line 2633 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
2635 2636 2637 |
# File 'lib/stripe/resources/tax/registration.rb', line 2635 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
2637 2638 2639 |
# File 'lib/stripe/resources/tax/registration.rb', line 2637 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
2639 2640 2641 |
# File 'lib/stripe/resources/tax/registration.rb', line 2639 def es @es end |
#et ⇒ Object
Options for the registration in ET.
2641 2642 2643 |
# File 'lib/stripe/resources/tax/registration.rb', line 2641 def et @et end |
#fi ⇒ Object
Options for the registration in FI.
2643 2644 2645 |
# File 'lib/stripe/resources/tax/registration.rb', line 2643 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
2645 2646 2647 |
# File 'lib/stripe/resources/tax/registration.rb', line 2645 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
2647 2648 2649 |
# File 'lib/stripe/resources/tax/registration.rb', line 2647 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
2649 2650 2651 |
# File 'lib/stripe/resources/tax/registration.rb', line 2649 def ge @ge end |
#gn ⇒ Object
Options for the registration in GN.
2651 2652 2653 |
# File 'lib/stripe/resources/tax/registration.rb', line 2651 def gn @gn end |
#gr ⇒ Object
Options for the registration in GR.
2653 2654 2655 |
# File 'lib/stripe/resources/tax/registration.rb', line 2653 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
2655 2656 2657 |
# File 'lib/stripe/resources/tax/registration.rb', line 2655 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
2657 2658 2659 |
# File 'lib/stripe/resources/tax/registration.rb', line 2657 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
2659 2660 2661 |
# File 'lib/stripe/resources/tax/registration.rb', line 2659 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
2661 2662 2663 |
# File 'lib/stripe/resources/tax/registration.rb', line 2661 def ie @ie end |
#in ⇒ Object
Options for the registration in IN.
2663 2664 2665 |
# File 'lib/stripe/resources/tax/registration.rb', line 2663 def in @in end |
#is ⇒ Object
Options for the registration in IS.
2665 2666 2667 |
# File 'lib/stripe/resources/tax/registration.rb', line 2665 def is @is end |
#it ⇒ Object
Options for the registration in IT.
2667 2668 2669 |
# File 'lib/stripe/resources/tax/registration.rb', line 2667 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
2669 2670 2671 |
# File 'lib/stripe/resources/tax/registration.rb', line 2669 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
2671 2672 2673 |
# File 'lib/stripe/resources/tax/registration.rb', line 2671 def ke @ke end |
#kg ⇒ Object
Options for the registration in KG.
2673 2674 2675 |
# File 'lib/stripe/resources/tax/registration.rb', line 2673 def kg @kg end |
#kh ⇒ Object
Options for the registration in KH.
2675 2676 2677 |
# File 'lib/stripe/resources/tax/registration.rb', line 2675 def kh @kh end |
#kr ⇒ Object
Options for the registration in KR.
2677 2678 2679 |
# File 'lib/stripe/resources/tax/registration.rb', line 2677 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
2679 2680 2681 |
# File 'lib/stripe/resources/tax/registration.rb', line 2679 def kz @kz end |
#la ⇒ Object
Options for the registration in LA.
2681 2682 2683 |
# File 'lib/stripe/resources/tax/registration.rb', line 2681 def la @la end |
#lt ⇒ Object
Options for the registration in LT.
2683 2684 2685 |
# File 'lib/stripe/resources/tax/registration.rb', line 2683 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
2685 2686 2687 |
# File 'lib/stripe/resources/tax/registration.rb', line 2685 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
2687 2688 2689 |
# File 'lib/stripe/resources/tax/registration.rb', line 2687 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
2689 2690 2691 |
# File 'lib/stripe/resources/tax/registration.rb', line 2689 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
2691 2692 2693 |
# File 'lib/stripe/resources/tax/registration.rb', line 2691 def md @md end |
#me ⇒ Object
Options for the registration in ME.
2693 2694 2695 |
# File 'lib/stripe/resources/tax/registration.rb', line 2693 def me @me end |
#mk ⇒ Object
Options for the registration in MK.
2695 2696 2697 |
# File 'lib/stripe/resources/tax/registration.rb', line 2695 def mk @mk end |
#mr ⇒ Object
Options for the registration in MR.
2697 2698 2699 |
# File 'lib/stripe/resources/tax/registration.rb', line 2697 def mr @mr end |
#mt ⇒ Object
Options for the registration in MT.
2699 2700 2701 |
# File 'lib/stripe/resources/tax/registration.rb', line 2699 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
2701 2702 2703 |
# File 'lib/stripe/resources/tax/registration.rb', line 2701 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
2703 2704 2705 |
# File 'lib/stripe/resources/tax/registration.rb', line 2703 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
2705 2706 2707 |
# File 'lib/stripe/resources/tax/registration.rb', line 2705 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
2707 2708 2709 |
# File 'lib/stripe/resources/tax/registration.rb', line 2707 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
2709 2710 2711 |
# File 'lib/stripe/resources/tax/registration.rb', line 2709 def no @no end |
#np ⇒ Object
Options for the registration in NP.
2711 2712 2713 |
# File 'lib/stripe/resources/tax/registration.rb', line 2711 def np @np end |
#nz ⇒ Object
Options for the registration in NZ.
2713 2714 2715 |
# File 'lib/stripe/resources/tax/registration.rb', line 2713 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
2715 2716 2717 |
# File 'lib/stripe/resources/tax/registration.rb', line 2715 def om @om end |
#pe ⇒ Object
Options for the registration in PE.
2717 2718 2719 |
# File 'lib/stripe/resources/tax/registration.rb', line 2717 def pe @pe end |
#ph ⇒ Object
Options for the registration in PH.
2719 2720 2721 |
# File 'lib/stripe/resources/tax/registration.rb', line 2719 def ph @ph end |
#pl ⇒ Object
Options for the registration in PL.
2721 2722 2723 |
# File 'lib/stripe/resources/tax/registration.rb', line 2721 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
2723 2724 2725 |
# File 'lib/stripe/resources/tax/registration.rb', line 2723 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
2725 2726 2727 |
# File 'lib/stripe/resources/tax/registration.rb', line 2725 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
2727 2728 2729 |
# File 'lib/stripe/resources/tax/registration.rb', line 2727 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
2729 2730 2731 |
# File 'lib/stripe/resources/tax/registration.rb', line 2729 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
2731 2732 2733 |
# File 'lib/stripe/resources/tax/registration.rb', line 2731 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
2733 2734 2735 |
# File 'lib/stripe/resources/tax/registration.rb', line 2733 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
2735 2736 2737 |
# File 'lib/stripe/resources/tax/registration.rb', line 2735 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
2737 2738 2739 |
# File 'lib/stripe/resources/tax/registration.rb', line 2737 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
2739 2740 2741 |
# File 'lib/stripe/resources/tax/registration.rb', line 2739 def sk @sk end |
#sn ⇒ Object
Options for the registration in SN.
2741 2742 2743 |
# File 'lib/stripe/resources/tax/registration.rb', line 2741 def sn @sn end |
#sr ⇒ Object
Options for the registration in SR.
2743 2744 2745 |
# File 'lib/stripe/resources/tax/registration.rb', line 2743 def sr @sr end |
#th ⇒ Object
Options for the registration in TH.
2745 2746 2747 |
# File 'lib/stripe/resources/tax/registration.rb', line 2745 def th @th end |
#tj ⇒ Object
Options for the registration in TJ.
2747 2748 2749 |
# File 'lib/stripe/resources/tax/registration.rb', line 2747 def tj @tj end |
#tr ⇒ Object
Options for the registration in TR.
2749 2750 2751 |
# File 'lib/stripe/resources/tax/registration.rb', line 2749 def tr @tr end |
#tz ⇒ Object
Options for the registration in TZ.
2751 2752 2753 |
# File 'lib/stripe/resources/tax/registration.rb', line 2751 def tz @tz end |
#ua ⇒ Object
Options for the registration in UA.
2753 2754 2755 |
# File 'lib/stripe/resources/tax/registration.rb', line 2753 def ua @ua end |
#ug ⇒ Object
Options for the registration in UG.
2755 2756 2757 |
# File 'lib/stripe/resources/tax/registration.rb', line 2755 def ug @ug end |
#us ⇒ Object
Options for the registration in US.
2757 2758 2759 |
# File 'lib/stripe/resources/tax/registration.rb', line 2757 def us @us end |
#uy ⇒ Object
Options for the registration in UY.
2759 2760 2761 |
# File 'lib/stripe/resources/tax/registration.rb', line 2759 def uy @uy end |
#uz ⇒ Object
Options for the registration in UZ.
2761 2762 2763 |
# File 'lib/stripe/resources/tax/registration.rb', line 2761 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
2763 2764 2765 |
# File 'lib/stripe/resources/tax/registration.rb', line 2763 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
2765 2766 2767 |
# File 'lib/stripe/resources/tax/registration.rb', line 2765 def za @za end |
#zm ⇒ Object
Options for the registration in ZM.
2767 2768 2769 |
# File 'lib/stripe/resources/tax/registration.rb', line 2767 def zm @zm end |
#zw ⇒ Object
Options for the registration in ZW.
2769 2770 2771 |
# File 'lib/stripe/resources/tax/registration.rb', line 2769 def zw @zw end |