Class: Stripe::Tax::Registration::CreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#al ⇒ Object
Options for the registration in AL.
-
#am ⇒ Object
Options for the registration in AM.
-
#ao ⇒ Object
Options for the registration in AO.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#aw ⇒ Object
Options for the registration in AW.
-
#az ⇒ Object
Options for the registration in AZ.
-
#ba ⇒ Object
Options for the registration in BA.
-
#bb ⇒ Object
Options for the registration in BB.
-
#bd ⇒ Object
Options for the registration in BD.
-
#be ⇒ Object
Options for the registration in BE.
-
#bf ⇒ Object
Options for the registration in BF.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#bj ⇒ Object
Options for the registration in BJ.
-
#bs ⇒ Object
Options for the registration in BS.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#cd ⇒ Object
Options for the registration in CD.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#cm ⇒ Object
Options for the registration in CM.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cv ⇒ Object
Options for the registration in CV.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#et ⇒ Object
Options for the registration in ET.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gn ⇒ Object
Options for the registration in GN.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#in ⇒ Object
Options for the registration in IN.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kg ⇒ Object
Options for the registration in KG.
-
#kh ⇒ Object
Options for the registration in KH.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#la ⇒ Object
Options for the registration in LA.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#me ⇒ Object
Options for the registration in ME.
-
#mk ⇒ Object
Options for the registration in MK.
-
#mr ⇒ Object
Options for the registration in MR.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#np ⇒ Object
Options for the registration in NP.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pe ⇒ Object
Options for the registration in PE.
-
#ph ⇒ Object
Options for the registration in PH.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#sn ⇒ Object
Options for the registration in SN.
-
#sr ⇒ Object
Options for the registration in SR.
-
#th ⇒ Object
Options for the registration in TH.
-
#tj ⇒ Object
Options for the registration in TJ.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#ua ⇒ Object
Options for the registration in UA.
-
#ug ⇒ Object
Options for the registration in UG.
-
#us ⇒ Object
Options for the registration in US.
-
#uy ⇒ Object
Options for the registration in UY.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
-
#zm ⇒ Object
Options for the registration in ZM.
-
#zw ⇒ Object
Options for the registration in ZW.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 |
# File 'lib/stripe/resources/tax/registration.rb', line 2393 def initialize( ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil ) @ae = ae @al = al @am = am @ao = ao @at = at @au = au @aw = aw @az = az @ba = ba @bb = bb @bd = bd @be = be @bf = bf @bg = bg @bh = bh @bj = bj @bs = bs @by = by @ca = ca @cd = cd @ch = ch @cl = cl @cm = cm @co = co @cr = cr @cv = cv @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @et = et @fi = fi @fr = fr @gb = gb @ge = ge @gn = gn @gr = gr @hr = hr @hu = hu @id = id @ie = ie @in = in_ @is = is @it = it @jp = jp @ke = ke @kg = kg @kh = kh @kr = kr @kz = kz @la = la @lt = lt @lu = lu @lv = lv @ma = ma @md = md @me = me @mk = mk @mr = mr @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @np = np @nz = nz @om = om @pe = pe @ph = ph @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @sn = sn @sr = sr @th = th @tj = tj @tr = tr @tz = tz @ua = ua @ug = ug @us = us @uy = uy @uz = uz @vn = vn @za = za @zm = zm @zw = zw end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
2195 2196 2197 |
# File 'lib/stripe/resources/tax/registration.rb', line 2195 def ae @ae end |
#al ⇒ Object
Options for the registration in AL.
2197 2198 2199 |
# File 'lib/stripe/resources/tax/registration.rb', line 2197 def al @al end |
#am ⇒ Object
Options for the registration in AM.
2199 2200 2201 |
# File 'lib/stripe/resources/tax/registration.rb', line 2199 def am @am end |
#ao ⇒ Object
Options for the registration in AO.
2201 2202 2203 |
# File 'lib/stripe/resources/tax/registration.rb', line 2201 def ao @ao end |
#at ⇒ Object
Options for the registration in AT.
2203 2204 2205 |
# File 'lib/stripe/resources/tax/registration.rb', line 2203 def at @at end |
#au ⇒ Object
Options for the registration in AU.
2205 2206 2207 |
# File 'lib/stripe/resources/tax/registration.rb', line 2205 def au @au end |
#aw ⇒ Object
Options for the registration in AW.
2207 2208 2209 |
# File 'lib/stripe/resources/tax/registration.rb', line 2207 def aw @aw end |
#az ⇒ Object
Options for the registration in AZ.
2209 2210 2211 |
# File 'lib/stripe/resources/tax/registration.rb', line 2209 def az @az end |
#ba ⇒ Object
Options for the registration in BA.
2211 2212 2213 |
# File 'lib/stripe/resources/tax/registration.rb', line 2211 def ba @ba end |
#bb ⇒ Object
Options for the registration in BB.
2213 2214 2215 |
# File 'lib/stripe/resources/tax/registration.rb', line 2213 def bb @bb end |
#bd ⇒ Object
Options for the registration in BD.
2215 2216 2217 |
# File 'lib/stripe/resources/tax/registration.rb', line 2215 def bd @bd end |
#be ⇒ Object
Options for the registration in BE.
2217 2218 2219 |
# File 'lib/stripe/resources/tax/registration.rb', line 2217 def be @be end |
#bf ⇒ Object
Options for the registration in BF.
2219 2220 2221 |
# File 'lib/stripe/resources/tax/registration.rb', line 2219 def bf @bf end |
#bg ⇒ Object
Options for the registration in BG.
2221 2222 2223 |
# File 'lib/stripe/resources/tax/registration.rb', line 2221 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
2223 2224 2225 |
# File 'lib/stripe/resources/tax/registration.rb', line 2223 def bh @bh end |
#bj ⇒ Object
Options for the registration in BJ.
2225 2226 2227 |
# File 'lib/stripe/resources/tax/registration.rb', line 2225 def bj @bj end |
#bs ⇒ Object
Options for the registration in BS.
2227 2228 2229 |
# File 'lib/stripe/resources/tax/registration.rb', line 2227 def bs @bs end |
#by ⇒ Object
Options for the registration in BY.
2229 2230 2231 |
# File 'lib/stripe/resources/tax/registration.rb', line 2229 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
2231 2232 2233 |
# File 'lib/stripe/resources/tax/registration.rb', line 2231 def ca @ca end |
#cd ⇒ Object
Options for the registration in CD.
2233 2234 2235 |
# File 'lib/stripe/resources/tax/registration.rb', line 2233 def cd @cd end |
#ch ⇒ Object
Options for the registration in CH.
2235 2236 2237 |
# File 'lib/stripe/resources/tax/registration.rb', line 2235 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
2237 2238 2239 |
# File 'lib/stripe/resources/tax/registration.rb', line 2237 def cl @cl end |
#cm ⇒ Object
Options for the registration in CM.
2239 2240 2241 |
# File 'lib/stripe/resources/tax/registration.rb', line 2239 def cm @cm end |
#co ⇒ Object
Options for the registration in CO.
2241 2242 2243 |
# File 'lib/stripe/resources/tax/registration.rb', line 2241 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
2243 2244 2245 |
# File 'lib/stripe/resources/tax/registration.rb', line 2243 def cr @cr end |
#cv ⇒ Object
Options for the registration in CV.
2245 2246 2247 |
# File 'lib/stripe/resources/tax/registration.rb', line 2245 def cv @cv end |
#cy ⇒ Object
Options for the registration in CY.
2247 2248 2249 |
# File 'lib/stripe/resources/tax/registration.rb', line 2247 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
2249 2250 2251 |
# File 'lib/stripe/resources/tax/registration.rb', line 2249 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
2251 2252 2253 |
# File 'lib/stripe/resources/tax/registration.rb', line 2251 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
2253 2254 2255 |
# File 'lib/stripe/resources/tax/registration.rb', line 2253 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
2255 2256 2257 |
# File 'lib/stripe/resources/tax/registration.rb', line 2255 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
2257 2258 2259 |
# File 'lib/stripe/resources/tax/registration.rb', line 2257 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
2259 2260 2261 |
# File 'lib/stripe/resources/tax/registration.rb', line 2259 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
2261 2262 2263 |
# File 'lib/stripe/resources/tax/registration.rb', line 2261 def es @es end |
#et ⇒ Object
Options for the registration in ET.
2263 2264 2265 |
# File 'lib/stripe/resources/tax/registration.rb', line 2263 def et @et end |
#fi ⇒ Object
Options for the registration in FI.
2265 2266 2267 |
# File 'lib/stripe/resources/tax/registration.rb', line 2265 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
2267 2268 2269 |
# File 'lib/stripe/resources/tax/registration.rb', line 2267 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
2269 2270 2271 |
# File 'lib/stripe/resources/tax/registration.rb', line 2269 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
2271 2272 2273 |
# File 'lib/stripe/resources/tax/registration.rb', line 2271 def ge @ge end |
#gn ⇒ Object
Options for the registration in GN.
2273 2274 2275 |
# File 'lib/stripe/resources/tax/registration.rb', line 2273 def gn @gn end |
#gr ⇒ Object
Options for the registration in GR.
2275 2276 2277 |
# File 'lib/stripe/resources/tax/registration.rb', line 2275 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
2277 2278 2279 |
# File 'lib/stripe/resources/tax/registration.rb', line 2277 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
2279 2280 2281 |
# File 'lib/stripe/resources/tax/registration.rb', line 2279 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
2281 2282 2283 |
# File 'lib/stripe/resources/tax/registration.rb', line 2281 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
2283 2284 2285 |
# File 'lib/stripe/resources/tax/registration.rb', line 2283 def ie @ie end |
#in ⇒ Object
Options for the registration in IN.
2285 2286 2287 |
# File 'lib/stripe/resources/tax/registration.rb', line 2285 def in @in end |
#is ⇒ Object
Options for the registration in IS.
2287 2288 2289 |
# File 'lib/stripe/resources/tax/registration.rb', line 2287 def is @is end |
#it ⇒ Object
Options for the registration in IT.
2289 2290 2291 |
# File 'lib/stripe/resources/tax/registration.rb', line 2289 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
2291 2292 2293 |
# File 'lib/stripe/resources/tax/registration.rb', line 2291 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
2293 2294 2295 |
# File 'lib/stripe/resources/tax/registration.rb', line 2293 def ke @ke end |
#kg ⇒ Object
Options for the registration in KG.
2295 2296 2297 |
# File 'lib/stripe/resources/tax/registration.rb', line 2295 def kg @kg end |
#kh ⇒ Object
Options for the registration in KH.
2297 2298 2299 |
# File 'lib/stripe/resources/tax/registration.rb', line 2297 def kh @kh end |
#kr ⇒ Object
Options for the registration in KR.
2299 2300 2301 |
# File 'lib/stripe/resources/tax/registration.rb', line 2299 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
2301 2302 2303 |
# File 'lib/stripe/resources/tax/registration.rb', line 2301 def kz @kz end |
#la ⇒ Object
Options for the registration in LA.
2303 2304 2305 |
# File 'lib/stripe/resources/tax/registration.rb', line 2303 def la @la end |
#lt ⇒ Object
Options for the registration in LT.
2305 2306 2307 |
# File 'lib/stripe/resources/tax/registration.rb', line 2305 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
2307 2308 2309 |
# File 'lib/stripe/resources/tax/registration.rb', line 2307 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
2309 2310 2311 |
# File 'lib/stripe/resources/tax/registration.rb', line 2309 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
2311 2312 2313 |
# File 'lib/stripe/resources/tax/registration.rb', line 2311 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
2313 2314 2315 |
# File 'lib/stripe/resources/tax/registration.rb', line 2313 def md @md end |
#me ⇒ Object
Options for the registration in ME.
2315 2316 2317 |
# File 'lib/stripe/resources/tax/registration.rb', line 2315 def me @me end |
#mk ⇒ Object
Options for the registration in MK.
2317 2318 2319 |
# File 'lib/stripe/resources/tax/registration.rb', line 2317 def mk @mk end |
#mr ⇒ Object
Options for the registration in MR.
2319 2320 2321 |
# File 'lib/stripe/resources/tax/registration.rb', line 2319 def mr @mr end |
#mt ⇒ Object
Options for the registration in MT.
2321 2322 2323 |
# File 'lib/stripe/resources/tax/registration.rb', line 2321 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
2323 2324 2325 |
# File 'lib/stripe/resources/tax/registration.rb', line 2323 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
2325 2326 2327 |
# File 'lib/stripe/resources/tax/registration.rb', line 2325 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
2327 2328 2329 |
# File 'lib/stripe/resources/tax/registration.rb', line 2327 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
2329 2330 2331 |
# File 'lib/stripe/resources/tax/registration.rb', line 2329 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
2331 2332 2333 |
# File 'lib/stripe/resources/tax/registration.rb', line 2331 def no @no end |
#np ⇒ Object
Options for the registration in NP.
2333 2334 2335 |
# File 'lib/stripe/resources/tax/registration.rb', line 2333 def np @np end |
#nz ⇒ Object
Options for the registration in NZ.
2335 2336 2337 |
# File 'lib/stripe/resources/tax/registration.rb', line 2335 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
2337 2338 2339 |
# File 'lib/stripe/resources/tax/registration.rb', line 2337 def om @om end |
#pe ⇒ Object
Options for the registration in PE.
2339 2340 2341 |
# File 'lib/stripe/resources/tax/registration.rb', line 2339 def pe @pe end |
#ph ⇒ Object
Options for the registration in PH.
2341 2342 2343 |
# File 'lib/stripe/resources/tax/registration.rb', line 2341 def ph @ph end |
#pl ⇒ Object
Options for the registration in PL.
2343 2344 2345 |
# File 'lib/stripe/resources/tax/registration.rb', line 2343 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
2345 2346 2347 |
# File 'lib/stripe/resources/tax/registration.rb', line 2345 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
2347 2348 2349 |
# File 'lib/stripe/resources/tax/registration.rb', line 2347 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
2349 2350 2351 |
# File 'lib/stripe/resources/tax/registration.rb', line 2349 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
2351 2352 2353 |
# File 'lib/stripe/resources/tax/registration.rb', line 2351 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
2353 2354 2355 |
# File 'lib/stripe/resources/tax/registration.rb', line 2353 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
2355 2356 2357 |
# File 'lib/stripe/resources/tax/registration.rb', line 2355 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
2357 2358 2359 |
# File 'lib/stripe/resources/tax/registration.rb', line 2357 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
2359 2360 2361 |
# File 'lib/stripe/resources/tax/registration.rb', line 2359 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
2361 2362 2363 |
# File 'lib/stripe/resources/tax/registration.rb', line 2361 def sk @sk end |
#sn ⇒ Object
Options for the registration in SN.
2363 2364 2365 |
# File 'lib/stripe/resources/tax/registration.rb', line 2363 def sn @sn end |
#sr ⇒ Object
Options for the registration in SR.
2365 2366 2367 |
# File 'lib/stripe/resources/tax/registration.rb', line 2365 def sr @sr end |
#th ⇒ Object
Options for the registration in TH.
2367 2368 2369 |
# File 'lib/stripe/resources/tax/registration.rb', line 2367 def th @th end |
#tj ⇒ Object
Options for the registration in TJ.
2369 2370 2371 |
# File 'lib/stripe/resources/tax/registration.rb', line 2369 def tj @tj end |
#tr ⇒ Object
Options for the registration in TR.
2371 2372 2373 |
# File 'lib/stripe/resources/tax/registration.rb', line 2371 def tr @tr end |
#tz ⇒ Object
Options for the registration in TZ.
2373 2374 2375 |
# File 'lib/stripe/resources/tax/registration.rb', line 2373 def tz @tz end |
#ua ⇒ Object
Options for the registration in UA.
2375 2376 2377 |
# File 'lib/stripe/resources/tax/registration.rb', line 2375 def ua @ua end |
#ug ⇒ Object
Options for the registration in UG.
2377 2378 2379 |
# File 'lib/stripe/resources/tax/registration.rb', line 2377 def ug @ug end |
#us ⇒ Object
Options for the registration in US.
2379 2380 2381 |
# File 'lib/stripe/resources/tax/registration.rb', line 2379 def us @us end |
#uy ⇒ Object
Options for the registration in UY.
2381 2382 2383 |
# File 'lib/stripe/resources/tax/registration.rb', line 2381 def uy @uy end |
#uz ⇒ Object
Options for the registration in UZ.
2383 2384 2385 |
# File 'lib/stripe/resources/tax/registration.rb', line 2383 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
2385 2386 2387 |
# File 'lib/stripe/resources/tax/registration.rb', line 2385 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
2387 2388 2389 |
# File 'lib/stripe/resources/tax/registration.rb', line 2387 def za @za end |
#zm ⇒ Object
Options for the registration in ZM.
2389 2390 2391 |
# File 'lib/stripe/resources/tax/registration.rb', line 2389 def zm @zm end |
#zw ⇒ Object
Options for the registration in ZW.
2391 2392 2393 |
# File 'lib/stripe/resources/tax/registration.rb', line 2391 def zw @zw end |