Class: Stripe::Tax::Registration::CreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/tax/registration.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
# File 'lib/stripe/resources/tax/registration.rb', line 2321

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  aw: nil,
  az: nil,
  ba: nil,
  bb: nil,
  bd: nil,
  be: nil,
  bg: nil,
  bh: nil,
  bj: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  co: nil,
  cr: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  et: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kg: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  la: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  ph: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tz: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @aw = aw
  @az = az
  @ba = ba
  @bb = bb
  @bd = bd
  @be = be
  @bg = bg
  @bh = bh
  @bj = bj
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @co = co
  @cr = cr
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @et = et
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kg = kg
  @kh = kh
  @kr = kr
  @kz = kz
  @la = la
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @ph = ph
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tz = tz
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



2131
2132
2133
# File 'lib/stripe/resources/tax/registration.rb', line 2131

def ae
  @ae
end

#alObject

Options for the registration in AL.



2133
2134
2135
# File 'lib/stripe/resources/tax/registration.rb', line 2133

def al
  @al
end

#amObject

Options for the registration in AM.



2135
2136
2137
# File 'lib/stripe/resources/tax/registration.rb', line 2135

def am
  @am
end

#aoObject

Options for the registration in AO.



2137
2138
2139
# File 'lib/stripe/resources/tax/registration.rb', line 2137

def ao
  @ao
end

#atObject

Options for the registration in AT.



2139
2140
2141
# File 'lib/stripe/resources/tax/registration.rb', line 2139

def at
  @at
end

#auObject

Options for the registration in AU.



2141
2142
2143
# File 'lib/stripe/resources/tax/registration.rb', line 2141

def au
  @au
end

#awObject

Options for the registration in AW.



2143
2144
2145
# File 'lib/stripe/resources/tax/registration.rb', line 2143

def aw
  @aw
end

#azObject

Options for the registration in AZ.



2145
2146
2147
# File 'lib/stripe/resources/tax/registration.rb', line 2145

def az
  @az
end

#baObject

Options for the registration in BA.



2147
2148
2149
# File 'lib/stripe/resources/tax/registration.rb', line 2147

def ba
  @ba
end

#bbObject

Options for the registration in BB.



2149
2150
2151
# File 'lib/stripe/resources/tax/registration.rb', line 2149

def bb
  @bb
end

#bdObject

Options for the registration in BD.



2151
2152
2153
# File 'lib/stripe/resources/tax/registration.rb', line 2151

def bd
  @bd
end

#beObject

Options for the registration in BE.



2153
2154
2155
# File 'lib/stripe/resources/tax/registration.rb', line 2153

def be
  @be
end

#bgObject

Options for the registration in BG.



2155
2156
2157
# File 'lib/stripe/resources/tax/registration.rb', line 2155

def bg
  @bg
end

#bhObject

Options for the registration in BH.



2157
2158
2159
# File 'lib/stripe/resources/tax/registration.rb', line 2157

def bh
  @bh
end

#bjObject

Options for the registration in BJ.



2159
2160
2161
# File 'lib/stripe/resources/tax/registration.rb', line 2159

def bj
  @bj
end

#bsObject

Options for the registration in BS.



2161
2162
2163
# File 'lib/stripe/resources/tax/registration.rb', line 2161

def bs
  @bs
end

#byObject

Options for the registration in BY.



2163
2164
2165
# File 'lib/stripe/resources/tax/registration.rb', line 2163

def by
  @by
end

#caObject

Options for the registration in CA.



2165
2166
2167
# File 'lib/stripe/resources/tax/registration.rb', line 2165

def ca
  @ca
end

#cdObject

Options for the registration in CD.



2167
2168
2169
# File 'lib/stripe/resources/tax/registration.rb', line 2167

def cd
  @cd
end

#chObject

Options for the registration in CH.



2169
2170
2171
# File 'lib/stripe/resources/tax/registration.rb', line 2169

def ch
  @ch
end

#clObject

Options for the registration in CL.



2171
2172
2173
# File 'lib/stripe/resources/tax/registration.rb', line 2171

def cl
  @cl
end

#coObject

Options for the registration in CO.



2173
2174
2175
# File 'lib/stripe/resources/tax/registration.rb', line 2173

def co
  @co
end

#crObject

Options for the registration in CR.



2175
2176
2177
# File 'lib/stripe/resources/tax/registration.rb', line 2175

def cr
  @cr
end

#cyObject

Options for the registration in CY.



2177
2178
2179
# File 'lib/stripe/resources/tax/registration.rb', line 2177

def cy
  @cy
end

#czObject

Options for the registration in CZ.



2179
2180
2181
# File 'lib/stripe/resources/tax/registration.rb', line 2179

def cz
  @cz
end

#deObject

Options for the registration in DE.



2181
2182
2183
# File 'lib/stripe/resources/tax/registration.rb', line 2181

def de
  @de
end

#dkObject

Options for the registration in DK.



2183
2184
2185
# File 'lib/stripe/resources/tax/registration.rb', line 2183

def dk
  @dk
end

#ecObject

Options for the registration in EC.



2185
2186
2187
# File 'lib/stripe/resources/tax/registration.rb', line 2185

def ec
  @ec
end

#eeObject

Options for the registration in EE.



2187
2188
2189
# File 'lib/stripe/resources/tax/registration.rb', line 2187

def ee
  @ee
end

#egObject

Options for the registration in EG.



2189
2190
2191
# File 'lib/stripe/resources/tax/registration.rb', line 2189

def eg
  @eg
end

#esObject

Options for the registration in ES.



2191
2192
2193
# File 'lib/stripe/resources/tax/registration.rb', line 2191

def es
  @es
end

#etObject

Options for the registration in ET.



2193
2194
2195
# File 'lib/stripe/resources/tax/registration.rb', line 2193

def et
  @et
end

#fiObject

Options for the registration in FI.



2195
2196
2197
# File 'lib/stripe/resources/tax/registration.rb', line 2195

def fi
  @fi
end

#frObject

Options for the registration in FR.



2197
2198
2199
# File 'lib/stripe/resources/tax/registration.rb', line 2197

def fr
  @fr
end

#gbObject

Options for the registration in GB.



2199
2200
2201
# File 'lib/stripe/resources/tax/registration.rb', line 2199

def gb
  @gb
end

#geObject

Options for the registration in GE.



2201
2202
2203
# File 'lib/stripe/resources/tax/registration.rb', line 2201

def ge
  @ge
end

#gnObject

Options for the registration in GN.



2203
2204
2205
# File 'lib/stripe/resources/tax/registration.rb', line 2203

def gn
  @gn
end

#grObject

Options for the registration in GR.



2205
2206
2207
# File 'lib/stripe/resources/tax/registration.rb', line 2205

def gr
  @gr
end

#hrObject

Options for the registration in HR.



2207
2208
2209
# File 'lib/stripe/resources/tax/registration.rb', line 2207

def hr
  @hr
end

#huObject

Options for the registration in HU.



2209
2210
2211
# File 'lib/stripe/resources/tax/registration.rb', line 2209

def hu
  @hu
end

#idObject

Options for the registration in ID.



2211
2212
2213
# File 'lib/stripe/resources/tax/registration.rb', line 2211

def id
  @id
end

#ieObject

Options for the registration in IE.



2213
2214
2215
# File 'lib/stripe/resources/tax/registration.rb', line 2213

def ie
  @ie
end

#inObject

Options for the registration in IN.



2215
2216
2217
# File 'lib/stripe/resources/tax/registration.rb', line 2215

def in
  @in
end

#isObject

Options for the registration in IS.



2217
2218
2219
# File 'lib/stripe/resources/tax/registration.rb', line 2217

def is
  @is
end

#itObject

Options for the registration in IT.



2219
2220
2221
# File 'lib/stripe/resources/tax/registration.rb', line 2219

def it
  @it
end

#jpObject

Options for the registration in JP.



2221
2222
2223
# File 'lib/stripe/resources/tax/registration.rb', line 2221

def jp
  @jp
end

#keObject

Options for the registration in KE.



2223
2224
2225
# File 'lib/stripe/resources/tax/registration.rb', line 2223

def ke
  @ke
end

#kgObject

Options for the registration in KG.



2225
2226
2227
# File 'lib/stripe/resources/tax/registration.rb', line 2225

def kg
  @kg
end

#khObject

Options for the registration in KH.



2227
2228
2229
# File 'lib/stripe/resources/tax/registration.rb', line 2227

def kh
  @kh
end

#krObject

Options for the registration in KR.



2229
2230
2231
# File 'lib/stripe/resources/tax/registration.rb', line 2229

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



2231
2232
2233
# File 'lib/stripe/resources/tax/registration.rb', line 2231

def kz
  @kz
end

#laObject

Options for the registration in LA.



2233
2234
2235
# File 'lib/stripe/resources/tax/registration.rb', line 2233

def la
  @la
end

#ltObject

Options for the registration in LT.



2235
2236
2237
# File 'lib/stripe/resources/tax/registration.rb', line 2235

def lt
  @lt
end

#luObject

Options for the registration in LU.



2237
2238
2239
# File 'lib/stripe/resources/tax/registration.rb', line 2237

def lu
  @lu
end

#lvObject

Options for the registration in LV.



2239
2240
2241
# File 'lib/stripe/resources/tax/registration.rb', line 2239

def lv
  @lv
end

#maObject

Options for the registration in MA.



2241
2242
2243
# File 'lib/stripe/resources/tax/registration.rb', line 2241

def ma
  @ma
end

#mdObject

Options for the registration in MD.



2243
2244
2245
# File 'lib/stripe/resources/tax/registration.rb', line 2243

def md
  @md
end

#meObject

Options for the registration in ME.



2245
2246
2247
# File 'lib/stripe/resources/tax/registration.rb', line 2245

def me
  @me
end

#mkObject

Options for the registration in MK.



2247
2248
2249
# File 'lib/stripe/resources/tax/registration.rb', line 2247

def mk
  @mk
end

#mrObject

Options for the registration in MR.



2249
2250
2251
# File 'lib/stripe/resources/tax/registration.rb', line 2249

def mr
  @mr
end

#mtObject

Options for the registration in MT.



2251
2252
2253
# File 'lib/stripe/resources/tax/registration.rb', line 2251

def mt
  @mt
end

#mxObject

Options for the registration in MX.



2253
2254
2255
# File 'lib/stripe/resources/tax/registration.rb', line 2253

def mx
  @mx
end

#myObject

Options for the registration in MY.



2255
2256
2257
# File 'lib/stripe/resources/tax/registration.rb', line 2255

def my
  @my
end

#ngObject

Options for the registration in NG.



2257
2258
2259
# File 'lib/stripe/resources/tax/registration.rb', line 2257

def ng
  @ng
end

#nlObject

Options for the registration in NL.



2259
2260
2261
# File 'lib/stripe/resources/tax/registration.rb', line 2259

def nl
  @nl
end

#noObject

Options for the registration in NO.



2261
2262
2263
# File 'lib/stripe/resources/tax/registration.rb', line 2261

def no
  @no
end

#npObject

Options for the registration in NP.



2263
2264
2265
# File 'lib/stripe/resources/tax/registration.rb', line 2263

def np
  @np
end

#nzObject

Options for the registration in NZ.



2265
2266
2267
# File 'lib/stripe/resources/tax/registration.rb', line 2265

def nz
  @nz
end

#omObject

Options for the registration in OM.



2267
2268
2269
# File 'lib/stripe/resources/tax/registration.rb', line 2267

def om
  @om
end

#peObject

Options for the registration in PE.



2269
2270
2271
# File 'lib/stripe/resources/tax/registration.rb', line 2269

def pe
  @pe
end

#phObject

Options for the registration in PH.



2271
2272
2273
# File 'lib/stripe/resources/tax/registration.rb', line 2271

def ph
  @ph
end

#plObject

Options for the registration in PL.



2273
2274
2275
# File 'lib/stripe/resources/tax/registration.rb', line 2273

def pl
  @pl
end

#ptObject

Options for the registration in PT.



2275
2276
2277
# File 'lib/stripe/resources/tax/registration.rb', line 2275

def pt
  @pt
end

#roObject

Options for the registration in RO.



2277
2278
2279
# File 'lib/stripe/resources/tax/registration.rb', line 2277

def ro
  @ro
end

#rsObject

Options for the registration in RS.



2279
2280
2281
# File 'lib/stripe/resources/tax/registration.rb', line 2279

def rs
  @rs
end

#ruObject

Options for the registration in RU.



2281
2282
2283
# File 'lib/stripe/resources/tax/registration.rb', line 2281

def ru
  @ru
end

#saObject

Options for the registration in SA.



2283
2284
2285
# File 'lib/stripe/resources/tax/registration.rb', line 2283

def sa
  @sa
end

#seObject

Options for the registration in SE.



2285
2286
2287
# File 'lib/stripe/resources/tax/registration.rb', line 2285

def se
  @se
end

#sgObject

Options for the registration in SG.



2287
2288
2289
# File 'lib/stripe/resources/tax/registration.rb', line 2287

def sg
  @sg
end

#siObject

Options for the registration in SI.



2289
2290
2291
# File 'lib/stripe/resources/tax/registration.rb', line 2289

def si
  @si
end

#skObject

Options for the registration in SK.



2291
2292
2293
# File 'lib/stripe/resources/tax/registration.rb', line 2291

def sk
  @sk
end

#snObject

Options for the registration in SN.



2293
2294
2295
# File 'lib/stripe/resources/tax/registration.rb', line 2293

def sn
  @sn
end

#srObject

Options for the registration in SR.



2295
2296
2297
# File 'lib/stripe/resources/tax/registration.rb', line 2295

def sr
  @sr
end

#thObject

Options for the registration in TH.



2297
2298
2299
# File 'lib/stripe/resources/tax/registration.rb', line 2297

def th
  @th
end

#tjObject

Options for the registration in TJ.



2299
2300
2301
# File 'lib/stripe/resources/tax/registration.rb', line 2299

def tj
  @tj
end

#trObject

Options for the registration in TR.



2301
2302
2303
# File 'lib/stripe/resources/tax/registration.rb', line 2301

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



2303
2304
2305
# File 'lib/stripe/resources/tax/registration.rb', line 2303

def tz
  @tz
end

#ugObject

Options for the registration in UG.



2305
2306
2307
# File 'lib/stripe/resources/tax/registration.rb', line 2305

def ug
  @ug
end

#usObject

Options for the registration in US.



2307
2308
2309
# File 'lib/stripe/resources/tax/registration.rb', line 2307

def us
  @us
end

#uyObject

Options for the registration in UY.



2309
2310
2311
# File 'lib/stripe/resources/tax/registration.rb', line 2309

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



2311
2312
2313
# File 'lib/stripe/resources/tax/registration.rb', line 2311

def uz
  @uz
end

#vnObject

Options for the registration in VN.



2313
2314
2315
# File 'lib/stripe/resources/tax/registration.rb', line 2313

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



2315
2316
2317
# File 'lib/stripe/resources/tax/registration.rb', line 2315

def za
  @za
end

#zmObject

Options for the registration in ZM.



2317
2318
2319
# File 'lib/stripe/resources/tax/registration.rb', line 2317

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



2319
2320
2321
# File 'lib/stripe/resources/tax/registration.rb', line 2319

def zw
  @zw
end