Class: Stripe::Tax::Registration::CreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Ba, Bb, Be, Bg, Bh, Bs, By, Ca, Cd, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kh, Kr, Kz, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#al ⇒ Object
Options for the registration in AL.
-
#am ⇒ Object
Options for the registration in AM.
-
#ao ⇒ Object
Options for the registration in AO.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#ba ⇒ Object
Options for the registration in BA.
-
#bb ⇒ Object
Options for the registration in BB.
-
#be ⇒ Object
Options for the registration in BE.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#bs ⇒ Object
Options for the registration in BS.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#cd ⇒ Object
Options for the registration in CD.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gn ⇒ Object
Options for the registration in GN.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kh ⇒ Object
Options for the registration in KH.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#me ⇒ Object
Options for the registration in ME.
-
#mk ⇒ Object
Options for the registration in MK.
-
#mr ⇒ Object
Options for the registration in MR.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#np ⇒ Object
Options for the registration in NP.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pe ⇒ Object
Options for the registration in PE.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#sn ⇒ Object
Options for the registration in SN.
-
#sr ⇒ Object
Options for the registration in SR.
-
#th ⇒ Object
Options for the registration in TH.
-
#tj ⇒ Object
Options for the registration in TJ.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#ug ⇒ Object
Options for the registration in UG.
-
#us ⇒ Object
Options for the registration in US.
-
#uy ⇒ Object
Options for the registration in UY.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
-
#zm ⇒ Object
Options for the registration in ZM.
-
#zw ⇒ Object
Options for the registration in ZW.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, ba: nil, bb: nil, be: nil, bg: nil, bh: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, is: nil, it: nil, jp: nil, ke: nil, kh: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 |
# File 'lib/stripe/resources/tax/registration.rb', line 2159 def initialize( ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, ba: nil, bb: nil, be: nil, bg: nil, bh: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, is: nil, it: nil, jp: nil, ke: nil, kh: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil ) @ae = ae @al = al @am = am @ao = ao @at = at @au = au @ba = ba @bb = bb @be = be @bg = bg @bh = bh @bs = bs @by = by @ca = ca @cd = cd @ch = ch @cl = cl @co = co @cr = cr @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @fi = fi @fr = fr @gb = gb @ge = ge @gn = gn @gr = gr @hr = hr @hu = hu @id = id @ie = ie @is = is @it = it @jp = jp @ke = ke @kh = kh @kr = kr @kz = kz @lt = lt @lu = lu @lv = lv @ma = ma @md = md @me = me @mk = mk @mr = mr @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @np = np @nz = nz @om = om @pe = pe @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @sn = sn @sr = sr @th = th @tj = tj @tr = tr @tz = tz @ug = ug @us = us @uy = uy @uz = uz @vn = vn @za = za @zm = zm @zw = zw end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
1987 1988 1989 |
# File 'lib/stripe/resources/tax/registration.rb', line 1987 def ae @ae end |
#al ⇒ Object
Options for the registration in AL.
1989 1990 1991 |
# File 'lib/stripe/resources/tax/registration.rb', line 1989 def al @al end |
#am ⇒ Object
Options for the registration in AM.
1991 1992 1993 |
# File 'lib/stripe/resources/tax/registration.rb', line 1991 def am @am end |
#ao ⇒ Object
Options for the registration in AO.
1993 1994 1995 |
# File 'lib/stripe/resources/tax/registration.rb', line 1993 def ao @ao end |
#at ⇒ Object
Options for the registration in AT.
1995 1996 1997 |
# File 'lib/stripe/resources/tax/registration.rb', line 1995 def at @at end |
#au ⇒ Object
Options for the registration in AU.
1997 1998 1999 |
# File 'lib/stripe/resources/tax/registration.rb', line 1997 def au @au end |
#ba ⇒ Object
Options for the registration in BA.
1999 2000 2001 |
# File 'lib/stripe/resources/tax/registration.rb', line 1999 def ba @ba end |
#bb ⇒ Object
Options for the registration in BB.
2001 2002 2003 |
# File 'lib/stripe/resources/tax/registration.rb', line 2001 def bb @bb end |
#be ⇒ Object
Options for the registration in BE.
2003 2004 2005 |
# File 'lib/stripe/resources/tax/registration.rb', line 2003 def be @be end |
#bg ⇒ Object
Options for the registration in BG.
2005 2006 2007 |
# File 'lib/stripe/resources/tax/registration.rb', line 2005 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
2007 2008 2009 |
# File 'lib/stripe/resources/tax/registration.rb', line 2007 def bh @bh end |
#bs ⇒ Object
Options for the registration in BS.
2009 2010 2011 |
# File 'lib/stripe/resources/tax/registration.rb', line 2009 def bs @bs end |
#by ⇒ Object
Options for the registration in BY.
2011 2012 2013 |
# File 'lib/stripe/resources/tax/registration.rb', line 2011 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
2013 2014 2015 |
# File 'lib/stripe/resources/tax/registration.rb', line 2013 def ca @ca end |
#cd ⇒ Object
Options for the registration in CD.
2015 2016 2017 |
# File 'lib/stripe/resources/tax/registration.rb', line 2015 def cd @cd end |
#ch ⇒ Object
Options for the registration in CH.
2017 2018 2019 |
# File 'lib/stripe/resources/tax/registration.rb', line 2017 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
2019 2020 2021 |
# File 'lib/stripe/resources/tax/registration.rb', line 2019 def cl @cl end |
#co ⇒ Object
Options for the registration in CO.
2021 2022 2023 |
# File 'lib/stripe/resources/tax/registration.rb', line 2021 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
2023 2024 2025 |
# File 'lib/stripe/resources/tax/registration.rb', line 2023 def cr @cr end |
#cy ⇒ Object
Options for the registration in CY.
2025 2026 2027 |
# File 'lib/stripe/resources/tax/registration.rb', line 2025 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
2027 2028 2029 |
# File 'lib/stripe/resources/tax/registration.rb', line 2027 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
2029 2030 2031 |
# File 'lib/stripe/resources/tax/registration.rb', line 2029 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
2031 2032 2033 |
# File 'lib/stripe/resources/tax/registration.rb', line 2031 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
2033 2034 2035 |
# File 'lib/stripe/resources/tax/registration.rb', line 2033 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
2035 2036 2037 |
# File 'lib/stripe/resources/tax/registration.rb', line 2035 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
2037 2038 2039 |
# File 'lib/stripe/resources/tax/registration.rb', line 2037 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
2039 2040 2041 |
# File 'lib/stripe/resources/tax/registration.rb', line 2039 def es @es end |
#fi ⇒ Object
Options for the registration in FI.
2041 2042 2043 |
# File 'lib/stripe/resources/tax/registration.rb', line 2041 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
2043 2044 2045 |
# File 'lib/stripe/resources/tax/registration.rb', line 2043 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
2045 2046 2047 |
# File 'lib/stripe/resources/tax/registration.rb', line 2045 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
2047 2048 2049 |
# File 'lib/stripe/resources/tax/registration.rb', line 2047 def ge @ge end |
#gn ⇒ Object
Options for the registration in GN.
2049 2050 2051 |
# File 'lib/stripe/resources/tax/registration.rb', line 2049 def gn @gn end |
#gr ⇒ Object
Options for the registration in GR.
2051 2052 2053 |
# File 'lib/stripe/resources/tax/registration.rb', line 2051 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
2053 2054 2055 |
# File 'lib/stripe/resources/tax/registration.rb', line 2053 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
2055 2056 2057 |
# File 'lib/stripe/resources/tax/registration.rb', line 2055 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
2057 2058 2059 |
# File 'lib/stripe/resources/tax/registration.rb', line 2057 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
2059 2060 2061 |
# File 'lib/stripe/resources/tax/registration.rb', line 2059 def ie @ie end |
#is ⇒ Object
Options for the registration in IS.
2061 2062 2063 |
# File 'lib/stripe/resources/tax/registration.rb', line 2061 def is @is end |
#it ⇒ Object
Options for the registration in IT.
2063 2064 2065 |
# File 'lib/stripe/resources/tax/registration.rb', line 2063 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
2065 2066 2067 |
# File 'lib/stripe/resources/tax/registration.rb', line 2065 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
2067 2068 2069 |
# File 'lib/stripe/resources/tax/registration.rb', line 2067 def ke @ke end |
#kh ⇒ Object
Options for the registration in KH.
2069 2070 2071 |
# File 'lib/stripe/resources/tax/registration.rb', line 2069 def kh @kh end |
#kr ⇒ Object
Options for the registration in KR.
2071 2072 2073 |
# File 'lib/stripe/resources/tax/registration.rb', line 2071 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
2073 2074 2075 |
# File 'lib/stripe/resources/tax/registration.rb', line 2073 def kz @kz end |
#lt ⇒ Object
Options for the registration in LT.
2075 2076 2077 |
# File 'lib/stripe/resources/tax/registration.rb', line 2075 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
2077 2078 2079 |
# File 'lib/stripe/resources/tax/registration.rb', line 2077 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
2079 2080 2081 |
# File 'lib/stripe/resources/tax/registration.rb', line 2079 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
2081 2082 2083 |
# File 'lib/stripe/resources/tax/registration.rb', line 2081 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
2083 2084 2085 |
# File 'lib/stripe/resources/tax/registration.rb', line 2083 def md @md end |
#me ⇒ Object
Options for the registration in ME.
2085 2086 2087 |
# File 'lib/stripe/resources/tax/registration.rb', line 2085 def me @me end |
#mk ⇒ Object
Options for the registration in MK.
2087 2088 2089 |
# File 'lib/stripe/resources/tax/registration.rb', line 2087 def mk @mk end |
#mr ⇒ Object
Options for the registration in MR.
2089 2090 2091 |
# File 'lib/stripe/resources/tax/registration.rb', line 2089 def mr @mr end |
#mt ⇒ Object
Options for the registration in MT.
2091 2092 2093 |
# File 'lib/stripe/resources/tax/registration.rb', line 2091 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
2093 2094 2095 |
# File 'lib/stripe/resources/tax/registration.rb', line 2093 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
2095 2096 2097 |
# File 'lib/stripe/resources/tax/registration.rb', line 2095 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
2097 2098 2099 |
# File 'lib/stripe/resources/tax/registration.rb', line 2097 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
2099 2100 2101 |
# File 'lib/stripe/resources/tax/registration.rb', line 2099 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
2101 2102 2103 |
# File 'lib/stripe/resources/tax/registration.rb', line 2101 def no @no end |
#np ⇒ Object
Options for the registration in NP.
2103 2104 2105 |
# File 'lib/stripe/resources/tax/registration.rb', line 2103 def np @np end |
#nz ⇒ Object
Options for the registration in NZ.
2105 2106 2107 |
# File 'lib/stripe/resources/tax/registration.rb', line 2105 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
2107 2108 2109 |
# File 'lib/stripe/resources/tax/registration.rb', line 2107 def om @om end |
#pe ⇒ Object
Options for the registration in PE.
2109 2110 2111 |
# File 'lib/stripe/resources/tax/registration.rb', line 2109 def pe @pe end |
#pl ⇒ Object
Options for the registration in PL.
2111 2112 2113 |
# File 'lib/stripe/resources/tax/registration.rb', line 2111 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
2113 2114 2115 |
# File 'lib/stripe/resources/tax/registration.rb', line 2113 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
2115 2116 2117 |
# File 'lib/stripe/resources/tax/registration.rb', line 2115 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
2117 2118 2119 |
# File 'lib/stripe/resources/tax/registration.rb', line 2117 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
2119 2120 2121 |
# File 'lib/stripe/resources/tax/registration.rb', line 2119 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
2121 2122 2123 |
# File 'lib/stripe/resources/tax/registration.rb', line 2121 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
2123 2124 2125 |
# File 'lib/stripe/resources/tax/registration.rb', line 2123 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
2125 2126 2127 |
# File 'lib/stripe/resources/tax/registration.rb', line 2125 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
2127 2128 2129 |
# File 'lib/stripe/resources/tax/registration.rb', line 2127 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
2129 2130 2131 |
# File 'lib/stripe/resources/tax/registration.rb', line 2129 def sk @sk end |
#sn ⇒ Object
Options for the registration in SN.
2131 2132 2133 |
# File 'lib/stripe/resources/tax/registration.rb', line 2131 def sn @sn end |
#sr ⇒ Object
Options for the registration in SR.
2133 2134 2135 |
# File 'lib/stripe/resources/tax/registration.rb', line 2133 def sr @sr end |
#th ⇒ Object
Options for the registration in TH.
2135 2136 2137 |
# File 'lib/stripe/resources/tax/registration.rb', line 2135 def th @th end |
#tj ⇒ Object
Options for the registration in TJ.
2137 2138 2139 |
# File 'lib/stripe/resources/tax/registration.rb', line 2137 def tj @tj end |
#tr ⇒ Object
Options for the registration in TR.
2139 2140 2141 |
# File 'lib/stripe/resources/tax/registration.rb', line 2139 def tr @tr end |
#tz ⇒ Object
Options for the registration in TZ.
2141 2142 2143 |
# File 'lib/stripe/resources/tax/registration.rb', line 2141 def tz @tz end |
#ug ⇒ Object
Options for the registration in UG.
2143 2144 2145 |
# File 'lib/stripe/resources/tax/registration.rb', line 2143 def ug @ug end |
#us ⇒ Object
Options for the registration in US.
2145 2146 2147 |
# File 'lib/stripe/resources/tax/registration.rb', line 2145 def us @us end |
#uy ⇒ Object
Options for the registration in UY.
2147 2148 2149 |
# File 'lib/stripe/resources/tax/registration.rb', line 2147 def uy @uy end |
#uz ⇒ Object
Options for the registration in UZ.
2149 2150 2151 |
# File 'lib/stripe/resources/tax/registration.rb', line 2149 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
2151 2152 2153 |
# File 'lib/stripe/resources/tax/registration.rb', line 2151 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
2153 2154 2155 |
# File 'lib/stripe/resources/tax/registration.rb', line 2153 def za @za end |
#zm ⇒ Object
Options for the registration in ZM.
2155 2156 2157 |
# File 'lib/stripe/resources/tax/registration.rb', line 2155 def zm @zm end |
#zw ⇒ Object
Options for the registration in ZW.
2157 2158 2159 |
# File 'lib/stripe/resources/tax/registration.rb', line 2157 def zw @zw end |