Class: Stripe::Tax::Registration::CreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Ae, At, Au, Be, Bg, Bh, By, Ca, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kr, Kz, Lt, Lu, Lv, Ma, Md, Mt, Mx, My, Ng, Nl, No, Nz, Om, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Th, Tr, Tz, Us, Uz, Vn, Za
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#be ⇒ Object
Options for the registration in BE.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#th ⇒ Object
Options for the registration in TH.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#us ⇒ Object
Options for the registration in US.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(ae: nil, at: nil, au: nil, be: nil, bg: nil, bh: nil, by: nil, ca: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, is: nil, it: nil, jp: nil, ke: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, nz: nil, om: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, th: nil, tr: nil, tz: nil, us: nil, uz: nil, vn: nil, za: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 |
# File 'lib/stripe/resources/tax/registration.rb', line 1979 def initialize( ae: nil, at: nil, au: nil, be: nil, bg: nil, bh: nil, by: nil, ca: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, is: nil, it: nil, jp: nil, ke: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, nz: nil, om: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, th: nil, tr: nil, tz: nil, us: nil, uz: nil, vn: nil, za: nil ) @ae = ae @at = at @au = au @be = be @bg = bg @bh = bh @by = by @ca = ca @ch = ch @cl = cl @co = co @cr = cr @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @fi = fi @fr = fr @gb = gb @ge = ge @gr = gr @hr = hr @hu = hu @id = id @ie = ie @is = is @it = it @jp = jp @ke = ke @kr = kr @kz = kz @lt = lt @lu = lu @lv = lv @ma = ma @md = md @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @nz = nz @om = om @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @th = th @tr = tr @tz = tz @us = us @uz = uz @vn = vn @za = za end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
1785 1786 1787 |
# File 'lib/stripe/resources/tax/registration.rb', line 1785 def ae @ae end |
#at ⇒ Object
Options for the registration in AT.
1788 1789 1790 |
# File 'lib/stripe/resources/tax/registration.rb', line 1788 def at @at end |
#au ⇒ Object
Options for the registration in AU.
1791 1792 1793 |
# File 'lib/stripe/resources/tax/registration.rb', line 1791 def au @au end |
#be ⇒ Object
Options for the registration in BE.
1794 1795 1796 |
# File 'lib/stripe/resources/tax/registration.rb', line 1794 def be @be end |
#bg ⇒ Object
Options for the registration in BG.
1797 1798 1799 |
# File 'lib/stripe/resources/tax/registration.rb', line 1797 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
1800 1801 1802 |
# File 'lib/stripe/resources/tax/registration.rb', line 1800 def bh @bh end |
#by ⇒ Object
Options for the registration in BY.
1803 1804 1805 |
# File 'lib/stripe/resources/tax/registration.rb', line 1803 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
1806 1807 1808 |
# File 'lib/stripe/resources/tax/registration.rb', line 1806 def ca @ca end |
#ch ⇒ Object
Options for the registration in CH.
1809 1810 1811 |
# File 'lib/stripe/resources/tax/registration.rb', line 1809 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
1812 1813 1814 |
# File 'lib/stripe/resources/tax/registration.rb', line 1812 def cl @cl end |
#co ⇒ Object
Options for the registration in CO.
1815 1816 1817 |
# File 'lib/stripe/resources/tax/registration.rb', line 1815 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
1818 1819 1820 |
# File 'lib/stripe/resources/tax/registration.rb', line 1818 def cr @cr end |
#cy ⇒ Object
Options for the registration in CY.
1821 1822 1823 |
# File 'lib/stripe/resources/tax/registration.rb', line 1821 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
1824 1825 1826 |
# File 'lib/stripe/resources/tax/registration.rb', line 1824 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
1827 1828 1829 |
# File 'lib/stripe/resources/tax/registration.rb', line 1827 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
1830 1831 1832 |
# File 'lib/stripe/resources/tax/registration.rb', line 1830 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
1833 1834 1835 |
# File 'lib/stripe/resources/tax/registration.rb', line 1833 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
1836 1837 1838 |
# File 'lib/stripe/resources/tax/registration.rb', line 1836 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
1839 1840 1841 |
# File 'lib/stripe/resources/tax/registration.rb', line 1839 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
1842 1843 1844 |
# File 'lib/stripe/resources/tax/registration.rb', line 1842 def es @es end |
#fi ⇒ Object
Options for the registration in FI.
1845 1846 1847 |
# File 'lib/stripe/resources/tax/registration.rb', line 1845 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
1848 1849 1850 |
# File 'lib/stripe/resources/tax/registration.rb', line 1848 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
1851 1852 1853 |
# File 'lib/stripe/resources/tax/registration.rb', line 1851 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
1854 1855 1856 |
# File 'lib/stripe/resources/tax/registration.rb', line 1854 def ge @ge end |
#gr ⇒ Object
Options for the registration in GR.
1857 1858 1859 |
# File 'lib/stripe/resources/tax/registration.rb', line 1857 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
1860 1861 1862 |
# File 'lib/stripe/resources/tax/registration.rb', line 1860 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
1863 1864 1865 |
# File 'lib/stripe/resources/tax/registration.rb', line 1863 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
1866 1867 1868 |
# File 'lib/stripe/resources/tax/registration.rb', line 1866 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
1869 1870 1871 |
# File 'lib/stripe/resources/tax/registration.rb', line 1869 def ie @ie end |
#is ⇒ Object
Options for the registration in IS.
1872 1873 1874 |
# File 'lib/stripe/resources/tax/registration.rb', line 1872 def is @is end |
#it ⇒ Object
Options for the registration in IT.
1875 1876 1877 |
# File 'lib/stripe/resources/tax/registration.rb', line 1875 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
1878 1879 1880 |
# File 'lib/stripe/resources/tax/registration.rb', line 1878 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
1881 1882 1883 |
# File 'lib/stripe/resources/tax/registration.rb', line 1881 def ke @ke end |
#kr ⇒ Object
Options for the registration in KR.
1884 1885 1886 |
# File 'lib/stripe/resources/tax/registration.rb', line 1884 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
1887 1888 1889 |
# File 'lib/stripe/resources/tax/registration.rb', line 1887 def kz @kz end |
#lt ⇒ Object
Options for the registration in LT.
1890 1891 1892 |
# File 'lib/stripe/resources/tax/registration.rb', line 1890 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
1893 1894 1895 |
# File 'lib/stripe/resources/tax/registration.rb', line 1893 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
1896 1897 1898 |
# File 'lib/stripe/resources/tax/registration.rb', line 1896 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
1899 1900 1901 |
# File 'lib/stripe/resources/tax/registration.rb', line 1899 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
1902 1903 1904 |
# File 'lib/stripe/resources/tax/registration.rb', line 1902 def md @md end |
#mt ⇒ Object
Options for the registration in MT.
1905 1906 1907 |
# File 'lib/stripe/resources/tax/registration.rb', line 1905 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
1908 1909 1910 |
# File 'lib/stripe/resources/tax/registration.rb', line 1908 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
1911 1912 1913 |
# File 'lib/stripe/resources/tax/registration.rb', line 1911 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
1914 1915 1916 |
# File 'lib/stripe/resources/tax/registration.rb', line 1914 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
1917 1918 1919 |
# File 'lib/stripe/resources/tax/registration.rb', line 1917 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
1920 1921 1922 |
# File 'lib/stripe/resources/tax/registration.rb', line 1920 def no @no end |
#nz ⇒ Object
Options for the registration in NZ.
1923 1924 1925 |
# File 'lib/stripe/resources/tax/registration.rb', line 1923 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
1926 1927 1928 |
# File 'lib/stripe/resources/tax/registration.rb', line 1926 def om @om end |
#pl ⇒ Object
Options for the registration in PL.
1929 1930 1931 |
# File 'lib/stripe/resources/tax/registration.rb', line 1929 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
1932 1933 1934 |
# File 'lib/stripe/resources/tax/registration.rb', line 1932 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
1935 1936 1937 |
# File 'lib/stripe/resources/tax/registration.rb', line 1935 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
1938 1939 1940 |
# File 'lib/stripe/resources/tax/registration.rb', line 1938 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
1941 1942 1943 |
# File 'lib/stripe/resources/tax/registration.rb', line 1941 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
1944 1945 1946 |
# File 'lib/stripe/resources/tax/registration.rb', line 1944 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
1947 1948 1949 |
# File 'lib/stripe/resources/tax/registration.rb', line 1947 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
1950 1951 1952 |
# File 'lib/stripe/resources/tax/registration.rb', line 1950 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
1953 1954 1955 |
# File 'lib/stripe/resources/tax/registration.rb', line 1953 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
1956 1957 1958 |
# File 'lib/stripe/resources/tax/registration.rb', line 1956 def sk @sk end |
#th ⇒ Object
Options for the registration in TH.
1959 1960 1961 |
# File 'lib/stripe/resources/tax/registration.rb', line 1959 def th @th end |
#tr ⇒ Object
Options for the registration in TR.
1962 1963 1964 |
# File 'lib/stripe/resources/tax/registration.rb', line 1962 def tr @tr end |
#tz ⇒ Object
Options for the registration in TZ.
1965 1966 1967 |
# File 'lib/stripe/resources/tax/registration.rb', line 1965 def tz @tz end |
#us ⇒ Object
Options for the registration in US.
1968 1969 1970 |
# File 'lib/stripe/resources/tax/registration.rb', line 1968 def us @us end |
#uz ⇒ Object
Options for the registration in UZ.
1971 1972 1973 |
# File 'lib/stripe/resources/tax/registration.rb', line 1971 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
1974 1975 1976 |
# File 'lib/stripe/resources/tax/registration.rb', line 1974 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
1977 1978 1979 |
# File 'lib/stripe/resources/tax/registration.rb', line 1977 def za @za end |