Class: Stripe::Tax::Registration::CreateParams::CountryOptions::At
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::At
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ At
constructor
A new instance of At.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ At
Returns a new instance of At.
991 992 993 994 |
# File 'lib/stripe/resources/tax/registration.rb', line 991 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
987 988 989 |
# File 'lib/stripe/resources/tax/registration.rb', line 987 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
989 990 991 |
# File 'lib/stripe/resources/tax/registration.rb', line 989 def type @type end |