Class: Stripe::Tax::Registration::CreateParams::CountryOptions::At
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::At
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ At
constructor
A new instance of At.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ At
Returns a new instance of At.
963 964 965 966 |
# File 'lib/stripe/resources/tax/registration.rb', line 963 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
959 960 961 |
# File 'lib/stripe/resources/tax/registration.rb', line 959 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
961 962 963 |
# File 'lib/stripe/resources/tax/registration.rb', line 961 def type @type end |