Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Cy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Cy
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Cy
constructor
A new instance of Cy.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Cy
Returns a new instance of Cy.
1226 1227 1228 1229 |
# File 'lib/stripe/resources/tax/registration.rb', line 1226 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1222 1223 1224 |
# File 'lib/stripe/resources/tax/registration.rb', line 1222 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1224 1225 1226 |
# File 'lib/stripe/resources/tax/registration.rb', line 1224 def type @type end |