Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Cy
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Cy
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Cy
constructor
A new instance of Cy.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Cy
Returns a new instance of Cy.
1086 1087 1088 1089 |
# File 'lib/stripe/resources/tax/registration.rb', line 1086 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1082 1083 1084 |
# File 'lib/stripe/resources/tax/registration.rb', line 1082 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1084 1085 1086 |
# File 'lib/stripe/resources/tax/registration.rb', line 1084 def type @type end |