Class: Stripe::Tax::Registration::CreateParams::CountryOptions::De
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::De
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ De
constructor
A new instance of De.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ De
Returns a new instance of De.
1273 1274 1275 1276 |
# File 'lib/stripe/resources/tax/registration.rb', line 1273 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1269 1270 1271 |
# File 'lib/stripe/resources/tax/registration.rb', line 1269 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1271 1272 1273 |
# File 'lib/stripe/resources/tax/registration.rb', line 1271 def type @type end |