Class: Stripe::Tax::Registration::CreateParams::CountryOptions::De
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::De
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ De
constructor
A new instance of De.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ De
Returns a new instance of De.
1218 1219 1220 1221 |
# File 'lib/stripe/resources/tax/registration.rb', line 1218 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1214 1215 1216 |
# File 'lib/stripe/resources/tax/registration.rb', line 1214 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1216 1217 1218 |
# File 'lib/stripe/resources/tax/registration.rb', line 1216 def type @type end |