Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Dk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Dk
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Dk
constructor
A new instance of Dk.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Dk
Returns a new instance of Dk.
1286 1287 1288 1289 |
# File 'lib/stripe/resources/tax/registration.rb', line 1286 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1282 1283 1284 |
# File 'lib/stripe/resources/tax/registration.rb', line 1282 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1284 1285 1286 |
# File 'lib/stripe/resources/tax/registration.rb', line 1284 def type @type end |