Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
1513 1514 1515 1516 |
# File 'lib/stripe/resources/tax/registration.rb', line 1513 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1509 1510 1511 |
# File 'lib/stripe/resources/tax/registration.rb', line 1509 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1511 1512 1513 |
# File 'lib/stripe/resources/tax/registration.rb', line 1511 def type @type end |