Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
1315 1316 1317 1318 |
# File 'lib/stripe/resources/tax/registration.rb', line 1315 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1311 1312 1313 |
# File 'lib/stripe/resources/tax/registration.rb', line 1311 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1313 1314 1315 |
# File 'lib/stripe/resources/tax/registration.rb', line 1313 def type @type end |