Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
1168 1169 1170 1171 |
# File 'lib/stripe/resources/tax/registration.rb', line 1168 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1164 1165 1166 |
# File 'lib/stripe/resources/tax/registration.rb', line 1164 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1166 1167 1168 |
# File 'lib/stripe/resources/tax/registration.rb', line 1166 def type @type end |