Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Fr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Fr
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Fr
constructor
A new instance of Fr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Fr
Returns a new instance of Fr.
1400 1401 1402 1403 |
# File 'lib/stripe/resources/tax/registration.rb', line 1400 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1396 1397 1398 |
# File 'lib/stripe/resources/tax/registration.rb', line 1396 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1398 1399 1400 |
# File 'lib/stripe/resources/tax/registration.rb', line 1398 def type @type end |