Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Gr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Gr
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Gr
constructor
A new instance of Gr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Gr
Returns a new instance of Gr.
1440 1441 1442 1443 |
# File 'lib/stripe/resources/tax/registration.rb', line 1440 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1436 1437 1438 |
# File 'lib/stripe/resources/tax/registration.rb', line 1436 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1438 1439 1440 |
# File 'lib/stripe/resources/tax/registration.rb', line 1438 def type @type end |