Class: Stripe::Tax::Registration::CreateParams::CountryOptions::It
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::It
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ It
constructor
A new instance of It.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ It
Returns a new instance of It.
1554 1555 1556 1557 |
# File 'lib/stripe/resources/tax/registration.rb', line 1554 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1550 1551 1552 |
# File 'lib/stripe/resources/tax/registration.rb', line 1550 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1552 1553 1554 |
# File 'lib/stripe/resources/tax/registration.rb', line 1552 def type @type end |