Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Lt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Lt
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lt
constructor
A new instance of Lt.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lt
Returns a new instance of Lt.
1447 1448 1449 1450 |
# File 'lib/stripe/resources/tax/registration.rb', line 1447 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1443 1444 1445 |
# File 'lib/stripe/resources/tax/registration.rb', line 1443 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1445 1446 1447 |
# File 'lib/stripe/resources/tax/registration.rb', line 1445 def type @type end |