Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Lu
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Lu
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lu
constructor
A new instance of Lu.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lu
Returns a new instance of Lu.
1657 1658 1659 1660 |
# File 'lib/stripe/resources/tax/registration.rb', line 1657 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1653 1654 1655 |
# File 'lib/stripe/resources/tax/registration.rb', line 1653 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1655 1656 1657 |
# File 'lib/stripe/resources/tax/registration.rb', line 1655 def type @type end |