Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Lv
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Lv
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lv
constructor
A new instance of Lv.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lv
Returns a new instance of Lv.
1622 1623 1624 1625 |
# File 'lib/stripe/resources/tax/registration.rb', line 1622 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1618 1619 1620 |
# File 'lib/stripe/resources/tax/registration.rb', line 1618 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1620 1621 1622 |
# File 'lib/stripe/resources/tax/registration.rb', line 1620 def type @type end |