Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Nl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Nl
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Nl
constructor
A new instance of Nl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Nl
Returns a new instance of Nl.
2068 2069 2070 2071 |
# File 'lib/stripe/resources/tax/registration.rb', line 2068 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
2064 2065 2066 |
# File 'lib/stripe/resources/tax/registration.rb', line 2064 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
2066 2067 2068 |
# File 'lib/stripe/resources/tax/registration.rb', line 2066 def type @type end |