Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pl
constructor
A new instance of Pl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pl
Returns a new instance of Pl.
1863 1864 1865 1866 |
# File 'lib/stripe/resources/tax/registration.rb', line 1863 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1859 1860 1861 |
# File 'lib/stripe/resources/tax/registration.rb', line 1859 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1861 1862 1863 |
# File 'lib/stripe/resources/tax/registration.rb', line 1861 def type @type end |