Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pl
constructor
A new instance of Pl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pl
Returns a new instance of Pl.
1856 1857 1858 1859 |
# File 'lib/stripe/resources/tax/registration.rb', line 1856 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1852 1853 1854 |
# File 'lib/stripe/resources/tax/registration.rb', line 1852 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1854 1855 1856 |
# File 'lib/stripe/resources/tax/registration.rb', line 1854 def type @type end |