Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Pl
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Pl
constructor
A new instance of Pl.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Pl
Returns a new instance of Pl.
1680 1681 1682 1683 |
# File 'lib/stripe/resources/tax/registration.rb', line 1680 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1676 1677 1678 |
# File 'lib/stripe/resources/tax/registration.rb', line 1676 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1678 1679 1680 |
# File 'lib/stripe/resources/tax/registration.rb', line 1678 def type @type end |