Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ro
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ro
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ro
constructor
A new instance of Ro.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ro
Returns a new instance of Ro.
1720 1721 1722 1723 |
# File 'lib/stripe/resources/tax/registration.rb', line 1720 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1716 1717 1718 |
# File 'lib/stripe/resources/tax/registration.rb', line 1716 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1718 1719 1720 |
# File 'lib/stripe/resources/tax/registration.rb', line 1718 def type @type end |