Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Ro
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Ro
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ro
constructor
A new instance of Ro.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ro
Returns a new instance of Ro.
1704 1705 1706 1707 |
# File 'lib/stripe/resources/tax/registration.rb', line 1704 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1700 1701 1702 |
# File 'lib/stripe/resources/tax/registration.rb', line 1700 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1702 1703 1704 |
# File 'lib/stripe/resources/tax/registration.rb', line 1702 def type @type end |