Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Sk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Sk
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Sk
constructor
A new instance of Sk.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Sk
Returns a new instance of Sk.
1944 1945 1946 1947 |
# File 'lib/stripe/resources/tax/registration.rb', line 1944 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1940 1941 1942 |
# File 'lib/stripe/resources/tax/registration.rb', line 1940 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1942 1943 1944 |
# File 'lib/stripe/resources/tax/registration.rb', line 1942 def type @type end |