Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Sk
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Sk
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Sk
constructor
A new instance of Sk.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Sk
Returns a new instance of Sk.
1800 1801 1802 1803 |
# File 'lib/stripe/resources/tax/registration.rb', line 1800 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1796 1797 1798 |
# File 'lib/stripe/resources/tax/registration.rb', line 1796 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1798 1799 1800 |
# File 'lib/stripe/resources/tax/registration.rb', line 1798 def type @type end |