Class: Stripe::Tax::Registration::CreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::CreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/resources/tax/registration.rb
Defined Under Namespace
Classes: LocalAmusementTax, LocalLeaseTax, StateSalesTax
Instance Attribute Summary collapse
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
Constructor Details
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 |
# File 'lib/stripe/resources/tax/registration.rb', line 2062 def initialize( local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
2052 2053 2054 |
# File 'lib/stripe/resources/tax/registration.rb', line 2052 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
2054 2055 2056 |
# File 'lib/stripe/resources/tax/registration.rb', line 2054 def local_lease_tax @local_lease_tax end |
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
2056 2057 2058 |
# File 'lib/stripe/resources/tax/registration.rb', line 2056 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
2058 2059 2060 |
# File 'lib/stripe/resources/tax/registration.rb', line 2058 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
2060 2061 2062 |
# File 'lib/stripe/resources/tax/registration.rb', line 2060 def type @type end |