Class: Stripe::Tax::Registration::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



924
925
926
927
928
929
930
931
932
933
934
935
936
# File 'lib/stripe/resources/tax/registration.rb', line 924

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



914
915
916
# File 'lib/stripe/resources/tax/registration.rb', line 914

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



916
917
918
# File 'lib/stripe/resources/tax/registration.rb', line 916

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



918
919
920
# File 'lib/stripe/resources/tax/registration.rb', line 918

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



920
921
922
# File 'lib/stripe/resources/tax/registration.rb', line 920

def starting_after
  @starting_after
end

#statusObject

The status of the Tax Registration.



922
923
924
# File 'lib/stripe/resources/tax/registration.rb', line 922

def status
  @status
end