Class: Stripe::Tax::Registration::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3007
3008
3009
3010
3011
# File 'lib/stripe/resources/tax/registration.rb', line 3007

def initialize(active_from: nil, expand: nil, expires_at: nil)
  @active_from = active_from
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the registration becomes active. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



3001
3002
3003
# File 'lib/stripe/resources/tax/registration.rb', line 3001

def active_from
  @active_from
end

#expandObject

Specifies which fields in the response should be expanded.



3003
3004
3005
# File 'lib/stripe/resources/tax/registration.rb', line 3003

def expand
  @expand
end

#expires_atObject

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



3005
3006
3007
# File 'lib/stripe/resources/tax/registration.rb', line 3005

def expires_at
  @expires_at
end