Class: Stripe::Tax::Registration::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Registration::UpdateParams
- Defined in:
- lib/stripe/resources/tax/registration.rb
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the registration becomes active.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2609 2610 2611 2612 2613 |
# File 'lib/stripe/resources/tax/registration.rb', line 2609 def initialize(active_from: nil, expand: nil, expires_at: nil) @active_from = active_from @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the registration becomes active. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.
2603 2604 2605 |
# File 'lib/stripe/resources/tax/registration.rb', line 2603 def active_from @active_from end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2605 2606 2607 |
# File 'lib/stripe/resources/tax/registration.rb', line 2605 def @expand end |
#expires_at ⇒ Object
If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.
2607 2608 2609 |
# File 'lib/stripe/resources/tax/registration.rb', line 2607 def expires_at @expires_at end |