Class: Stripe::Tax::Registration::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax/registration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2378
2379
2380
2381
2382
# File 'lib/stripe/resources/tax/registration.rb', line 2378

def initialize(active_from: nil, expand: nil, expires_at: nil)
  @active_from = active_from
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the registration becomes active. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



2372
2373
2374
# File 'lib/stripe/resources/tax/registration.rb', line 2372

def active_from
  @active_from
end

#expandObject

Specifies which fields in the response should be expanded.



2374
2375
2376
# File 'lib/stripe/resources/tax/registration.rb', line 2374

def expand
  @expand
end

#expires_atObject

If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.



2376
2377
2378
# File 'lib/stripe/resources/tax/registration.rb', line 2376

def expires_at
  @expires_at
end