Class: Stripe::Tax::RegistrationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams

Returns a new instance of RegistrationCreateParams.



2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2483

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either now to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2473
2474
2475
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2473

def active_from
  @active_from
end

#countryObject

Two-letter country code (ISO 3166-1 alpha-2).



2475
2476
2477
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2475

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified country.



2477
2478
2479
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2477

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2479
2480
2481
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2479

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2481
2482
2483
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2481

def expires_at
  @expires_at
end