Class: Stripe::Tax::RegistrationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: CountryOptions
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the Tax Registration becomes active.
-
#country ⇒ Object
Two-letter country code (ISO 3166-1 alpha-2).
-
#country_options ⇒ Object
Specific options for a registration in the specified
country. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
constructor
A new instance of RegistrationCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
Returns a new instance of RegistrationCreateParams.
2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2172 def initialize( active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil ) @active_from = active_from @country = country @country_options = @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the Tax Registration becomes active. It can be either now to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
2162 2163 2164 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2162 def active_from @active_from end |
#country ⇒ Object
Two-letter country code (ISO 3166-1 alpha-2).
2164 2165 2166 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2164 def country @country end |
#country_options ⇒ Object
Specific options for a registration in the specified country.
2166 2167 2168 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2166 def @country_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2168 2169 2170 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2168 def @expand end |
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
2170 2171 2172 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2170 def expires_at @expires_at end |