Class: Stripe::Tax::RegistrationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams

Returns a new instance of RegistrationCreateParams.



2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2055

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either now to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2045
2046
2047
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2045

def active_from
  @active_from
end

#countryObject

Two-letter country code (ISO 3166-1 alpha-2).



2047
2048
2049
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2047

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified country.



2049
2050
2051
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2049

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2051
2052
2053
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2051

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2053
2054
2055
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2053

def expires_at
  @expires_at
end