Class: Stripe::Tax::RegistrationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams

Returns a new instance of RegistrationCreateParams.



2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2159

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either now to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2149
2150
2151
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2149

def active_from
  @active_from
end

#countryObject

Two-letter country code (ISO 3166-1 alpha-2).



2151
2152
2153
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2151

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified country.



2153
2154
2155
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2153

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2155
2156
2157
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2155

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2157
2158
2159
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2157

def expires_at
  @expires_at
end