Class: Stripe::Tax::RegistrationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: CountryOptions
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the Tax Registration becomes active.
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
constructor
A new instance of RegistrationCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
Returns a new instance of RegistrationCreateParams.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2146 def initialize( active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil ) @active_from = active_from @country = country @country_options = @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
2136 2137 2138 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2136 def active_from @active_from end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2138 2139 2140 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2138 def country @country end |
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
2140 2141 2142 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2140 def @country_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2142 2143 2144 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2142 def @expand end |
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
2144 2145 2146 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2144 def expires_at @expires_at end |