Class: Stripe::Tax::RegistrationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams

Returns a new instance of RegistrationCreateParams.



2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2133

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2123
2124
2125
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2123

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2125
2126
2127
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2125

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2127
2128
2129
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2127

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2129
2130
2131
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2129

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2131
2132
2133
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2131

def expires_at
  @expires_at
end