Class: Stripe::Tax::RegistrationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams

Returns a new instance of RegistrationCreateParams.



2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2042

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



2032
2033
2034
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2032

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2034
2035
2036
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2034

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



2036
2037
2038
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2036

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



2038
2039
2040
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2038

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2040
2041
2042
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2040

def expires_at
  @expires_at
end