Class: Stripe::Tax::RegistrationCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams

Returns a new instance of RegistrationCreateParams.



2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2003

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



1993
1994
1995
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1993

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1995
1996
1997
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1995

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



1997
1998
1999
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1997

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



1999
2000
2001
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1999

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



2001
2002
2003
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2001

def expires_at
  @expires_at
end