Class: Stripe::Tax::RegistrationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: CountryOptions
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the Tax Registration becomes active.
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
constructor
A new instance of RegistrationCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
Returns a new instance of RegistrationCreateParams.
2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2003 def initialize( active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil ) @active_from = active_from @country = country @country_options = @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
1993 1994 1995 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1993 def active_from @active_from end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
1995 1996 1997 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1995 def country @country end |
#country_options ⇒ Object
Specific options for a registration in the specified ‘country`.
1997 1998 1999 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1997 def @country_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1999 2000 2001 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1999 def @expand end |
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
2001 2002 2003 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2001 def expires_at @expires_at end |