Class: Stripe::Tax::RegistrationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: CountryOptions
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the Tax Registration becomes active.
-
#country ⇒ Object
Two-letter country code (ISO 3166-1 alpha-2).
-
#country_options ⇒ Object
Specific options for a registration in the specified
country. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
constructor
A new instance of RegistrationCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ RegistrationCreateParams
Returns a new instance of RegistrationCreateParams.
2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2379 def initialize( active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil ) @active_from = active_from @country = country @country_options = @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the Tax Registration becomes active. It can be either now to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
2369 2370 2371 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2369 def active_from @active_from end |
#country ⇒ Object
Two-letter country code (ISO 3166-1 alpha-2).
2371 2372 2373 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2371 def country @country end |
#country_options ⇒ Object
Specific options for a registration in the specified country.
2373 2374 2375 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2373 def @country_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2375 2376 2377 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2375 def @expand end |
#expires_at ⇒ Object
If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.
2377 2378 2379 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2377 def expires_at @expires_at end |