Class: Stripe::Tax::RegistrationCreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lk: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tw: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2266

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  aw: nil,
  az: nil,
  ba: nil,
  bb: nil,
  bd: nil,
  be: nil,
  bf: nil,
  bg: nil,
  bh: nil,
  bj: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  cm: nil,
  co: nil,
  cr: nil,
  cv: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  et: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kg: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  la: nil,
  lk: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  ph: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tw: nil,
  tz: nil,
  ua: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @aw = aw
  @az = az
  @ba = ba
  @bb = bb
  @bd = bd
  @be = be
  @bf = bf
  @bg = bg
  @bh = bh
  @bj = bj
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @cm = cm
  @co = co
  @cr = cr
  @cv = cv
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @et = et
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kg = kg
  @kh = kh
  @kr = kr
  @kz = kz
  @la = la
  @lk = lk
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @ph = ph
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tw = tw
  @tz = tz
  @ua = ua
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



2064
2065
2066
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2064

def ae
  @ae
end

#alObject

Options for the registration in AL.



2066
2067
2068
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2066

def al
  @al
end

#amObject

Options for the registration in AM.



2068
2069
2070
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2068

def am
  @am
end

#aoObject

Options for the registration in AO.



2070
2071
2072
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2070

def ao
  @ao
end

#atObject

Options for the registration in AT.



2072
2073
2074
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2072

def at
  @at
end

#auObject

Options for the registration in AU.



2074
2075
2076
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2074

def au
  @au
end

#awObject

Options for the registration in AW.



2076
2077
2078
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2076

def aw
  @aw
end

#azObject

Options for the registration in AZ.



2078
2079
2080
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2078

def az
  @az
end

#baObject

Options for the registration in BA.



2080
2081
2082
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2080

def ba
  @ba
end

#bbObject

Options for the registration in BB.



2082
2083
2084
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2082

def bb
  @bb
end

#bdObject

Options for the registration in BD.



2084
2085
2086
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2084

def bd
  @bd
end

#beObject

Options for the registration in BE.



2086
2087
2088
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2086

def be
  @be
end

#bfObject

Options for the registration in BF.



2088
2089
2090
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2088

def bf
  @bf
end

#bgObject

Options for the registration in BG.



2090
2091
2092
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2090

def bg
  @bg
end

#bhObject

Options for the registration in BH.



2092
2093
2094
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2092

def bh
  @bh
end

#bjObject

Options for the registration in BJ.



2094
2095
2096
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2094

def bj
  @bj
end

#bsObject

Options for the registration in BS.



2096
2097
2098
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2096

def bs
  @bs
end

#byObject

Options for the registration in BY.



2098
2099
2100
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2098

def by
  @by
end

#caObject

Options for the registration in CA.



2100
2101
2102
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2100

def ca
  @ca
end

#cdObject

Options for the registration in CD.



2102
2103
2104
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2102

def cd
  @cd
end

#chObject

Options for the registration in CH.



2104
2105
2106
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2104

def ch
  @ch
end

#clObject

Options for the registration in CL.



2106
2107
2108
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2106

def cl
  @cl
end

#cmObject

Options for the registration in CM.



2108
2109
2110
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2108

def cm
  @cm
end

#coObject

Options for the registration in CO.



2110
2111
2112
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2110

def co
  @co
end

#crObject

Options for the registration in CR.



2112
2113
2114
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2112

def cr
  @cr
end

#cvObject

Options for the registration in CV.



2114
2115
2116
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2114

def cv
  @cv
end

#cyObject

Options for the registration in CY.



2116
2117
2118
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2116

def cy
  @cy
end

#czObject

Options for the registration in CZ.



2118
2119
2120
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2118

def cz
  @cz
end

#deObject

Options for the registration in DE.



2120
2121
2122
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2120

def de
  @de
end

#dkObject

Options for the registration in DK.



2122
2123
2124
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2122

def dk
  @dk
end

#ecObject

Options for the registration in EC.



2124
2125
2126
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2124

def ec
  @ec
end

#eeObject

Options for the registration in EE.



2126
2127
2128
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2126

def ee
  @ee
end

#egObject

Options for the registration in EG.



2128
2129
2130
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2128

def eg
  @eg
end

#esObject

Options for the registration in ES.



2130
2131
2132
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2130

def es
  @es
end

#etObject

Options for the registration in ET.



2132
2133
2134
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2132

def et
  @et
end

#fiObject

Options for the registration in FI.



2134
2135
2136
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2134

def fi
  @fi
end

#frObject

Options for the registration in FR.



2136
2137
2138
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2136

def fr
  @fr
end

#gbObject

Options for the registration in GB.



2138
2139
2140
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2138

def gb
  @gb
end

#geObject

Options for the registration in GE.



2140
2141
2142
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2140

def ge
  @ge
end

#gnObject

Options for the registration in GN.



2142
2143
2144
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2142

def gn
  @gn
end

#grObject

Options for the registration in GR.



2144
2145
2146
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2144

def gr
  @gr
end

#hrObject

Options for the registration in HR.



2146
2147
2148
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2146

def hr
  @hr
end

#huObject

Options for the registration in HU.



2148
2149
2150
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2148

def hu
  @hu
end

#idObject

Options for the registration in ID.



2150
2151
2152
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2150

def id
  @id
end

#ieObject

Options for the registration in IE.



2152
2153
2154
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2152

def ie
  @ie
end

#inObject

Options for the registration in IN.



2154
2155
2156
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2154

def in
  @in
end

#isObject

Options for the registration in IS.



2156
2157
2158
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2156

def is
  @is
end

#itObject

Options for the registration in IT.



2158
2159
2160
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2158

def it
  @it
end

#jpObject

Options for the registration in JP.



2160
2161
2162
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2160

def jp
  @jp
end

#keObject

Options for the registration in KE.



2162
2163
2164
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2162

def ke
  @ke
end

#kgObject

Options for the registration in KG.



2164
2165
2166
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2164

def kg
  @kg
end

#khObject

Options for the registration in KH.



2166
2167
2168
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2166

def kh
  @kh
end

#krObject

Options for the registration in KR.



2168
2169
2170
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2168

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



2170
2171
2172
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2170

def kz
  @kz
end

#laObject

Options for the registration in LA.



2172
2173
2174
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2172

def la
  @la
end

#lkObject

Options for the registration in LK.



2174
2175
2176
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2174

def lk
  @lk
end

#ltObject

Options for the registration in LT.



2176
2177
2178
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2176

def lt
  @lt
end

#luObject

Options for the registration in LU.



2178
2179
2180
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2178

def lu
  @lu
end

#lvObject

Options for the registration in LV.



2180
2181
2182
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2180

def lv
  @lv
end

#maObject

Options for the registration in MA.



2182
2183
2184
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2182

def ma
  @ma
end

#mdObject

Options for the registration in MD.



2184
2185
2186
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2184

def md
  @md
end

#meObject

Options for the registration in ME.



2186
2187
2188
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2186

def me
  @me
end

#mkObject

Options for the registration in MK.



2188
2189
2190
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2188

def mk
  @mk
end

#mrObject

Options for the registration in MR.



2190
2191
2192
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2190

def mr
  @mr
end

#mtObject

Options for the registration in MT.



2192
2193
2194
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2192

def mt
  @mt
end

#mxObject

Options for the registration in MX.



2194
2195
2196
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2194

def mx
  @mx
end

#myObject

Options for the registration in MY.



2196
2197
2198
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2196

def my
  @my
end

#ngObject

Options for the registration in NG.



2198
2199
2200
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2198

def ng
  @ng
end

#nlObject

Options for the registration in NL.



2200
2201
2202
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2200

def nl
  @nl
end

#noObject

Options for the registration in NO.



2202
2203
2204
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2202

def no
  @no
end

#npObject

Options for the registration in NP.



2204
2205
2206
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2204

def np
  @np
end

#nzObject

Options for the registration in NZ.



2206
2207
2208
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2206

def nz
  @nz
end

#omObject

Options for the registration in OM.



2208
2209
2210
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2208

def om
  @om
end

#peObject

Options for the registration in PE.



2210
2211
2212
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2210

def pe
  @pe
end

#phObject

Options for the registration in PH.



2212
2213
2214
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2212

def ph
  @ph
end

#plObject

Options for the registration in PL.



2214
2215
2216
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2214

def pl
  @pl
end

#ptObject

Options for the registration in PT.



2216
2217
2218
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2216

def pt
  @pt
end

#roObject

Options for the registration in RO.



2218
2219
2220
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2218

def ro
  @ro
end

#rsObject

Options for the registration in RS.



2220
2221
2222
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2220

def rs
  @rs
end

#ruObject

Options for the registration in RU.



2222
2223
2224
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2222

def ru
  @ru
end

#saObject

Options for the registration in SA.



2224
2225
2226
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2224

def sa
  @sa
end

#seObject

Options for the registration in SE.



2226
2227
2228
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2226

def se
  @se
end

#sgObject

Options for the registration in SG.



2228
2229
2230
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2228

def sg
  @sg
end

#siObject

Options for the registration in SI.



2230
2231
2232
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2230

def si
  @si
end

#skObject

Options for the registration in SK.



2232
2233
2234
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2232

def sk
  @sk
end

#snObject

Options for the registration in SN.



2234
2235
2236
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2234

def sn
  @sn
end

#srObject

Options for the registration in SR.



2236
2237
2238
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2236

def sr
  @sr
end

#thObject

Options for the registration in TH.



2238
2239
2240
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2238

def th
  @th
end

#tjObject

Options for the registration in TJ.



2240
2241
2242
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2240

def tj
  @tj
end

#trObject

Options for the registration in TR.



2242
2243
2244
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2242

def tr
  @tr
end

#twObject

Options for the registration in TW.



2244
2245
2246
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2244

def tw
  @tw
end

#tzObject

Options for the registration in TZ.



2246
2247
2248
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2246

def tz
  @tz
end

#uaObject

Options for the registration in UA.



2248
2249
2250
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2248

def ua
  @ua
end

#ugObject

Options for the registration in UG.



2250
2251
2252
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2250

def ug
  @ug
end

#usObject

Options for the registration in US.



2252
2253
2254
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2252

def us
  @us
end

#uyObject

Options for the registration in UY.



2254
2255
2256
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2254

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



2256
2257
2258
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2256

def uz
  @uz
end

#vnObject

Options for the registration in VN.



2258
2259
2260
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2258

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



2260
2261
2262
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2260

def za
  @za
end

#zmObject

Options for the registration in ZM.



2262
2263
2264
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2262

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



2264
2265
2266
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2264

def zw
  @zw
end