Class: Stripe::Tax::RegistrationCreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lk: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tw: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1955

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  aw: nil,
  az: nil,
  ba: nil,
  bb: nil,
  bd: nil,
  be: nil,
  bf: nil,
  bg: nil,
  bh: nil,
  bj: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  cm: nil,
  co: nil,
  cr: nil,
  cv: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  et: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kg: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  la: nil,
  lk: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  ph: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tw: nil,
  tz: nil,
  ua: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @aw = aw
  @az = az
  @ba = ba
  @bb = bb
  @bd = bd
  @be = be
  @bf = bf
  @bg = bg
  @bh = bh
  @bj = bj
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @cm = cm
  @co = co
  @cr = cr
  @cv = cv
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @et = et
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kg = kg
  @kh = kh
  @kr = kr
  @kz = kz
  @la = la
  @lk = lk
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @ph = ph
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tw = tw
  @tz = tz
  @ua = ua
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



1753
1754
1755
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1753

def ae
  @ae
end

#alObject

Options for the registration in AL.



1755
1756
1757
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1755

def al
  @al
end

#amObject

Options for the registration in AM.



1757
1758
1759
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1757

def am
  @am
end

#aoObject

Options for the registration in AO.



1759
1760
1761
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1759

def ao
  @ao
end

#atObject

Options for the registration in AT.



1761
1762
1763
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1761

def at
  @at
end

#auObject

Options for the registration in AU.



1763
1764
1765
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1763

def au
  @au
end

#awObject

Options for the registration in AW.



1765
1766
1767
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1765

def aw
  @aw
end

#azObject

Options for the registration in AZ.



1767
1768
1769
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1767

def az
  @az
end

#baObject

Options for the registration in BA.



1769
1770
1771
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1769

def ba
  @ba
end

#bbObject

Options for the registration in BB.



1771
1772
1773
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1771

def bb
  @bb
end

#bdObject

Options for the registration in BD.



1773
1774
1775
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1773

def bd
  @bd
end

#beObject

Options for the registration in BE.



1775
1776
1777
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1775

def be
  @be
end

#bfObject

Options for the registration in BF.



1777
1778
1779
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1777

def bf
  @bf
end

#bgObject

Options for the registration in BG.



1779
1780
1781
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1779

def bg
  @bg
end

#bhObject

Options for the registration in BH.



1781
1782
1783
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1781

def bh
  @bh
end

#bjObject

Options for the registration in BJ.



1783
1784
1785
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1783

def bj
  @bj
end

#bsObject

Options for the registration in BS.



1785
1786
1787
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1785

def bs
  @bs
end

#byObject

Options for the registration in BY.



1787
1788
1789
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1787

def by
  @by
end

#caObject

Options for the registration in CA.



1789
1790
1791
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1789

def ca
  @ca
end

#cdObject

Options for the registration in CD.



1791
1792
1793
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1791

def cd
  @cd
end

#chObject

Options for the registration in CH.



1793
1794
1795
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1793

def ch
  @ch
end

#clObject

Options for the registration in CL.



1795
1796
1797
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1795

def cl
  @cl
end

#cmObject

Options for the registration in CM.



1797
1798
1799
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1797

def cm
  @cm
end

#coObject

Options for the registration in CO.



1799
1800
1801
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1799

def co
  @co
end

#crObject

Options for the registration in CR.



1801
1802
1803
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1801

def cr
  @cr
end

#cvObject

Options for the registration in CV.



1803
1804
1805
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1803

def cv
  @cv
end

#cyObject

Options for the registration in CY.



1805
1806
1807
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1805

def cy
  @cy
end

#czObject

Options for the registration in CZ.



1807
1808
1809
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1807

def cz
  @cz
end

#deObject

Options for the registration in DE.



1809
1810
1811
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1809

def de
  @de
end

#dkObject

Options for the registration in DK.



1811
1812
1813
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1811

def dk
  @dk
end

#ecObject

Options for the registration in EC.



1813
1814
1815
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1813

def ec
  @ec
end

#eeObject

Options for the registration in EE.



1815
1816
1817
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1815

def ee
  @ee
end

#egObject

Options for the registration in EG.



1817
1818
1819
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1817

def eg
  @eg
end

#esObject

Options for the registration in ES.



1819
1820
1821
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1819

def es
  @es
end

#etObject

Options for the registration in ET.



1821
1822
1823
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1821

def et
  @et
end

#fiObject

Options for the registration in FI.



1823
1824
1825
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1823

def fi
  @fi
end

#frObject

Options for the registration in FR.



1825
1826
1827
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1825

def fr
  @fr
end

#gbObject

Options for the registration in GB.



1827
1828
1829
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1827

def gb
  @gb
end

#geObject

Options for the registration in GE.



1829
1830
1831
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1829

def ge
  @ge
end

#gnObject

Options for the registration in GN.



1831
1832
1833
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1831

def gn
  @gn
end

#grObject

Options for the registration in GR.



1833
1834
1835
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1833

def gr
  @gr
end

#hrObject

Options for the registration in HR.



1835
1836
1837
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1835

def hr
  @hr
end

#huObject

Options for the registration in HU.



1837
1838
1839
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1837

def hu
  @hu
end

#idObject

Options for the registration in ID.



1839
1840
1841
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1839

def id
  @id
end

#ieObject

Options for the registration in IE.



1841
1842
1843
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1841

def ie
  @ie
end

#inObject

Options for the registration in IN.



1843
1844
1845
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1843

def in
  @in
end

#isObject

Options for the registration in IS.



1845
1846
1847
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1845

def is
  @is
end

#itObject

Options for the registration in IT.



1847
1848
1849
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1847

def it
  @it
end

#jpObject

Options for the registration in JP.



1849
1850
1851
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1849

def jp
  @jp
end

#keObject

Options for the registration in KE.



1851
1852
1853
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1851

def ke
  @ke
end

#kgObject

Options for the registration in KG.



1853
1854
1855
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1853

def kg
  @kg
end

#khObject

Options for the registration in KH.



1855
1856
1857
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1855

def kh
  @kh
end

#krObject

Options for the registration in KR.



1857
1858
1859
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1857

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



1859
1860
1861
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1859

def kz
  @kz
end

#laObject

Options for the registration in LA.



1861
1862
1863
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1861

def la
  @la
end

#lkObject

Options for the registration in LK.



1863
1864
1865
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1863

def lk
  @lk
end

#ltObject

Options for the registration in LT.



1865
1866
1867
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1865

def lt
  @lt
end

#luObject

Options for the registration in LU.



1867
1868
1869
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1867

def lu
  @lu
end

#lvObject

Options for the registration in LV.



1869
1870
1871
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1869

def lv
  @lv
end

#maObject

Options for the registration in MA.



1871
1872
1873
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1871

def ma
  @ma
end

#mdObject

Options for the registration in MD.



1873
1874
1875
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1873

def md
  @md
end

#meObject

Options for the registration in ME.



1875
1876
1877
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1875

def me
  @me
end

#mkObject

Options for the registration in MK.



1877
1878
1879
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1877

def mk
  @mk
end

#mrObject

Options for the registration in MR.



1879
1880
1881
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1879

def mr
  @mr
end

#mtObject

Options for the registration in MT.



1881
1882
1883
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1881

def mt
  @mt
end

#mxObject

Options for the registration in MX.



1883
1884
1885
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1883

def mx
  @mx
end

#myObject

Options for the registration in MY.



1885
1886
1887
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1885

def my
  @my
end

#ngObject

Options for the registration in NG.



1887
1888
1889
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1887

def ng
  @ng
end

#nlObject

Options for the registration in NL.



1889
1890
1891
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1889

def nl
  @nl
end

#noObject

Options for the registration in NO.



1891
1892
1893
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1891

def no
  @no
end

#npObject

Options for the registration in NP.



1893
1894
1895
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1893

def np
  @np
end

#nzObject

Options for the registration in NZ.



1895
1896
1897
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1895

def nz
  @nz
end

#omObject

Options for the registration in OM.



1897
1898
1899
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1897

def om
  @om
end

#peObject

Options for the registration in PE.



1899
1900
1901
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1899

def pe
  @pe
end

#phObject

Options for the registration in PH.



1901
1902
1903
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1901

def ph
  @ph
end

#plObject

Options for the registration in PL.



1903
1904
1905
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1903

def pl
  @pl
end

#ptObject

Options for the registration in PT.



1905
1906
1907
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1905

def pt
  @pt
end

#roObject

Options for the registration in RO.



1907
1908
1909
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1907

def ro
  @ro
end

#rsObject

Options for the registration in RS.



1909
1910
1911
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1909

def rs
  @rs
end

#ruObject

Options for the registration in RU.



1911
1912
1913
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1911

def ru
  @ru
end

#saObject

Options for the registration in SA.



1913
1914
1915
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1913

def sa
  @sa
end

#seObject

Options for the registration in SE.



1915
1916
1917
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1915

def se
  @se
end

#sgObject

Options for the registration in SG.



1917
1918
1919
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1917

def sg
  @sg
end

#siObject

Options for the registration in SI.



1919
1920
1921
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1919

def si
  @si
end

#skObject

Options for the registration in SK.



1921
1922
1923
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1921

def sk
  @sk
end

#snObject

Options for the registration in SN.



1923
1924
1925
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1923

def sn
  @sn
end

#srObject

Options for the registration in SR.



1925
1926
1927
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1925

def sr
  @sr
end

#thObject

Options for the registration in TH.



1927
1928
1929
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1927

def th
  @th
end

#tjObject

Options for the registration in TJ.



1929
1930
1931
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1929

def tj
  @tj
end

#trObject

Options for the registration in TR.



1931
1932
1933
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1931

def tr
  @tr
end

#twObject

Options for the registration in TW.



1933
1934
1935
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1933

def tw
  @tw
end

#tzObject

Options for the registration in TZ.



1935
1936
1937
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1935

def tz
  @tz
end

#uaObject

Options for the registration in UA.



1937
1938
1939
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1937

def ua
  @ua
end

#ugObject

Options for the registration in UG.



1939
1940
1941
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1939

def ug
  @ug
end

#usObject

Options for the registration in US.



1941
1942
1943
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1941

def us
  @us
end

#uyObject

Options for the registration in UY.



1943
1944
1945
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1943

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



1945
1946
1947
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1945

def uz
  @uz
end

#vnObject

Options for the registration in VN.



1947
1948
1949
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1947

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



1949
1950
1951
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1949

def za
  @za
end

#zmObject

Options for the registration in ZM.



1951
1952
1953
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1951

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



1953
1954
1955
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1953

def zw
  @zw
end