Class: Stripe::Tax::RegistrationCreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#al ⇒ Object
Options for the registration in AL.
-
#am ⇒ Object
Options for the registration in AM.
-
#ao ⇒ Object
Options for the registration in AO.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#aw ⇒ Object
Options for the registration in AW.
-
#az ⇒ Object
Options for the registration in AZ.
-
#ba ⇒ Object
Options for the registration in BA.
-
#bb ⇒ Object
Options for the registration in BB.
-
#bd ⇒ Object
Options for the registration in BD.
-
#be ⇒ Object
Options for the registration in BE.
-
#bf ⇒ Object
Options for the registration in BF.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#bj ⇒ Object
Options for the registration in BJ.
-
#bs ⇒ Object
Options for the registration in BS.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#cd ⇒ Object
Options for the registration in CD.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#cm ⇒ Object
Options for the registration in CM.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cv ⇒ Object
Options for the registration in CV.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#et ⇒ Object
Options for the registration in ET.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gn ⇒ Object
Options for the registration in GN.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#in ⇒ Object
Options for the registration in IN.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kg ⇒ Object
Options for the registration in KG.
-
#kh ⇒ Object
Options for the registration in KH.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#la ⇒ Object
Options for the registration in LA.
-
#lk ⇒ Object
Options for the registration in LK.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#me ⇒ Object
Options for the registration in ME.
-
#mk ⇒ Object
Options for the registration in MK.
-
#mr ⇒ Object
Options for the registration in MR.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#np ⇒ Object
Options for the registration in NP.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pe ⇒ Object
Options for the registration in PE.
-
#ph ⇒ Object
Options for the registration in PH.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#sn ⇒ Object
Options for the registration in SN.
-
#sr ⇒ Object
Options for the registration in SR.
-
#th ⇒ Object
Options for the registration in TH.
-
#tj ⇒ Object
Options for the registration in TJ.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tw ⇒ Object
Options for the registration in TW.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#ua ⇒ Object
Options for the registration in UA.
-
#ug ⇒ Object
Options for the registration in UG.
-
#us ⇒ Object
Options for the registration in US.
-
#uy ⇒ Object
Options for the registration in UY.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
-
#zm ⇒ Object
Options for the registration in ZM.
-
#zw ⇒ Object
Options for the registration in ZW.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lk: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tw: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1942 def initialize( ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lk: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tw: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil ) @ae = ae @al = al @am = am @ao = ao @at = at @au = au @aw = aw @az = az @ba = ba @bb = bb @bd = bd @be = be @bf = bf @bg = bg @bh = bh @bj = bj @bs = bs @by = by @ca = ca @cd = cd @ch = ch @cl = cl @cm = cm @co = co @cr = cr @cv = cv @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @et = et @fi = fi @fr = fr @gb = gb @ge = ge @gn = gn @gr = gr @hr = hr @hu = hu @id = id @ie = ie @in = in_ @is = is @it = it @jp = jp @ke = ke @kg = kg @kh = kh @kr = kr @kz = kz @la = la @lk = lk @lt = lt @lu = lu @lv = lv @ma = ma @md = md @me = me @mk = mk @mr = mr @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @np = np @nz = nz @om = om @pe = pe @ph = ph @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @sn = sn @sr = sr @th = th @tj = tj @tr = tr @tw = tw @tz = tz @ua = ua @ug = ug @us = us @uy = uy @uz = uz @vn = vn @za = za @zm = zm @zw = zw end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
1740 1741 1742 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1740 def ae @ae end |
#al ⇒ Object
Options for the registration in AL.
1742 1743 1744 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1742 def al @al end |
#am ⇒ Object
Options for the registration in AM.
1744 1745 1746 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1744 def am @am end |
#ao ⇒ Object
Options for the registration in AO.
1746 1747 1748 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1746 def ao @ao end |
#at ⇒ Object
Options for the registration in AT.
1748 1749 1750 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1748 def at @at end |
#au ⇒ Object
Options for the registration in AU.
1750 1751 1752 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1750 def au @au end |
#aw ⇒ Object
Options for the registration in AW.
1752 1753 1754 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1752 def aw @aw end |
#az ⇒ Object
Options for the registration in AZ.
1754 1755 1756 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1754 def az @az end |
#ba ⇒ Object
Options for the registration in BA.
1756 1757 1758 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1756 def ba @ba end |
#bb ⇒ Object
Options for the registration in BB.
1758 1759 1760 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1758 def bb @bb end |
#bd ⇒ Object
Options for the registration in BD.
1760 1761 1762 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1760 def bd @bd end |
#be ⇒ Object
Options for the registration in BE.
1762 1763 1764 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1762 def be @be end |
#bf ⇒ Object
Options for the registration in BF.
1764 1765 1766 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1764 def bf @bf end |
#bg ⇒ Object
Options for the registration in BG.
1766 1767 1768 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1766 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
1768 1769 1770 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1768 def bh @bh end |
#bj ⇒ Object
Options for the registration in BJ.
1770 1771 1772 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1770 def bj @bj end |
#bs ⇒ Object
Options for the registration in BS.
1772 1773 1774 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1772 def bs @bs end |
#by ⇒ Object
Options for the registration in BY.
1774 1775 1776 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1774 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
1776 1777 1778 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1776 def ca @ca end |
#cd ⇒ Object
Options for the registration in CD.
1778 1779 1780 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1778 def cd @cd end |
#ch ⇒ Object
Options for the registration in CH.
1780 1781 1782 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1780 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
1782 1783 1784 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1782 def cl @cl end |
#cm ⇒ Object
Options for the registration in CM.
1784 1785 1786 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1784 def cm @cm end |
#co ⇒ Object
Options for the registration in CO.
1786 1787 1788 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1786 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
1788 1789 1790 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1788 def cr @cr end |
#cv ⇒ Object
Options for the registration in CV.
1790 1791 1792 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1790 def cv @cv end |
#cy ⇒ Object
Options for the registration in CY.
1792 1793 1794 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1792 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
1794 1795 1796 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1794 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
1796 1797 1798 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1796 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
1798 1799 1800 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1798 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
1800 1801 1802 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1800 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
1802 1803 1804 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1802 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
1804 1805 1806 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1804 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
1806 1807 1808 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1806 def es @es end |
#et ⇒ Object
Options for the registration in ET.
1808 1809 1810 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1808 def et @et end |
#fi ⇒ Object
Options for the registration in FI.
1810 1811 1812 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1810 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
1812 1813 1814 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1812 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
1814 1815 1816 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1814 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
1816 1817 1818 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1816 def ge @ge end |
#gn ⇒ Object
Options for the registration in GN.
1818 1819 1820 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1818 def gn @gn end |
#gr ⇒ Object
Options for the registration in GR.
1820 1821 1822 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1820 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
1822 1823 1824 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1822 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
1824 1825 1826 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1824 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
1826 1827 1828 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1826 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
1828 1829 1830 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1828 def ie @ie end |
#in ⇒ Object
Options for the registration in IN.
1830 1831 1832 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1830 def in @in end |
#is ⇒ Object
Options for the registration in IS.
1832 1833 1834 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1832 def is @is end |
#it ⇒ Object
Options for the registration in IT.
1834 1835 1836 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1834 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
1836 1837 1838 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1836 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
1838 1839 1840 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1838 def ke @ke end |
#kg ⇒ Object
Options for the registration in KG.
1840 1841 1842 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1840 def kg @kg end |
#kh ⇒ Object
Options for the registration in KH.
1842 1843 1844 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1842 def kh @kh end |
#kr ⇒ Object
Options for the registration in KR.
1844 1845 1846 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1844 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
1846 1847 1848 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1846 def kz @kz end |
#la ⇒ Object
Options for the registration in LA.
1848 1849 1850 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1848 def la @la end |
#lk ⇒ Object
Options for the registration in LK.
1850 1851 1852 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1850 def lk @lk end |
#lt ⇒ Object
Options for the registration in LT.
1852 1853 1854 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1852 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
1854 1855 1856 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1854 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
1856 1857 1858 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1856 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
1858 1859 1860 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1858 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
1860 1861 1862 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1860 def md @md end |
#me ⇒ Object
Options for the registration in ME.
1862 1863 1864 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1862 def me @me end |
#mk ⇒ Object
Options for the registration in MK.
1864 1865 1866 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1864 def mk @mk end |
#mr ⇒ Object
Options for the registration in MR.
1866 1867 1868 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1866 def mr @mr end |
#mt ⇒ Object
Options for the registration in MT.
1868 1869 1870 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1868 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
1870 1871 1872 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1870 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
1872 1873 1874 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1872 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
1874 1875 1876 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1874 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
1876 1877 1878 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1876 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
1878 1879 1880 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1878 def no @no end |
#np ⇒ Object
Options for the registration in NP.
1880 1881 1882 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1880 def np @np end |
#nz ⇒ Object
Options for the registration in NZ.
1882 1883 1884 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1882 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
1884 1885 1886 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1884 def om @om end |
#pe ⇒ Object
Options for the registration in PE.
1886 1887 1888 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1886 def pe @pe end |
#ph ⇒ Object
Options for the registration in PH.
1888 1889 1890 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1888 def ph @ph end |
#pl ⇒ Object
Options for the registration in PL.
1890 1891 1892 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1890 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
1892 1893 1894 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1892 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
1894 1895 1896 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1894 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
1896 1897 1898 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1896 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
1898 1899 1900 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1898 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
1900 1901 1902 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1900 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
1902 1903 1904 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1902 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
1904 1905 1906 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1904 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
1906 1907 1908 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1906 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
1908 1909 1910 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1908 def sk @sk end |
#sn ⇒ Object
Options for the registration in SN.
1910 1911 1912 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1910 def sn @sn end |
#sr ⇒ Object
Options for the registration in SR.
1912 1913 1914 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1912 def sr @sr end |
#th ⇒ Object
Options for the registration in TH.
1914 1915 1916 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1914 def th @th end |
#tj ⇒ Object
Options for the registration in TJ.
1916 1917 1918 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1916 def tj @tj end |
#tr ⇒ Object
Options for the registration in TR.
1918 1919 1920 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1918 def tr @tr end |
#tw ⇒ Object
Options for the registration in TW.
1920 1921 1922 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1920 def tw @tw end |
#tz ⇒ Object
Options for the registration in TZ.
1922 1923 1924 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1922 def tz @tz end |
#ua ⇒ Object
Options for the registration in UA.
1924 1925 1926 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1924 def ua @ua end |
#ug ⇒ Object
Options for the registration in UG.
1926 1927 1928 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1926 def ug @ug end |
#us ⇒ Object
Options for the registration in US.
1928 1929 1930 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1928 def us @us end |
#uy ⇒ Object
Options for the registration in UY.
1930 1931 1932 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1930 def uy @uy end |
#uz ⇒ Object
Options for the registration in UZ.
1932 1933 1934 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1932 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
1934 1935 1936 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1934 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
1936 1937 1938 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1936 def za @za end |
#zm ⇒ Object
Options for the registration in ZM.
1938 1939 1940 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1938 def zm @zm end |
#zw ⇒ Object
Options for the registration in ZW.
1940 1941 1942 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1940 def zw @zw end |