Class: Stripe::Tax::RegistrationCreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/tax/registration_create_params.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1790

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  aw: nil,
  az: nil,
  ba: nil,
  bb: nil,
  bd: nil,
  be: nil,
  bf: nil,
  bg: nil,
  bh: nil,
  bj: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  cm: nil,
  co: nil,
  cr: nil,
  cv: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  et: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kg: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  la: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  ph: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tz: nil,
  ua: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @aw = aw
  @az = az
  @ba = ba
  @bb = bb
  @bd = bd
  @be = be
  @bf = bf
  @bg = bg
  @bh = bh
  @bj = bj
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @cm = cm
  @co = co
  @cr = cr
  @cv = cv
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @et = et
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kg = kg
  @kh = kh
  @kr = kr
  @kz = kz
  @la = la
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @ph = ph
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tz = tz
  @ua = ua
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



1592
1593
1594
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1592

def ae
  @ae
end

#alObject

Options for the registration in AL.



1594
1595
1596
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1594

def al
  @al
end

#amObject

Options for the registration in AM.



1596
1597
1598
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1596

def am
  @am
end

#aoObject

Options for the registration in AO.



1598
1599
1600
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1598

def ao
  @ao
end

#atObject

Options for the registration in AT.



1600
1601
1602
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1600

def at
  @at
end

#auObject

Options for the registration in AU.



1602
1603
1604
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1602

def au
  @au
end

#awObject

Options for the registration in AW.



1604
1605
1606
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1604

def aw
  @aw
end

#azObject

Options for the registration in AZ.



1606
1607
1608
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1606

def az
  @az
end

#baObject

Options for the registration in BA.



1608
1609
1610
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1608

def ba
  @ba
end

#bbObject

Options for the registration in BB.



1610
1611
1612
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1610

def bb
  @bb
end

#bdObject

Options for the registration in BD.



1612
1613
1614
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1612

def bd
  @bd
end

#beObject

Options for the registration in BE.



1614
1615
1616
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1614

def be
  @be
end

#bfObject

Options for the registration in BF.



1616
1617
1618
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1616

def bf
  @bf
end

#bgObject

Options for the registration in BG.



1618
1619
1620
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1618

def bg
  @bg
end

#bhObject

Options for the registration in BH.



1620
1621
1622
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1620

def bh
  @bh
end

#bjObject

Options for the registration in BJ.



1622
1623
1624
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1622

def bj
  @bj
end

#bsObject

Options for the registration in BS.



1624
1625
1626
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1624

def bs
  @bs
end

#byObject

Options for the registration in BY.



1626
1627
1628
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1626

def by
  @by
end

#caObject

Options for the registration in CA.



1628
1629
1630
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1628

def ca
  @ca
end

#cdObject

Options for the registration in CD.



1630
1631
1632
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1630

def cd
  @cd
end

#chObject

Options for the registration in CH.



1632
1633
1634
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1632

def ch
  @ch
end

#clObject

Options for the registration in CL.



1634
1635
1636
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1634

def cl
  @cl
end

#cmObject

Options for the registration in CM.



1636
1637
1638
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1636

def cm
  @cm
end

#coObject

Options for the registration in CO.



1638
1639
1640
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1638

def co
  @co
end

#crObject

Options for the registration in CR.



1640
1641
1642
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1640

def cr
  @cr
end

#cvObject

Options for the registration in CV.



1642
1643
1644
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1642

def cv
  @cv
end

#cyObject

Options for the registration in CY.



1644
1645
1646
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1644

def cy
  @cy
end

#czObject

Options for the registration in CZ.



1646
1647
1648
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1646

def cz
  @cz
end

#deObject

Options for the registration in DE.



1648
1649
1650
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1648

def de
  @de
end

#dkObject

Options for the registration in DK.



1650
1651
1652
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1650

def dk
  @dk
end

#ecObject

Options for the registration in EC.



1652
1653
1654
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1652

def ec
  @ec
end

#eeObject

Options for the registration in EE.



1654
1655
1656
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1654

def ee
  @ee
end

#egObject

Options for the registration in EG.



1656
1657
1658
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1656

def eg
  @eg
end

#esObject

Options for the registration in ES.



1658
1659
1660
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1658

def es
  @es
end

#etObject

Options for the registration in ET.



1660
1661
1662
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1660

def et
  @et
end

#fiObject

Options for the registration in FI.



1662
1663
1664
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1662

def fi
  @fi
end

#frObject

Options for the registration in FR.



1664
1665
1666
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1664

def fr
  @fr
end

#gbObject

Options for the registration in GB.



1666
1667
1668
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1666

def gb
  @gb
end

#geObject

Options for the registration in GE.



1668
1669
1670
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1668

def ge
  @ge
end

#gnObject

Options for the registration in GN.



1670
1671
1672
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1670

def gn
  @gn
end

#grObject

Options for the registration in GR.



1672
1673
1674
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1672

def gr
  @gr
end

#hrObject

Options for the registration in HR.



1674
1675
1676
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1674

def hr
  @hr
end

#huObject

Options for the registration in HU.



1676
1677
1678
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1676

def hu
  @hu
end

#idObject

Options for the registration in ID.



1678
1679
1680
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1678

def id
  @id
end

#ieObject

Options for the registration in IE.



1680
1681
1682
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1680

def ie
  @ie
end

#inObject

Options for the registration in IN.



1682
1683
1684
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1682

def in
  @in
end

#isObject

Options for the registration in IS.



1684
1685
1686
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1684

def is
  @is
end

#itObject

Options for the registration in IT.



1686
1687
1688
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1686

def it
  @it
end

#jpObject

Options for the registration in JP.



1688
1689
1690
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1688

def jp
  @jp
end

#keObject

Options for the registration in KE.



1690
1691
1692
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1690

def ke
  @ke
end

#kgObject

Options for the registration in KG.



1692
1693
1694
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1692

def kg
  @kg
end

#khObject

Options for the registration in KH.



1694
1695
1696
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1694

def kh
  @kh
end

#krObject

Options for the registration in KR.



1696
1697
1698
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1696

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



1698
1699
1700
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1698

def kz
  @kz
end

#laObject

Options for the registration in LA.



1700
1701
1702
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1700

def la
  @la
end

#ltObject

Options for the registration in LT.



1702
1703
1704
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1702

def lt
  @lt
end

#luObject

Options for the registration in LU.



1704
1705
1706
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1704

def lu
  @lu
end

#lvObject

Options for the registration in LV.



1706
1707
1708
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1706

def lv
  @lv
end

#maObject

Options for the registration in MA.



1708
1709
1710
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1708

def ma
  @ma
end

#mdObject

Options for the registration in MD.



1710
1711
1712
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1710

def md
  @md
end

#meObject

Options for the registration in ME.



1712
1713
1714
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1712

def me
  @me
end

#mkObject

Options for the registration in MK.



1714
1715
1716
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1714

def mk
  @mk
end

#mrObject

Options for the registration in MR.



1716
1717
1718
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1716

def mr
  @mr
end

#mtObject

Options for the registration in MT.



1718
1719
1720
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1718

def mt
  @mt
end

#mxObject

Options for the registration in MX.



1720
1721
1722
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1720

def mx
  @mx
end

#myObject

Options for the registration in MY.



1722
1723
1724
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1722

def my
  @my
end

#ngObject

Options for the registration in NG.



1724
1725
1726
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1724

def ng
  @ng
end

#nlObject

Options for the registration in NL.



1726
1727
1728
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1726

def nl
  @nl
end

#noObject

Options for the registration in NO.



1728
1729
1730
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1728

def no
  @no
end

#npObject

Options for the registration in NP.



1730
1731
1732
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1730

def np
  @np
end

#nzObject

Options for the registration in NZ.



1732
1733
1734
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1732

def nz
  @nz
end

#omObject

Options for the registration in OM.



1734
1735
1736
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1734

def om
  @om
end

#peObject

Options for the registration in PE.



1736
1737
1738
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1736

def pe
  @pe
end

#phObject

Options for the registration in PH.



1738
1739
1740
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1738

def ph
  @ph
end

#plObject

Options for the registration in PL.



1740
1741
1742
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1740

def pl
  @pl
end

#ptObject

Options for the registration in PT.



1742
1743
1744
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1742

def pt
  @pt
end

#roObject

Options for the registration in RO.



1744
1745
1746
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1744

def ro
  @ro
end

#rsObject

Options for the registration in RS.



1746
1747
1748
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1746

def rs
  @rs
end

#ruObject

Options for the registration in RU.



1748
1749
1750
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1748

def ru
  @ru
end

#saObject

Options for the registration in SA.



1750
1751
1752
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1750

def sa
  @sa
end

#seObject

Options for the registration in SE.



1752
1753
1754
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1752

def se
  @se
end

#sgObject

Options for the registration in SG.



1754
1755
1756
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1754

def sg
  @sg
end

#siObject

Options for the registration in SI.



1756
1757
1758
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1756

def si
  @si
end

#skObject

Options for the registration in SK.



1758
1759
1760
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1758

def sk
  @sk
end

#snObject

Options for the registration in SN.



1760
1761
1762
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1760

def sn
  @sn
end

#srObject

Options for the registration in SR.



1762
1763
1764
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1762

def sr
  @sr
end

#thObject

Options for the registration in TH.



1764
1765
1766
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1764

def th
  @th
end

#tjObject

Options for the registration in TJ.



1766
1767
1768
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1766

def tj
  @tj
end

#trObject

Options for the registration in TR.



1768
1769
1770
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1768

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



1770
1771
1772
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1770

def tz
  @tz
end

#uaObject

Options for the registration in UA.



1772
1773
1774
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1772

def ua
  @ua
end

#ugObject

Options for the registration in UG.



1774
1775
1776
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1774

def ug
  @ug
end

#usObject

Options for the registration in US.



1776
1777
1778
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1776

def us
  @us
end

#uyObject

Options for the registration in UY.



1778
1779
1780
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1778

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



1780
1781
1782
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1780

def uz
  @uz
end

#vnObject

Options for the registration in VN.



1782
1783
1784
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1782

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



1784
1785
1786
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1784

def za
  @za
end

#zmObject

Options for the registration in ZM.



1786
1787
1788
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1786

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



1788
1789
1790
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1788

def zw
  @zw
end