Class: Stripe::Tax::RegistrationCreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lk, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tw, Tz, Ua, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#al ⇒ Object
Options for the registration in AL.
-
#am ⇒ Object
Options for the registration in AM.
-
#ao ⇒ Object
Options for the registration in AO.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#aw ⇒ Object
Options for the registration in AW.
-
#az ⇒ Object
Options for the registration in AZ.
-
#ba ⇒ Object
Options for the registration in BA.
-
#bb ⇒ Object
Options for the registration in BB.
-
#bd ⇒ Object
Options for the registration in BD.
-
#be ⇒ Object
Options for the registration in BE.
-
#bf ⇒ Object
Options for the registration in BF.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#bj ⇒ Object
Options for the registration in BJ.
-
#bs ⇒ Object
Options for the registration in BS.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#cd ⇒ Object
Options for the registration in CD.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#cm ⇒ Object
Options for the registration in CM.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cv ⇒ Object
Options for the registration in CV.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#et ⇒ Object
Options for the registration in ET.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gn ⇒ Object
Options for the registration in GN.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#in ⇒ Object
Options for the registration in IN.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kg ⇒ Object
Options for the registration in KG.
-
#kh ⇒ Object
Options for the registration in KH.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#la ⇒ Object
Options for the registration in LA.
-
#lk ⇒ Object
Options for the registration in LK.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#me ⇒ Object
Options for the registration in ME.
-
#mk ⇒ Object
Options for the registration in MK.
-
#mr ⇒ Object
Options for the registration in MR.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#np ⇒ Object
Options for the registration in NP.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pe ⇒ Object
Options for the registration in PE.
-
#ph ⇒ Object
Options for the registration in PH.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#sn ⇒ Object
Options for the registration in SN.
-
#sr ⇒ Object
Options for the registration in SR.
-
#th ⇒ Object
Options for the registration in TH.
-
#tj ⇒ Object
Options for the registration in TJ.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tw ⇒ Object
Options for the registration in TW.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#ua ⇒ Object
Options for the registration in UA.
-
#ug ⇒ Object
Options for the registration in UG.
-
#us ⇒ Object
Options for the registration in US.
-
#uy ⇒ Object
Options for the registration in UY.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
-
#zm ⇒ Object
Options for the registration in ZM.
-
#zw ⇒ Object
Options for the registration in ZW.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lk: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tw: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2162 def initialize( ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lk: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tw: nil, tz: nil, ua: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil ) @ae = ae @al = al @am = am @ao = ao @at = at @au = au @aw = aw @az = az @ba = ba @bb = bb @bd = bd @be = be @bf = bf @bg = bg @bh = bh @bj = bj @bs = bs @by = by @ca = ca @cd = cd @ch = ch @cl = cl @cm = cm @co = co @cr = cr @cv = cv @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @et = et @fi = fi @fr = fr @gb = gb @ge = ge @gn = gn @gr = gr @hr = hr @hu = hu @id = id @ie = ie @in = in_ @is = is @it = it @jp = jp @ke = ke @kg = kg @kh = kh @kr = kr @kz = kz @la = la @lk = lk @lt = lt @lu = lu @lv = lv @ma = ma @md = md @me = me @mk = mk @mr = mr @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @np = np @nz = nz @om = om @pe = pe @ph = ph @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @sn = sn @sr = sr @th = th @tj = tj @tr = tr @tw = tw @tz = tz @ua = ua @ug = ug @us = us @uy = uy @uz = uz @vn = vn @za = za @zm = zm @zw = zw end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
1960 1961 1962 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1960 def ae @ae end |
#al ⇒ Object
Options for the registration in AL.
1962 1963 1964 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1962 def al @al end |
#am ⇒ Object
Options for the registration in AM.
1964 1965 1966 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1964 def am @am end |
#ao ⇒ Object
Options for the registration in AO.
1966 1967 1968 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1966 def ao @ao end |
#at ⇒ Object
Options for the registration in AT.
1968 1969 1970 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1968 def at @at end |
#au ⇒ Object
Options for the registration in AU.
1970 1971 1972 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1970 def au @au end |
#aw ⇒ Object
Options for the registration in AW.
1972 1973 1974 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1972 def aw @aw end |
#az ⇒ Object
Options for the registration in AZ.
1974 1975 1976 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1974 def az @az end |
#ba ⇒ Object
Options for the registration in BA.
1976 1977 1978 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1976 def ba @ba end |
#bb ⇒ Object
Options for the registration in BB.
1978 1979 1980 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1978 def bb @bb end |
#bd ⇒ Object
Options for the registration in BD.
1980 1981 1982 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1980 def bd @bd end |
#be ⇒ Object
Options for the registration in BE.
1982 1983 1984 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1982 def be @be end |
#bf ⇒ Object
Options for the registration in BF.
1984 1985 1986 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1984 def bf @bf end |
#bg ⇒ Object
Options for the registration in BG.
1986 1987 1988 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1986 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
1988 1989 1990 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1988 def bh @bh end |
#bj ⇒ Object
Options for the registration in BJ.
1990 1991 1992 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1990 def bj @bj end |
#bs ⇒ Object
Options for the registration in BS.
1992 1993 1994 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1992 def bs @bs end |
#by ⇒ Object
Options for the registration in BY.
1994 1995 1996 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1994 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
1996 1997 1998 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1996 def ca @ca end |
#cd ⇒ Object
Options for the registration in CD.
1998 1999 2000 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1998 def cd @cd end |
#ch ⇒ Object
Options for the registration in CH.
2000 2001 2002 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2000 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
2002 2003 2004 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2002 def cl @cl end |
#cm ⇒ Object
Options for the registration in CM.
2004 2005 2006 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2004 def cm @cm end |
#co ⇒ Object
Options for the registration in CO.
2006 2007 2008 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2006 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
2008 2009 2010 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2008 def cr @cr end |
#cv ⇒ Object
Options for the registration in CV.
2010 2011 2012 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2010 def cv @cv end |
#cy ⇒ Object
Options for the registration in CY.
2012 2013 2014 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2012 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
2014 2015 2016 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2014 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
2016 2017 2018 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2016 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
2018 2019 2020 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2018 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
2020 2021 2022 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2020 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
2022 2023 2024 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2022 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
2024 2025 2026 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2024 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
2026 2027 2028 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2026 def es @es end |
#et ⇒ Object
Options for the registration in ET.
2028 2029 2030 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2028 def et @et end |
#fi ⇒ Object
Options for the registration in FI.
2030 2031 2032 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2030 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
2032 2033 2034 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2032 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
2034 2035 2036 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2034 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
2036 2037 2038 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2036 def ge @ge end |
#gn ⇒ Object
Options for the registration in GN.
2038 2039 2040 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2038 def gn @gn end |
#gr ⇒ Object
Options for the registration in GR.
2040 2041 2042 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2040 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
2042 2043 2044 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2042 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
2044 2045 2046 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2044 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
2046 2047 2048 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2046 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
2048 2049 2050 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2048 def ie @ie end |
#in ⇒ Object
Options for the registration in IN.
2050 2051 2052 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2050 def in @in end |
#is ⇒ Object
Options for the registration in IS.
2052 2053 2054 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2052 def is @is end |
#it ⇒ Object
Options for the registration in IT.
2054 2055 2056 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2054 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
2056 2057 2058 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2056 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
2058 2059 2060 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2058 def ke @ke end |
#kg ⇒ Object
Options for the registration in KG.
2060 2061 2062 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2060 def kg @kg end |
#kh ⇒ Object
Options for the registration in KH.
2062 2063 2064 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2062 def kh @kh end |
#kr ⇒ Object
Options for the registration in KR.
2064 2065 2066 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2064 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
2066 2067 2068 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2066 def kz @kz end |
#la ⇒ Object
Options for the registration in LA.
2068 2069 2070 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2068 def la @la end |
#lk ⇒ Object
Options for the registration in LK.
2070 2071 2072 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2070 def lk @lk end |
#lt ⇒ Object
Options for the registration in LT.
2072 2073 2074 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2072 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
2074 2075 2076 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2074 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
2076 2077 2078 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2076 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
2078 2079 2080 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2078 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
2080 2081 2082 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2080 def md @md end |
#me ⇒ Object
Options for the registration in ME.
2082 2083 2084 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2082 def me @me end |
#mk ⇒ Object
Options for the registration in MK.
2084 2085 2086 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2084 def mk @mk end |
#mr ⇒ Object
Options for the registration in MR.
2086 2087 2088 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2086 def mr @mr end |
#mt ⇒ Object
Options for the registration in MT.
2088 2089 2090 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2088 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
2090 2091 2092 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2090 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
2092 2093 2094 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2092 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
2094 2095 2096 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2094 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
2096 2097 2098 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2096 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
2098 2099 2100 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2098 def no @no end |
#np ⇒ Object
Options for the registration in NP.
2100 2101 2102 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2100 def np @np end |
#nz ⇒ Object
Options for the registration in NZ.
2102 2103 2104 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2102 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
2104 2105 2106 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2104 def om @om end |
#pe ⇒ Object
Options for the registration in PE.
2106 2107 2108 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2106 def pe @pe end |
#ph ⇒ Object
Options for the registration in PH.
2108 2109 2110 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2108 def ph @ph end |
#pl ⇒ Object
Options for the registration in PL.
2110 2111 2112 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2110 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
2112 2113 2114 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2112 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
2114 2115 2116 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2114 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
2116 2117 2118 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2116 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
2118 2119 2120 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2118 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
2120 2121 2122 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2120 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
2122 2123 2124 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2122 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
2124 2125 2126 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2124 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
2126 2127 2128 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2126 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
2128 2129 2130 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2128 def sk @sk end |
#sn ⇒ Object
Options for the registration in SN.
2130 2131 2132 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2130 def sn @sn end |
#sr ⇒ Object
Options for the registration in SR.
2132 2133 2134 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2132 def sr @sr end |
#th ⇒ Object
Options for the registration in TH.
2134 2135 2136 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2134 def th @th end |
#tj ⇒ Object
Options for the registration in TJ.
2136 2137 2138 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2136 def tj @tj end |
#tr ⇒ Object
Options for the registration in TR.
2138 2139 2140 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2138 def tr @tr end |
#tw ⇒ Object
Options for the registration in TW.
2140 2141 2142 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2140 def tw @tw end |
#tz ⇒ Object
Options for the registration in TZ.
2142 2143 2144 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2142 def tz @tz end |
#ua ⇒ Object
Options for the registration in UA.
2144 2145 2146 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2144 def ua @ua end |
#ug ⇒ Object
Options for the registration in UG.
2146 2147 2148 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2146 def ug @ug end |
#us ⇒ Object
Options for the registration in US.
2148 2149 2150 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2148 def us @us end |
#uy ⇒ Object
Options for the registration in UY.
2150 2151 2152 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2150 def uy @uy end |
#uz ⇒ Object
Options for the registration in UZ.
2152 2153 2154 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2152 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
2154 2155 2156 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2154 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
2156 2157 2158 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2156 def za @za end |
#zm ⇒ Object
Options for the registration in ZM.
2158 2159 2160 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2158 def zm @zm end |
#zw ⇒ Object
Options for the registration in ZW.
2160 2161 2162 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 2160 def zw @zw end |