Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Lt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Lt
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Lt
constructor
A new instance of Lt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Lt
Returns a new instance of Lt.
911 912 913 914 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 911 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
907 908 909 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 907 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
909 910 911 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 909 def type @type end |