Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Nl
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Nl
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Nl
constructor
A new instance of Nl.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Nl
Returns a new instance of Nl.
1096 1097 1098 1099 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1096 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1092 1093 1094 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1092 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1094 1095 1096 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1094 def type @type end |