Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Si
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Si
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Si
constructor
A new instance of Si.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Si
Returns a new instance of Si.
1341 1342 1343 1344 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1341 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1337 1338 1339 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1337 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1339 1340 1341 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1339 def type @type end |