Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: AdmissionsTax, AttendanceTax, EntertainmentTax, GrossReceiptsTax, HospitalityTax, LocalAmusementTax, LocalLeaseTax, LuxuryTax, MassTransitParkingTax, ParkingTax, ResortTax, StateSalesTax, TourismTax
Instance Attribute Summary collapse
-
#admissions_tax ⇒ Object
Options for the admission tax registration.
-
#attendance_tax ⇒ Object
Options for the attendance tax registration.
-
#entertainment_tax ⇒ Object
Options for the entertainment tax registration.
-
#gross_receipts_tax ⇒ Object
Options for the gross receipts tax registration.
-
#hospitality_tax ⇒ Object
Options for the hospitality tax registration.
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#luxury_tax ⇒ Object
Options for the luxury tax registration.
-
#mass_transit_parking_tax ⇒ Object
Options for the mass transit parking tax registration.
-
#parking_tax ⇒ Object
Options for the parking tax registration.
-
#resort_tax ⇒ Object
Options for the resort tax registration.
-
#state ⇒ Object
Two-letter US state code (ISO 3166-2).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#tourism_tax ⇒ Object
Options for the tourism tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(admissions_tax: nil, attendance_tax: nil, entertainment_tax: nil, gross_receipts_tax: nil, hospitality_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, luxury_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, resort_tax: nil, state: nil, state_sales_tax: nil, tourism_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1942 def initialize( admissions_tax: nil, attendance_tax: nil, entertainment_tax: nil, gross_receipts_tax: nil, hospitality_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, luxury_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, resort_tax: nil, state: nil, state_sales_tax: nil, tourism_tax: nil, type: nil ) @admissions_tax = admissions_tax @attendance_tax = attendance_tax @entertainment_tax = entertainment_tax @gross_receipts_tax = gross_receipts_tax @hospitality_tax = hospitality_tax @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @luxury_tax = luxury_tax @mass_transit_parking_tax = mass_transit_parking_tax @parking_tax = parking_tax @resort_tax = resort_tax @state = state @state_sales_tax = state_sales_tax @tourism_tax = tourism_tax @type = type end |
Instance Attribute Details
#admissions_tax ⇒ Object
Options for the admission tax registration.
1912 1913 1914 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1912 def admissions_tax @admissions_tax end |
#attendance_tax ⇒ Object
Options for the attendance tax registration.
1914 1915 1916 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1914 def attendance_tax @attendance_tax end |
#entertainment_tax ⇒ Object
Options for the entertainment tax registration.
1916 1917 1918 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1916 def entertainment_tax @entertainment_tax end |
#gross_receipts_tax ⇒ Object
Options for the gross receipts tax registration.
1918 1919 1920 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1918 def gross_receipts_tax @gross_receipts_tax end |
#hospitality_tax ⇒ Object
Options for the hospitality tax registration.
1920 1921 1922 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1920 def hospitality_tax @hospitality_tax end |
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1922 1923 1924 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1922 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1924 1925 1926 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1924 def local_lease_tax @local_lease_tax end |
#luxury_tax ⇒ Object
Options for the luxury tax registration.
1926 1927 1928 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1926 def luxury_tax @luxury_tax end |
#mass_transit_parking_tax ⇒ Object
Options for the mass transit parking tax registration.
1928 1929 1930 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1928 def mass_transit_parking_tax @mass_transit_parking_tax end |
#parking_tax ⇒ Object
Options for the parking tax registration.
1930 1931 1932 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1930 def parking_tax @parking_tax end |
#resort_tax ⇒ Object
Options for the resort tax registration.
1932 1933 1934 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1932 def resort_tax @resort_tax end |
#state ⇒ Object
Two-letter US state code (ISO 3166-2).
1934 1935 1936 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1934 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1936 1937 1938 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1936 def state_sales_tax @state_sales_tax end |
#tourism_tax ⇒ Object
Options for the tourism tax registration.
1938 1939 1940 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1938 def tourism_tax @tourism_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1940 1941 1942 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1940 def type @type end |