Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: LocalAmusementTax, LocalLeaseTax, MassTransitParkingTax, ParkingTax, StateSalesTax
Instance Attribute Summary collapse
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#mass_transit_parking_tax ⇒ Object
Options for the mass transit parking tax registration.
-
#parking_tax ⇒ Object
Options for the parking tax registration.
-
#state ⇒ Object
Two-letter US state code (ISO 3166-2).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(local_amusement_tax: nil, local_lease_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(local_amusement_tax: nil, local_lease_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1530 def initialize( local_amusement_tax: nil, local_lease_tax: nil, mass_transit_parking_tax: nil, parking_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @mass_transit_parking_tax = mass_transit_parking_tax @parking_tax = parking_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1516 1517 1518 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1516 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1518 1519 1520 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1518 def local_lease_tax @local_lease_tax end |
#mass_transit_parking_tax ⇒ Object
Options for the mass transit parking tax registration.
1520 1521 1522 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1520 def mass_transit_parking_tax @mass_transit_parking_tax end |
#parking_tax ⇒ Object
Options for the parking tax registration.
1522 1523 1524 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1522 def parking_tax @parking_tax end |
#state ⇒ Object
Two-letter US state code (ISO 3166-2).
1524 1525 1526 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1524 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1526 1527 1528 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1526 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1528 1529 1530 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1528 def type @type end |