Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: AdmissionsTax, AttendanceTax, EntertainmentTax, GrossReceiptsTax, HospitalityTax, LocalAmusementTax, LocalLeaseTax, LuxuryTax, ResortTax, StateSalesTax, TourismTax
Instance Attribute Summary collapse
-
#admissions_tax ⇒ Object
Options for the admission tax registration.
-
#attendance_tax ⇒ Object
Options for the attendance tax registration.
-
#entertainment_tax ⇒ Object
Options for the entertainment tax registration.
-
#gross_receipts_tax ⇒ Object
Options for the gross receipts tax registration.
-
#hospitality_tax ⇒ Object
Options for the hospitality tax registration.
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#luxury_tax ⇒ Object
Options for the luxury tax registration.
-
#resort_tax ⇒ Object
Options for the resort tax registration.
-
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#tourism_tax ⇒ Object
Options for the tourism tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(admissions_tax: nil, attendance_tax: nil, entertainment_tax: nil, gross_receipts_tax: nil, hospitality_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, luxury_tax: nil, resort_tax: nil, state: nil, state_sales_tax: nil, tourism_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(admissions_tax: nil, attendance_tax: nil, entertainment_tax: nil, gross_receipts_tax: nil, hospitality_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, luxury_tax: nil, resort_tax: nil, state: nil, state_sales_tax: nil, tourism_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1596 def initialize( admissions_tax: nil, attendance_tax: nil, entertainment_tax: nil, gross_receipts_tax: nil, hospitality_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, luxury_tax: nil, resort_tax: nil, state: nil, state_sales_tax: nil, tourism_tax: nil, type: nil ) @admissions_tax = admissions_tax @attendance_tax = attendance_tax @entertainment_tax = entertainment_tax @gross_receipts_tax = gross_receipts_tax @hospitality_tax = hospitality_tax @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @luxury_tax = luxury_tax @resort_tax = resort_tax @state = state @state_sales_tax = state_sales_tax @tourism_tax = tourism_tax @type = type end |
Instance Attribute Details
#admissions_tax ⇒ Object
Options for the admission tax registration.
1570 1571 1572 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1570 def admissions_tax @admissions_tax end |
#attendance_tax ⇒ Object
Options for the attendance tax registration.
1572 1573 1574 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1572 def attendance_tax @attendance_tax end |
#entertainment_tax ⇒ Object
Options for the entertainment tax registration.
1574 1575 1576 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1574 def entertainment_tax @entertainment_tax end |
#gross_receipts_tax ⇒ Object
Options for the gross receipts tax registration.
1576 1577 1578 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1576 def gross_receipts_tax @gross_receipts_tax end |
#hospitality_tax ⇒ Object
Options for the hospitality tax registration.
1578 1579 1580 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1578 def hospitality_tax @hospitality_tax end |
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1580 1581 1582 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1580 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1582 1583 1584 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1582 def local_lease_tax @local_lease_tax end |
#luxury_tax ⇒ Object
Options for the luxury tax registration.
1584 1585 1586 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1584 def luxury_tax @luxury_tax end |
#resort_tax ⇒ Object
Options for the resort tax registration.
1586 1587 1588 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1586 def resort_tax @resort_tax end |
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
1588 1589 1590 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1588 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1590 1591 1592 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1590 def state_sales_tax @state_sales_tax end |
#tourism_tax ⇒ Object
Options for the tourism tax registration.
1592 1593 1594 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1592 def tourism_tax @tourism_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1594 1595 1596 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1594 def type @type end |