Class: Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationCreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/params/tax/registration_create_params.rb
Defined Under Namespace
Classes: HomeRuleTax, LocalAmusementTax, LocalLeaseTax, StateSalesTax
Instance Attribute Summary collapse
-
#home_rule_tax ⇒ Object
Options for the home rule tax registration.
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(home_rule_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(home_rule_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1519 def initialize( home_rule_tax: nil, local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @home_rule_tax = home_rule_tax @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#home_rule_tax ⇒ Object
Options for the home rule tax registration.
1507 1508 1509 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1507 def home_rule_tax @home_rule_tax end |
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1509 1510 1511 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1509 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1511 1512 1513 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1511 def local_lease_tax @local_lease_tax end |
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
1513 1514 1515 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1513 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1515 1516 1517 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1515 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1517 1518 1519 |
# File 'lib/stripe/params/tax/registration_create_params.rb', line 1517 def type @type end |