Class: Stripe::Tax::RegistrationService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Tax::RegistrationService
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Returns a Tax Registration object.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
1741 1742 1743 1744 1745 1746 1747 1748 1749 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1741 def create(params = {}, opts = {}) request( method: :post, path: "/v1/tax/registrations", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1752 def list(params = {}, opts = {}) request( method: :get, path: "/v1/tax/registrations", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Returns a Tax Registration object.
1763 1764 1765 1766 1767 1768 1769 1770 1771 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1763 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.
1776 1777 1778 1779 1780 1781 1782 1783 1784 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1776 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |