Class: Stripe::Tax::RegistrationService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: CreateParams, ListParams, RetrieveParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Creates a new Tax Registration object.



1689
1690
1691
1692
1693
1694
1695
1696
1697
# File 'lib/stripe/services/tax/registration_service.rb', line 1689

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of Tax Registration objects.



1700
1701
1702
1703
1704
1705
1706
1707
1708
# File 'lib/stripe/services/tax/registration_service.rb', line 1700

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/tax/registrations",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Returns a Tax Registration object.



1711
1712
1713
1714
1715
1716
1717
1718
1719
# File 'lib/stripe/services/tax/registration_service.rb', line 1711

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(id, params = {}, opts = {}) ⇒ Object

Updates an existing Tax Registration object.

A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.



1724
1725
1726
1727
1728
1729
1730
1731
1732
# File 'lib/stripe/services/tax/registration_service.rb', line 1724

def update(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end