Class: Stripe::Tax::RegistrationService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Tax::RegistrationService
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Returns a Tax Registration object.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a new Tax Registration object.
1406 1407 1408 1409 1410 1411 1412 1413 1414 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1406 def create(params = {}, opts = {}) request( method: :post, path: "/v1/tax/registrations", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Tax Registration objects.
1417 1418 1419 1420 1421 1422 1423 1424 1425 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1417 def list(params = {}, opts = {}) request( method: :get, path: "/v1/tax/registrations", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Returns a Tax Registration object.
1428 1429 1430 1431 1432 1433 1434 1435 1436 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1428 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates an existing Tax Registration object.
A registration cannot be deleted after it has been created. If you wish to end a registration you may do so by setting expires_at.
1441 1442 1443 1444 1445 1446 1447 1448 1449 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1441 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/tax/registrations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |