Class: Stripe::Tax::RegistrationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
# File 'lib/stripe/services/tax/registration_service.rb', line 1701

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



1691
1692
1693
# File 'lib/stripe/services/tax/registration_service.rb', line 1691

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1693
1694
1695
# File 'lib/stripe/services/tax/registration_service.rb', line 1693

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



1695
1696
1697
# File 'lib/stripe/services/tax/registration_service.rb', line 1695

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



1697
1698
1699
# File 'lib/stripe/services/tax/registration_service.rb', line 1697

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



1699
1700
1701
# File 'lib/stripe/services/tax/registration_service.rb', line 1699

def expires_at
  @expires_at
end