Class: Stripe::Tax::RegistrationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
# File 'lib/stripe/services/tax/registration_service.rb', line 1649

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



1639
1640
1641
# File 'lib/stripe/services/tax/registration_service.rb', line 1639

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1641
1642
1643
# File 'lib/stripe/services/tax/registration_service.rb', line 1641

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



1643
1644
1645
# File 'lib/stripe/services/tax/registration_service.rb', line 1643

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



1645
1646
1647
# File 'lib/stripe/services/tax/registration_service.rb', line 1645

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



1647
1648
1649
# File 'lib/stripe/services/tax/registration_service.rb', line 1647

def expires_at
  @expires_at
end