Class: Stripe::Tax::RegistrationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
# File 'lib/stripe/services/tax/registration_service.rb', line 1545

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



1535
1536
1537
# File 'lib/stripe/services/tax/registration_service.rb', line 1535

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1537
1538
1539
# File 'lib/stripe/services/tax/registration_service.rb', line 1537

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



1539
1540
1541
# File 'lib/stripe/services/tax/registration_service.rb', line 1539

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



1541
1542
1543
# File 'lib/stripe/services/tax/registration_service.rb', line 1541

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



1543
1544
1545
# File 'lib/stripe/services/tax/registration_service.rb', line 1543

def expires_at
  @expires_at
end