Class: Stripe::Tax::RegistrationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: CountryOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active_from: nil, country: nil, country_options: nil, expand: nil, expires_at: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
# File 'lib/stripe/services/tax/registration_service.rb', line 1364

def initialize(
  active_from: nil,
  country: nil,
  country_options: nil,
  expand: nil,
  expires_at: nil
)
  @active_from = active_from
  @country = country
  @country_options = country_options
  @expand = expand
  @expires_at = expires_at
end

Instance Attribute Details

#active_fromObject

Time at which the Tax Registration becomes active. It can be either ‘now` to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.



1350
1351
1352
# File 'lib/stripe/services/tax/registration_service.rb', line 1350

def active_from
  @active_from
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1353
1354
1355
# File 'lib/stripe/services/tax/registration_service.rb', line 1353

def country
  @country
end

#country_optionsObject

Specific options for a registration in the specified ‘country`.



1356
1357
1358
# File 'lib/stripe/services/tax/registration_service.rb', line 1356

def country_options
  @country_options
end

#expandObject

Specifies which fields in the response should be expanded.



1359
1360
1361
# File 'lib/stripe/services/tax/registration_service.rb', line 1359

def expand
  @expand
end

#expires_atObject

If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch.



1362
1363
1364
# File 'lib/stripe/services/tax/registration_service.rb', line 1362

def expires_at
  @expires_at
end