Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Ae, Al, Am, Ao, At, Au, Aw, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bj, Bs, By, Ca, Cd, Ch, Cl, Cm, Co, Cr, Cv, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Et, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kg, Kh, Kr, Kz, La, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Ph, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw
Instance Attribute Summary collapse
-
#ae ⇒ Object
Options for the registration in AE.
-
#al ⇒ Object
Options for the registration in AL.
-
#am ⇒ Object
Options for the registration in AM.
-
#ao ⇒ Object
Options for the registration in AO.
-
#at ⇒ Object
Options for the registration in AT.
-
#au ⇒ Object
Options for the registration in AU.
-
#aw ⇒ Object
Options for the registration in AW.
-
#az ⇒ Object
Options for the registration in AZ.
-
#ba ⇒ Object
Options for the registration in BA.
-
#bb ⇒ Object
Options for the registration in BB.
-
#bd ⇒ Object
Options for the registration in BD.
-
#be ⇒ Object
Options for the registration in BE.
-
#bf ⇒ Object
Options for the registration in BF.
-
#bg ⇒ Object
Options for the registration in BG.
-
#bh ⇒ Object
Options for the registration in BH.
-
#bj ⇒ Object
Options for the registration in BJ.
-
#bs ⇒ Object
Options for the registration in BS.
-
#by ⇒ Object
Options for the registration in BY.
-
#ca ⇒ Object
Options for the registration in CA.
-
#cd ⇒ Object
Options for the registration in CD.
-
#ch ⇒ Object
Options for the registration in CH.
-
#cl ⇒ Object
Options for the registration in CL.
-
#cm ⇒ Object
Options for the registration in CM.
-
#co ⇒ Object
Options for the registration in CO.
-
#cr ⇒ Object
Options for the registration in CR.
-
#cv ⇒ Object
Options for the registration in CV.
-
#cy ⇒ Object
Options for the registration in CY.
-
#cz ⇒ Object
Options for the registration in CZ.
-
#de ⇒ Object
Options for the registration in DE.
-
#dk ⇒ Object
Options for the registration in DK.
-
#ec ⇒ Object
Options for the registration in EC.
-
#ee ⇒ Object
Options for the registration in EE.
-
#eg ⇒ Object
Options for the registration in EG.
-
#es ⇒ Object
Options for the registration in ES.
-
#et ⇒ Object
Options for the registration in ET.
-
#fi ⇒ Object
Options for the registration in FI.
-
#fr ⇒ Object
Options for the registration in FR.
-
#gb ⇒ Object
Options for the registration in GB.
-
#ge ⇒ Object
Options for the registration in GE.
-
#gn ⇒ Object
Options for the registration in GN.
-
#gr ⇒ Object
Options for the registration in GR.
-
#hr ⇒ Object
Options for the registration in HR.
-
#hu ⇒ Object
Options for the registration in HU.
-
#id ⇒ Object
Options for the registration in ID.
-
#ie ⇒ Object
Options for the registration in IE.
-
#in ⇒ Object
Options for the registration in IN.
-
#is ⇒ Object
Options for the registration in IS.
-
#it ⇒ Object
Options for the registration in IT.
-
#jp ⇒ Object
Options for the registration in JP.
-
#ke ⇒ Object
Options for the registration in KE.
-
#kg ⇒ Object
Options for the registration in KG.
-
#kh ⇒ Object
Options for the registration in KH.
-
#kr ⇒ Object
Options for the registration in KR.
-
#kz ⇒ Object
Options for the registration in KZ.
-
#la ⇒ Object
Options for the registration in LA.
-
#lt ⇒ Object
Options for the registration in LT.
-
#lu ⇒ Object
Options for the registration in LU.
-
#lv ⇒ Object
Options for the registration in LV.
-
#ma ⇒ Object
Options for the registration in MA.
-
#md ⇒ Object
Options for the registration in MD.
-
#me ⇒ Object
Options for the registration in ME.
-
#mk ⇒ Object
Options for the registration in MK.
-
#mr ⇒ Object
Options for the registration in MR.
-
#mt ⇒ Object
Options for the registration in MT.
-
#mx ⇒ Object
Options for the registration in MX.
-
#my ⇒ Object
Options for the registration in MY.
-
#ng ⇒ Object
Options for the registration in NG.
-
#nl ⇒ Object
Options for the registration in NL.
-
#no ⇒ Object
Options for the registration in NO.
-
#np ⇒ Object
Options for the registration in NP.
-
#nz ⇒ Object
Options for the registration in NZ.
-
#om ⇒ Object
Options for the registration in OM.
-
#pe ⇒ Object
Options for the registration in PE.
-
#ph ⇒ Object
Options for the registration in PH.
-
#pl ⇒ Object
Options for the registration in PL.
-
#pt ⇒ Object
Options for the registration in PT.
-
#ro ⇒ Object
Options for the registration in RO.
-
#rs ⇒ Object
Options for the registration in RS.
-
#ru ⇒ Object
Options for the registration in RU.
-
#sa ⇒ Object
Options for the registration in SA.
-
#se ⇒ Object
Options for the registration in SE.
-
#sg ⇒ Object
Options for the registration in SG.
-
#si ⇒ Object
Options for the registration in SI.
-
#sk ⇒ Object
Options for the registration in SK.
-
#sn ⇒ Object
Options for the registration in SN.
-
#sr ⇒ Object
Options for the registration in SR.
-
#th ⇒ Object
Options for the registration in TH.
-
#tj ⇒ Object
Options for the registration in TJ.
-
#tr ⇒ Object
Options for the registration in TR.
-
#tz ⇒ Object
Options for the registration in TZ.
-
#ug ⇒ Object
Options for the registration in UG.
-
#us ⇒ Object
Options for the registration in US.
-
#uy ⇒ Object
Options for the registration in UY.
-
#uz ⇒ Object
Options for the registration in UZ.
-
#vn ⇒ Object
Options for the registration in VN.
-
#za ⇒ Object
Options for the registration in ZA.
-
#zm ⇒ Object
Options for the registration in ZM.
-
#zw ⇒ Object
Options for the registration in ZW.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions
Returns a new instance of CountryOptions.
1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1477 def initialize( ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, aw: nil, az: nil, ba: nil, bb: nil, bd: nil, be: nil, bf: nil, bg: nil, bh: nil, bj: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, cm: nil, co: nil, cr: nil, cv: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, et: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kg: nil, kh: nil, kr: nil, kz: nil, la: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, ph: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil ) @ae = ae @al = al @am = am @ao = ao @at = at @au = au @aw = aw @az = az @ba = ba @bb = bb @bd = bd @be = be @bf = bf @bg = bg @bh = bh @bj = bj @bs = bs @by = by @ca = ca @cd = cd @ch = ch @cl = cl @cm = cm @co = co @cr = cr @cv = cv @cy = cy @cz = cz @de = de @dk = dk @ec = ec @ee = ee @eg = eg @es = es @et = et @fi = fi @fr = fr @gb = gb @ge = ge @gn = gn @gr = gr @hr = hr @hu = hu @id = id @ie = ie @in = in_ @is = is @it = it @jp = jp @ke = ke @kg = kg @kh = kh @kr = kr @kz = kz @la = la @lt = lt @lu = lu @lv = lv @ma = ma @md = md @me = me @mk = mk @mr = mr @mt = mt @mx = mx @my = my @ng = ng @nl = nl @no = no @np = np @nz = nz @om = om @pe = pe @ph = ph @pl = pl @pt = pt @ro = ro @rs = rs @ru = ru @sa = sa @se = se @sg = sg @si = si @sk = sk @sn = sn @sr = sr @th = th @tj = tj @tr = tr @tz = tz @ug = ug @us = us @uy = uy @uz = uz @vn = vn @za = za @zm = zm @zw = zw end |
Instance Attribute Details
#ae ⇒ Object
Options for the registration in AE.
1281 1282 1283 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1281 def ae @ae end |
#al ⇒ Object
Options for the registration in AL.
1283 1284 1285 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1283 def al @al end |
#am ⇒ Object
Options for the registration in AM.
1285 1286 1287 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1285 def am @am end |
#ao ⇒ Object
Options for the registration in AO.
1287 1288 1289 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1287 def ao @ao end |
#at ⇒ Object
Options for the registration in AT.
1289 1290 1291 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1289 def at @at end |
#au ⇒ Object
Options for the registration in AU.
1291 1292 1293 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1291 def au @au end |
#aw ⇒ Object
Options for the registration in AW.
1293 1294 1295 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1293 def aw @aw end |
#az ⇒ Object
Options for the registration in AZ.
1295 1296 1297 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1295 def az @az end |
#ba ⇒ Object
Options for the registration in BA.
1297 1298 1299 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1297 def ba @ba end |
#bb ⇒ Object
Options for the registration in BB.
1299 1300 1301 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1299 def bb @bb end |
#bd ⇒ Object
Options for the registration in BD.
1301 1302 1303 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1301 def bd @bd end |
#be ⇒ Object
Options for the registration in BE.
1303 1304 1305 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1303 def be @be end |
#bf ⇒ Object
Options for the registration in BF.
1305 1306 1307 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1305 def bf @bf end |
#bg ⇒ Object
Options for the registration in BG.
1307 1308 1309 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1307 def bg @bg end |
#bh ⇒ Object
Options for the registration in BH.
1309 1310 1311 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1309 def bh @bh end |
#bj ⇒ Object
Options for the registration in BJ.
1311 1312 1313 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1311 def bj @bj end |
#bs ⇒ Object
Options for the registration in BS.
1313 1314 1315 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1313 def bs @bs end |
#by ⇒ Object
Options for the registration in BY.
1315 1316 1317 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1315 def by @by end |
#ca ⇒ Object
Options for the registration in CA.
1317 1318 1319 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1317 def ca @ca end |
#cd ⇒ Object
Options for the registration in CD.
1319 1320 1321 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1319 def cd @cd end |
#ch ⇒ Object
Options for the registration in CH.
1321 1322 1323 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1321 def ch @ch end |
#cl ⇒ Object
Options for the registration in CL.
1323 1324 1325 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1323 def cl @cl end |
#cm ⇒ Object
Options for the registration in CM.
1325 1326 1327 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1325 def cm @cm end |
#co ⇒ Object
Options for the registration in CO.
1327 1328 1329 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1327 def co @co end |
#cr ⇒ Object
Options for the registration in CR.
1329 1330 1331 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1329 def cr @cr end |
#cv ⇒ Object
Options for the registration in CV.
1331 1332 1333 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1331 def cv @cv end |
#cy ⇒ Object
Options for the registration in CY.
1333 1334 1335 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1333 def cy @cy end |
#cz ⇒ Object
Options for the registration in CZ.
1335 1336 1337 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1335 def cz @cz end |
#de ⇒ Object
Options for the registration in DE.
1337 1338 1339 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1337 def de @de end |
#dk ⇒ Object
Options for the registration in DK.
1339 1340 1341 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1339 def dk @dk end |
#ec ⇒ Object
Options for the registration in EC.
1341 1342 1343 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1341 def ec @ec end |
#ee ⇒ Object
Options for the registration in EE.
1343 1344 1345 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1343 def ee @ee end |
#eg ⇒ Object
Options for the registration in EG.
1345 1346 1347 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1345 def eg @eg end |
#es ⇒ Object
Options for the registration in ES.
1347 1348 1349 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1347 def es @es end |
#et ⇒ Object
Options for the registration in ET.
1349 1350 1351 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1349 def et @et end |
#fi ⇒ Object
Options for the registration in FI.
1351 1352 1353 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1351 def fi @fi end |
#fr ⇒ Object
Options for the registration in FR.
1353 1354 1355 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1353 def fr @fr end |
#gb ⇒ Object
Options for the registration in GB.
1355 1356 1357 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1355 def gb @gb end |
#ge ⇒ Object
Options for the registration in GE.
1357 1358 1359 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1357 def ge @ge end |
#gn ⇒ Object
Options for the registration in GN.
1359 1360 1361 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1359 def gn @gn end |
#gr ⇒ Object
Options for the registration in GR.
1361 1362 1363 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1361 def gr @gr end |
#hr ⇒ Object
Options for the registration in HR.
1363 1364 1365 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1363 def hr @hr end |
#hu ⇒ Object
Options for the registration in HU.
1365 1366 1367 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1365 def hu @hu end |
#id ⇒ Object
Options for the registration in ID.
1367 1368 1369 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1367 def id @id end |
#ie ⇒ Object
Options for the registration in IE.
1369 1370 1371 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1369 def ie @ie end |
#in ⇒ Object
Options for the registration in IN.
1371 1372 1373 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1371 def in @in end |
#is ⇒ Object
Options for the registration in IS.
1373 1374 1375 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1373 def is @is end |
#it ⇒ Object
Options for the registration in IT.
1375 1376 1377 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1375 def it @it end |
#jp ⇒ Object
Options for the registration in JP.
1377 1378 1379 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1377 def jp @jp end |
#ke ⇒ Object
Options for the registration in KE.
1379 1380 1381 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1379 def ke @ke end |
#kg ⇒ Object
Options for the registration in KG.
1381 1382 1383 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1381 def kg @kg end |
#kh ⇒ Object
Options for the registration in KH.
1383 1384 1385 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1383 def kh @kh end |
#kr ⇒ Object
Options for the registration in KR.
1385 1386 1387 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1385 def kr @kr end |
#kz ⇒ Object
Options for the registration in KZ.
1387 1388 1389 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1387 def kz @kz end |
#la ⇒ Object
Options for the registration in LA.
1389 1390 1391 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1389 def la @la end |
#lt ⇒ Object
Options for the registration in LT.
1391 1392 1393 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1391 def lt @lt end |
#lu ⇒ Object
Options for the registration in LU.
1393 1394 1395 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1393 def lu @lu end |
#lv ⇒ Object
Options for the registration in LV.
1395 1396 1397 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1395 def lv @lv end |
#ma ⇒ Object
Options for the registration in MA.
1397 1398 1399 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1397 def ma @ma end |
#md ⇒ Object
Options for the registration in MD.
1399 1400 1401 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1399 def md @md end |
#me ⇒ Object
Options for the registration in ME.
1401 1402 1403 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1401 def me @me end |
#mk ⇒ Object
Options for the registration in MK.
1403 1404 1405 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1403 def mk @mk end |
#mr ⇒ Object
Options for the registration in MR.
1405 1406 1407 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1405 def mr @mr end |
#mt ⇒ Object
Options for the registration in MT.
1407 1408 1409 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1407 def mt @mt end |
#mx ⇒ Object
Options for the registration in MX.
1409 1410 1411 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1409 def mx @mx end |
#my ⇒ Object
Options for the registration in MY.
1411 1412 1413 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1411 def my @my end |
#ng ⇒ Object
Options for the registration in NG.
1413 1414 1415 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1413 def ng @ng end |
#nl ⇒ Object
Options for the registration in NL.
1415 1416 1417 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1415 def nl @nl end |
#no ⇒ Object
Options for the registration in NO.
1417 1418 1419 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1417 def no @no end |
#np ⇒ Object
Options for the registration in NP.
1419 1420 1421 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1419 def np @np end |
#nz ⇒ Object
Options for the registration in NZ.
1421 1422 1423 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1421 def nz @nz end |
#om ⇒ Object
Options for the registration in OM.
1423 1424 1425 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1423 def om @om end |
#pe ⇒ Object
Options for the registration in PE.
1425 1426 1427 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1425 def pe @pe end |
#ph ⇒ Object
Options for the registration in PH.
1427 1428 1429 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1427 def ph @ph end |
#pl ⇒ Object
Options for the registration in PL.
1429 1430 1431 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1429 def pl @pl end |
#pt ⇒ Object
Options for the registration in PT.
1431 1432 1433 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1431 def pt @pt end |
#ro ⇒ Object
Options for the registration in RO.
1433 1434 1435 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1433 def ro @ro end |
#rs ⇒ Object
Options for the registration in RS.
1435 1436 1437 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1435 def rs @rs end |
#ru ⇒ Object
Options for the registration in RU.
1437 1438 1439 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1437 def ru @ru end |
#sa ⇒ Object
Options for the registration in SA.
1439 1440 1441 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1439 def sa @sa end |
#se ⇒ Object
Options for the registration in SE.
1441 1442 1443 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1441 def se @se end |
#sg ⇒ Object
Options for the registration in SG.
1443 1444 1445 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1443 def sg @sg end |
#si ⇒ Object
Options for the registration in SI.
1445 1446 1447 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1445 def si @si end |
#sk ⇒ Object
Options for the registration in SK.
1447 1448 1449 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1447 def sk @sk end |
#sn ⇒ Object
Options for the registration in SN.
1449 1450 1451 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1449 def sn @sn end |
#sr ⇒ Object
Options for the registration in SR.
1451 1452 1453 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1451 def sr @sr end |
#th ⇒ Object
Options for the registration in TH.
1453 1454 1455 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1453 def th @th end |
#tj ⇒ Object
Options for the registration in TJ.
1455 1456 1457 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1455 def tj @tj end |
#tr ⇒ Object
Options for the registration in TR.
1457 1458 1459 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1457 def tr @tr end |
#tz ⇒ Object
Options for the registration in TZ.
1459 1460 1461 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1459 def tz @tz end |
#ug ⇒ Object
Options for the registration in UG.
1461 1462 1463 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1461 def ug @ug end |
#us ⇒ Object
Options for the registration in US.
1463 1464 1465 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1463 def us @us end |
#uy ⇒ Object
Options for the registration in UY.
1465 1466 1467 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1465 def uy @uy end |
#uz ⇒ Object
Options for the registration in UZ.
1467 1468 1469 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1467 def uz @uz end |
#vn ⇒ Object
Options for the registration in VN.
1469 1470 1471 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1469 def vn @vn end |
#za ⇒ Object
Options for the registration in ZA.
1471 1472 1473 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1471 def za @za end |
#zm ⇒ Object
Options for the registration in ZM.
1473 1474 1475 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1473 def zm @zm end |
#zw ⇒ Object
Options for the registration in ZW.
1475 1476 1477 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1475 def zw @zw end |