Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Ba, Bb, Be, Bg, Bh, Bs, By, Ca, Cd, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, In, Is, It, Jp, Ke, Kh, Kr, Kz, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, ba: nil, bb: nil, be: nil, bg: nil, bh: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, in_: nil, is: nil, it: nil, jp: nil, ke: nil, kh: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
# File 'lib/stripe/services/tax/registration_service.rb', line 1356

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  ba: nil,
  bb: nil,
  be: nil,
  bg: nil,
  bh: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  co: nil,
  cr: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  in_: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tz: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @ba = ba
  @bb = bb
  @be = be
  @bg = bg
  @bh = bh
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @co = co
  @cr = cr
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @in = in_
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kh = kh
  @kr = kr
  @kz = kz
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tz = tz
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



1182
1183
1184
# File 'lib/stripe/services/tax/registration_service.rb', line 1182

def ae
  @ae
end

#alObject

Options for the registration in AL.



1184
1185
1186
# File 'lib/stripe/services/tax/registration_service.rb', line 1184

def al
  @al
end

#amObject

Options for the registration in AM.



1186
1187
1188
# File 'lib/stripe/services/tax/registration_service.rb', line 1186

def am
  @am
end

#aoObject

Options for the registration in AO.



1188
1189
1190
# File 'lib/stripe/services/tax/registration_service.rb', line 1188

def ao
  @ao
end

#atObject

Options for the registration in AT.



1190
1191
1192
# File 'lib/stripe/services/tax/registration_service.rb', line 1190

def at
  @at
end

#auObject

Options for the registration in AU.



1192
1193
1194
# File 'lib/stripe/services/tax/registration_service.rb', line 1192

def au
  @au
end

#baObject

Options for the registration in BA.



1194
1195
1196
# File 'lib/stripe/services/tax/registration_service.rb', line 1194

def ba
  @ba
end

#bbObject

Options for the registration in BB.



1196
1197
1198
# File 'lib/stripe/services/tax/registration_service.rb', line 1196

def bb
  @bb
end

#beObject

Options for the registration in BE.



1198
1199
1200
# File 'lib/stripe/services/tax/registration_service.rb', line 1198

def be
  @be
end

#bgObject

Options for the registration in BG.



1200
1201
1202
# File 'lib/stripe/services/tax/registration_service.rb', line 1200

def bg
  @bg
end

#bhObject

Options for the registration in BH.



1202
1203
1204
# File 'lib/stripe/services/tax/registration_service.rb', line 1202

def bh
  @bh
end

#bsObject

Options for the registration in BS.



1204
1205
1206
# File 'lib/stripe/services/tax/registration_service.rb', line 1204

def bs
  @bs
end

#byObject

Options for the registration in BY.



1206
1207
1208
# File 'lib/stripe/services/tax/registration_service.rb', line 1206

def by
  @by
end

#caObject

Options for the registration in CA.



1208
1209
1210
# File 'lib/stripe/services/tax/registration_service.rb', line 1208

def ca
  @ca
end

#cdObject

Options for the registration in CD.



1210
1211
1212
# File 'lib/stripe/services/tax/registration_service.rb', line 1210

def cd
  @cd
end

#chObject

Options for the registration in CH.



1212
1213
1214
# File 'lib/stripe/services/tax/registration_service.rb', line 1212

def ch
  @ch
end

#clObject

Options for the registration in CL.



1214
1215
1216
# File 'lib/stripe/services/tax/registration_service.rb', line 1214

def cl
  @cl
end

#coObject

Options for the registration in CO.



1216
1217
1218
# File 'lib/stripe/services/tax/registration_service.rb', line 1216

def co
  @co
end

#crObject

Options for the registration in CR.



1218
1219
1220
# File 'lib/stripe/services/tax/registration_service.rb', line 1218

def cr
  @cr
end

#cyObject

Options for the registration in CY.



1220
1221
1222
# File 'lib/stripe/services/tax/registration_service.rb', line 1220

def cy
  @cy
end

#czObject

Options for the registration in CZ.



1222
1223
1224
# File 'lib/stripe/services/tax/registration_service.rb', line 1222

def cz
  @cz
end

#deObject

Options for the registration in DE.



1224
1225
1226
# File 'lib/stripe/services/tax/registration_service.rb', line 1224

def de
  @de
end

#dkObject

Options for the registration in DK.



1226
1227
1228
# File 'lib/stripe/services/tax/registration_service.rb', line 1226

def dk
  @dk
end

#ecObject

Options for the registration in EC.



1228
1229
1230
# File 'lib/stripe/services/tax/registration_service.rb', line 1228

def ec
  @ec
end

#eeObject

Options for the registration in EE.



1230
1231
1232
# File 'lib/stripe/services/tax/registration_service.rb', line 1230

def ee
  @ee
end

#egObject

Options for the registration in EG.



1232
1233
1234
# File 'lib/stripe/services/tax/registration_service.rb', line 1232

def eg
  @eg
end

#esObject

Options for the registration in ES.



1234
1235
1236
# File 'lib/stripe/services/tax/registration_service.rb', line 1234

def es
  @es
end

#fiObject

Options for the registration in FI.



1236
1237
1238
# File 'lib/stripe/services/tax/registration_service.rb', line 1236

def fi
  @fi
end

#frObject

Options for the registration in FR.



1238
1239
1240
# File 'lib/stripe/services/tax/registration_service.rb', line 1238

def fr
  @fr
end

#gbObject

Options for the registration in GB.



1240
1241
1242
# File 'lib/stripe/services/tax/registration_service.rb', line 1240

def gb
  @gb
end

#geObject

Options for the registration in GE.



1242
1243
1244
# File 'lib/stripe/services/tax/registration_service.rb', line 1242

def ge
  @ge
end

#gnObject

Options for the registration in GN.



1244
1245
1246
# File 'lib/stripe/services/tax/registration_service.rb', line 1244

def gn
  @gn
end

#grObject

Options for the registration in GR.



1246
1247
1248
# File 'lib/stripe/services/tax/registration_service.rb', line 1246

def gr
  @gr
end

#hrObject

Options for the registration in HR.



1248
1249
1250
# File 'lib/stripe/services/tax/registration_service.rb', line 1248

def hr
  @hr
end

#huObject

Options for the registration in HU.



1250
1251
1252
# File 'lib/stripe/services/tax/registration_service.rb', line 1250

def hu
  @hu
end

#idObject

Options for the registration in ID.



1252
1253
1254
# File 'lib/stripe/services/tax/registration_service.rb', line 1252

def id
  @id
end

#ieObject

Options for the registration in IE.



1254
1255
1256
# File 'lib/stripe/services/tax/registration_service.rb', line 1254

def ie
  @ie
end

#inObject

Options for the registration in IN.



1256
1257
1258
# File 'lib/stripe/services/tax/registration_service.rb', line 1256

def in
  @in
end

#isObject

Options for the registration in IS.



1258
1259
1260
# File 'lib/stripe/services/tax/registration_service.rb', line 1258

def is
  @is
end

#itObject

Options for the registration in IT.



1260
1261
1262
# File 'lib/stripe/services/tax/registration_service.rb', line 1260

def it
  @it
end

#jpObject

Options for the registration in JP.



1262
1263
1264
# File 'lib/stripe/services/tax/registration_service.rb', line 1262

def jp
  @jp
end

#keObject

Options for the registration in KE.



1264
1265
1266
# File 'lib/stripe/services/tax/registration_service.rb', line 1264

def ke
  @ke
end

#khObject

Options for the registration in KH.



1266
1267
1268
# File 'lib/stripe/services/tax/registration_service.rb', line 1266

def kh
  @kh
end

#krObject

Options for the registration in KR.



1268
1269
1270
# File 'lib/stripe/services/tax/registration_service.rb', line 1268

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



1270
1271
1272
# File 'lib/stripe/services/tax/registration_service.rb', line 1270

def kz
  @kz
end

#ltObject

Options for the registration in LT.



1272
1273
1274
# File 'lib/stripe/services/tax/registration_service.rb', line 1272

def lt
  @lt
end

#luObject

Options for the registration in LU.



1274
1275
1276
# File 'lib/stripe/services/tax/registration_service.rb', line 1274

def lu
  @lu
end

#lvObject

Options for the registration in LV.



1276
1277
1278
# File 'lib/stripe/services/tax/registration_service.rb', line 1276

def lv
  @lv
end

#maObject

Options for the registration in MA.



1278
1279
1280
# File 'lib/stripe/services/tax/registration_service.rb', line 1278

def ma
  @ma
end

#mdObject

Options for the registration in MD.



1280
1281
1282
# File 'lib/stripe/services/tax/registration_service.rb', line 1280

def md
  @md
end

#meObject

Options for the registration in ME.



1282
1283
1284
# File 'lib/stripe/services/tax/registration_service.rb', line 1282

def me
  @me
end

#mkObject

Options for the registration in MK.



1284
1285
1286
# File 'lib/stripe/services/tax/registration_service.rb', line 1284

def mk
  @mk
end

#mrObject

Options for the registration in MR.



1286
1287
1288
# File 'lib/stripe/services/tax/registration_service.rb', line 1286

def mr
  @mr
end

#mtObject

Options for the registration in MT.



1288
1289
1290
# File 'lib/stripe/services/tax/registration_service.rb', line 1288

def mt
  @mt
end

#mxObject

Options for the registration in MX.



1290
1291
1292
# File 'lib/stripe/services/tax/registration_service.rb', line 1290

def mx
  @mx
end

#myObject

Options for the registration in MY.



1292
1293
1294
# File 'lib/stripe/services/tax/registration_service.rb', line 1292

def my
  @my
end

#ngObject

Options for the registration in NG.



1294
1295
1296
# File 'lib/stripe/services/tax/registration_service.rb', line 1294

def ng
  @ng
end

#nlObject

Options for the registration in NL.



1296
1297
1298
# File 'lib/stripe/services/tax/registration_service.rb', line 1296

def nl
  @nl
end

#noObject

Options for the registration in NO.



1298
1299
1300
# File 'lib/stripe/services/tax/registration_service.rb', line 1298

def no
  @no
end

#npObject

Options for the registration in NP.



1300
1301
1302
# File 'lib/stripe/services/tax/registration_service.rb', line 1300

def np
  @np
end

#nzObject

Options for the registration in NZ.



1302
1303
1304
# File 'lib/stripe/services/tax/registration_service.rb', line 1302

def nz
  @nz
end

#omObject

Options for the registration in OM.



1304
1305
1306
# File 'lib/stripe/services/tax/registration_service.rb', line 1304

def om
  @om
end

#peObject

Options for the registration in PE.



1306
1307
1308
# File 'lib/stripe/services/tax/registration_service.rb', line 1306

def pe
  @pe
end

#plObject

Options for the registration in PL.



1308
1309
1310
# File 'lib/stripe/services/tax/registration_service.rb', line 1308

def pl
  @pl
end

#ptObject

Options for the registration in PT.



1310
1311
1312
# File 'lib/stripe/services/tax/registration_service.rb', line 1310

def pt
  @pt
end

#roObject

Options for the registration in RO.



1312
1313
1314
# File 'lib/stripe/services/tax/registration_service.rb', line 1312

def ro
  @ro
end

#rsObject

Options for the registration in RS.



1314
1315
1316
# File 'lib/stripe/services/tax/registration_service.rb', line 1314

def rs
  @rs
end

#ruObject

Options for the registration in RU.



1316
1317
1318
# File 'lib/stripe/services/tax/registration_service.rb', line 1316

def ru
  @ru
end

#saObject

Options for the registration in SA.



1318
1319
1320
# File 'lib/stripe/services/tax/registration_service.rb', line 1318

def sa
  @sa
end

#seObject

Options for the registration in SE.



1320
1321
1322
# File 'lib/stripe/services/tax/registration_service.rb', line 1320

def se
  @se
end

#sgObject

Options for the registration in SG.



1322
1323
1324
# File 'lib/stripe/services/tax/registration_service.rb', line 1322

def sg
  @sg
end

#siObject

Options for the registration in SI.



1324
1325
1326
# File 'lib/stripe/services/tax/registration_service.rb', line 1324

def si
  @si
end

#skObject

Options for the registration in SK.



1326
1327
1328
# File 'lib/stripe/services/tax/registration_service.rb', line 1326

def sk
  @sk
end

#snObject

Options for the registration in SN.



1328
1329
1330
# File 'lib/stripe/services/tax/registration_service.rb', line 1328

def sn
  @sn
end

#srObject

Options for the registration in SR.



1330
1331
1332
# File 'lib/stripe/services/tax/registration_service.rb', line 1330

def sr
  @sr
end

#thObject

Options for the registration in TH.



1332
1333
1334
# File 'lib/stripe/services/tax/registration_service.rb', line 1332

def th
  @th
end

#tjObject

Options for the registration in TJ.



1334
1335
1336
# File 'lib/stripe/services/tax/registration_service.rb', line 1334

def tj
  @tj
end

#trObject

Options for the registration in TR.



1336
1337
1338
# File 'lib/stripe/services/tax/registration_service.rb', line 1336

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



1338
1339
1340
# File 'lib/stripe/services/tax/registration_service.rb', line 1338

def tz
  @tz
end

#ugObject

Options for the registration in UG.



1340
1341
1342
# File 'lib/stripe/services/tax/registration_service.rb', line 1340

def ug
  @ug
end

#usObject

Options for the registration in US.



1342
1343
1344
# File 'lib/stripe/services/tax/registration_service.rb', line 1342

def us
  @us
end

#uyObject

Options for the registration in UY.



1344
1345
1346
# File 'lib/stripe/services/tax/registration_service.rb', line 1344

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



1346
1347
1348
# File 'lib/stripe/services/tax/registration_service.rb', line 1346

def uz
  @uz
end

#vnObject

Options for the registration in VN.



1348
1349
1350
# File 'lib/stripe/services/tax/registration_service.rb', line 1348

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



1350
1351
1352
# File 'lib/stripe/services/tax/registration_service.rb', line 1350

def za
  @za
end

#zmObject

Options for the registration in ZM.



1352
1353
1354
# File 'lib/stripe/services/tax/registration_service.rb', line 1352

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



1354
1355
1356
# File 'lib/stripe/services/tax/registration_service.rb', line 1354

def zw
  @zw
end