Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: Ae, At, Au, Be, Bg, Bh, By, Ca, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kr, Kz, Lt, Lu, Lv, Ma, Md, Mt, Mx, My, Ng, Nl, No, Nz, Om, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Th, Tr, Tz, Us, Uz, Vn, Za

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, at: nil, au: nil, be: nil, bg: nil, bh: nil, by: nil, ca: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, is: nil, it: nil, jp: nil, ke: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, nz: nil, om: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, th: nil, tr: nil, tz: nil, us: nil, uz: nil, vn: nil, za: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
# File 'lib/stripe/services/tax/registration_service.rb', line 1215

def initialize(
  ae: nil,
  at: nil,
  au: nil,
  be: nil,
  bg: nil,
  bh: nil,
  by: nil,
  ca: nil,
  ch: nil,
  cl: nil,
  co: nil,
  cr: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kr: nil,
  kz: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  nz: nil,
  om: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  th: nil,
  tr: nil,
  tz: nil,
  us: nil,
  uz: nil,
  vn: nil,
  za: nil
)
  @ae = ae
  @at = at
  @au = au
  @be = be
  @bg = bg
  @bh = bh
  @by = by
  @ca = ca
  @ch = ch
  @cl = cl
  @co = co
  @cr = cr
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kr = kr
  @kz = kz
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @nz = nz
  @om = om
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @th = th
  @tr = tr
  @tz = tz
  @us = us
  @uz = uz
  @vn = vn
  @za = za
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



1021
1022
1023
# File 'lib/stripe/services/tax/registration_service.rb', line 1021

def ae
  @ae
end

#atObject

Options for the registration in AT.



1024
1025
1026
# File 'lib/stripe/services/tax/registration_service.rb', line 1024

def at
  @at
end

#auObject

Options for the registration in AU.



1027
1028
1029
# File 'lib/stripe/services/tax/registration_service.rb', line 1027

def au
  @au
end

#beObject

Options for the registration in BE.



1030
1031
1032
# File 'lib/stripe/services/tax/registration_service.rb', line 1030

def be
  @be
end

#bgObject

Options for the registration in BG.



1033
1034
1035
# File 'lib/stripe/services/tax/registration_service.rb', line 1033

def bg
  @bg
end

#bhObject

Options for the registration in BH.



1036
1037
1038
# File 'lib/stripe/services/tax/registration_service.rb', line 1036

def bh
  @bh
end

#byObject

Options for the registration in BY.



1039
1040
1041
# File 'lib/stripe/services/tax/registration_service.rb', line 1039

def by
  @by
end

#caObject

Options for the registration in CA.



1042
1043
1044
# File 'lib/stripe/services/tax/registration_service.rb', line 1042

def ca
  @ca
end

#chObject

Options for the registration in CH.



1045
1046
1047
# File 'lib/stripe/services/tax/registration_service.rb', line 1045

def ch
  @ch
end

#clObject

Options for the registration in CL.



1048
1049
1050
# File 'lib/stripe/services/tax/registration_service.rb', line 1048

def cl
  @cl
end

#coObject

Options for the registration in CO.



1051
1052
1053
# File 'lib/stripe/services/tax/registration_service.rb', line 1051

def co
  @co
end

#crObject

Options for the registration in CR.



1054
1055
1056
# File 'lib/stripe/services/tax/registration_service.rb', line 1054

def cr
  @cr
end

#cyObject

Options for the registration in CY.



1057
1058
1059
# File 'lib/stripe/services/tax/registration_service.rb', line 1057

def cy
  @cy
end

#czObject

Options for the registration in CZ.



1060
1061
1062
# File 'lib/stripe/services/tax/registration_service.rb', line 1060

def cz
  @cz
end

#deObject

Options for the registration in DE.



1063
1064
1065
# File 'lib/stripe/services/tax/registration_service.rb', line 1063

def de
  @de
end

#dkObject

Options for the registration in DK.



1066
1067
1068
# File 'lib/stripe/services/tax/registration_service.rb', line 1066

def dk
  @dk
end

#ecObject

Options for the registration in EC.



1069
1070
1071
# File 'lib/stripe/services/tax/registration_service.rb', line 1069

def ec
  @ec
end

#eeObject

Options for the registration in EE.



1072
1073
1074
# File 'lib/stripe/services/tax/registration_service.rb', line 1072

def ee
  @ee
end

#egObject

Options for the registration in EG.



1075
1076
1077
# File 'lib/stripe/services/tax/registration_service.rb', line 1075

def eg
  @eg
end

#esObject

Options for the registration in ES.



1078
1079
1080
# File 'lib/stripe/services/tax/registration_service.rb', line 1078

def es
  @es
end

#fiObject

Options for the registration in FI.



1081
1082
1083
# File 'lib/stripe/services/tax/registration_service.rb', line 1081

def fi
  @fi
end

#frObject

Options for the registration in FR.



1084
1085
1086
# File 'lib/stripe/services/tax/registration_service.rb', line 1084

def fr
  @fr
end

#gbObject

Options for the registration in GB.



1087
1088
1089
# File 'lib/stripe/services/tax/registration_service.rb', line 1087

def gb
  @gb
end

#geObject

Options for the registration in GE.



1090
1091
1092
# File 'lib/stripe/services/tax/registration_service.rb', line 1090

def ge
  @ge
end

#grObject

Options for the registration in GR.



1093
1094
1095
# File 'lib/stripe/services/tax/registration_service.rb', line 1093

def gr
  @gr
end

#hrObject

Options for the registration in HR.



1096
1097
1098
# File 'lib/stripe/services/tax/registration_service.rb', line 1096

def hr
  @hr
end

#huObject

Options for the registration in HU.



1099
1100
1101
# File 'lib/stripe/services/tax/registration_service.rb', line 1099

def hu
  @hu
end

#idObject

Options for the registration in ID.



1102
1103
1104
# File 'lib/stripe/services/tax/registration_service.rb', line 1102

def id
  @id
end

#ieObject

Options for the registration in IE.



1105
1106
1107
# File 'lib/stripe/services/tax/registration_service.rb', line 1105

def ie
  @ie
end

#isObject

Options for the registration in IS.



1108
1109
1110
# File 'lib/stripe/services/tax/registration_service.rb', line 1108

def is
  @is
end

#itObject

Options for the registration in IT.



1111
1112
1113
# File 'lib/stripe/services/tax/registration_service.rb', line 1111

def it
  @it
end

#jpObject

Options for the registration in JP.



1114
1115
1116
# File 'lib/stripe/services/tax/registration_service.rb', line 1114

def jp
  @jp
end

#keObject

Options for the registration in KE.



1117
1118
1119
# File 'lib/stripe/services/tax/registration_service.rb', line 1117

def ke
  @ke
end

#krObject

Options for the registration in KR.



1120
1121
1122
# File 'lib/stripe/services/tax/registration_service.rb', line 1120

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



1123
1124
1125
# File 'lib/stripe/services/tax/registration_service.rb', line 1123

def kz
  @kz
end

#ltObject

Options for the registration in LT.



1126
1127
1128
# File 'lib/stripe/services/tax/registration_service.rb', line 1126

def lt
  @lt
end

#luObject

Options for the registration in LU.



1129
1130
1131
# File 'lib/stripe/services/tax/registration_service.rb', line 1129

def lu
  @lu
end

#lvObject

Options for the registration in LV.



1132
1133
1134
# File 'lib/stripe/services/tax/registration_service.rb', line 1132

def lv
  @lv
end

#maObject

Options for the registration in MA.



1135
1136
1137
# File 'lib/stripe/services/tax/registration_service.rb', line 1135

def ma
  @ma
end

#mdObject

Options for the registration in MD.



1138
1139
1140
# File 'lib/stripe/services/tax/registration_service.rb', line 1138

def md
  @md
end

#mtObject

Options for the registration in MT.



1141
1142
1143
# File 'lib/stripe/services/tax/registration_service.rb', line 1141

def mt
  @mt
end

#mxObject

Options for the registration in MX.



1144
1145
1146
# File 'lib/stripe/services/tax/registration_service.rb', line 1144

def mx
  @mx
end

#myObject

Options for the registration in MY.



1147
1148
1149
# File 'lib/stripe/services/tax/registration_service.rb', line 1147

def my
  @my
end

#ngObject

Options for the registration in NG.



1150
1151
1152
# File 'lib/stripe/services/tax/registration_service.rb', line 1150

def ng
  @ng
end

#nlObject

Options for the registration in NL.



1153
1154
1155
# File 'lib/stripe/services/tax/registration_service.rb', line 1153

def nl
  @nl
end

#noObject

Options for the registration in NO.



1156
1157
1158
# File 'lib/stripe/services/tax/registration_service.rb', line 1156

def no
  @no
end

#nzObject

Options for the registration in NZ.



1159
1160
1161
# File 'lib/stripe/services/tax/registration_service.rb', line 1159

def nz
  @nz
end

#omObject

Options for the registration in OM.



1162
1163
1164
# File 'lib/stripe/services/tax/registration_service.rb', line 1162

def om
  @om
end

#plObject

Options for the registration in PL.



1165
1166
1167
# File 'lib/stripe/services/tax/registration_service.rb', line 1165

def pl
  @pl
end

#ptObject

Options for the registration in PT.



1168
1169
1170
# File 'lib/stripe/services/tax/registration_service.rb', line 1168

def pt
  @pt
end

#roObject

Options for the registration in RO.



1171
1172
1173
# File 'lib/stripe/services/tax/registration_service.rb', line 1171

def ro
  @ro
end

#rsObject

Options for the registration in RS.



1174
1175
1176
# File 'lib/stripe/services/tax/registration_service.rb', line 1174

def rs
  @rs
end

#ruObject

Options for the registration in RU.



1177
1178
1179
# File 'lib/stripe/services/tax/registration_service.rb', line 1177

def ru
  @ru
end

#saObject

Options for the registration in SA.



1180
1181
1182
# File 'lib/stripe/services/tax/registration_service.rb', line 1180

def sa
  @sa
end

#seObject

Options for the registration in SE.



1183
1184
1185
# File 'lib/stripe/services/tax/registration_service.rb', line 1183

def se
  @se
end

#sgObject

Options for the registration in SG.



1186
1187
1188
# File 'lib/stripe/services/tax/registration_service.rb', line 1186

def sg
  @sg
end

#siObject

Options for the registration in SI.



1189
1190
1191
# File 'lib/stripe/services/tax/registration_service.rb', line 1189

def si
  @si
end

#skObject

Options for the registration in SK.



1192
1193
1194
# File 'lib/stripe/services/tax/registration_service.rb', line 1192

def sk
  @sk
end

#thObject

Options for the registration in TH.



1195
1196
1197
# File 'lib/stripe/services/tax/registration_service.rb', line 1195

def th
  @th
end

#trObject

Options for the registration in TR.



1198
1199
1200
# File 'lib/stripe/services/tax/registration_service.rb', line 1198

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



1201
1202
1203
# File 'lib/stripe/services/tax/registration_service.rb', line 1201

def tz
  @tz
end

#usObject

Options for the registration in US.



1204
1205
1206
# File 'lib/stripe/services/tax/registration_service.rb', line 1204

def us
  @us
end

#uzObject

Options for the registration in UZ.



1207
1208
1209
# File 'lib/stripe/services/tax/registration_service.rb', line 1207

def uz
  @uz
end

#vnObject

Options for the registration in VN.



1210
1211
1212
# File 'lib/stripe/services/tax/registration_service.rb', line 1210

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



1213
1214
1215
# File 'lib/stripe/services/tax/registration_service.rb', line 1213

def za
  @za
end