Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/tax/registration_service.rb

Defined Under Namespace

Classes: Ae, Al, Am, Ao, At, Au, Ba, Bb, Be, Bg, Bh, Bs, By, Ca, Cd, Ch, Cl, Co, Cr, Cy, Cz, De, Dk, Ec, Ee, Eg, Es, Fi, Fr, Gb, Ge, Gn, Gr, Hr, Hu, Id, Ie, Is, It, Jp, Ke, Kh, Kr, Kz, Lt, Lu, Lv, Ma, Md, Me, Mk, Mr, Mt, Mx, My, Ng, Nl, No, Np, Nz, Om, Pe, Pl, Pt, Ro, Rs, Ru, Sa, Se, Sg, Si, Sk, Sn, Sr, Th, Tj, Tr, Tz, Ug, Us, Uy, Uz, Vn, Za, Zm, Zw

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ae: nil, al: nil, am: nil, ao: nil, at: nil, au: nil, ba: nil, bb: nil, be: nil, bg: nil, bh: nil, bs: nil, by: nil, ca: nil, cd: nil, ch: nil, cl: nil, co: nil, cr: nil, cy: nil, cz: nil, de: nil, dk: nil, ec: nil, ee: nil, eg: nil, es: nil, fi: nil, fr: nil, gb: nil, ge: nil, gn: nil, gr: nil, hr: nil, hu: nil, id: nil, ie: nil, is: nil, it: nil, jp: nil, ke: nil, kh: nil, kr: nil, kz: nil, lt: nil, lu: nil, lv: nil, ma: nil, md: nil, me: nil, mk: nil, mr: nil, mt: nil, mx: nil, my: nil, ng: nil, nl: nil, no: nil, np: nil, nz: nil, om: nil, pe: nil, pl: nil, pt: nil, ro: nil, rs: nil, ru: nil, sa: nil, se: nil, sg: nil, si: nil, sk: nil, sn: nil, sr: nil, th: nil, tj: nil, tr: nil, tz: nil, ug: nil, us: nil, uy: nil, uz: nil, vn: nil, za: nil, zm: nil, zw: nil) ⇒ CountryOptions

Returns a new instance of CountryOptions.



1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
# File 'lib/stripe/services/tax/registration_service.rb', line 1345

def initialize(
  ae: nil,
  al: nil,
  am: nil,
  ao: nil,
  at: nil,
  au: nil,
  ba: nil,
  bb: nil,
  be: nil,
  bg: nil,
  bh: nil,
  bs: nil,
  by: nil,
  ca: nil,
  cd: nil,
  ch: nil,
  cl: nil,
  co: nil,
  cr: nil,
  cy: nil,
  cz: nil,
  de: nil,
  dk: nil,
  ec: nil,
  ee: nil,
  eg: nil,
  es: nil,
  fi: nil,
  fr: nil,
  gb: nil,
  ge: nil,
  gn: nil,
  gr: nil,
  hr: nil,
  hu: nil,
  id: nil,
  ie: nil,
  is: nil,
  it: nil,
  jp: nil,
  ke: nil,
  kh: nil,
  kr: nil,
  kz: nil,
  lt: nil,
  lu: nil,
  lv: nil,
  ma: nil,
  md: nil,
  me: nil,
  mk: nil,
  mr: nil,
  mt: nil,
  mx: nil,
  my: nil,
  ng: nil,
  nl: nil,
  no: nil,
  np: nil,
  nz: nil,
  om: nil,
  pe: nil,
  pl: nil,
  pt: nil,
  ro: nil,
  rs: nil,
  ru: nil,
  sa: nil,
  se: nil,
  sg: nil,
  si: nil,
  sk: nil,
  sn: nil,
  sr: nil,
  th: nil,
  tj: nil,
  tr: nil,
  tz: nil,
  ug: nil,
  us: nil,
  uy: nil,
  uz: nil,
  vn: nil,
  za: nil,
  zm: nil,
  zw: nil
)
  @ae = ae
  @al = al
  @am = am
  @ao = ao
  @at = at
  @au = au
  @ba = ba
  @bb = bb
  @be = be
  @bg = bg
  @bh = bh
  @bs = bs
  @by = by
  @ca = ca
  @cd = cd
  @ch = ch
  @cl = cl
  @co = co
  @cr = cr
  @cy = cy
  @cz = cz
  @de = de
  @dk = dk
  @ec = ec
  @ee = ee
  @eg = eg
  @es = es
  @fi = fi
  @fr = fr
  @gb = gb
  @ge = ge
  @gn = gn
  @gr = gr
  @hr = hr
  @hu = hu
  @id = id
  @ie = ie
  @is = is
  @it = it
  @jp = jp
  @ke = ke
  @kh = kh
  @kr = kr
  @kz = kz
  @lt = lt
  @lu = lu
  @lv = lv
  @ma = ma
  @md = md
  @me = me
  @mk = mk
  @mr = mr
  @mt = mt
  @mx = mx
  @my = my
  @ng = ng
  @nl = nl
  @no = no
  @np = np
  @nz = nz
  @om = om
  @pe = pe
  @pl = pl
  @pt = pt
  @ro = ro
  @rs = rs
  @ru = ru
  @sa = sa
  @se = se
  @sg = sg
  @si = si
  @sk = sk
  @sn = sn
  @sr = sr
  @th = th
  @tj = tj
  @tr = tr
  @tz = tz
  @ug = ug
  @us = us
  @uy = uy
  @uz = uz
  @vn = vn
  @za = za
  @zm = zm
  @zw = zw
end

Instance Attribute Details

#aeObject

Options for the registration in AE.



1173
1174
1175
# File 'lib/stripe/services/tax/registration_service.rb', line 1173

def ae
  @ae
end

#alObject

Options for the registration in AL.



1175
1176
1177
# File 'lib/stripe/services/tax/registration_service.rb', line 1175

def al
  @al
end

#amObject

Options for the registration in AM.



1177
1178
1179
# File 'lib/stripe/services/tax/registration_service.rb', line 1177

def am
  @am
end

#aoObject

Options for the registration in AO.



1179
1180
1181
# File 'lib/stripe/services/tax/registration_service.rb', line 1179

def ao
  @ao
end

#atObject

Options for the registration in AT.



1181
1182
1183
# File 'lib/stripe/services/tax/registration_service.rb', line 1181

def at
  @at
end

#auObject

Options for the registration in AU.



1183
1184
1185
# File 'lib/stripe/services/tax/registration_service.rb', line 1183

def au
  @au
end

#baObject

Options for the registration in BA.



1185
1186
1187
# File 'lib/stripe/services/tax/registration_service.rb', line 1185

def ba
  @ba
end

#bbObject

Options for the registration in BB.



1187
1188
1189
# File 'lib/stripe/services/tax/registration_service.rb', line 1187

def bb
  @bb
end

#beObject

Options for the registration in BE.



1189
1190
1191
# File 'lib/stripe/services/tax/registration_service.rb', line 1189

def be
  @be
end

#bgObject

Options for the registration in BG.



1191
1192
1193
# File 'lib/stripe/services/tax/registration_service.rb', line 1191

def bg
  @bg
end

#bhObject

Options for the registration in BH.



1193
1194
1195
# File 'lib/stripe/services/tax/registration_service.rb', line 1193

def bh
  @bh
end

#bsObject

Options for the registration in BS.



1195
1196
1197
# File 'lib/stripe/services/tax/registration_service.rb', line 1195

def bs
  @bs
end

#byObject

Options for the registration in BY.



1197
1198
1199
# File 'lib/stripe/services/tax/registration_service.rb', line 1197

def by
  @by
end

#caObject

Options for the registration in CA.



1199
1200
1201
# File 'lib/stripe/services/tax/registration_service.rb', line 1199

def ca
  @ca
end

#cdObject

Options for the registration in CD.



1201
1202
1203
# File 'lib/stripe/services/tax/registration_service.rb', line 1201

def cd
  @cd
end

#chObject

Options for the registration in CH.



1203
1204
1205
# File 'lib/stripe/services/tax/registration_service.rb', line 1203

def ch
  @ch
end

#clObject

Options for the registration in CL.



1205
1206
1207
# File 'lib/stripe/services/tax/registration_service.rb', line 1205

def cl
  @cl
end

#coObject

Options for the registration in CO.



1207
1208
1209
# File 'lib/stripe/services/tax/registration_service.rb', line 1207

def co
  @co
end

#crObject

Options for the registration in CR.



1209
1210
1211
# File 'lib/stripe/services/tax/registration_service.rb', line 1209

def cr
  @cr
end

#cyObject

Options for the registration in CY.



1211
1212
1213
# File 'lib/stripe/services/tax/registration_service.rb', line 1211

def cy
  @cy
end

#czObject

Options for the registration in CZ.



1213
1214
1215
# File 'lib/stripe/services/tax/registration_service.rb', line 1213

def cz
  @cz
end

#deObject

Options for the registration in DE.



1215
1216
1217
# File 'lib/stripe/services/tax/registration_service.rb', line 1215

def de
  @de
end

#dkObject

Options for the registration in DK.



1217
1218
1219
# File 'lib/stripe/services/tax/registration_service.rb', line 1217

def dk
  @dk
end

#ecObject

Options for the registration in EC.



1219
1220
1221
# File 'lib/stripe/services/tax/registration_service.rb', line 1219

def ec
  @ec
end

#eeObject

Options for the registration in EE.



1221
1222
1223
# File 'lib/stripe/services/tax/registration_service.rb', line 1221

def ee
  @ee
end

#egObject

Options for the registration in EG.



1223
1224
1225
# File 'lib/stripe/services/tax/registration_service.rb', line 1223

def eg
  @eg
end

#esObject

Options for the registration in ES.



1225
1226
1227
# File 'lib/stripe/services/tax/registration_service.rb', line 1225

def es
  @es
end

#fiObject

Options for the registration in FI.



1227
1228
1229
# File 'lib/stripe/services/tax/registration_service.rb', line 1227

def fi
  @fi
end

#frObject

Options for the registration in FR.



1229
1230
1231
# File 'lib/stripe/services/tax/registration_service.rb', line 1229

def fr
  @fr
end

#gbObject

Options for the registration in GB.



1231
1232
1233
# File 'lib/stripe/services/tax/registration_service.rb', line 1231

def gb
  @gb
end

#geObject

Options for the registration in GE.



1233
1234
1235
# File 'lib/stripe/services/tax/registration_service.rb', line 1233

def ge
  @ge
end

#gnObject

Options for the registration in GN.



1235
1236
1237
# File 'lib/stripe/services/tax/registration_service.rb', line 1235

def gn
  @gn
end

#grObject

Options for the registration in GR.



1237
1238
1239
# File 'lib/stripe/services/tax/registration_service.rb', line 1237

def gr
  @gr
end

#hrObject

Options for the registration in HR.



1239
1240
1241
# File 'lib/stripe/services/tax/registration_service.rb', line 1239

def hr
  @hr
end

#huObject

Options for the registration in HU.



1241
1242
1243
# File 'lib/stripe/services/tax/registration_service.rb', line 1241

def hu
  @hu
end

#idObject

Options for the registration in ID.



1243
1244
1245
# File 'lib/stripe/services/tax/registration_service.rb', line 1243

def id
  @id
end

#ieObject

Options for the registration in IE.



1245
1246
1247
# File 'lib/stripe/services/tax/registration_service.rb', line 1245

def ie
  @ie
end

#isObject

Options for the registration in IS.



1247
1248
1249
# File 'lib/stripe/services/tax/registration_service.rb', line 1247

def is
  @is
end

#itObject

Options for the registration in IT.



1249
1250
1251
# File 'lib/stripe/services/tax/registration_service.rb', line 1249

def it
  @it
end

#jpObject

Options for the registration in JP.



1251
1252
1253
# File 'lib/stripe/services/tax/registration_service.rb', line 1251

def jp
  @jp
end

#keObject

Options for the registration in KE.



1253
1254
1255
# File 'lib/stripe/services/tax/registration_service.rb', line 1253

def ke
  @ke
end

#khObject

Options for the registration in KH.



1255
1256
1257
# File 'lib/stripe/services/tax/registration_service.rb', line 1255

def kh
  @kh
end

#krObject

Options for the registration in KR.



1257
1258
1259
# File 'lib/stripe/services/tax/registration_service.rb', line 1257

def kr
  @kr
end

#kzObject

Options for the registration in KZ.



1259
1260
1261
# File 'lib/stripe/services/tax/registration_service.rb', line 1259

def kz
  @kz
end

#ltObject

Options for the registration in LT.



1261
1262
1263
# File 'lib/stripe/services/tax/registration_service.rb', line 1261

def lt
  @lt
end

#luObject

Options for the registration in LU.



1263
1264
1265
# File 'lib/stripe/services/tax/registration_service.rb', line 1263

def lu
  @lu
end

#lvObject

Options for the registration in LV.



1265
1266
1267
# File 'lib/stripe/services/tax/registration_service.rb', line 1265

def lv
  @lv
end

#maObject

Options for the registration in MA.



1267
1268
1269
# File 'lib/stripe/services/tax/registration_service.rb', line 1267

def ma
  @ma
end

#mdObject

Options for the registration in MD.



1269
1270
1271
# File 'lib/stripe/services/tax/registration_service.rb', line 1269

def md
  @md
end

#meObject

Options for the registration in ME.



1271
1272
1273
# File 'lib/stripe/services/tax/registration_service.rb', line 1271

def me
  @me
end

#mkObject

Options for the registration in MK.



1273
1274
1275
# File 'lib/stripe/services/tax/registration_service.rb', line 1273

def mk
  @mk
end

#mrObject

Options for the registration in MR.



1275
1276
1277
# File 'lib/stripe/services/tax/registration_service.rb', line 1275

def mr
  @mr
end

#mtObject

Options for the registration in MT.



1277
1278
1279
# File 'lib/stripe/services/tax/registration_service.rb', line 1277

def mt
  @mt
end

#mxObject

Options for the registration in MX.



1279
1280
1281
# File 'lib/stripe/services/tax/registration_service.rb', line 1279

def mx
  @mx
end

#myObject

Options for the registration in MY.



1281
1282
1283
# File 'lib/stripe/services/tax/registration_service.rb', line 1281

def my
  @my
end

#ngObject

Options for the registration in NG.



1283
1284
1285
# File 'lib/stripe/services/tax/registration_service.rb', line 1283

def ng
  @ng
end

#nlObject

Options for the registration in NL.



1285
1286
1287
# File 'lib/stripe/services/tax/registration_service.rb', line 1285

def nl
  @nl
end

#noObject

Options for the registration in NO.



1287
1288
1289
# File 'lib/stripe/services/tax/registration_service.rb', line 1287

def no
  @no
end

#npObject

Options for the registration in NP.



1289
1290
1291
# File 'lib/stripe/services/tax/registration_service.rb', line 1289

def np
  @np
end

#nzObject

Options for the registration in NZ.



1291
1292
1293
# File 'lib/stripe/services/tax/registration_service.rb', line 1291

def nz
  @nz
end

#omObject

Options for the registration in OM.



1293
1294
1295
# File 'lib/stripe/services/tax/registration_service.rb', line 1293

def om
  @om
end

#peObject

Options for the registration in PE.



1295
1296
1297
# File 'lib/stripe/services/tax/registration_service.rb', line 1295

def pe
  @pe
end

#plObject

Options for the registration in PL.



1297
1298
1299
# File 'lib/stripe/services/tax/registration_service.rb', line 1297

def pl
  @pl
end

#ptObject

Options for the registration in PT.



1299
1300
1301
# File 'lib/stripe/services/tax/registration_service.rb', line 1299

def pt
  @pt
end

#roObject

Options for the registration in RO.



1301
1302
1303
# File 'lib/stripe/services/tax/registration_service.rb', line 1301

def ro
  @ro
end

#rsObject

Options for the registration in RS.



1303
1304
1305
# File 'lib/stripe/services/tax/registration_service.rb', line 1303

def rs
  @rs
end

#ruObject

Options for the registration in RU.



1305
1306
1307
# File 'lib/stripe/services/tax/registration_service.rb', line 1305

def ru
  @ru
end

#saObject

Options for the registration in SA.



1307
1308
1309
# File 'lib/stripe/services/tax/registration_service.rb', line 1307

def sa
  @sa
end

#seObject

Options for the registration in SE.



1309
1310
1311
# File 'lib/stripe/services/tax/registration_service.rb', line 1309

def se
  @se
end

#sgObject

Options for the registration in SG.



1311
1312
1313
# File 'lib/stripe/services/tax/registration_service.rb', line 1311

def sg
  @sg
end

#siObject

Options for the registration in SI.



1313
1314
1315
# File 'lib/stripe/services/tax/registration_service.rb', line 1313

def si
  @si
end

#skObject

Options for the registration in SK.



1315
1316
1317
# File 'lib/stripe/services/tax/registration_service.rb', line 1315

def sk
  @sk
end

#snObject

Options for the registration in SN.



1317
1318
1319
# File 'lib/stripe/services/tax/registration_service.rb', line 1317

def sn
  @sn
end

#srObject

Options for the registration in SR.



1319
1320
1321
# File 'lib/stripe/services/tax/registration_service.rb', line 1319

def sr
  @sr
end

#thObject

Options for the registration in TH.



1321
1322
1323
# File 'lib/stripe/services/tax/registration_service.rb', line 1321

def th
  @th
end

#tjObject

Options for the registration in TJ.



1323
1324
1325
# File 'lib/stripe/services/tax/registration_service.rb', line 1323

def tj
  @tj
end

#trObject

Options for the registration in TR.



1325
1326
1327
# File 'lib/stripe/services/tax/registration_service.rb', line 1325

def tr
  @tr
end

#tzObject

Options for the registration in TZ.



1327
1328
1329
# File 'lib/stripe/services/tax/registration_service.rb', line 1327

def tz
  @tz
end

#ugObject

Options for the registration in UG.



1329
1330
1331
# File 'lib/stripe/services/tax/registration_service.rb', line 1329

def ug
  @ug
end

#usObject

Options for the registration in US.



1331
1332
1333
# File 'lib/stripe/services/tax/registration_service.rb', line 1331

def us
  @us
end

#uyObject

Options for the registration in UY.



1333
1334
1335
# File 'lib/stripe/services/tax/registration_service.rb', line 1333

def uy
  @uy
end

#uzObject

Options for the registration in UZ.



1335
1336
1337
# File 'lib/stripe/services/tax/registration_service.rb', line 1335

def uz
  @uz
end

#vnObject

Options for the registration in VN.



1337
1338
1339
# File 'lib/stripe/services/tax/registration_service.rb', line 1337

def vn
  @vn
end

#zaObject

Options for the registration in ZA.



1339
1340
1341
# File 'lib/stripe/services/tax/registration_service.rb', line 1339

def za
  @za
end

#zmObject

Options for the registration in ZM.



1341
1342
1343
# File 'lib/stripe/services/tax/registration_service.rb', line 1341

def zm
  @zm
end

#zwObject

Options for the registration in ZW.



1343
1344
1345
# File 'lib/stripe/services/tax/registration_service.rb', line 1343

def zw
  @zw
end