Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::At
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::At
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ At
constructor
A new instance of At.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ At
Returns a new instance of At.
86 87 88 89 |
# File 'lib/stripe/services/tax/registration_service.rb', line 86 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
82 83 84 |
# File 'lib/stripe/services/tax/registration_service.rb', line 82 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
84 85 86 |
# File 'lib/stripe/services/tax/registration_service.rb', line 84 def type @type end |