Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Cz
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Cz
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Cz
constructor
A new instance of Cz.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Cz
Returns a new instance of Cz.
285 286 287 288 |
# File 'lib/stripe/services/tax/registration_service.rb', line 285 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
281 282 283 |
# File 'lib/stripe/services/tax/registration_service.rb', line 281 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
283 284 285 |
# File 'lib/stripe/services/tax/registration_service.rb', line 283 def type @type end |