Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ee
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ee
constructor
A new instance of Ee.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ee
Returns a new instance of Ee.
354 355 356 357 |
# File 'lib/stripe/services/tax/registration_service.rb', line 354 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
350 351 352 |
# File 'lib/stripe/services/tax/registration_service.rb', line 350 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
352 353 354 |
# File 'lib/stripe/services/tax/registration_service.rb', line 352 def type @type end |