Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Fr
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Fr
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Fr
constructor
A new instance of Fr.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Fr
Returns a new instance of Fr.
423 424 425 426 |
# File 'lib/stripe/services/tax/registration_service.rb', line 423 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
419 420 421 |
# File 'lib/stripe/services/tax/registration_service.rb', line 419 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
421 422 423 |
# File 'lib/stripe/services/tax/registration_service.rb', line 421 def type @type end |