Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ro
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Ro
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Ro
constructor
A new instance of Ro.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Ro
Returns a new instance of Ro.
998 999 1000 1001 |
# File 'lib/stripe/services/tax/registration_service.rb', line 998 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
994 995 996 |
# File 'lib/stripe/services/tax/registration_service.rb', line 994 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
996 997 998 |
# File 'lib/stripe/services/tax/registration_service.rb', line 996 def type @type end |