Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Si
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Si
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: Standard
Instance Attribute Summary collapse
-
#standard ⇒ Object
Options for the standard registration.
-
#type ⇒ Object
Type of registration to be created in an EU country.
Instance Method Summary collapse
-
#initialize(standard: nil, type: nil) ⇒ Si
constructor
A new instance of Si.
Methods inherited from RequestParams
Constructor Details
#initialize(standard: nil, type: nil) ⇒ Si
Returns a new instance of Si.
1074 1075 1076 1077 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1074 def initialize(standard: nil, type: nil) @standard = standard @type = type end |
Instance Attribute Details
#standard ⇒ Object
Options for the standard registration.
1070 1071 1072 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1070 def standard @standard end |
#type ⇒ Object
Type of registration to be created in an EU country.
1072 1073 1074 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1072 def type @type end |