Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: LocalAmusementTax, LocalLeaseTax, StateSalesTax
Instance Attribute Summary collapse
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
Constructor Details
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1212 def initialize( local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1202 1203 1204 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1202 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1204 1205 1206 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1204 def local_lease_tax @local_lease_tax end |
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
1206 1207 1208 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1206 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1208 1209 1210 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1208 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1210 1211 1212 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1210 def type @type end |