Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Us
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Us
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Defined Under Namespace
Classes: LocalAmusementTax, LocalLeaseTax, StateSalesTax
Instance Attribute Summary collapse
-
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
-
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
-
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
-
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
-
#type ⇒ Object
Type of registration to be created in the US.
Instance Method Summary collapse
-
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
constructor
A new instance of Us.
Methods inherited from RequestParams
Constructor Details
#initialize(local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil) ⇒ Us
Returns a new instance of Us.
1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1113 def initialize( local_amusement_tax: nil, local_lease_tax: nil, state: nil, state_sales_tax: nil, type: nil ) @local_amusement_tax = local_amusement_tax @local_lease_tax = local_lease_tax @state = state @state_sales_tax = state_sales_tax @type = type end |
Instance Attribute Details
#local_amusement_tax ⇒ Object
Options for the local amusement tax registration.
1103 1104 1105 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1103 def local_amusement_tax @local_amusement_tax end |
#local_lease_tax ⇒ Object
Options for the local lease tax registration.
1105 1106 1107 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1105 def local_lease_tax @local_lease_tax end |
#state ⇒ Object
Two-letter US state code ([ISO 3166-2](en.wikipedia.org/wiki/ISO_3166-2)).
1107 1108 1109 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1107 def state @state end |
#state_sales_tax ⇒ Object
Options for the state sales tax registration.
1109 1110 1111 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1109 def state_sales_tax @state_sales_tax end |
#type ⇒ Object
Type of registration to be created in the US.
1111 1112 1113 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1111 def type @type end |