Class: Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Us::StateSalesTax::Election
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::CreateParams::CountryOptions::Us::StateSalesTax::Election
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Instance Attribute Summary collapse
-
#jurisdiction ⇒ Object
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction.
-
#type ⇒ Object
The type of the election for the state sales tax registration.
Instance Method Summary collapse
-
#initialize(jurisdiction: nil, type: nil) ⇒ Election
constructor
A new instance of Election.
Methods inherited from RequestParams
Constructor Details
#initialize(jurisdiction: nil, type: nil) ⇒ Election
Returns a new instance of Election.
1081 1082 1083 1084 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1081 def initialize(jurisdiction: nil, type: nil) @jurisdiction = jurisdiction @type = type end |
Instance Attribute Details
#jurisdiction ⇒ Object
A [FIPS code](www.census.gov/library/reference/code-lists/ansi.html) representing the local jurisdiction. Supported FIPS codes are: ‘003` (Allegheny County) and `60000` (Philadelphia City).
1077 1078 1079 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1077 def jurisdiction @jurisdiction end |
#type ⇒ Object
The type of the election for the state sales tax registration.
1079 1080 1081 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1079 def type @type end |