Class: Stripe::Tax::RegistrationService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::RegistrationService::UpdateParams
- Defined in:
- lib/stripe/services/tax/registration_service.rb
Instance Attribute Summary collapse
-
#active_from ⇒ Object
Time at which the registration becomes active.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
If set, the registration stops being active at this time.
Instance Method Summary collapse
-
#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active_from: nil, expand: nil, expires_at: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1398 1399 1400 1401 1402 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1398 def initialize(active_from: nil, expand: nil, expires_at: nil) @active_from = active_from @expand = @expires_at = expires_at end |
Instance Attribute Details
#active_from ⇒ Object
Time at which the registration becomes active. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.
1390 1391 1392 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1390 def active_from @active_from end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1393 1394 1395 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1393 def @expand end |
#expires_at ⇒ Object
If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be either ‘now` to indicate the current time, or a timestamp measured in seconds since the Unix epoch.
1396 1397 1398 |
# File 'lib/stripe/services/tax/registration_service.rb', line 1396 def expires_at @expires_at end |