Class: Stripe::Tax::Settings::StatusDetails::Pending

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/tax/settings.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#missing_fieldsObject (readonly)

The list of missing fields that are required to perform calculations. It includes the entry ‘head_office` when the status is `pending`. It is recommended to set the optional values even if they aren’t listed as required for calculating taxes. Calculations can fail if missing fields aren’t explicitly provided on every call.



48
49
50
# File 'lib/stripe/resources/tax/settings.rb', line 48

def missing_fields
  @missing_fields
end