Class: Stripe::Tax::Transaction

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/tax/transaction.rb

Overview

A Tax Transaction records the tax collected from or refunded to your customer.

Related guide: [Calculate tax in your custom payment flow](stripe.com/docs/tax/custom#tax-transaction)

Defined Under Namespace

Classes: CustomerDetails, Reversal, ShipFromDetails, ShippingCost

Constant Summary collapse

OBJECT_NAME =
"tax.transaction"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



51
52
53
# File 'lib/stripe/resources/tax/transaction.rb', line 51

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



53
54
55
# File 'lib/stripe/resources/tax/transaction.rb', line 53

def currency
  @currency
end

#customerObject (readonly)

The ID of an existing [Customer](stripe.com/docs/api/customers/object) used for the resource.



55
56
57
# File 'lib/stripe/resources/tax/transaction.rb', line 55

def customer
  @customer
end

#customer_detailsObject (readonly)

Attribute for field customer_details



57
58
59
# File 'lib/stripe/resources/tax/transaction.rb', line 57

def customer_details
  @customer_details
end

#idObject (readonly)

Unique identifier for the transaction.



59
60
61
# File 'lib/stripe/resources/tax/transaction.rb', line 59

def id
  @id
end

#line_itemsObject (readonly)

The tax collected or refunded, by line item.



61
62
63
# File 'lib/stripe/resources/tax/transaction.rb', line 61

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



63
64
65
# File 'lib/stripe/resources/tax/transaction.rb', line 63

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



65
66
67
# File 'lib/stripe/resources/tax/transaction.rb', line 65

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



67
68
69
# File 'lib/stripe/resources/tax/transaction.rb', line 67

def object
  @object
end

#posted_atObject (readonly)

The Unix timestamp representing when the tax liability is assumed or reduced.



69
70
71
# File 'lib/stripe/resources/tax/transaction.rb', line 69

def posted_at
  @posted_at
end

#referenceObject (readonly)

A custom unique identifier, such as ‘myOrder_123’.



71
72
73
# File 'lib/stripe/resources/tax/transaction.rb', line 71

def reference
  @reference
end

#reversalObject (readonly)

If ‘type=reversal`, contains information about what was reversed.



73
74
75
# File 'lib/stripe/resources/tax/transaction.rb', line 73

def reversal
  @reversal
end

#ship_from_detailsObject (readonly)

The details of the ship from location, such as the address.



75
76
77
# File 'lib/stripe/resources/tax/transaction.rb', line 75

def ship_from_details
  @ship_from_details
end

#shipping_costObject (readonly)

The shipping cost details for the transaction.



77
78
79
# File 'lib/stripe/resources/tax/transaction.rb', line 77

def shipping_cost
  @shipping_cost
end

#tax_dateObject (readonly)

Timestamp of date at which the tax rules and rates in effect applies for the calculation.



79
80
81
# File 'lib/stripe/resources/tax/transaction.rb', line 79

def tax_date
  @tax_date
end

#typeObject (readonly)

If ‘reversal`, this transaction reverses an earlier transaction.



81
82
83
# File 'lib/stripe/resources/tax/transaction.rb', line 81

def type
  @type
end

Class Method Details

.create_from_calculation(params = {}, opts = {}) ⇒ Object

Creates a Tax Transaction from a calculation, if that calculation hasn’t expired. Calculations expire after 90 days.



84
85
86
87
88
89
90
91
# File 'lib/stripe/resources/tax/transaction.rb', line 84

def self.create_from_calculation(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/transactions/create_from_calculation",
    params: params,
    opts: opts
  )
end

.create_reversal(params = {}, opts = {}) ⇒ Object

Partially or fully reverses a previously created Transaction.



94
95
96
97
98
99
100
101
# File 'lib/stripe/resources/tax/transaction.rb', line 94

def self.create_reversal(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/tax/transactions/create_reversal",
    params: params,
    opts: opts
  )
end

.list_line_items(transaction, params = {}, opts = {}) ⇒ Object

Retrieves the line items of a committed standalone transaction as a collection.



114
115
116
117
118
119
120
121
# File 'lib/stripe/resources/tax/transaction.rb', line 114

def self.list_line_items(transaction, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/tax/transactions/%<transaction>s/line_items", { transaction: CGI.escape(transaction) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/tax/transaction.rb', line 11

def self.object_name
  "tax.transaction"
end

Instance Method Details

#list_line_items(params = {}, opts = {}) ⇒ Object

Retrieves the line items of a committed standalone transaction as a collection.



104
105
106
107
108
109
110
111
# File 'lib/stripe/resources/tax/transaction.rb', line 104

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/tax/transactions/%<transaction>s/line_items", { transaction: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end