Class: Stripe::Tax::Transaction::CreateFromCalculationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Transaction::CreateFromCalculationParams
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Instance Attribute Summary collapse
-
#calculation ⇒ Object
Tax Calculation ID to be used as input when creating the transaction.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#posted_at ⇒ Object
The Unix timestamp representing when the tax liability is assumed or reduced, which determines the liability posting period and handling in tax liability reports.
-
#reference ⇒ Object
A custom order or sale identifier, such as ‘myOrder_123’.
Instance Method Summary collapse
-
#initialize(calculation: nil, expand: nil, metadata: nil, posted_at: nil, reference: nil) ⇒ CreateFromCalculationParams
constructor
A new instance of CreateFromCalculationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(calculation: nil, expand: nil, metadata: nil, posted_at: nil, reference: nil) ⇒ CreateFromCalculationParams
Returns a new instance of CreateFromCalculationParams.
231 232 233 234 235 236 237 |
# File 'lib/stripe/resources/tax/transaction.rb', line 231 def initialize(calculation: nil, expand: nil, metadata: nil, posted_at: nil, reference: nil) @calculation = calculation @expand = @metadata = @posted_at = posted_at @reference = reference end |
Instance Attribute Details
#calculation ⇒ Object
Tax Calculation ID to be used as input when creating the transaction.
221 222 223 |
# File 'lib/stripe/resources/tax/transaction.rb', line 221 def calculation @calculation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
223 224 225 |
# File 'lib/stripe/resources/tax/transaction.rb', line 223 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
225 226 227 |
# File 'lib/stripe/resources/tax/transaction.rb', line 225 def @metadata end |
#posted_at ⇒ Object
The Unix timestamp representing when the tax liability is assumed or reduced, which determines the liability posting period and handling in tax liability reports. The timestamp must fall within the ‘tax_date` and the current time, unless the `tax_date` is scheduled in advance. Defaults to the current time.
227 228 229 |
# File 'lib/stripe/resources/tax/transaction.rb', line 227 def posted_at @posted_at end |
#reference ⇒ Object
A custom order or sale identifier, such as ‘myOrder_123’. Must be unique across all transactions, including reversals.
229 230 231 |
# File 'lib/stripe/resources/tax/transaction.rb', line 229 def reference @reference end |