Class: Stripe::Tax::Transaction::CreateFromCalculationParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Transaction::CreateFromCalculationParams
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Instance Attribute Summary collapse
-
#calculation ⇒ Object
Tax Calculation ID to be used as input when creating the transaction.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#posted_at ⇒ Object
The Unix timestamp representing when the tax liability is assumed or reduced, which determines the liability posting period and handling in tax liability reports.
-
#reference ⇒ Object
A custom order or sale identifier, such as ‘myOrder_123’.
Instance Method Summary collapse
-
#initialize(calculation: nil, expand: nil, metadata: nil, posted_at: nil, reference: nil) ⇒ CreateFromCalculationParams
constructor
A new instance of CreateFromCalculationParams.
Methods inherited from RequestParams
Constructor Details
#initialize(calculation: nil, expand: nil, metadata: nil, posted_at: nil, reference: nil) ⇒ CreateFromCalculationParams
Returns a new instance of CreateFromCalculationParams.
160 161 162 163 164 165 166 |
# File 'lib/stripe/resources/tax/transaction.rb', line 160 def initialize(calculation: nil, expand: nil, metadata: nil, posted_at: nil, reference: nil) @calculation = calculation @expand = @metadata = @posted_at = posted_at @reference = reference end |
Instance Attribute Details
#calculation ⇒ Object
Tax Calculation ID to be used as input when creating the transaction.
150 151 152 |
# File 'lib/stripe/resources/tax/transaction.rb', line 150 def calculation @calculation end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
152 153 154 |
# File 'lib/stripe/resources/tax/transaction.rb', line 152 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
154 155 156 |
# File 'lib/stripe/resources/tax/transaction.rb', line 154 def @metadata end |
#posted_at ⇒ Object
The Unix timestamp representing when the tax liability is assumed or reduced, which determines the liability posting period and handling in tax liability reports. The timestamp must fall within the ‘tax_date` and the current time, unless the `tax_date` is scheduled in advance. Defaults to the current time.
156 157 158 |
# File 'lib/stripe/resources/tax/transaction.rb', line 156 def posted_at @posted_at end |
#reference ⇒ Object
A custom order or sale identifier, such as ‘myOrder_123’. Must be unique across all transactions, including reversals.
158 159 160 |
# File 'lib/stripe/resources/tax/transaction.rb', line 158 def reference @reference end |