Class: Stripe::Tax::Transaction::CreateReversalParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Transaction::CreateReversalParams
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Defined Under Namespace
Classes: LineItem, ShippingCost
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flat_amount ⇒ Object
A flat amount to reverse across the entire transaction, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#line_items ⇒ Object
The line item amounts to reverse.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mode ⇒ Object
If ‘partial`, the provided line item or shipping cost amounts are reversed.
-
#original_transaction ⇒ Object
The ID of the Transaction to partially or fully reverse.
-
#reference ⇒ Object
A custom identifier for this reversal, such as ‘myOrder_123-refund_1`, which must be unique across all transactions.
-
#shipping_cost ⇒ Object
The shipping cost to reverse.
Instance Method Summary collapse
-
#initialize(expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil) ⇒ CreateReversalParams
constructor
A new instance of CreateReversalParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil) ⇒ CreateReversalParams
Returns a new instance of CreateReversalParams.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/stripe/resources/tax/transaction.rb', line 279 def initialize( expand: nil, flat_amount: nil, line_items: nil, metadata: nil, mode: nil, original_transaction: nil, reference: nil, shipping_cost: nil ) @expand = @flat_amount = flat_amount @line_items = line_items @metadata = @mode = mode @original_transaction = original_transaction @reference = reference @shipping_cost = shipping_cost end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
256 257 258 |
# File 'lib/stripe/resources/tax/transaction.rb', line 256 def @expand end |
#flat_amount ⇒ Object
A flat amount to reverse across the entire transaction, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative. This value represents the total amount to refund from the transaction, including taxes.
259 260 261 |
# File 'lib/stripe/resources/tax/transaction.rb', line 259 def flat_amount @flat_amount end |
#line_items ⇒ Object
The line item amounts to reverse.
262 263 264 |
# File 'lib/stripe/resources/tax/transaction.rb', line 262 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
265 266 267 |
# File 'lib/stripe/resources/tax/transaction.rb', line 265 def @metadata end |
#mode ⇒ Object
If ‘partial`, the provided line item or shipping cost amounts are reversed. If `full`, the original transaction is fully reversed.
268 269 270 |
# File 'lib/stripe/resources/tax/transaction.rb', line 268 def mode @mode end |
#original_transaction ⇒ Object
The ID of the Transaction to partially or fully reverse.
271 272 273 |
# File 'lib/stripe/resources/tax/transaction.rb', line 271 def original_transaction @original_transaction end |
#reference ⇒ Object
A custom identifier for this reversal, such as ‘myOrder_123-refund_1`, which must be unique across all transactions. The reference helps identify this reversal transaction in exported [tax reports](stripe.com/docs/tax/reports).
274 275 276 |
# File 'lib/stripe/resources/tax/transaction.rb', line 274 def reference @reference end |
#shipping_cost ⇒ Object
The shipping cost to reverse.
277 278 279 |
# File 'lib/stripe/resources/tax/transaction.rb', line 277 def shipping_cost @shipping_cost end |