Class: Stripe::Tax::Transaction::CreateReversalParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Transaction::CreateReversalParams::LineItem
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#original_line_item ⇒ Object
The ‘id` of the line item to reverse in the original transaction.
-
#quantity ⇒ Object
The quantity reversed.
-
#reference ⇒ Object
A custom identifier for this line item in the reversal transaction, such as ‘L1-refund’.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_tax: nil, metadata: nil, original_line_item: nil, quantity: nil, reference: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_tax: nil, metadata: nil, original_line_item: nil, quantity: nil, reference: nil) ⇒ LineItem
Returns a new instance of LineItem.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/stripe/resources/tax/transaction.rb', line 175 def initialize( amount: nil, amount_tax: nil, metadata: nil, original_line_item: nil, quantity: nil, reference: nil ) @amount = amount @amount_tax = amount_tax @metadata = @original_line_item = original_line_item @quantity = quantity @reference = reference end |
Instance Attribute Details
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
163 164 165 |
# File 'lib/stripe/resources/tax/transaction.rb', line 163 def amount @amount end |
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
165 166 167 |
# File 'lib/stripe/resources/tax/transaction.rb', line 165 def amount_tax @amount_tax end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
167 168 169 |
# File 'lib/stripe/resources/tax/transaction.rb', line 167 def @metadata end |
#original_line_item ⇒ Object
The ‘id` of the line item to reverse in the original transaction.
169 170 171 |
# File 'lib/stripe/resources/tax/transaction.rb', line 169 def original_line_item @original_line_item end |
#quantity ⇒ Object
The quantity reversed. Appears in [tax exports](stripe.com/docs/tax/reports), but does not affect the amount of tax reversed.
171 172 173 |
# File 'lib/stripe/resources/tax/transaction.rb', line 171 def quantity @quantity end |
#reference ⇒ Object
A custom identifier for this line item in the reversal transaction, such as ‘L1-refund’.
173 174 175 |
# File 'lib/stripe/resources/tax/transaction.rb', line 173 def reference @reference end |