Class: Stripe::Tax::Transaction::CreateReversalParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/tax/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_tax: nil, metadata: nil, original_line_item: nil, quantity: nil, reference: nil) ⇒ LineItem

Returns a new instance of LineItem.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/stripe/resources/tax/transaction.rb', line 184

def initialize(
  amount: nil,
  amount_tax: nil,
  metadata: nil,
  original_line_item: nil,
  quantity: nil,
  reference: nil
)
  @amount = amount
  @amount_tax = amount_tax
  @metadata = 
  @original_line_item = original_line_item
  @quantity = quantity
  @reference = reference
end

Instance Attribute Details

#amountObject

The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.



172
173
174
# File 'lib/stripe/resources/tax/transaction.rb', line 172

def amount
  @amount
end

#amount_taxObject

The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.



174
175
176
# File 'lib/stripe/resources/tax/transaction.rb', line 174

def amount_tax
  @amount_tax
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



176
177
178
# File 'lib/stripe/resources/tax/transaction.rb', line 176

def 
  @metadata
end

#original_line_itemObject

The ‘id` of the line item to reverse in the original transaction.



178
179
180
# File 'lib/stripe/resources/tax/transaction.rb', line 178

def original_line_item
  @original_line_item
end

#quantityObject

The quantity reversed. Appears in [tax exports](stripe.com/docs/tax/reports), but does not affect the amount of tax reversed.



180
181
182
# File 'lib/stripe/resources/tax/transaction.rb', line 180

def quantity
  @quantity
end

#referenceObject

A custom identifier for this line item in the reversal transaction, such as ‘L1-refund’.



182
183
184
# File 'lib/stripe/resources/tax/transaction.rb', line 182

def reference
  @reference
end