Class: Stripe::Tax::Transaction::CreateReversalParams::ShippingCost
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Tax::Transaction::CreateReversalParams::ShippingCost
- Defined in:
- lib/stripe/resources/tax/transaction.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
-
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_tax: nil) ⇒ ShippingCost
constructor
A new instance of ShippingCost.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_tax: nil) ⇒ ShippingCost
Returns a new instance of ShippingCost.
250 251 252 253 |
# File 'lib/stripe/resources/tax/transaction.rb', line 250 def initialize(amount: nil, amount_tax: nil) @amount = amount @amount_tax = amount_tax end |
Instance Attribute Details
#amount ⇒ Object
The amount to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
245 246 247 |
# File 'lib/stripe/resources/tax/transaction.rb', line 245 def amount @amount end |
#amount_tax ⇒ Object
The amount of tax to reverse, in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) in negative.
248 249 250 |
# File 'lib/stripe/resources/tax/transaction.rb', line 248 def amount_tax @amount_tax end |