Class: Stripe::TaxFund::Context
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::TaxFund::Context
- Defined in:
- lib/stripe/resources/tax_fund.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#checkout_session ⇒ Object
readonly
The Checkout Session associated with this sweep, if any.
-
#credit_note ⇒ Object
readonly
The Credit Note associated with this sweep, if any.
-
#invoice ⇒ Object
readonly
The Invoice associated with this sweep, if any.
-
#payment_intent ⇒ Object
readonly
The PaymentIntent associated with this sweep, if any.
-
#refund ⇒ Object
readonly
The Refund associated with this sweep, if any.
-
#tax_transaction ⇒ Object
readonly
The Tax Transaction associated with this sweep, if any.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#checkout_session ⇒ Object (readonly)
The Checkout Session associated with this sweep, if any.
17 18 19 |
# File 'lib/stripe/resources/tax_fund.rb', line 17 def checkout_session @checkout_session end |
#credit_note ⇒ Object (readonly)
The Credit Note associated with this sweep, if any.
19 20 21 |
# File 'lib/stripe/resources/tax_fund.rb', line 19 def credit_note @credit_note end |
#invoice ⇒ Object (readonly)
The Invoice associated with this sweep, if any.
21 22 23 |
# File 'lib/stripe/resources/tax_fund.rb', line 21 def invoice @invoice end |
#payment_intent ⇒ Object (readonly)
The PaymentIntent associated with this sweep, if any.
23 24 25 |
# File 'lib/stripe/resources/tax_fund.rb', line 23 def payment_intent @payment_intent end |
#refund ⇒ Object (readonly)
The Refund associated with this sweep, if any.
25 26 27 |
# File 'lib/stripe/resources/tax_fund.rb', line 25 def refund @refund end |
#tax_transaction ⇒ Object (readonly)
The Tax Transaction associated with this sweep, if any.
27 28 29 |
# File 'lib/stripe/resources/tax_fund.rb', line 27 def tax_transaction @tax_transaction end |
Class Method Details
.field_remappings ⇒ Object
33 34 35 |
# File 'lib/stripe/resources/tax_fund.rb', line 33 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
29 30 31 |
# File 'lib/stripe/resources/tax_fund.rb', line 29 def self.inner_class_types @inner_class_types = {} end |