Class: Stripe::TaxRate::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TaxRate::CreateParams
- Defined in:
- lib/stripe/resources/tax_rate.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Flag determining whether the tax rate is active or inactive (archived).
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#percentage ⇒ Object
This represents the tax rate percent out of 100.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, inclusive: nil, jurisdiction: nil, metadata: nil, percentage: nil, state: nil, tax_type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, inclusive: nil, jurisdiction: nil, metadata: nil, percentage: nil, state: nil, tax_type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/stripe/resources/tax_rate.rb', line 121 def initialize( active: nil, country: nil, description: nil, display_name: nil, expand: nil, inclusive: nil, jurisdiction: nil, metadata: nil, percentage: nil, state: nil, tax_type: nil ) @active = active @country = country @description = description @display_name = display_name @expand = @inclusive = inclusive @jurisdiction = jurisdiction @metadata = @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#active ⇒ Object
Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
89 90 91 |
# File 'lib/stripe/resources/tax_rate.rb', line 89 def active @active end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
92 93 94 |
# File 'lib/stripe/resources/tax_rate.rb', line 92 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
95 96 97 |
# File 'lib/stripe/resources/tax_rate.rb', line 95 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
98 99 100 |
# File 'lib/stripe/resources/tax_rate.rb', line 98 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
101 102 103 |
# File 'lib/stripe/resources/tax_rate.rb', line 101 def @expand end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
104 105 106 |
# File 'lib/stripe/resources/tax_rate.rb', line 104 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
107 108 109 |
# File 'lib/stripe/resources/tax_rate.rb', line 107 def jurisdiction @jurisdiction end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
110 111 112 |
# File 'lib/stripe/resources/tax_rate.rb', line 110 def @metadata end |
#percentage ⇒ Object
This represents the tax rate percent out of 100.
113 114 115 |
# File 'lib/stripe/resources/tax_rate.rb', line 113 def percentage @percentage end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.
116 117 118 |
# File 'lib/stripe/resources/tax_rate.rb', line 116 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
119 120 121 |
# File 'lib/stripe/resources/tax_rate.rb', line 119 def tax_type @tax_type end |