Class: Stripe::TaxRate::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TaxRate::UpdateParams
- Defined in:
- lib/stripe/resources/tax_rate.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Flag determining whether the tax rate is active or inactive (archived).
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/stripe/resources/tax_rate.rb', line 156 def initialize( active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil ) @active = active @country = country @description = description @display_name = display_name @expand = @jurisdiction = jurisdiction @metadata = @state = state @tax_type = tax_type end |
Instance Attribute Details
#active ⇒ Object
Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.
138 139 140 |
# File 'lib/stripe/resources/tax_rate.rb', line 138 def active @active end |
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
140 141 142 |
# File 'lib/stripe/resources/tax_rate.rb', line 140 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
142 143 144 |
# File 'lib/stripe/resources/tax_rate.rb', line 142 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
144 145 146 |
# File 'lib/stripe/resources/tax_rate.rb', line 144 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
146 147 148 |
# File 'lib/stripe/resources/tax_rate.rb', line 146 def @expand end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
148 149 150 |
# File 'lib/stripe/resources/tax_rate.rb', line 148 def jurisdiction @jurisdiction end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
150 151 152 |
# File 'lib/stripe/resources/tax_rate.rb', line 150 def @metadata end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, “NY” for New York, United States.
152 153 154 |
# File 'lib/stripe/resources/tax_rate.rb', line 152 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
154 155 156 |
# File 'lib/stripe/resources/tax_rate.rb', line 154 def tax_type @tax_type end |