Class: Stripe::TaxRate::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax_rate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/stripe/resources/tax_rate.rb', line 157

def initialize(
  active: nil,
  country: nil,
  description: nil,
  display_name: nil,
  expand: nil,
  jurisdiction: nil,
  metadata: nil,
  state: nil,
  tax_type: nil
)
  @active = active
  @country = country
  @description = description
  @display_name = display_name
  @expand = expand
  @jurisdiction = jurisdiction
  @metadata = 
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#activeObject

Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.



139
140
141
# File 'lib/stripe/resources/tax_rate.rb', line 139

def active
  @active
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



141
142
143
# File 'lib/stripe/resources/tax_rate.rb', line 141

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



143
144
145
# File 'lib/stripe/resources/tax_rate.rb', line 143

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



145
146
147
# File 'lib/stripe/resources/tax_rate.rb', line 145

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



147
148
149
# File 'lib/stripe/resources/tax_rate.rb', line 147

def expand
  @expand
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



149
150
151
# File 'lib/stripe/resources/tax_rate.rb', line 149

def jurisdiction
  @jurisdiction
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



151
152
153
# File 'lib/stripe/resources/tax_rate.rb', line 151

def 
  @metadata
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, “NY” for New York, United States.



153
154
155
# File 'lib/stripe/resources/tax_rate.rb', line 153

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



155
156
157
# File 'lib/stripe/resources/tax_rate.rb', line 155

def tax_type
  @tax_type
end