Class: Stripe::TaxRate::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/tax_rate.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, country: nil, description: nil, display_name: nil, expand: nil, jurisdiction: nil, metadata: nil, state: nil, tax_type: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/stripe/resources/tax_rate.rb', line 185

def initialize(
  active: nil,
  country: nil,
  description: nil,
  display_name: nil,
  expand: nil,
  jurisdiction: nil,
  metadata: nil,
  state: nil,
  tax_type: nil
)
  @active = active
  @country = country
  @description = description
  @display_name = display_name
  @expand = expand
  @jurisdiction = jurisdiction
  @metadata = 
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#activeObject

Flag determining whether the tax rate is active or inactive (archived). Inactive tax rates cannot be used with new applications or Checkout Sessions, but will still work for subscriptions and invoices that already have it set.



159
160
161
# File 'lib/stripe/resources/tax_rate.rb', line 159

def active
  @active
end

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



162
163
164
# File 'lib/stripe/resources/tax_rate.rb', line 162

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



165
166
167
# File 'lib/stripe/resources/tax_rate.rb', line 165

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



168
169
170
# File 'lib/stripe/resources/tax_rate.rb', line 168

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



171
172
173
# File 'lib/stripe/resources/tax_rate.rb', line 171

def expand
  @expand
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



174
175
176
# File 'lib/stripe/resources/tax_rate.rb', line 174

def jurisdiction
  @jurisdiction
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



177
178
179
# File 'lib/stripe/resources/tax_rate.rb', line 177

def 
  @metadata
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.



180
181
182
# File 'lib/stripe/resources/tax_rate.rb', line 180

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



183
184
185
# File 'lib/stripe/resources/tax_rate.rb', line 183

def tax_type
  @tax_type
end