Class: Stripe::Terminal::Configuration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Configuration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Overview
A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).
Defined Under Namespace
Classes: BbposWisepad3, BbposWiseposE, Cellular, Offline, RebootWindow, StripeS700, StripeS710, Tipping, VerifoneM425, VerifoneP400, VerifoneP630, VerifoneUx700, VerifoneV660p, Wifi
Constant Summary collapse
- OBJECT_NAME =
"terminal.configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bbpos_wisepad3 ⇒ Object
readonly
Attribute for field bbpos_wisepad3.
-
#bbpos_wisepos_e ⇒ Object
readonly
Attribute for field bbpos_wisepos_e.
-
#cellular ⇒ Object
readonly
Attribute for field cellular.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_account_default ⇒ Object
readonly
Whether this Configuration is the default for your account.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#name ⇒ Object
readonly
String indicating the name of the Configuration object, set by the user.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#reboot_window ⇒ Object
readonly
Attribute for field reboot_window.
-
#stripe_s700 ⇒ Object
readonly
Attribute for field stripe_s700.
-
#stripe_s710 ⇒ Object
readonly
Attribute for field stripe_s710.
-
#tipping ⇒ Object
readonly
Attribute for field tipping.
-
#verifone_m425 ⇒ Object
readonly
Attribute for field verifone_m425.
-
#verifone_p400 ⇒ Object
readonly
Attribute for field verifone_p400.
-
#verifone_p630 ⇒ Object
readonly
Attribute for field verifone_p630.
-
#verifone_ux700 ⇒ Object
readonly
Attribute for field verifone_ux700.
-
#verifone_v660p ⇒ Object
readonly
Attribute for field verifone_v660p.
-
#wifi ⇒ Object
readonly
Attribute for field wifi.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
-
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bbpos_wisepad3 ⇒ Object (readonly)
Attribute for field bbpos_wisepad3
685 686 687 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 685 def bbpos_wisepad3 @bbpos_wisepad3 end |
#bbpos_wisepos_e ⇒ Object (readonly)
Attribute for field bbpos_wisepos_e
687 688 689 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 687 def bbpos_wisepos_e @bbpos_wisepos_e end |
#cellular ⇒ Object (readonly)
Attribute for field cellular
689 690 691 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 689 def cellular @cellular end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
691 692 693 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 691 def deleted @deleted end |
#id ⇒ Object (readonly)
Unique identifier for the object.
693 694 695 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 693 def id @id end |
#is_account_default ⇒ Object (readonly)
Whether this Configuration is the default for your account
695 696 697 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 695 def is_account_default @is_account_default end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
697 698 699 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 697 def livemode @livemode end |
#name ⇒ Object (readonly)
String indicating the name of the Configuration object, set by the user
699 700 701 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 699 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
701 702 703 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 701 def object @object end |
#offline ⇒ Object (readonly)
Attribute for field offline
703 704 705 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 703 def offline @offline end |
#reboot_window ⇒ Object (readonly)
Attribute for field reboot_window
705 706 707 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 705 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object (readonly)
Attribute for field stripe_s700
707 708 709 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 707 def stripe_s700 @stripe_s700 end |
#stripe_s710 ⇒ Object (readonly)
Attribute for field stripe_s710
709 710 711 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 709 def stripe_s710 @stripe_s710 end |
#tipping ⇒ Object (readonly)
Attribute for field tipping
711 712 713 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 711 def tipping @tipping end |
#verifone_m425 ⇒ Object (readonly)
Attribute for field verifone_m425
713 714 715 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 713 def verifone_m425 @verifone_m425 end |
#verifone_p400 ⇒ Object (readonly)
Attribute for field verifone_p400
715 716 717 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 715 def verifone_p400 @verifone_p400 end |
#verifone_p630 ⇒ Object (readonly)
Attribute for field verifone_p630
717 718 719 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 717 def verifone_p630 @verifone_p630 end |
#verifone_ux700 ⇒ Object (readonly)
Attribute for field verifone_ux700
719 720 721 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 719 def verifone_ux700 @verifone_ux700 end |
#verifone_v660p ⇒ Object (readonly)
Attribute for field verifone_v660p
721 722 723 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 721 def verifone_v660p @verifone_v660p end |
#wifi ⇒ Object (readonly)
Attribute for field wifi
723 724 725 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 723 def wifi @wifi end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
726 727 728 729 730 731 732 733 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 726 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
736 737 738 739 740 741 742 743 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 736 def self.delete(configuration, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
794 795 796 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 794 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 775 def self.inner_class_types @inner_class_types = { bbpos_wisepad3: BbposWisepad3, bbpos_wisepos_e: BbposWiseposE, cellular: Cellular, offline: Offline, reboot_window: RebootWindow, stripe_s700: StripeS700, stripe_s710: StripeS710, tipping: Tipping, verifone_m425: VerifoneM425, verifone_p400: VerifoneP400, verifone_p630: VerifoneP630, verifone_ux700: VerifoneUx700, verifone_v660p: VerifoneV660p, wifi: Wifi, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
756 757 758 759 760 761 762 763 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 756 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 15 def self.object_name "terminal.configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
766 767 768 769 770 771 772 773 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 766 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
746 747 748 749 750 751 752 753 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 746 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }), params: params, opts: opts ) end |