Class: Stripe::Terminal::Configuration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Configuration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Overview
A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).
Defined Under Namespace
Classes: BbposWisepad3, BbposWiseposE, Cellular, Offline, ReaderSecurity, RebootWindow, StripeS700, StripeS710, Tipping, VerifoneP400, Wifi
Constant Summary collapse
- OBJECT_NAME =
"terminal.configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bbpos_wisepad3 ⇒ Object
readonly
Attribute for field bbpos_wisepad3.
-
#bbpos_wisepos_e ⇒ Object
readonly
Attribute for field bbpos_wisepos_e.
-
#cellular ⇒ Object
readonly
Attribute for field cellular.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_account_default ⇒ Object
readonly
Whether this Configuration is the default for your account.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#name ⇒ Object
readonly
String indicating the name of the Configuration object, set by the user.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#reader_security ⇒ Object
readonly
Attribute for field reader_security.
-
#reboot_window ⇒ Object
readonly
Attribute for field reboot_window.
-
#stripe_s700 ⇒ Object
readonly
Attribute for field stripe_s700.
-
#stripe_s710 ⇒ Object
readonly
Attribute for field stripe_s710.
-
#tipping ⇒ Object
readonly
Attribute for field tipping.
-
#verifone_p400 ⇒ Object
readonly
Attribute for field verifone_p400.
-
#wifi ⇒ Object
readonly
Attribute for field wifi.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
-
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bbpos_wisepad3 ⇒ Object (readonly)
Attribute for field bbpos_wisepad3
646 647 648 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 646 def bbpos_wisepad3 @bbpos_wisepad3 end |
#bbpos_wisepos_e ⇒ Object (readonly)
Attribute for field bbpos_wisepos_e
648 649 650 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 648 def bbpos_wisepos_e @bbpos_wisepos_e end |
#cellular ⇒ Object (readonly)
Attribute for field cellular
650 651 652 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 650 def cellular @cellular end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
652 653 654 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 652 def deleted @deleted end |
#id ⇒ Object (readonly)
Unique identifier for the object.
654 655 656 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 654 def id @id end |
#is_account_default ⇒ Object (readonly)
Whether this Configuration is the default for your account
656 657 658 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 656 def is_account_default @is_account_default end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
658 659 660 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 658 def livemode @livemode end |
#name ⇒ Object (readonly)
String indicating the name of the Configuration object, set by the user
660 661 662 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 660 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
662 663 664 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 662 def object @object end |
#offline ⇒ Object (readonly)
Attribute for field offline
664 665 666 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 664 def offline @offline end |
#reader_security ⇒ Object (readonly)
Attribute for field reader_security
666 667 668 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 666 def reader_security @reader_security end |
#reboot_window ⇒ Object (readonly)
Attribute for field reboot_window
668 669 670 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 668 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object (readonly)
Attribute for field stripe_s700
670 671 672 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 670 def stripe_s700 @stripe_s700 end |
#stripe_s710 ⇒ Object (readonly)
Attribute for field stripe_s710
672 673 674 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 672 def stripe_s710 @stripe_s710 end |
#tipping ⇒ Object (readonly)
Attribute for field tipping
674 675 676 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 674 def tipping @tipping end |
#verifone_p400 ⇒ Object (readonly)
Attribute for field verifone_p400
676 677 678 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 676 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object (readonly)
Attribute for field wifi
678 679 680 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 678 def wifi @wifi end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
681 682 683 684 685 686 687 688 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 681 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
691 692 693 694 695 696 697 698 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 691 def self.delete(configuration, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
746 747 748 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 746 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 730 def self.inner_class_types @inner_class_types = { bbpos_wisepad3: BbposWisepad3, bbpos_wisepos_e: BbposWiseposE, cellular: Cellular, offline: Offline, reader_security: ReaderSecurity, reboot_window: RebootWindow, stripe_s700: StripeS700, stripe_s710: StripeS710, tipping: Tipping, verifone_p400: VerifoneP400, wifi: Wifi, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
711 712 713 714 715 716 717 718 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 711 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 15 def self.object_name "terminal.configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
721 722 723 724 725 726 727 728 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 721 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
701 702 703 704 705 706 707 708 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 701 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }), params: params, opts: opts ) end |