Class: Stripe::Terminal::Configuration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Configuration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Overview
A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).
Defined Under Namespace
Classes: BbposWisepad3, BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Constant Summary collapse
- OBJECT_NAME =
"terminal.configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bbpos_wisepad3 ⇒ Object
readonly
Attribute for field bbpos_wisepad3.
-
#bbpos_wisepos_e ⇒ Object
readonly
Attribute for field bbpos_wisepos_e.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_account_default ⇒ Object
readonly
Whether this Configuration is the default for your account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#name ⇒ Object
readonly
String indicating the name of the Configuration object, set by the user.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#reader_security ⇒ Object
readonly
Attribute for field reader_security.
-
#reboot_window ⇒ Object
readonly
Attribute for field reboot_window.
-
#stripe_s700 ⇒ Object
readonly
Attribute for field stripe_s700.
-
#tipping ⇒ Object
readonly
Attribute for field tipping.
-
#verifone_p400 ⇒ Object
readonly
Attribute for field verifone_p400.
-
#wifi ⇒ Object
readonly
Attribute for field wifi.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
-
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bbpos_wisepad3 ⇒ Object (readonly)
Attribute for field bbpos_wisepad3
620 621 622 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 620 def bbpos_wisepad3 @bbpos_wisepad3 end |
#bbpos_wisepos_e ⇒ Object (readonly)
Attribute for field bbpos_wisepos_e
622 623 624 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 622 def bbpos_wisepos_e @bbpos_wisepos_e end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
648 649 650 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 648 def deleted @deleted end |
#id ⇒ Object (readonly)
Unique identifier for the object.
624 625 626 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 624 def id @id end |
#is_account_default ⇒ Object (readonly)
Whether this Configuration is the default for your account
626 627 628 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 626 def is_account_default @is_account_default end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
628 629 630 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 628 def livemode @livemode end |
#name ⇒ Object (readonly)
String indicating the name of the Configuration object, set by the user
630 631 632 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 630 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
632 633 634 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 632 def object @object end |
#offline ⇒ Object (readonly)
Attribute for field offline
634 635 636 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 634 def offline @offline end |
#reader_security ⇒ Object (readonly)
Attribute for field reader_security
636 637 638 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 636 def reader_security @reader_security end |
#reboot_window ⇒ Object (readonly)
Attribute for field reboot_window
638 639 640 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 638 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object (readonly)
Attribute for field stripe_s700
640 641 642 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 640 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object (readonly)
Attribute for field tipping
642 643 644 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 642 def tipping @tipping end |
#verifone_p400 ⇒ Object (readonly)
Attribute for field verifone_p400
644 645 646 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 644 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object (readonly)
Attribute for field wifi
646 647 648 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 646 def wifi @wifi end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
651 652 653 654 655 656 657 658 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 651 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
661 662 663 664 665 666 667 668 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 661 def self.delete(configuration, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
714 715 716 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 714 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
700 701 702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 700 def self.inner_class_types @inner_class_types = { bbpos_wisepad3: BbposWisepad3, bbpos_wisepos_e: BbposWiseposE, offline: Offline, reader_security: ReaderSecurity, reboot_window: RebootWindow, stripe_s700: StripeS700, tipping: Tipping, verifone_p400: VerifoneP400, wifi: Wifi, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
681 682 683 684 685 686 687 688 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 681 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 15 def self.object_name "terminal.configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
691 692 693 694 695 696 697 698 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 691 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
671 672 673 674 675 676 677 678 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 671 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }), params: params, opts: opts ) end |