Class: Stripe::Terminal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/configuration.rb

Overview

A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).

Defined Under Namespace

Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, UpdateParams, VerifoneP400, Wifi

Constant Summary collapse

OBJECT_NAME =
"terminal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bbpos_wisepos_eObject (readonly)

Attribute for field bbpos_wisepos_e



1810
1811
1812
# File 'lib/stripe/resources/terminal/configuration.rb', line 1810

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#deletedObject (readonly)

Always true for a deleted object



1836
1837
1838
# File 'lib/stripe/resources/terminal/configuration.rb', line 1836

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



1812
1813
1814
# File 'lib/stripe/resources/terminal/configuration.rb', line 1812

def id
  @id
end

#is_account_defaultObject (readonly)

Whether this Configuration is the default for your account



1814
1815
1816
# File 'lib/stripe/resources/terminal/configuration.rb', line 1814

def 
  @is_account_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1816
1817
1818
# File 'lib/stripe/resources/terminal/configuration.rb', line 1816

def livemode
  @livemode
end

#nameObject (readonly)

String indicating the name of the Configuration object, set by the user



1818
1819
1820
# File 'lib/stripe/resources/terminal/configuration.rb', line 1818

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1820
1821
1822
# File 'lib/stripe/resources/terminal/configuration.rb', line 1820

def object
  @object
end

#offlineObject (readonly)

Attribute for field offline



1822
1823
1824
# File 'lib/stripe/resources/terminal/configuration.rb', line 1822

def offline
  @offline
end

#reader_securityObject (readonly)

Attribute for field reader_security



1824
1825
1826
# File 'lib/stripe/resources/terminal/configuration.rb', line 1824

def reader_security
  @reader_security
end

#reboot_windowObject (readonly)

Attribute for field reboot_window



1826
1827
1828
# File 'lib/stripe/resources/terminal/configuration.rb', line 1826

def reboot_window
  @reboot_window
end

#stripe_s700Object (readonly)

Attribute for field stripe_s700



1828
1829
1830
# File 'lib/stripe/resources/terminal/configuration.rb', line 1828

def stripe_s700
  @stripe_s700
end

#tippingObject (readonly)

Attribute for field tipping



1830
1831
1832
# File 'lib/stripe/resources/terminal/configuration.rb', line 1830

def tipping
  @tipping
end

#verifone_p400Object (readonly)

Attribute for field verifone_p400



1832
1833
1834
# File 'lib/stripe/resources/terminal/configuration.rb', line 1832

def verifone_p400
  @verifone_p400
end

#wifiObject (readonly)

Attribute for field wifi



1834
1835
1836
# File 'lib/stripe/resources/terminal/configuration.rb', line 1834

def wifi
  @wifi
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Configuration object.



1839
1840
1841
1842
1843
1844
1845
1846
# File 'lib/stripe/resources/terminal/configuration.rb', line 1839

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.delete(configuration, params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1849
1850
1851
1852
1853
1854
1855
1856
# File 'lib/stripe/resources/terminal/configuration.rb', line 1849

def self.delete(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



1901
1902
1903
# File 'lib/stripe/resources/terminal/configuration.rb', line 1901

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
# File 'lib/stripe/resources/terminal/configuration.rb', line 1888

def self.inner_class_types
  @inner_class_types = {
    bbpos_wisepos_e: BbposWiseposE,
    offline: Offline,
    reader_security: ReaderSecurity,
    reboot_window: RebootWindow,
    stripe_s700: StripeS700,
    tipping: Tipping,
    verifone_p400: VerifoneP400,
    wifi: Wifi,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Configuration objects.



1869
1870
1871
1872
1873
1874
1875
1876
# File 'lib/stripe/resources/terminal/configuration.rb', line 1869

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/terminal/configuration.rb', line 15

def self.object_name
  "terminal.configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Updates a new Configuration object.



1879
1880
1881
1882
1883
1884
1885
1886
# File 'lib/stripe/resources/terminal/configuration.rb', line 1879

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1859
1860
1861
1862
1863
1864
1865
1866
# File 'lib/stripe/resources/terminal/configuration.rb', line 1859

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end