Class: Stripe::Terminal::Configuration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Configuration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Overview
A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).
Defined Under Namespace
Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, UpdateParams, VerifoneP400, Wifi
Constant Summary collapse
- OBJECT_NAME =
"terminal.configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
readonly
Attribute for field bbpos_wisepos_e.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_account_default ⇒ Object
readonly
Whether this Configuration is the default for your account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#name ⇒ Object
readonly
String indicating the name of the Configuration object, set by the user.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#reader_security ⇒ Object
readonly
Attribute for field reader_security.
-
#reboot_window ⇒ Object
readonly
Attribute for field reboot_window.
-
#stripe_s700 ⇒ Object
readonly
Attribute for field stripe_s700.
-
#tipping ⇒ Object
readonly
Attribute for field tipping.
-
#verifone_p400 ⇒ Object
readonly
Attribute for field verifone_p400.
-
#wifi ⇒ Object
readonly
Attribute for field wifi.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
-
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object (readonly)
Attribute for field bbpos_wisepos_e
1528 1529 1530 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1528 def bbpos_wisepos_e @bbpos_wisepos_e end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
1554 1555 1556 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1554 def deleted @deleted end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1530 1531 1532 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1530 def id @id end |
#is_account_default ⇒ Object (readonly)
Whether this Configuration is the default for your account
1532 1533 1534 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1532 def is_account_default @is_account_default end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1534 1535 1536 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1534 def livemode @livemode end |
#name ⇒ Object (readonly)
String indicating the name of the Configuration object, set by the user
1536 1537 1538 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1536 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1538 1539 1540 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1538 def object @object end |
#offline ⇒ Object (readonly)
Attribute for field offline
1540 1541 1542 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1540 def offline @offline end |
#reader_security ⇒ Object (readonly)
Attribute for field reader_security
1542 1543 1544 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1542 def reader_security @reader_security end |
#reboot_window ⇒ Object (readonly)
Attribute for field reboot_window
1544 1545 1546 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1544 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object (readonly)
Attribute for field stripe_s700
1546 1547 1548 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1546 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object (readonly)
Attribute for field tipping
1548 1549 1550 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1548 def tipping @tipping end |
#verifone_p400 ⇒ Object (readonly)
Attribute for field verifone_p400
1550 1551 1552 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1550 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object (readonly)
Attribute for field wifi
1552 1553 1554 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1552 def wifi @wifi end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
1557 1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1557 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
1567 1568 1569 1570 1571 1572 1573 1574 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1567 def self.delete(configuration, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1587 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 15 def self.object_name "terminal.configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
1597 1598 1599 1600 1601 1602 1603 1604 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1597 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
1577 1578 1579 1580 1581 1582 1583 1584 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1577 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }), params: params, opts: opts ) end |