Class: Stripe::Terminal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/configuration.rb

Overview

A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).

Defined Under Namespace

Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, RebootWindow, StripeS700, Tipping, UpdateParams, VerifoneP400, Wifi

Constant Summary collapse

OBJECT_NAME =
"terminal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bbpos_wisepos_eObject (readonly)

Attribute for field bbpos_wisepos_e



1497
1498
1499
# File 'lib/stripe/resources/terminal/configuration.rb', line 1497

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#deletedObject (readonly)

Always true for a deleted object



1521
1522
1523
# File 'lib/stripe/resources/terminal/configuration.rb', line 1521

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



1499
1500
1501
# File 'lib/stripe/resources/terminal/configuration.rb', line 1499

def id
  @id
end

#is_account_defaultObject (readonly)

Whether this Configuration is the default for your account



1501
1502
1503
# File 'lib/stripe/resources/terminal/configuration.rb', line 1501

def 
  @is_account_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1503
1504
1505
# File 'lib/stripe/resources/terminal/configuration.rb', line 1503

def livemode
  @livemode
end

#nameObject (readonly)

String indicating the name of the Configuration object, set by the user



1505
1506
1507
# File 'lib/stripe/resources/terminal/configuration.rb', line 1505

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1507
1508
1509
# File 'lib/stripe/resources/terminal/configuration.rb', line 1507

def object
  @object
end

#offlineObject (readonly)

Attribute for field offline



1509
1510
1511
# File 'lib/stripe/resources/terminal/configuration.rb', line 1509

def offline
  @offline
end

#reboot_windowObject (readonly)

Attribute for field reboot_window



1511
1512
1513
# File 'lib/stripe/resources/terminal/configuration.rb', line 1511

def reboot_window
  @reboot_window
end

#stripe_s700Object (readonly)

Attribute for field stripe_s700



1513
1514
1515
# File 'lib/stripe/resources/terminal/configuration.rb', line 1513

def stripe_s700
  @stripe_s700
end

#tippingObject (readonly)

Attribute for field tipping



1515
1516
1517
# File 'lib/stripe/resources/terminal/configuration.rb', line 1515

def tipping
  @tipping
end

#verifone_p400Object (readonly)

Attribute for field verifone_p400



1517
1518
1519
# File 'lib/stripe/resources/terminal/configuration.rb', line 1517

def verifone_p400
  @verifone_p400
end

#wifiObject (readonly)

Attribute for field wifi



1519
1520
1521
# File 'lib/stripe/resources/terminal/configuration.rb', line 1519

def wifi
  @wifi
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Configuration object.



1524
1525
1526
1527
1528
1529
1530
1531
# File 'lib/stripe/resources/terminal/configuration.rb', line 1524

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.delete(configuration, params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1534
1535
1536
1537
1538
1539
1540
1541
# File 'lib/stripe/resources/terminal/configuration.rb', line 1534

def self.delete(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Configuration objects.



1554
1555
1556
1557
1558
1559
1560
1561
# File 'lib/stripe/resources/terminal/configuration.rb', line 1554

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/terminal/configuration.rb', line 15

def self.object_name
  "terminal.configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Updates a new Configuration object.



1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/stripe/resources/terminal/configuration.rb', line 1564

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1544
1545
1546
1547
1548
1549
1550
1551
# File 'lib/stripe/resources/terminal/configuration.rb', line 1544

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end