Class: Stripe::Terminal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/configuration.rb

Overview

A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the [Terminal configurations documentation](docs.stripe.com/terminal/fleet/configurations-overview).

Defined Under Namespace

Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, RebootWindow, StripeS700, Tipping, UpdateParams, VerifoneP400, Wifi

Constant Summary collapse

OBJECT_NAME =
"terminal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bbpos_wisepos_eObject (readonly)

Attribute for field bbpos_wisepos_e



1448
1449
1450
# File 'lib/stripe/resources/terminal/configuration.rb', line 1448

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#deletedObject (readonly)

Always true for a deleted object



1472
1473
1474
# File 'lib/stripe/resources/terminal/configuration.rb', line 1472

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



1450
1451
1452
# File 'lib/stripe/resources/terminal/configuration.rb', line 1450

def id
  @id
end

#is_account_defaultObject (readonly)

Whether this Configuration is the default for your account



1452
1453
1454
# File 'lib/stripe/resources/terminal/configuration.rb', line 1452

def 
  @is_account_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1454
1455
1456
# File 'lib/stripe/resources/terminal/configuration.rb', line 1454

def livemode
  @livemode
end

#nameObject (readonly)

String indicating the name of the Configuration object, set by the user



1456
1457
1458
# File 'lib/stripe/resources/terminal/configuration.rb', line 1456

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1458
1459
1460
# File 'lib/stripe/resources/terminal/configuration.rb', line 1458

def object
  @object
end

#offlineObject (readonly)

Attribute for field offline



1460
1461
1462
# File 'lib/stripe/resources/terminal/configuration.rb', line 1460

def offline
  @offline
end

#reboot_windowObject (readonly)

Attribute for field reboot_window



1462
1463
1464
# File 'lib/stripe/resources/terminal/configuration.rb', line 1462

def reboot_window
  @reboot_window
end

#stripe_s700Object (readonly)

Attribute for field stripe_s700



1464
1465
1466
# File 'lib/stripe/resources/terminal/configuration.rb', line 1464

def stripe_s700
  @stripe_s700
end

#tippingObject (readonly)

Attribute for field tipping



1466
1467
1468
# File 'lib/stripe/resources/terminal/configuration.rb', line 1466

def tipping
  @tipping
end

#verifone_p400Object (readonly)

Attribute for field verifone_p400



1468
1469
1470
# File 'lib/stripe/resources/terminal/configuration.rb', line 1468

def verifone_p400
  @verifone_p400
end

#wifiObject (readonly)

Attribute for field wifi



1470
1471
1472
# File 'lib/stripe/resources/terminal/configuration.rb', line 1470

def wifi
  @wifi
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Configuration object.



1475
1476
1477
1478
1479
1480
1481
1482
# File 'lib/stripe/resources/terminal/configuration.rb', line 1475

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.delete(configuration, params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1485
1486
1487
1488
1489
1490
1491
1492
# File 'lib/stripe/resources/terminal/configuration.rb', line 1485

def self.delete(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Configuration objects.



1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/stripe/resources/terminal/configuration.rb', line 1505

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/terminal/configuration.rb', line 15

def self.object_name
  "terminal.configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Updates a new Configuration object.



1515
1516
1517
1518
1519
1520
1521
1522
# File 'lib/stripe/resources/terminal/configuration.rb', line 1515

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/stripe/resources/terminal/configuration.rb', line 1495

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end