Class: Stripe::Terminal::Configuration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Configuration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Overview
A Configurations object represents how features should be configured for terminal readers.
Defined Under Namespace
Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, RebootWindow, StripeS700, Tipping, UpdateParams, VerifoneP400, Wifi
Constant Summary collapse
- OBJECT_NAME =
"terminal.configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
readonly
Attribute for field bbpos_wisepos_e.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_account_default ⇒ Object
readonly
Whether this Configuration is the default for your account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#name ⇒ Object
readonly
String indicating the name of the Configuration object, set by the user.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#reboot_window ⇒ Object
readonly
Attribute for field reboot_window.
-
#stripe_s700 ⇒ Object
readonly
Attribute for field stripe_s700.
-
#tipping ⇒ Object
readonly
Attribute for field tipping.
-
#verifone_p400 ⇒ Object
readonly
Attribute for field verifone_p400.
-
#wifi ⇒ Object
readonly
Attribute for field wifi.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
-
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
- .object_name ⇒ Object
-
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object (readonly)
Attribute for field bbpos_wisepos_e
1251 1252 1253 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1251 def bbpos_wisepos_e @bbpos_wisepos_e end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
1275 1276 1277 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1275 def deleted @deleted end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1253 1254 1255 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1253 def id @id end |
#is_account_default ⇒ Object (readonly)
Whether this Configuration is the default for your account
1255 1256 1257 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1255 def is_account_default @is_account_default end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1257 1258 1259 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1257 def livemode @livemode end |
#name ⇒ Object (readonly)
String indicating the name of the Configuration object, set by the user
1259 1260 1261 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1259 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1261 1262 1263 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1261 def object @object end |
#offline ⇒ Object (readonly)
Attribute for field offline
1263 1264 1265 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1263 def offline @offline end |
#reboot_window ⇒ Object (readonly)
Attribute for field reboot_window
1265 1266 1267 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1265 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object (readonly)
Attribute for field stripe_s700
1267 1268 1269 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1267 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object (readonly)
Attribute for field tipping
1269 1270 1271 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1269 def tipping @tipping end |
#verifone_p400 ⇒ Object (readonly)
Attribute for field verifone_p400
1271 1272 1273 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1271 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object (readonly)
Attribute for field wifi
1273 1274 1275 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1273 def wifi @wifi end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
1278 1279 1280 1281 1282 1283 1284 1285 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1278 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.delete(configuration, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
1288 1289 1290 1291 1292 1293 1294 1295 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1288 def self.delete(configuration, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
1308 1309 1310 1311 1312 1313 1314 1315 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1308 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 14 def self.object_name "terminal.configuration" end |
.update(configuration, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
1318 1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1318 def self.update(configuration, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
1298 1299 1300 1301 1302 1303 1304 1305 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1298 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }), params: params, opts: opts ) end |