Class: Stripe::Terminal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/configuration.rb

Overview

A Configurations object represents how features should be configured for terminal readers.

Defined Under Namespace

Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, RebootWindow, RetrieveParams, StripeS700, Tipping, UpdateParams, VerifoneP400

Constant Summary collapse

OBJECT_NAME =
"terminal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bbpos_wisepos_eObject (readonly)

Attribute for field bbpos_wisepos_e



1158
1159
1160
# File 'lib/stripe/resources/terminal/configuration.rb', line 1158

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#deletedObject (readonly)

Always true for a deleted object



1191
1192
1193
# File 'lib/stripe/resources/terminal/configuration.rb', line 1191

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



1161
1162
1163
# File 'lib/stripe/resources/terminal/configuration.rb', line 1161

def id
  @id
end

#is_account_defaultObject (readonly)

Whether this Configuration is the default for your account



1164
1165
1166
# File 'lib/stripe/resources/terminal/configuration.rb', line 1164

def 
  @is_account_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1167
1168
1169
# File 'lib/stripe/resources/terminal/configuration.rb', line 1167

def livemode
  @livemode
end

#nameObject (readonly)

String indicating the name of the Configuration object, set by the user



1170
1171
1172
# File 'lib/stripe/resources/terminal/configuration.rb', line 1170

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1173
1174
1175
# File 'lib/stripe/resources/terminal/configuration.rb', line 1173

def object
  @object
end

#offlineObject (readonly)

Attribute for field offline



1176
1177
1178
# File 'lib/stripe/resources/terminal/configuration.rb', line 1176

def offline
  @offline
end

#reboot_windowObject (readonly)

Attribute for field reboot_window



1179
1180
1181
# File 'lib/stripe/resources/terminal/configuration.rb', line 1179

def reboot_window
  @reboot_window
end

#stripe_s700Object (readonly)

Attribute for field stripe_s700



1182
1183
1184
# File 'lib/stripe/resources/terminal/configuration.rb', line 1182

def stripe_s700
  @stripe_s700
end

#tippingObject (readonly)

Attribute for field tipping



1185
1186
1187
# File 'lib/stripe/resources/terminal/configuration.rb', line 1185

def tipping
  @tipping
end

#verifone_p400Object (readonly)

Attribute for field verifone_p400



1188
1189
1190
# File 'lib/stripe/resources/terminal/configuration.rb', line 1188

def verifone_p400
  @verifone_p400
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Configuration object.



1194
1195
1196
1197
1198
1199
1200
1201
# File 'lib/stripe/resources/terminal/configuration.rb', line 1194

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.delete(id, params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1204
1205
1206
1207
1208
1209
1210
1211
# File 'lib/stripe/resources/terminal/configuration.rb', line 1204

def self.delete(id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Configuration objects.



1224
1225
1226
1227
1228
1229
1230
1231
# File 'lib/stripe/resources/terminal/configuration.rb', line 1224

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/terminal/configuration.rb', line 14

def self.object_name
  "terminal.configuration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a new Configuration object.



1234
1235
1236
1237
1238
1239
1240
1241
# File 'lib/stripe/resources/terminal/configuration.rb', line 1234

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1214
1215
1216
1217
1218
1219
1220
1221
# File 'lib/stripe/resources/terminal/configuration.rb', line 1214

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end