Class: Stripe::Terminal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/configuration.rb

Overview

A Configurations object represents how features should be configured for terminal readers.

Defined Under Namespace

Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, RebootWindow, RetrieveParams, StripeS700, Tipping, UpdateParams, VerifoneP400

Constant Summary collapse

OBJECT_NAME =
"terminal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bbpos_wisepos_eObject (readonly)

Attribute for field bbpos_wisepos_e



1005
1006
1007
# File 'lib/stripe/resources/terminal/configuration.rb', line 1005

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#deletedObject (readonly)

Always true for a deleted object



1027
1028
1029
# File 'lib/stripe/resources/terminal/configuration.rb', line 1027

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



1007
1008
1009
# File 'lib/stripe/resources/terminal/configuration.rb', line 1007

def id
  @id
end

#is_account_defaultObject (readonly)

Whether this Configuration is the default for your account



1009
1010
1011
# File 'lib/stripe/resources/terminal/configuration.rb', line 1009

def 
  @is_account_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1011
1012
1013
# File 'lib/stripe/resources/terminal/configuration.rb', line 1011

def livemode
  @livemode
end

#nameObject (readonly)

String indicating the name of the Configuration object, set by the user



1013
1014
1015
# File 'lib/stripe/resources/terminal/configuration.rb', line 1013

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1015
1016
1017
# File 'lib/stripe/resources/terminal/configuration.rb', line 1015

def object
  @object
end

#offlineObject (readonly)

Attribute for field offline



1017
1018
1019
# File 'lib/stripe/resources/terminal/configuration.rb', line 1017

def offline
  @offline
end

#reboot_windowObject (readonly)

Attribute for field reboot_window



1019
1020
1021
# File 'lib/stripe/resources/terminal/configuration.rb', line 1019

def reboot_window
  @reboot_window
end

#stripe_s700Object (readonly)

Attribute for field stripe_s700



1021
1022
1023
# File 'lib/stripe/resources/terminal/configuration.rb', line 1021

def stripe_s700
  @stripe_s700
end

#tippingObject (readonly)

Attribute for field tipping



1023
1024
1025
# File 'lib/stripe/resources/terminal/configuration.rb', line 1023

def tipping
  @tipping
end

#verifone_p400Object (readonly)

Attribute for field verifone_p400



1025
1026
1027
# File 'lib/stripe/resources/terminal/configuration.rb', line 1025

def verifone_p400
  @verifone_p400
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Configuration object.



1030
1031
1032
1033
1034
1035
1036
1037
# File 'lib/stripe/resources/terminal/configuration.rb', line 1030

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.delete(id, params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1040
1041
1042
1043
1044
1045
1046
1047
# File 'lib/stripe/resources/terminal/configuration.rb', line 1040

def self.delete(id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Configuration objects.



1060
1061
1062
1063
1064
1065
1066
1067
# File 'lib/stripe/resources/terminal/configuration.rb', line 1060

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/terminal/configuration.rb', line 14

def self.object_name
  "terminal.configuration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a new Configuration object.



1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/stripe/resources/terminal/configuration.rb', line 1070

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1050
1051
1052
1053
1054
1055
1056
1057
# File 'lib/stripe/resources/terminal/configuration.rb', line 1050

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end