Class: Stripe::Terminal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/configuration.rb

Overview

A Configurations object represents how features should be configured for terminal readers.

Defined Under Namespace

Classes: BbposWiseposE, CreateParams, DeleteParams, ListParams, Offline, RebootWindow, RetrieveParams, StripeS700, Tipping, UpdateParams, VerifoneP400

Constant Summary collapse

OBJECT_NAME =
"terminal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bbpos_wisepos_eObject (readonly)

Attribute for field bbpos_wisepos_e



1054
1055
1056
# File 'lib/stripe/resources/terminal/configuration.rb', line 1054

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#deletedObject (readonly)

Always true for a deleted object



1076
1077
1078
# File 'lib/stripe/resources/terminal/configuration.rb', line 1076

def deleted
  @deleted
end

#idObject (readonly)

Unique identifier for the object.



1056
1057
1058
# File 'lib/stripe/resources/terminal/configuration.rb', line 1056

def id
  @id
end

#is_account_defaultObject (readonly)

Whether this Configuration is the default for your account



1058
1059
1060
# File 'lib/stripe/resources/terminal/configuration.rb', line 1058

def 
  @is_account_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1060
1061
1062
# File 'lib/stripe/resources/terminal/configuration.rb', line 1060

def livemode
  @livemode
end

#nameObject (readonly)

String indicating the name of the Configuration object, set by the user



1062
1063
1064
# File 'lib/stripe/resources/terminal/configuration.rb', line 1062

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1064
1065
1066
# File 'lib/stripe/resources/terminal/configuration.rb', line 1064

def object
  @object
end

#offlineObject (readonly)

Attribute for field offline



1066
1067
1068
# File 'lib/stripe/resources/terminal/configuration.rb', line 1066

def offline
  @offline
end

#reboot_windowObject (readonly)

Attribute for field reboot_window



1068
1069
1070
# File 'lib/stripe/resources/terminal/configuration.rb', line 1068

def reboot_window
  @reboot_window
end

#stripe_s700Object (readonly)

Attribute for field stripe_s700



1070
1071
1072
# File 'lib/stripe/resources/terminal/configuration.rb', line 1070

def stripe_s700
  @stripe_s700
end

#tippingObject (readonly)

Attribute for field tipping



1072
1073
1074
# File 'lib/stripe/resources/terminal/configuration.rb', line 1072

def tipping
  @tipping
end

#verifone_p400Object (readonly)

Attribute for field verifone_p400



1074
1075
1076
# File 'lib/stripe/resources/terminal/configuration.rb', line 1074

def verifone_p400
  @verifone_p400
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Configuration object.



1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/stripe/resources/terminal/configuration.rb', line 1079

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.delete(id, params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/stripe/resources/terminal/configuration.rb', line 1089

def self.delete(id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Configuration objects.



1109
1110
1111
1112
1113
1114
1115
1116
# File 'lib/stripe/resources/terminal/configuration.rb', line 1109

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/terminal/configuration.rb', line 14

def self.object_name
  "terminal.configuration"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a new Configuration object.



1119
1120
1121
1122
1123
1124
1125
1126
# File 'lib/stripe/resources/terminal/configuration.rb', line 1119

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Configuration object.



1099
1100
1101
1102
1103
1104
1105
1106
# File 'lib/stripe/resources/terminal/configuration.rb', line 1099

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end