Class: Stripe::Terminal::Configuration
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Configuration
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Overview
A Configurations object represents how features should be configured for terminal readers.
Defined Under Namespace
Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400
Constant Summary collapse
- OBJECT_NAME =
"terminal.configuration"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
readonly
Attribute for field bbpos_wisepos_e.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_account_default ⇒ Object
readonly
Whether this Configuration is the default for your account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#name ⇒ Object
readonly
String indicating the name of the Configuration object, set by the user.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#offline ⇒ Object
readonly
Attribute for field offline.
-
#reboot_window ⇒ Object
readonly
Attribute for field reboot_window.
-
#stripe_s700 ⇒ Object
readonly
Attribute for field stripe_s700.
-
#tipping ⇒ Object
readonly
Attribute for field tipping.
-
#verifone_p400 ⇒ Object
readonly
Attribute for field verifone_p400.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
-
.delete(id, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object (readonly)
Attribute for field bbpos_wisepos_e
101 102 103 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 101 def bbpos_wisepos_e @bbpos_wisepos_e end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
123 124 125 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 123 def deleted @deleted end |
#id ⇒ Object (readonly)
Unique identifier for the object.
103 104 105 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 103 def id @id end |
#is_account_default ⇒ Object (readonly)
Whether this Configuration is the default for your account
105 106 107 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 105 def is_account_default @is_account_default end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
107 108 109 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 107 def livemode @livemode end |
#name ⇒ Object (readonly)
String indicating the name of the Configuration object, set by the user
109 110 111 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 109 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
111 112 113 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 111 def object @object end |
#offline ⇒ Object (readonly)
Attribute for field offline
113 114 115 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 113 def offline @offline end |
#reboot_window ⇒ Object (readonly)
Attribute for field reboot_window
115 116 117 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 115 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object (readonly)
Attribute for field stripe_s700
117 118 119 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 117 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object (readonly)
Attribute for field tipping
119 120 121 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 119 def tipping @tipping end |
#verifone_p400 ⇒ Object (readonly)
Attribute for field verifone_p400
121 122 123 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 121 def verifone_p400 @verifone_p400 end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Configuration object.
126 127 128 129 130 131 132 133 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 126 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/configurations", params: params, opts: opts ) end |
.delete(id, params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
136 137 138 139 140 141 142 143 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 136 def self.delete(id, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Configuration objects.
156 157 158 159 160 161 162 163 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 156 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/configurations", params: filters, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 14 def self.object_name "terminal.configuration" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates a new Configuration object.
166 167 168 169 170 171 172 173 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 166 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/configurations/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Configuration object.
146 147 148 149 150 151 152 153 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 146 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/configurations/%<configuration>s", { configuration: CGI.escape(self["id"]) }), params: params, opts: opts ) end |