Class: Stripe::Terminal::Configuration::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
# File 'lib/stripe/resources/terminal/configuration.rb', line 1503

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reader_security: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reader_security = reader_security
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



1483
1484
1485
# File 'lib/stripe/resources/terminal/configuration.rb', line 1483

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



1485
1486
1487
# File 'lib/stripe/resources/terminal/configuration.rb', line 1485

def expand
  @expand
end

#nameObject

Name of the configuration



1487
1488
1489
# File 'lib/stripe/resources/terminal/configuration.rb', line 1487

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



1489
1490
1491
# File 'lib/stripe/resources/terminal/configuration.rb', line 1489

def offline
  @offline
end

#reader_securityObject

Configurations for reader security settings.



1491
1492
1493
# File 'lib/stripe/resources/terminal/configuration.rb', line 1491

def reader_security
  @reader_security
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



1493
1494
1495
# File 'lib/stripe/resources/terminal/configuration.rb', line 1493

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



1495
1496
1497
# File 'lib/stripe/resources/terminal/configuration.rb', line 1495

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



1497
1498
1499
# File 'lib/stripe/resources/terminal/configuration.rb', line 1497

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



1499
1500
1501
# File 'lib/stripe/resources/terminal/configuration.rb', line 1499

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



1501
1502
1503
# File 'lib/stripe/resources/terminal/configuration.rb', line 1501

def wifi
  @wifi
end