Class: Stripe::Terminal::Configuration::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::CreateParams
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1425 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
1407 1408 1409 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1407 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1409 1410 1411 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1409 def @expand end |
#name ⇒ Object
Name of the configuration
1411 1412 1413 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1411 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
1413 1414 1415 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1413 def offline @offline end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
1415 1416 1417 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1415 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
1417 1418 1419 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1417 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
1419 1420 1421 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1419 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
1421 1422 1423 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1421 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
1423 1424 1425 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1423 def wifi @wifi end |