Class: Stripe::Terminal::Configuration::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::ListParams
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#is_account_default ⇒ Object
if present, only return the account default or non-default configurations.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
757 758 759 760 761 762 763 764 765 766 767 768 769 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 757 def initialize( ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil ) @ending_before = ending_before @expand = @is_account_default = is_account_default @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
747 748 749 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 747 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
749 750 751 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 749 def @expand end |
#is_account_default ⇒ Object
if present, only return the account default or non-default configurations.
751 752 753 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 751 def is_account_default @is_account_default end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
753 754 755 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 753 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
755 756 757 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 755 def starting_after @starting_after end |