Class: Stripe::Terminal::Configuration::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::UpdateParams
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reader_security ⇒ Object
Configurations for reader security settings.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1171 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reader_security = reader_security @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
1151 1152 1153 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1151 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1153 1154 1155 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1153 def @expand end |
#name ⇒ Object
Name of the configuration
1155 1156 1157 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1155 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
1157 1158 1159 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1157 def offline @offline end |
#reader_security ⇒ Object
Configurations for reader security settings.
1159 1160 1161 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1159 def reader_security @reader_security end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
1161 1162 1163 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1161 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
1163 1164 1165 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1163 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
1165 1166 1167 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1165 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
1167 1168 1169 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1167 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
1169 1170 1171 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 1169 def wifi @wifi end |