Class: Stripe::Terminal::Configuration::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::UpdateParams
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reader_security ⇒ Object
Configurations for reader security settings.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 889 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reader_security = reader_security @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
869 870 871 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 869 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
871 872 873 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 871 def @expand end |
#name ⇒ Object
Name of the configuration
873 874 875 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 873 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
875 876 877 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 875 def offline @offline end |
#reader_security ⇒ Object
Configurations for reader security settings.
877 878 879 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 877 def reader_security @reader_security end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
879 880 881 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 879 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
881 882 883 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 881 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
883 884 885 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 883 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
885 886 887 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 885 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
887 888 889 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 887 def wifi @wifi end |