Class: Stripe::Terminal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
# File 'lib/stripe/resources/terminal/configuration.rb', line 873

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



855
856
857
# File 'lib/stripe/resources/terminal/configuration.rb', line 855

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



857
858
859
# File 'lib/stripe/resources/terminal/configuration.rb', line 857

def expand
  @expand
end

#nameObject

Name of the configuration



859
860
861
# File 'lib/stripe/resources/terminal/configuration.rb', line 859

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



861
862
863
# File 'lib/stripe/resources/terminal/configuration.rb', line 861

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



863
864
865
# File 'lib/stripe/resources/terminal/configuration.rb', line 863

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



865
866
867
# File 'lib/stripe/resources/terminal/configuration.rb', line 865

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



867
868
869
# File 'lib/stripe/resources/terminal/configuration.rb', line 867

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



869
870
871
# File 'lib/stripe/resources/terminal/configuration.rb', line 869

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



871
872
873
# File 'lib/stripe/resources/terminal/configuration.rb', line 871

def wifi
  @wifi
end