Class: Stripe::Terminal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
# File 'lib/stripe/resources/terminal/configuration.rb', line 843

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



825
826
827
# File 'lib/stripe/resources/terminal/configuration.rb', line 825

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



827
828
829
# File 'lib/stripe/resources/terminal/configuration.rb', line 827

def expand
  @expand
end

#nameObject

Name of the configuration



829
830
831
# File 'lib/stripe/resources/terminal/configuration.rb', line 829

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



831
832
833
# File 'lib/stripe/resources/terminal/configuration.rb', line 831

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



833
834
835
# File 'lib/stripe/resources/terminal/configuration.rb', line 833

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



835
836
837
# File 'lib/stripe/resources/terminal/configuration.rb', line 835

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



837
838
839
# File 'lib/stripe/resources/terminal/configuration.rb', line 837

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



839
840
841
# File 'lib/stripe/resources/terminal/configuration.rb', line 839

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



841
842
843
# File 'lib/stripe/resources/terminal/configuration.rb', line 841

def wifi
  @wifi
end