Class: Stripe::Terminal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
# File 'lib/stripe/resources/terminal/configuration.rb', line 722

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



704
705
706
# File 'lib/stripe/resources/terminal/configuration.rb', line 704

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



706
707
708
# File 'lib/stripe/resources/terminal/configuration.rb', line 706

def expand
  @expand
end

#nameObject

Name of the configuration



708
709
710
# File 'lib/stripe/resources/terminal/configuration.rb', line 708

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



710
711
712
# File 'lib/stripe/resources/terminal/configuration.rb', line 710

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



712
713
714
# File 'lib/stripe/resources/terminal/configuration.rb', line 712

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



714
715
716
# File 'lib/stripe/resources/terminal/configuration.rb', line 714

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



716
717
718
# File 'lib/stripe/resources/terminal/configuration.rb', line 716

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



718
719
720
# File 'lib/stripe/resources/terminal/configuration.rb', line 718

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



720
721
722
# File 'lib/stripe/resources/terminal/configuration.rb', line 720

def wifi
  @wifi
end