Class: Stripe::Terminal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'lib/stripe/resources/terminal/configuration.rb', line 677

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



654
655
656
# File 'lib/stripe/resources/terminal/configuration.rb', line 654

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



657
658
659
# File 'lib/stripe/resources/terminal/configuration.rb', line 657

def expand
  @expand
end

#nameObject

Name of the configuration



660
661
662
# File 'lib/stripe/resources/terminal/configuration.rb', line 660

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



663
664
665
# File 'lib/stripe/resources/terminal/configuration.rb', line 663

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



666
667
668
# File 'lib/stripe/resources/terminal/configuration.rb', line 666

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



669
670
671
# File 'lib/stripe/resources/terminal/configuration.rb', line 669

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



672
673
674
# File 'lib/stripe/resources/terminal/configuration.rb', line 672

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



675
676
677
# File 'lib/stripe/resources/terminal/configuration.rb', line 675

def verifone_p400
  @verifone_p400
end