Class: Stripe::Terminal::Configuration::UpdateParams::Wifi

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/configuration.rb

Defined Under Namespace

Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi

Returns a new instance of Wifi.



856
857
858
859
860
861
862
863
864
865
866
# File 'lib/stripe/resources/terminal/configuration.rb', line 856

def initialize(
  enterprise_eap_peap: nil,
  enterprise_eap_tls: nil,
  personal_psk: nil,
  type: nil
)
  @enterprise_eap_peap = enterprise_eap_peap
  @enterprise_eap_tls = enterprise_eap_tls
  @personal_psk = personal_psk
  @type = type
end

Instance Attribute Details

#enterprise_eap_peapObject

Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.



848
849
850
# File 'lib/stripe/resources/terminal/configuration.rb', line 848

def enterprise_eap_peap
  @enterprise_eap_peap
end

#enterprise_eap_tlsObject

Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.



850
851
852
# File 'lib/stripe/resources/terminal/configuration.rb', line 850

def enterprise_eap_tls
  @enterprise_eap_tls
end

#personal_pskObject

Credentials for a WPA-Personal WiFi network.



852
853
854
# File 'lib/stripe/resources/terminal/configuration.rb', line 852

def personal_psk
  @personal_psk
end

#typeObject

Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.



854
855
856
# File 'lib/stripe/resources/terminal/configuration.rb', line 854

def type
  @type
end