Class: Stripe::Terminal::Configuration::UpdateParams::Wifi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Configuration::UpdateParams::Wifi
- Defined in:
- lib/stripe/resources/terminal/configuration.rb
Defined Under Namespace
Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk
Instance Attribute Summary collapse
-
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
-
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
-
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
-
#type ⇒ Object
Security type of the WiFi network.
Instance Method Summary collapse
-
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
constructor
A new instance of Wifi.
Methods inherited from RequestParams
Constructor Details
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
Returns a new instance of Wifi.
691 692 693 694 695 696 697 698 699 700 701 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 691 def initialize( enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil ) @enterprise_eap_peap = enterprise_eap_peap @enterprise_eap_tls = enterprise_eap_tls @personal_psk = personal_psk @type = type end |
Instance Attribute Details
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
683 684 685 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 683 def enterprise_eap_peap @enterprise_eap_peap end |
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
685 686 687 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 685 def enterprise_eap_tls @enterprise_eap_tls end |
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
687 688 689 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 687 def personal_psk @personal_psk end |
#type ⇒ Object
Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.
689 690 691 |
# File 'lib/stripe/resources/terminal/configuration.rb', line 689 def type @type end |