Class: Stripe::Terminal::ConfigurationCreateParams::Wifi

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/configuration_create_params.rb

Defined Under Namespace

Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi

Returns a new instance of Wifi.



562
563
564
565
566
567
568
569
570
571
572
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 562

def initialize(
  enterprise_eap_peap: nil,
  enterprise_eap_tls: nil,
  personal_psk: nil,
  type: nil
)
  @enterprise_eap_peap = enterprise_eap_peap
  @enterprise_eap_tls = enterprise_eap_tls
  @personal_psk = personal_psk
  @type = type
end

Instance Attribute Details

#enterprise_eap_peapObject

Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.



554
555
556
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 554

def enterprise_eap_peap
  @enterprise_eap_peap
end

#enterprise_eap_tlsObject

Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.



556
557
558
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 556

def enterprise_eap_tls
  @enterprise_eap_tls
end

#personal_pskObject

Credentials for a WPA-Personal WiFi network.



558
559
560
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 558

def personal_psk
  @personal_psk
end

#typeObject

Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.



560
561
562
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 560

def type
  @type
end