Class: Stripe::Terminal::ConfigurationCreateParams::Wifi

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/configuration_create_params.rb

Defined Under Namespace

Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi

Returns a new instance of Wifi.



544
545
546
547
548
549
550
551
552
553
554
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 544

def initialize(
  enterprise_eap_peap: nil,
  enterprise_eap_tls: nil,
  personal_psk: nil,
  type: nil
)
  @enterprise_eap_peap = enterprise_eap_peap
  @enterprise_eap_tls = enterprise_eap_tls
  @personal_psk = personal_psk
  @type = type
end

Instance Attribute Details

#enterprise_eap_peapObject

Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.



536
537
538
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 536

def enterprise_eap_peap
  @enterprise_eap_peap
end

#enterprise_eap_tlsObject

Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.



538
539
540
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 538

def enterprise_eap_tls
  @enterprise_eap_tls
end

#personal_pskObject

Credentials for a WPA-Personal WiFi network.



540
541
542
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 540

def personal_psk
  @personal_psk
end

#typeObject

Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.



542
543
544
# File 'lib/stripe/params/terminal/configuration_create_params.rb', line 542

def type
  @type
end