Class: Stripe::Terminal::ConfigurationService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reader_security ⇒ Object
Configurations for reader security settings.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1194 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reader_security = reader_security @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
1174 1175 1176 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1174 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1176 1177 1178 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1176 def @expand end |
#name ⇒ Object
Name of the configuration
1178 1179 1180 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1178 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
1180 1181 1182 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1180 def offline @offline end |
#reader_security ⇒ Object
Configurations for reader security settings.
1182 1183 1184 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1182 def reader_security @reader_security end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
1184 1185 1186 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1184 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
1186 1187 1188 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1186 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
1188 1189 1190 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1188 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
1190 1191 1192 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1190 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
1192 1193 1194 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1192 def wifi @wifi end |