Class: Stripe::Terminal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1170

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



1152
1153
1154
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1152

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



1154
1155
1156
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1154

def expand
  @expand
end

#nameObject

Name of the configuration



1156
1157
1158
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1156

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



1158
1159
1160
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1158

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



1160
1161
1162
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1160

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



1162
1163
1164
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1162

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



1164
1165
1166
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1164

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



1166
1167
1168
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1166

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



1168
1169
1170
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1168

def wifi
  @wifi
end