Class: Stripe::Terminal::ConfigurationService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1170 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
1152 1153 1154 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1152 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1154 1155 1156 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1154 def @expand end |
#name ⇒ Object
Name of the configuration
1156 1157 1158 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1156 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
1158 1159 1160 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1158 def offline @offline end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
1160 1161 1162 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1160 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
1162 1163 1164 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1162 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
1164 1165 1166 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1164 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
1166 1167 1168 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1166 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
1168 1169 1170 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1168 def wifi @wifi end |