Class: Stripe::Terminal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1132

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



1114
1115
1116
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1114

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



1116
1117
1118
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1116

def expand
  @expand
end

#nameObject

Name of the configuration



1118
1119
1120
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1118

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



1120
1121
1122
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1120

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



1122
1123
1124
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1122

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



1124
1125
1126
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1124

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



1126
1127
1128
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1126

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



1128
1129
1130
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1128

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



1130
1131
1132
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1130

def wifi
  @wifi
end