Class: Stripe::Terminal::ConfigurationService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 980 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
962 963 964 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 962 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
964 965 966 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 964 def @expand end |
#name ⇒ Object
Name of the configuration
966 967 968 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 966 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
968 969 970 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 968 def offline @offline end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
970 971 972 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 970 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
972 973 974 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 972 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
974 975 976 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 974 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
976 977 978 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 976 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
978 979 980 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 978 def wifi @wifi end |