Class: Stripe::Terminal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
# File 'lib/stripe/services/terminal/configuration_service.rb', line 817

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



801
802
803
# File 'lib/stripe/services/terminal/configuration_service.rb', line 801

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



803
804
805
# File 'lib/stripe/services/terminal/configuration_service.rb', line 803

def expand
  @expand
end

#nameObject

Name of the configuration



805
806
807
# File 'lib/stripe/services/terminal/configuration_service.rb', line 805

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



807
808
809
# File 'lib/stripe/services/terminal/configuration_service.rb', line 807

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



809
810
811
# File 'lib/stripe/services/terminal/configuration_service.rb', line 809

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



811
812
813
# File 'lib/stripe/services/terminal/configuration_service.rb', line 811

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



813
814
815
# File 'lib/stripe/services/terminal/configuration_service.rb', line 813

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



815
816
817
# File 'lib/stripe/services/terminal/configuration_service.rb', line 815

def verifone_p400
  @verifone_p400
end