Class: Stripe::Terminal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
# File 'lib/stripe/services/terminal/configuration_service.rb', line 887

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



864
865
866
# File 'lib/stripe/services/terminal/configuration_service.rb', line 864

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



867
868
869
# File 'lib/stripe/services/terminal/configuration_service.rb', line 867

def expand
  @expand
end

#nameObject

Name of the configuration



870
871
872
# File 'lib/stripe/services/terminal/configuration_service.rb', line 870

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



873
874
875
# File 'lib/stripe/services/terminal/configuration_service.rb', line 873

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



876
877
878
# File 'lib/stripe/services/terminal/configuration_service.rb', line 876

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



879
880
881
# File 'lib/stripe/services/terminal/configuration_service.rb', line 879

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



882
883
884
# File 'lib/stripe/services/terminal/configuration_service.rb', line 882

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



885
886
887
# File 'lib/stripe/services/terminal/configuration_service.rb', line 885

def verifone_p400
  @verifone_p400
end