Class: Stripe::Terminal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/stripe/services/terminal/configuration_service.rb', line 779

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



763
764
765
# File 'lib/stripe/services/terminal/configuration_service.rb', line 763

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



765
766
767
# File 'lib/stripe/services/terminal/configuration_service.rb', line 765

def expand
  @expand
end

#nameObject

Name of the configuration



767
768
769
# File 'lib/stripe/services/terminal/configuration_service.rb', line 767

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



769
770
771
# File 'lib/stripe/services/terminal/configuration_service.rb', line 769

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



771
772
773
# File 'lib/stripe/services/terminal/configuration_service.rb', line 771

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



773
774
775
# File 'lib/stripe/services/terminal/configuration_service.rb', line 773

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



775
776
777
# File 'lib/stripe/services/terminal/configuration_service.rb', line 775

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



777
778
779
# File 'lib/stripe/services/terminal/configuration_service.rb', line 777

def verifone_p400
  @verifone_p400
end