Class: Stripe::Terminal::ConfigurationService::CreateParams::Wifi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams::Wifi
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk
Instance Attribute Summary collapse
-
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
-
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
-
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
-
#type ⇒ Object
Security type of the WiFi network.
Instance Method Summary collapse
-
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
constructor
A new instance of Wifi.
Methods inherited from RequestParams
Constructor Details
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
Returns a new instance of Wifi.
1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1161 def initialize( enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil ) @enterprise_eap_peap = enterprise_eap_peap @enterprise_eap_tls = enterprise_eap_tls @personal_psk = personal_psk @type = type end |
Instance Attribute Details
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
1153 1154 1155 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1153 def enterprise_eap_peap @enterprise_eap_peap end |
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
1155 1156 1157 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1155 def enterprise_eap_tls @enterprise_eap_tls end |
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
1157 1158 1159 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1157 def personal_psk @personal_psk end |
#type ⇒ Object
Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.
1159 1160 1161 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1159 def type @type end |