Class: Stripe::Terminal::ConfigurationService::CreateParams::Wifi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::CreateParams::Wifi
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk
Instance Attribute Summary collapse
-
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
-
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
-
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
-
#type ⇒ Object
Security type of the WiFi network.
Instance Method Summary collapse
-
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
constructor
A new instance of Wifi.
Methods inherited from RequestParams
Constructor Details
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
Returns a new instance of Wifi.
1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1101 def initialize( enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil ) @enterprise_eap_peap = enterprise_eap_peap @enterprise_eap_tls = enterprise_eap_tls @personal_psk = personal_psk @type = type end |
Instance Attribute Details
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
1093 1094 1095 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1093 def enterprise_eap_peap @enterprise_eap_peap end |
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
1095 1096 1097 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1095 def enterprise_eap_tls @enterprise_eap_tls end |
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
1097 1098 1099 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1097 def personal_psk @personal_psk end |
#type ⇒ Object
Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.
1099 1100 1101 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 1099 def type @type end |