Class: Stripe::Terminal::ConfigurationService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, is_account_default: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/stripe/services/terminal/configuration_service.rb', line 408

def initialize(
  ending_before: nil,
  expand: nil,
  is_account_default: nil,
  limit: nil,
  starting_after: nil
)
  @ending_before = ending_before
  @expand = expand
  @is_account_default = 
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



398
399
400
# File 'lib/stripe/services/terminal/configuration_service.rb', line 398

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



400
401
402
# File 'lib/stripe/services/terminal/configuration_service.rb', line 400

def expand
  @expand
end

#is_account_defaultObject

if present, only return the account default or non-default configurations.



402
403
404
# File 'lib/stripe/services/terminal/configuration_service.rb', line 402

def 
  @is_account_default
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



404
405
406
# File 'lib/stripe/services/terminal/configuration_service.rb', line 404

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



406
407
408
# File 'lib/stripe/services/terminal/configuration_service.rb', line 406

def starting_after
  @starting_after
end