Class: Stripe::Terminal::ConfigurationService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::UpdateParams
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 474 def initialize( bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepos_e = bbpos_wisepos_e @expand = @name = name @offline = offline @reboot_window = reboot_window @stripe_s700 = stripe_s700 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers
456 457 458 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 456 def bbpos_wisepos_e @bbpos_wisepos_e end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
458 459 460 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 458 def @expand end |
#name ⇒ Object
Name of the configuration
460 461 462 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 460 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
462 463 464 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 462 def offline @offline end |
#reboot_window ⇒ Object
Reboot time settings for readers that support customized reboot time configuration.
464 465 466 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 464 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers
466 467 468 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 466 def stripe_s700 @stripe_s700 end |
#tipping ⇒ Object
Tipping configurations for readers supporting on-reader tips
468 469 470 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 468 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers
470 471 472 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 470 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
472 473 474 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 472 def wifi @wifi end |