Class: Stripe::Terminal::ConfigurationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/stripe/services/terminal/configuration_service.rb', line 427

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



404
405
406
# File 'lib/stripe/services/terminal/configuration_service.rb', line 404

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



407
408
409
# File 'lib/stripe/services/terminal/configuration_service.rb', line 407

def expand
  @expand
end

#nameObject

Name of the configuration



410
411
412
# File 'lib/stripe/services/terminal/configuration_service.rb', line 410

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



413
414
415
# File 'lib/stripe/services/terminal/configuration_service.rb', line 413

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



416
417
418
# File 'lib/stripe/services/terminal/configuration_service.rb', line 416

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



419
420
421
# File 'lib/stripe/services/terminal/configuration_service.rb', line 419

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



422
423
424
# File 'lib/stripe/services/terminal/configuration_service.rb', line 422

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



425
426
427
# File 'lib/stripe/services/terminal/configuration_service.rb', line 425

def verifone_p400
  @verifone_p400
end