Class: Stripe::Terminal::ConfigurationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/configuration_service.rb

Defined Under Namespace

Classes: BbposWiseposE, Offline, RebootWindow, StripeS700, Tipping, VerifoneP400

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/stripe/services/terminal/configuration_service.rb', line 375

def initialize(
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil
)
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
end

Instance Attribute Details

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers



359
360
361
# File 'lib/stripe/services/terminal/configuration_service.rb', line 359

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



361
362
363
# File 'lib/stripe/services/terminal/configuration_service.rb', line 361

def expand
  @expand
end

#nameObject

Name of the configuration



363
364
365
# File 'lib/stripe/services/terminal/configuration_service.rb', line 363

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



365
366
367
# File 'lib/stripe/services/terminal/configuration_service.rb', line 365

def offline
  @offline
end

#reboot_windowObject

Reboot time settings for readers that support customized reboot time configuration.



367
368
369
# File 'lib/stripe/services/terminal/configuration_service.rb', line 367

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers



369
370
371
# File 'lib/stripe/services/terminal/configuration_service.rb', line 369

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers supporting on-reader tips



371
372
373
# File 'lib/stripe/services/terminal/configuration_service.rb', line 371

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers



373
374
375
# File 'lib/stripe/services/terminal/configuration_service.rb', line 373

def verifone_p400
  @verifone_p400
end