Class: Stripe::Terminal::ConfigurationService::UpdateParams::Wifi
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationService::UpdateParams::Wifi
- Defined in:
- lib/stripe/services/terminal/configuration_service.rb
Defined Under Namespace
Classes: EnterpriseEapPeap, EnterpriseEapTls, PersonalPsk
Instance Attribute Summary collapse
-
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
-
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
-
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
-
#type ⇒ Object
Security type of the WiFi network.
Instance Method Summary collapse
-
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
constructor
A new instance of Wifi.
Methods inherited from RequestParams
Constructor Details
#initialize(enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil) ⇒ Wifi
Returns a new instance of Wifi.
519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 519 def initialize( enterprise_eap_peap: nil, enterprise_eap_tls: nil, personal_psk: nil, type: nil ) @enterprise_eap_peap = enterprise_eap_peap @enterprise_eap_tls = enterprise_eap_tls @personal_psk = personal_psk @type = type end |
Instance Attribute Details
#enterprise_eap_peap ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
511 512 513 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 511 def enterprise_eap_peap @enterprise_eap_peap end |
#enterprise_eap_tls ⇒ Object
Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
513 514 515 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 513 def enterprise_eap_tls @enterprise_eap_tls end |
#personal_psk ⇒ Object
Credentials for a WPA-Personal WiFi network.
515 516 517 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 515 def personal_psk @personal_psk end |
#type ⇒ Object
Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.
517 518 519 |
# File 'lib/stripe/services/terminal/configuration_service.rb', line 517 def type @type end |