Class: Stripe::Terminal::ConfigurationUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationUpdateParams
- Defined in:
- lib/stripe/params/terminal/configuration_update_params.rb
Defined Under Namespace
Classes: BbposWisepad3, BbposWiseposE, Cellular, Offline, ReaderSecurity, RebootWindow, StripeS700, StripeS710, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepad3 ⇒ Object
An object containing device type specific settings for BBPOS WisePad 3 readers.
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#cellular ⇒ Object
Configuration for cellular connectivity.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reader_security ⇒ Object
Configurations for reader security settings.
-
#reboot_window ⇒ Object
Reboot time settings for readers.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#stripe_s710 ⇒ Object
An object containing device type specific settings for Stripe S710 readers.
-
#tipping ⇒ Object
Tipping configurations for readers that support on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ ConfigurationUpdateParams
constructor
A new instance of ConfigurationUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ ConfigurationUpdateParams
Returns a new instance of ConfigurationUpdateParams.
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 601 def initialize( bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepad3 = bbpos_wisepad3 @bbpos_wisepos_e = bbpos_wisepos_e @cellular = cellular @expand = @name = name @offline = offline @reader_security = reader_security @reboot_window = reboot_window @stripe_s700 = stripe_s700 @stripe_s710 = stripe_s710 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepad3 ⇒ Object
An object containing device type specific settings for BBPOS WisePad 3 readers.
575 576 577 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 575 def bbpos_wisepad3 @bbpos_wisepad3 end |
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
577 578 579 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 577 def bbpos_wisepos_e @bbpos_wisepos_e end |
#cellular ⇒ Object
Configuration for cellular connectivity.
579 580 581 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 579 def cellular @cellular end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
581 582 583 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 581 def @expand end |
#name ⇒ Object
Name of the configuration
583 584 585 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 583 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
585 586 587 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 585 def offline @offline end |
#reader_security ⇒ Object
Configurations for reader security settings.
587 588 589 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 587 def reader_security @reader_security end |
#reboot_window ⇒ Object
Reboot time settings for readers. that support customized reboot time configuration.
589 590 591 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 589 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
591 592 593 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 591 def stripe_s700 @stripe_s700 end |
#stripe_s710 ⇒ Object
An object containing device type specific settings for Stripe S710 readers.
593 594 595 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 593 def stripe_s710 @stripe_s710 end |
#tipping ⇒ Object
Tipping configurations for readers that support on-reader tips.
595 596 597 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 595 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
597 598 599 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 597 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
599 600 601 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 599 def wifi @wifi end |