Class: Stripe::Terminal::ConfigurationUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/terminal/configuration_update_params.rb

Defined Under Namespace

Classes: BbposWisepad3, BbposWiseposE, Offline, ReaderSecurity, RebootWindow, StripeS700, Tipping, VerifoneP400, Wifi

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bbpos_wisepad3: nil, bbpos_wisepos_e: nil, expand: nil, name: nil, offline: nil, reader_security: nil, reboot_window: nil, stripe_s700: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ ConfigurationUpdateParams

Returns a new instance of ConfigurationUpdateParams.



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 598

def initialize(
  bbpos_wisepad3: nil,
  bbpos_wisepos_e: nil,
  expand: nil,
  name: nil,
  offline: nil,
  reader_security: nil,
  reboot_window: nil,
  stripe_s700: nil,
  tipping: nil,
  verifone_p400: nil,
  wifi: nil
)
  @bbpos_wisepad3 = bbpos_wisepad3
  @bbpos_wisepos_e = bbpos_wisepos_e
  @expand = expand
  @name = name
  @offline = offline
  @reader_security = reader_security
  @reboot_window = reboot_window
  @stripe_s700 = stripe_s700
  @tipping = tipping
  @verifone_p400 = verifone_p400
  @wifi = wifi
end

Instance Attribute Details

#bbpos_wisepad3Object

An object containing device type specific settings for BBPOS WisePad 3 readers.



576
577
578
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 576

def bbpos_wisepad3
  @bbpos_wisepad3
end

#bbpos_wisepos_eObject

An object containing device type specific settings for BBPOS WisePOS E readers.



578
579
580
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 578

def bbpos_wisepos_e
  @bbpos_wisepos_e
end

#expandObject

Specifies which fields in the response should be expanded.



580
581
582
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 580

def expand
  @expand
end

#nameObject

Name of the configuration



582
583
584
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 582

def name
  @name
end

#offlineObject

Configurations for collecting transactions offline.



584
585
586
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 584

def offline
  @offline
end

#reader_securityObject

Configurations for reader security settings.



586
587
588
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 586

def reader_security
  @reader_security
end

#reboot_windowObject

Reboot time settings for readers. that support customized reboot time configuration.



588
589
590
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 588

def reboot_window
  @reboot_window
end

#stripe_s700Object

An object containing device type specific settings for Stripe S700 readers.



590
591
592
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 590

def stripe_s700
  @stripe_s700
end

#tippingObject

Tipping configurations for readers. supporting on-reader tips



592
593
594
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 592

def tipping
  @tipping
end

#verifone_p400Object

An object containing device type specific settings for Verifone P400 readers.



594
595
596
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 594

def verifone_p400
  @verifone_p400
end

#wifiObject

Configurations for connecting to a WiFi network.



596
597
598
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 596

def wifi
  @wifi
end