Class: Stripe::Terminal::ConfigurationUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ConfigurationUpdateParams
- Defined in:
- lib/stripe/params/terminal/configuration_update_params.rb
Defined Under Namespace
Classes: BbposWisepad3, BbposWiseposE, Cellular, Offline, RebootWindow, StripeS700, StripeS710, Tipping, VerifoneP400, Wifi
Instance Attribute Summary collapse
-
#bbpos_wisepad3 ⇒ Object
An object containing device type specific settings for BBPOS WisePad 3 readers.
-
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
-
#cellular ⇒ Object
Configuration for cellular connectivity.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
Name of the configuration.
-
#offline ⇒ Object
Configurations for collecting transactions offline.
-
#reboot_window ⇒ Object
Reboot time settings for readers.
-
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
-
#stripe_s710 ⇒ Object
An object containing device type specific settings for Stripe S710 readers.
-
#tipping ⇒ Object
Tipping configurations for readers that support on-reader tips.
-
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
-
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
Instance Method Summary collapse
-
#initialize(bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ ConfigurationUpdateParams
constructor
A new instance of ConfigurationUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil) ⇒ ConfigurationUpdateParams
Returns a new instance of ConfigurationUpdateParams.
590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 590 def initialize( bbpos_wisepad3: nil, bbpos_wisepos_e: nil, cellular: nil, expand: nil, name: nil, offline: nil, reboot_window: nil, stripe_s700: nil, stripe_s710: nil, tipping: nil, verifone_p400: nil, wifi: nil ) @bbpos_wisepad3 = bbpos_wisepad3 @bbpos_wisepos_e = bbpos_wisepos_e @cellular = cellular = @name = name @offline = offline @reboot_window = reboot_window @stripe_s700 = stripe_s700 @stripe_s710 = stripe_s710 @tipping = tipping @verifone_p400 = verifone_p400 @wifi = wifi end |
Instance Attribute Details
#bbpos_wisepad3 ⇒ Object
An object containing device type specific settings for BBPOS WisePad 3 readers.
566 567 568 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 566 def bbpos_wisepad3 @bbpos_wisepad3 end |
#bbpos_wisepos_e ⇒ Object
An object containing device type specific settings for BBPOS WisePOS E readers.
568 569 570 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 568 def bbpos_wisepos_e @bbpos_wisepos_e end |
#cellular ⇒ Object
Configuration for cellular connectivity.
570 571 572 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 570 def cellular @cellular end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
572 573 574 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 572 def end |
#name ⇒ Object
Name of the configuration
574 575 576 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 574 def name @name end |
#offline ⇒ Object
Configurations for collecting transactions offline.
576 577 578 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 576 def offline @offline end |
#reboot_window ⇒ Object
Reboot time settings for readers. that support customized reboot time configuration.
578 579 580 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 578 def reboot_window @reboot_window end |
#stripe_s700 ⇒ Object
An object containing device type specific settings for Stripe S700 readers.
580 581 582 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 580 def stripe_s700 @stripe_s700 end |
#stripe_s710 ⇒ Object
An object containing device type specific settings for Stripe S710 readers.
582 583 584 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 582 def stripe_s710 @stripe_s710 end |
#tipping ⇒ Object
Tipping configurations for readers that support on-reader tips.
584 585 586 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 584 def tipping @tipping end |
#verifone_p400 ⇒ Object
An object containing device type specific settings for Verifone P400 readers.
586 587 588 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 586 def verifone_p400 @verifone_p400 end |
#wifi ⇒ Object
Configurations for connecting to a WiFi network.
588 589 590 |
# File 'lib/stripe/params/terminal/configuration_update_params.rb', line 588 def wifi @wifi end |