Class: Stripe::Terminal::Location

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/terminal/location.rb

Overview

A Location represents a grouping of readers.

Related guide: [Fleet management](stripe.com/docs/terminal/fleet/locations)

Defined Under Namespace

Classes: Address

Constant Summary collapse

OBJECT_NAME =
"terminal.location"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



24
25
26
# File 'lib/stripe/resources/terminal/location.rb', line 24

def address
  @address
end

#configuration_overridesObject (readonly)

The ID of a configuration that will be used to customize all readers in this location.



26
27
28
# File 'lib/stripe/resources/terminal/location.rb', line 26

def configuration_overrides
  @configuration_overrides
end

#deletedObject (readonly)

Always true for a deleted object



38
39
40
# File 'lib/stripe/resources/terminal/location.rb', line 38

def deleted
  @deleted
end

#display_nameObject (readonly)

The display name of the location.



28
29
30
# File 'lib/stripe/resources/terminal/location.rb', line 28

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



30
31
32
# File 'lib/stripe/resources/terminal/location.rb', line 30

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



32
33
34
# File 'lib/stripe/resources/terminal/location.rb', line 32

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



34
35
36
# File 'lib/stripe/resources/terminal/location.rb', line 34

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



36
37
38
# File 'lib/stripe/resources/terminal/location.rb', line 36

def object
  @object
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Location object. For further details, including which address fields are required in each country, see the [Manage locations](stripe.com/docs/terminal/fleet/locations) guide.



42
43
44
45
46
47
48
49
# File 'lib/stripe/resources/terminal/location.rb', line 42

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/terminal/locations",
    params: params,
    opts: opts
  )
end

.delete(id, params = {}, opts = {}) ⇒ Object

Deletes a Location object.



52
53
54
55
56
57
58
59
# File 'lib/stripe/resources/terminal/location.rb', line 52

def self.delete(id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/locations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.list(filters = {}, opts = {}) ⇒ Object

Returns a list of Location objects.



72
73
74
75
76
77
78
79
# File 'lib/stripe/resources/terminal/location.rb', line 72

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/terminal/locations",
    params: filters,
    opts: opts
  )
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/terminal/location.rb', line 16

def self.object_name
  "terminal.location"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a Location object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



82
83
84
85
86
87
88
89
# File 'lib/stripe/resources/terminal/location.rb', line 82

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/terminal/locations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes a Location object.



62
63
64
65
66
67
68
69
# File 'lib/stripe/resources/terminal/location.rb', line 62

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/terminal/locations/%<location>s", { location: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end