Class: Stripe::Terminal::Location::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Location::CreateParams
- Defined in:
- lib/stripe/resources/terminal/location.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The full address of the location.
-
#configuration_overrides ⇒ Object
The ID of a configuration that will be used to customize all readers in this location.
-
#display_name ⇒ Object
A name for the location.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/stripe/resources/terminal/location.rb', line 155 def initialize( address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil ) @address = address @configuration_overrides = configuration_overrides @display_name = display_name @expand = @metadata = end |
Instance Attribute Details
#address ⇒ Object
The full address of the location.
145 146 147 |
# File 'lib/stripe/resources/terminal/location.rb', line 145 def address @address end |
#configuration_overrides ⇒ Object
The ID of a configuration that will be used to customize all readers in this location.
147 148 149 |
# File 'lib/stripe/resources/terminal/location.rb', line 147 def configuration_overrides @configuration_overrides end |
#display_name ⇒ Object
A name for the location. Maximum length is 1000 characters.
149 150 151 |
# File 'lib/stripe/resources/terminal/location.rb', line 149 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
151 152 153 |
# File 'lib/stripe/resources/terminal/location.rb', line 151 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
153 154 155 |
# File 'lib/stripe/resources/terminal/location.rb', line 153 def @metadata end |