Class: Stripe::Terminal::Location::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/location.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/stripe/resources/terminal/location.rb', line 164

def initialize(
  address: nil,
  configuration_overrides: nil,
  display_name: nil,
  expand: nil,
  metadata: nil
)
  @address = address
  @configuration_overrides = configuration_overrides
  @display_name = display_name
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#addressObject

The full address of the location.



154
155
156
# File 'lib/stripe/resources/terminal/location.rb', line 154

def address
  @address
end

#configuration_overridesObject

The ID of a configuration that will be used to customize all readers in this location.



156
157
158
# File 'lib/stripe/resources/terminal/location.rb', line 156

def configuration_overrides
  @configuration_overrides
end

#display_nameObject

A name for the location. Maximum length is 1000 characters.



158
159
160
# File 'lib/stripe/resources/terminal/location.rb', line 158

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



160
161
162
# File 'lib/stripe/resources/terminal/location.rb', line 160

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



162
163
164
# File 'lib/stripe/resources/terminal/location.rb', line 162

def 
  @metadata
end