Class: Stripe::Terminal::Location::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Location::CreateParams
- Defined in:
- lib/stripe/resources/terminal/location.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
The full address of the location.
-
#configuration_overrides ⇒ Object
The ID of a configuration that will be used to customize all readers in this location.
-
#display_name ⇒ Object
A name for the location.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/stripe/resources/terminal/location.rb', line 190 def initialize( address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil ) @address = address @configuration_overrides = configuration_overrides @display_name = display_name @expand = @metadata = end |
Instance Attribute Details
#address ⇒ Object
The full address of the location.
176 177 178 |
# File 'lib/stripe/resources/terminal/location.rb', line 176 def address @address end |
#configuration_overrides ⇒ Object
The ID of a configuration that will be used to customize all readers in this location.
179 180 181 |
# File 'lib/stripe/resources/terminal/location.rb', line 179 def configuration_overrides @configuration_overrides end |
#display_name ⇒ Object
A name for the location. Maximum length is 1000 characters.
182 183 184 |
# File 'lib/stripe/resources/terminal/location.rb', line 182 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
185 186 187 |
# File 'lib/stripe/resources/terminal/location.rb', line 185 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
188 189 190 |
# File 'lib/stripe/resources/terminal/location.rb', line 188 def @metadata end |