Class: Stripe::Terminal::Location::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/location.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/stripe/resources/terminal/location.rb', line 103

def initialize(
  address: nil,
  configuration_overrides: nil,
  display_name: nil,
  expand: nil,
  metadata: nil
)
  @address = address
  @configuration_overrides = configuration_overrides
  @display_name = display_name
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#addressObject

The full address of the location. You can’t change the location’s ‘country`. If you need to modify the `country` field, create a new `Location` object and re-register any existing readers to that location.



89
90
91
# File 'lib/stripe/resources/terminal/location.rb', line 89

def address
  @address
end

#configuration_overridesObject

The ID of a configuration that will be used to customize all readers in this location.



92
93
94
# File 'lib/stripe/resources/terminal/location.rb', line 92

def configuration_overrides
  @configuration_overrides
end

#display_nameObject

A name for the location.



95
96
97
# File 'lib/stripe/resources/terminal/location.rb', line 95

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



98
99
100
# File 'lib/stripe/resources/terminal/location.rb', line 98

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



101
102
103
# File 'lib/stripe/resources/terminal/location.rb', line 101

def 
  @metadata
end