Class: Stripe::Terminal::LocationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/location_service.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, configuration_overrides: nil, display_name: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/stripe/services/terminal/location_service.rb', line 70

def initialize(
  address: nil,
  configuration_overrides: nil,
  display_name: nil,
  expand: nil,
  metadata: nil
)
  @address = address
  @configuration_overrides = configuration_overrides
  @display_name = display_name
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#addressObject

The full address of the location. You can’t change the location’s ‘country`. If you need to modify the `country` field, create a new `Location` object and re-register any existing readers to that location.



56
57
58
# File 'lib/stripe/services/terminal/location_service.rb', line 56

def address
  @address
end

#configuration_overridesObject

The ID of a configuration that will be used to customize all readers in this location.



59
60
61
# File 'lib/stripe/services/terminal/location_service.rb', line 59

def configuration_overrides
  @configuration_overrides
end

#display_nameObject

A name for the location.



62
63
64
# File 'lib/stripe/services/terminal/location_service.rb', line 62

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



65
66
67
# File 'lib/stripe/services/terminal/location_service.rb', line 65

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



68
69
70
# File 'lib/stripe/services/terminal/location_service.rb', line 68

def 
  @metadata
end