Class: Stripe::Terminal::OnboardingLink
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::OnboardingLink
- Extended by:
- APIOperations::Create
- Defined in:
- lib/stripe/resources/terminal/onboarding_link.rb
Overview
Returns redirect links used for onboarding onto Tap to Pay on iPhone.
Defined Under Namespace
Classes: CreateParams, LinkOptions
Constant Summary collapse
- OBJECT_NAME =
"terminal.onboarding_link"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#link_options ⇒ Object
readonly
Link type options associated with the current onboarding link object.
-
#link_type ⇒ Object
readonly
The type of link being generated.
-
#object ⇒ Object
readonly
Attribute for field object.
-
#on_behalf_of ⇒ Object
readonly
Stripe account ID to generate the link for.
-
#redirect_url ⇒ Object
readonly
The link passed back to the user for their onboarding.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new OnboardingLink object that contains a redirect_url used for onboarding onto Tap to Pay on iPhone.
- .object_name ⇒ Object
Methods included from APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#link_options ⇒ Object (readonly)
Link type options associated with the current onboarding link object.
63 64 65 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 63 def @link_options end |
#link_type ⇒ Object (readonly)
The type of link being generated.
65 66 67 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 65 def link_type @link_type end |
#object ⇒ Object (readonly)
Attribute for field object
67 68 69 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 67 def object @object end |
#on_behalf_of ⇒ Object (readonly)
Stripe account ID to generate the link for.
69 70 71 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 69 def on_behalf_of @on_behalf_of end |
#redirect_url ⇒ Object (readonly)
The link passed back to the user for their onboarding.
71 72 73 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 71 def redirect_url @redirect_url end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new OnboardingLink object that contains a redirect_url used for onboarding onto Tap to Pay on iPhone.
74 75 76 77 78 79 80 81 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 74 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/onboarding_links", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 11 def self.object_name "terminal.onboarding_link" end |