Class: Stripe::Terminal::OnboardingLink::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::OnboardingLink::CreateParams
- Defined in:
- lib/stripe/resources/terminal/onboarding_link.rb
Defined Under Namespace
Classes: LinkOptions
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#link_options ⇒ Object
Specific fields needed to generate the desired link type.
-
#link_type ⇒ Object
The type of link being generated.
-
#on_behalf_of ⇒ Object
Stripe account ID to generate the link for.
Instance Method Summary collapse
-
#initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
71 72 73 74 75 76 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 71 def initialize(expand: nil, link_options: nil, link_type: nil, on_behalf_of: nil) @expand = @link_options = @link_type = link_type @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
63 64 65 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 63 def @expand end |
#link_options ⇒ Object
Specific fields needed to generate the desired link type.
65 66 67 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 65 def @link_options end |
#link_type ⇒ Object
The type of link being generated.
67 68 69 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 67 def link_type @link_type end |
#on_behalf_of ⇒ Object
Stripe account ID to generate the link for.
69 70 71 |
# File 'lib/stripe/resources/terminal/onboarding_link.rb', line 69 def on_behalf_of @on_behalf_of end |