Class: Stripe::Terminal::Reader
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::Reader
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Overview
A Reader represents a physical device for accepting payment details.
Related guide: [Connecting to a reader](stripe.com/docs/terminal/payments/connect-reader)
Defined Under Namespace
Classes: Action, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"terminal.reader"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#action ⇒ Object
readonly
The most recent action performed by the reader.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#device_sw_version ⇒ Object
readonly
The current software version of the reader.
-
#device_type ⇒ Object
readonly
Type of reader, one of ‘bbpos_wisepad3`, `stripe_m2`, `stripe_s700`, `bbpos_chipper2x`, `bbpos_wisepos_e`, `verifone_P400`, `simulated_wisepos_e`, or `mobile_phone_reader`.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#ip_address ⇒ Object
readonly
The local IP address of the reader.
-
#label ⇒ Object
readonly
Custom label given to the reader for easier identification.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#location ⇒ Object
readonly
The location identifier of the reader.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#serial_number ⇒ Object
readonly
Serial number of the reader.
-
#status ⇒ Object
readonly
The networking status of the reader.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel_action(reader, params = {}, opts = {}) ⇒ Object
Cancels the current reader action.
-
.collect_inputs(reader, params = {}, opts = {}) ⇒ Object
Initiates an input collection flow on a Reader.
-
.collect_payment_method(reader, params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation.
-
.confirm_payment_intent(reader, params = {}, opts = {}) ⇒ Object
Finalizes a payment on a Reader.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Reader object.
-
.delete(id, params = {}, opts = {}) ⇒ Object
Deletes a Reader object.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Reader objects.
- .object_name ⇒ Object
-
.process_payment_intent(reader, params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader.
-
.process_setup_intent(reader, params = {}, opts = {}) ⇒ Object
Initiates a setup intent flow on a Reader.
-
.refund_payment(reader, params = {}, opts = {}) ⇒ Object
Initiates a refund on a Reader.
-
.set_reader_display(reader, params = {}, opts = {}) ⇒ Object
Sets reader display to show cart details.
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates a Reader object by setting the values of the parameters passed.
Instance Method Summary collapse
-
#cancel_action(params = {}, opts = {}) ⇒ Object
Cancels the current reader action.
-
#collect_inputs(params = {}, opts = {}) ⇒ Object
Initiates an input collection flow on a Reader.
-
#collect_payment_method(params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation.
-
#confirm_payment_intent(params = {}, opts = {}) ⇒ Object
Finalizes a payment on a Reader.
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Reader object.
-
#process_payment_intent(params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader.
-
#process_setup_intent(params = {}, opts = {}) ⇒ Object
Initiates a setup intent flow on a Reader.
-
#refund_payment(params = {}, opts = {}) ⇒ Object
Initiates a refund on a Reader.
-
#set_reader_display(params = {}, opts = {}) ⇒ Object
Sets reader display to show cart details.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#action ⇒ Object (readonly)
The most recent action performed by the reader.
112 113 114 |
# File 'lib/stripe/resources/terminal/reader.rb', line 112 def action @action end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
136 137 138 |
# File 'lib/stripe/resources/terminal/reader.rb', line 136 def deleted @deleted end |
#device_sw_version ⇒ Object (readonly)
The current software version of the reader.
114 115 116 |
# File 'lib/stripe/resources/terminal/reader.rb', line 114 def device_sw_version @device_sw_version end |
#device_type ⇒ Object (readonly)
Type of reader, one of ‘bbpos_wisepad3`, `stripe_m2`, `stripe_s700`, `bbpos_chipper2x`, `bbpos_wisepos_e`, `verifone_P400`, `simulated_wisepos_e`, or `mobile_phone_reader`.
116 117 118 |
# File 'lib/stripe/resources/terminal/reader.rb', line 116 def device_type @device_type end |
#id ⇒ Object (readonly)
Unique identifier for the object.
118 119 120 |
# File 'lib/stripe/resources/terminal/reader.rb', line 118 def id @id end |
#ip_address ⇒ Object (readonly)
The local IP address of the reader.
120 121 122 |
# File 'lib/stripe/resources/terminal/reader.rb', line 120 def ip_address @ip_address end |
#label ⇒ Object (readonly)
Custom label given to the reader for easier identification.
122 123 124 |
# File 'lib/stripe/resources/terminal/reader.rb', line 122 def label @label end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
124 125 126 |
# File 'lib/stripe/resources/terminal/reader.rb', line 124 def livemode @livemode end |
#location ⇒ Object (readonly)
The location identifier of the reader.
126 127 128 |
# File 'lib/stripe/resources/terminal/reader.rb', line 126 def location @location end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
128 129 130 |
# File 'lib/stripe/resources/terminal/reader.rb', line 128 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
130 131 132 |
# File 'lib/stripe/resources/terminal/reader.rb', line 130 def object @object end |
#serial_number ⇒ Object (readonly)
Serial number of the reader.
132 133 134 |
# File 'lib/stripe/resources/terminal/reader.rb', line 132 def serial_number @serial_number end |
#status ⇒ Object (readonly)
The networking status of the reader. We do not recommend using this field in flows that may block taking payments.
134 135 136 |
# File 'lib/stripe/resources/terminal/reader.rb', line 134 def status @status end |
Class Method Details
.cancel_action(reader, params = {}, opts = {}) ⇒ Object
Cancels the current reader action.
149 150 151 152 153 154 155 156 |
# File 'lib/stripe/resources/terminal/reader.rb', line 149 def self.cancel_action(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/cancel_action", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.collect_inputs(reader, params = {}, opts = {}) ⇒ Object
Initiates an input collection flow on a Reader.
169 170 171 172 173 174 175 176 |
# File 'lib/stripe/resources/terminal/reader.rb', line 169 def self.collect_inputs(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/collect_inputs", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.collect_payment_method(reader, params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation.
189 190 191 192 193 194 195 196 |
# File 'lib/stripe/resources/terminal/reader.rb', line 189 def self.collect_payment_method(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/collect_payment_method", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.confirm_payment_intent(reader, params = {}, opts = {}) ⇒ Object
Finalizes a payment on a Reader.
209 210 211 212 213 214 215 216 |
# File 'lib/stripe/resources/terminal/reader.rb', line 209 def self.confirm_payment_intent(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/confirm_payment_intent", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a new Reader object.
219 220 221 222 223 224 225 226 |
# File 'lib/stripe/resources/terminal/reader.rb', line 219 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/terminal/readers", params: params, opts: opts ) end |
.delete(id, params = {}, opts = {}) ⇒ Object
Deletes a Reader object.
229 230 231 232 233 234 235 236 |
# File 'lib/stripe/resources/terminal/reader.rb', line 229 def self.delete(id, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/readers/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Reader objects.
249 250 251 252 253 254 255 256 |
# File 'lib/stripe/resources/terminal/reader.rb', line 249 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/terminal/readers", params: filters, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/terminal/reader.rb', line 16 def self.object_name "terminal.reader" end |
.process_payment_intent(reader, params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader.
269 270 271 272 273 274 275 276 |
# File 'lib/stripe/resources/terminal/reader.rb', line 269 def self.process_payment_intent(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/process_payment_intent", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.process_setup_intent(reader, params = {}, opts = {}) ⇒ Object
Initiates a setup intent flow on a Reader.
289 290 291 292 293 294 295 296 |
# File 'lib/stripe/resources/terminal/reader.rb', line 289 def self.process_setup_intent(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/process_setup_intent", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.refund_payment(reader, params = {}, opts = {}) ⇒ Object
Initiates a refund on a Reader
309 310 311 312 313 314 315 316 |
# File 'lib/stripe/resources/terminal/reader.rb', line 309 def self.refund_payment(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/refund_payment", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.set_reader_display(reader, params = {}, opts = {}) ⇒ Object
Sets reader display to show cart details.
329 330 331 332 333 334 335 336 |
# File 'lib/stripe/resources/terminal/reader.rb', line 329 def self.set_reader_display(reader, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/set_reader_display", { reader: CGI.escape(reader) }), params: params, opts: opts ) end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates a Reader object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
339 340 341 342 343 344 345 346 |
# File 'lib/stripe/resources/terminal/reader.rb', line 339 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#cancel_action(params = {}, opts = {}) ⇒ Object
Cancels the current reader action.
139 140 141 142 143 144 145 146 |
# File 'lib/stripe/resources/terminal/reader.rb', line 139 def cancel_action(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/cancel_action", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#collect_inputs(params = {}, opts = {}) ⇒ Object
Initiates an input collection flow on a Reader.
159 160 161 162 163 164 165 166 |
# File 'lib/stripe/resources/terminal/reader.rb', line 159 def collect_inputs(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/collect_inputs", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#collect_payment_method(params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation.
179 180 181 182 183 184 185 186 |
# File 'lib/stripe/resources/terminal/reader.rb', line 179 def collect_payment_method(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/collect_payment_method", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#confirm_payment_intent(params = {}, opts = {}) ⇒ Object
Finalizes a payment on a Reader.
199 200 201 202 203 204 205 206 |
# File 'lib/stripe/resources/terminal/reader.rb', line 199 def confirm_payment_intent(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/confirm_payment_intent", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete(params = {}, opts = {}) ⇒ Object
Deletes a Reader object.
239 240 241 242 243 244 245 246 |
# File 'lib/stripe/resources/terminal/reader.rb', line 239 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/terminal/readers/%<reader>s", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#process_payment_intent(params = {}, opts = {}) ⇒ Object
Initiates a payment flow on a Reader.
259 260 261 262 263 264 265 266 |
# File 'lib/stripe/resources/terminal/reader.rb', line 259 def process_payment_intent(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/process_payment_intent", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#process_setup_intent(params = {}, opts = {}) ⇒ Object
Initiates a setup intent flow on a Reader.
279 280 281 282 283 284 285 286 |
# File 'lib/stripe/resources/terminal/reader.rb', line 279 def process_setup_intent(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/process_setup_intent", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#refund_payment(params = {}, opts = {}) ⇒ Object
Initiates a refund on a Reader
299 300 301 302 303 304 305 306 |
# File 'lib/stripe/resources/terminal/reader.rb', line 299 def refund_payment(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/refund_payment", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#set_reader_display(params = {}, opts = {}) ⇒ Object
Sets reader display to show cart details.
319 320 321 322 323 324 325 326 |
# File 'lib/stripe/resources/terminal/reader.rb', line 319 def set_reader_display(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/terminal/readers/%<reader>s/set_reader_display", { reader: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
348 349 350 |
# File 'lib/stripe/resources/terminal/reader.rb', line 348 def test_helpers TestHelpers.new(self) end |