Class: Stripe::Terminal::Reader::Action
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: ApiError, CollectInputs, CollectPaymentMethod, ConfirmPaymentIntent, PrintContent, ProcessPaymentIntent, ProcessSetupIntent, RefundPayment, SetReaderDisplay
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#api_error ⇒ Object
readonly
The reader action failed due to an [API error](docs.stripe.com/api/errors).
-
#collect_inputs ⇒ Object
readonly
Represents a reader action to collect customer inputs.
-
#collect_payment_method ⇒ Object
readonly
Represents a reader action to collect a payment method.
-
#confirm_payment_intent ⇒ Object
readonly
Represents a reader action to confirm a payment.
-
#failure_code ⇒ Object
readonly
Failure code, only set if status is ‘failed`.
-
#failure_message ⇒ Object
readonly
Detailed failure message, only set if status is ‘failed`.
-
#print_content ⇒ Object
readonly
Represents a reader action to print content.
-
#process_payment_intent ⇒ Object
readonly
Represents a reader action to process a payment intent.
-
#process_setup_intent ⇒ Object
readonly
Represents a reader action to process a setup intent.
-
#refund_payment ⇒ Object
readonly
Represents a reader action to refund a payment.
-
#set_reader_display ⇒ Object
readonly
Represents a reader action to set the reader display.
-
#status ⇒ Object
readonly
Status of the action performed by the reader.
-
#type ⇒ Object
readonly
Type of action performed by the reader.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#api_error ⇒ Object (readonly)
The reader action failed due to an [API error](docs.stripe.com/api/errors). Only present when ‘status` is `failed` and the underlying failure was an API error. Avoid parsing the `message` field for programmatic logic; use `type` or `code` instead. The `message` field is for display to humans only and may be updated at anytime. Requires [reader version](docs.stripe.com/terminal/readers/stripe-reader-s700-s710#reader-software-version) 2.42 or later. Readers on older versions always return null.
570 571 572 |
# File 'lib/stripe/resources/terminal/reader.rb', line 570 def api_error @api_error end |
#collect_inputs ⇒ Object (readonly)
Represents a reader action to collect customer inputs
572 573 574 |
# File 'lib/stripe/resources/terminal/reader.rb', line 572 def collect_inputs @collect_inputs end |
#collect_payment_method ⇒ Object (readonly)
Represents a reader action to collect a payment method
574 575 576 |
# File 'lib/stripe/resources/terminal/reader.rb', line 574 def collect_payment_method @collect_payment_method end |
#confirm_payment_intent ⇒ Object (readonly)
Represents a reader action to confirm a payment
576 577 578 |
# File 'lib/stripe/resources/terminal/reader.rb', line 576 def confirm_payment_intent @confirm_payment_intent end |
#failure_code ⇒ Object (readonly)
Failure code, only set if status is ‘failed`.
578 579 580 |
# File 'lib/stripe/resources/terminal/reader.rb', line 578 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Detailed failure message, only set if status is ‘failed`.
580 581 582 |
# File 'lib/stripe/resources/terminal/reader.rb', line 580 def @failure_message end |
#print_content ⇒ Object (readonly)
Represents a reader action to print content
582 583 584 |
# File 'lib/stripe/resources/terminal/reader.rb', line 582 def print_content @print_content end |
#process_payment_intent ⇒ Object (readonly)
Represents a reader action to process a payment intent
584 585 586 |
# File 'lib/stripe/resources/terminal/reader.rb', line 584 def process_payment_intent @process_payment_intent end |
#process_setup_intent ⇒ Object (readonly)
Represents a reader action to process a setup intent
586 587 588 |
# File 'lib/stripe/resources/terminal/reader.rb', line 586 def process_setup_intent @process_setup_intent end |
#refund_payment ⇒ Object (readonly)
Represents a reader action to refund a payment
588 589 590 |
# File 'lib/stripe/resources/terminal/reader.rb', line 588 def refund_payment @refund_payment end |
#set_reader_display ⇒ Object (readonly)
Represents a reader action to set the reader display
590 591 592 |
# File 'lib/stripe/resources/terminal/reader.rb', line 590 def set_reader_display @set_reader_display end |
#status ⇒ Object (readonly)
Status of the action performed by the reader.
592 593 594 |
# File 'lib/stripe/resources/terminal/reader.rb', line 592 def status @status end |
#type ⇒ Object (readonly)
Type of action performed by the reader.
594 595 596 |
# File 'lib/stripe/resources/terminal/reader.rb', line 594 def type @type end |
Class Method Details
.field_remappings ⇒ Object
610 611 612 |
# File 'lib/stripe/resources/terminal/reader.rb', line 610 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/stripe/resources/terminal/reader.rb', line 596 def self.inner_class_types @inner_class_types = { api_error: ApiError, collect_inputs: CollectInputs, collect_payment_method: CollectPaymentMethod, confirm_payment_intent: ConfirmPaymentIntent, print_content: PrintContent, process_payment_intent: ProcessPaymentIntent, process_setup_intent: ProcessSetupIntent, refund_payment: RefundPayment, set_reader_display: SetReaderDisplay, } end |