Class: Stripe::Terminal::Reader::Action

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CollectInputs, CollectPaymentMethod, ConfirmPaymentIntent, PrintContent, ProcessPaymentIntent, ProcessSetupIntent, RefundPayment, SetReaderDisplay

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#collect_inputsObject (readonly)

Represents a reader action to collect customer inputs



493
494
495
# File 'lib/stripe/resources/terminal/reader.rb', line 493

def collect_inputs
  @collect_inputs
end

#collect_payment_methodObject (readonly)

Represents a reader action to collect a payment method



495
496
497
# File 'lib/stripe/resources/terminal/reader.rb', line 495

def collect_payment_method
  @collect_payment_method
end

#confirm_payment_intentObject (readonly)

Represents a reader action to confirm a payment



497
498
499
# File 'lib/stripe/resources/terminal/reader.rb', line 497

def confirm_payment_intent
  @confirm_payment_intent
end

#failure_codeObject (readonly)

Failure code, only set if status is ‘failed`.



499
500
501
# File 'lib/stripe/resources/terminal/reader.rb', line 499

def failure_code
  @failure_code
end

#failure_messageObject (readonly)

Detailed failure message, only set if status is ‘failed`.



501
502
503
# File 'lib/stripe/resources/terminal/reader.rb', line 501

def failure_message
  @failure_message
end

Represents a reader action to print content



503
504
505
# File 'lib/stripe/resources/terminal/reader.rb', line 503

def print_content
  @print_content
end

#process_payment_intentObject (readonly)

Represents a reader action to process a payment intent



505
506
507
# File 'lib/stripe/resources/terminal/reader.rb', line 505

def process_payment_intent
  @process_payment_intent
end

#process_setup_intentObject (readonly)

Represents a reader action to process a setup intent



507
508
509
# File 'lib/stripe/resources/terminal/reader.rb', line 507

def process_setup_intent
  @process_setup_intent
end

#refund_paymentObject (readonly)

Represents a reader action to refund a payment



509
510
511
# File 'lib/stripe/resources/terminal/reader.rb', line 509

def refund_payment
  @refund_payment
end

#set_reader_displayObject (readonly)

Represents a reader action to set the reader display



511
512
513
# File 'lib/stripe/resources/terminal/reader.rb', line 511

def set_reader_display
  @set_reader_display
end

#statusObject (readonly)

Status of the action performed by the reader.



513
514
515
# File 'lib/stripe/resources/terminal/reader.rb', line 513

def status
  @status
end

#typeObject (readonly)

Type of action performed by the reader.



515
516
517
# File 'lib/stripe/resources/terminal/reader.rb', line 515

def type
  @type
end

Class Method Details

.field_remappingsObject



530
531
532
# File 'lib/stripe/resources/terminal/reader.rb', line 530

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/stripe/resources/terminal/reader.rb', line 517

def self.inner_class_types
  @inner_class_types = {
    collect_inputs: CollectInputs,
    collect_payment_method: CollectPaymentMethod,
    confirm_payment_intent: ConfirmPaymentIntent,
    print_content: PrintContent,
    process_payment_intent: ProcessPaymentIntent,
    process_setup_intent: ProcessSetupIntent,
    refund_payment: RefundPayment,
    set_reader_display: SetReaderDisplay,
  }
end