Class: Stripe::Terminal::Reader::Action
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CollectInputs, ProcessPaymentIntent, ProcessSetupIntent, RefundPayment, SetReaderDisplay
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collect_inputs ⇒ Object
readonly
Represents a reader action to collect customer inputs.
-
#failure_code ⇒ Object
readonly
Failure code, only set if status is ‘failed`.
-
#failure_message ⇒ Object
readonly
Detailed failure message, only set if status is ‘failed`.
-
#process_payment_intent ⇒ Object
readonly
Represents a reader action to process a payment intent.
-
#process_setup_intent ⇒ Object
readonly
Represents a reader action to process a setup intent.
-
#refund_payment ⇒ Object
readonly
Represents a reader action to refund a payment.
-
#set_reader_display ⇒ Object
readonly
Represents a reader action to set the reader display.
-
#status ⇒ Object
readonly
Status of the action performed by the reader.
-
#type ⇒ Object
readonly
Type of action performed by the reader.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collect_inputs ⇒ Object (readonly)
Represents a reader action to collect customer inputs
199 200 201 |
# File 'lib/stripe/resources/terminal/reader.rb', line 199 def collect_inputs @collect_inputs end |
#failure_code ⇒ Object (readonly)
Failure code, only set if status is ‘failed`.
201 202 203 |
# File 'lib/stripe/resources/terminal/reader.rb', line 201 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Detailed failure message, only set if status is ‘failed`.
203 204 205 |
# File 'lib/stripe/resources/terminal/reader.rb', line 203 def @failure_message end |
#process_payment_intent ⇒ Object (readonly)
Represents a reader action to process a payment intent
205 206 207 |
# File 'lib/stripe/resources/terminal/reader.rb', line 205 def process_payment_intent @process_payment_intent end |
#process_setup_intent ⇒ Object (readonly)
Represents a reader action to process a setup intent
207 208 209 |
# File 'lib/stripe/resources/terminal/reader.rb', line 207 def process_setup_intent @process_setup_intent end |
#refund_payment ⇒ Object (readonly)
Represents a reader action to refund a payment
209 210 211 |
# File 'lib/stripe/resources/terminal/reader.rb', line 209 def refund_payment @refund_payment end |
#set_reader_display ⇒ Object (readonly)
Represents a reader action to set the reader display
211 212 213 |
# File 'lib/stripe/resources/terminal/reader.rb', line 211 def set_reader_display @set_reader_display end |
#status ⇒ Object (readonly)
Status of the action performed by the reader.
213 214 215 |
# File 'lib/stripe/resources/terminal/reader.rb', line 213 def status @status end |
#type ⇒ Object (readonly)
Type of action performed by the reader.
215 216 217 |
# File 'lib/stripe/resources/terminal/reader.rb', line 215 def type @type end |