Class: Stripe::Terminal::Reader::Action
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CollectInputs, CollectPaymentMethod, ConfirmPaymentIntent, ProcessPaymentIntent, ProcessSetupIntent, RefundPayment, SetReaderDisplay
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collect_inputs ⇒ Object
readonly
Represents a reader action to collect customer inputs.
-
#collect_payment_method ⇒ Object
readonly
Represents a reader action to collect a payment method.
-
#confirm_payment_intent ⇒ Object
readonly
Represents a reader action to confirm a payment.
-
#failure_code ⇒ Object
readonly
Failure code, only set if status is ‘failed`.
-
#failure_message ⇒ Object
readonly
Detailed failure message, only set if status is ‘failed`.
-
#process_payment_intent ⇒ Object
readonly
Represents a reader action to process a payment intent.
-
#process_setup_intent ⇒ Object
readonly
Represents a reader action to process a setup intent.
-
#refund_payment ⇒ Object
readonly
Represents a reader action to refund a payment.
-
#set_reader_display ⇒ Object
readonly
Represents a reader action to set the reader display.
-
#status ⇒ Object
readonly
Status of the action performed by the reader.
-
#type ⇒ Object
readonly
Type of action performed by the reader.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collect_inputs ⇒ Object (readonly)
Represents a reader action to collect customer inputs
289 290 291 |
# File 'lib/stripe/resources/terminal/reader.rb', line 289 def collect_inputs @collect_inputs end |
#collect_payment_method ⇒ Object (readonly)
Represents a reader action to collect a payment method
292 293 294 |
# File 'lib/stripe/resources/terminal/reader.rb', line 292 def collect_payment_method @collect_payment_method end |
#confirm_payment_intent ⇒ Object (readonly)
Represents a reader action to confirm a payment
295 296 297 |
# File 'lib/stripe/resources/terminal/reader.rb', line 295 def confirm_payment_intent @confirm_payment_intent end |
#failure_code ⇒ Object (readonly)
Failure code, only set if status is ‘failed`.
298 299 300 |
# File 'lib/stripe/resources/terminal/reader.rb', line 298 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Detailed failure message, only set if status is ‘failed`.
301 302 303 |
# File 'lib/stripe/resources/terminal/reader.rb', line 301 def @failure_message end |
#process_payment_intent ⇒ Object (readonly)
Represents a reader action to process a payment intent
304 305 306 |
# File 'lib/stripe/resources/terminal/reader.rb', line 304 def process_payment_intent @process_payment_intent end |
#process_setup_intent ⇒ Object (readonly)
Represents a reader action to process a setup intent
307 308 309 |
# File 'lib/stripe/resources/terminal/reader.rb', line 307 def process_setup_intent @process_setup_intent end |
#refund_payment ⇒ Object (readonly)
Represents a reader action to refund a payment
310 311 312 |
# File 'lib/stripe/resources/terminal/reader.rb', line 310 def refund_payment @refund_payment end |
#set_reader_display ⇒ Object (readonly)
Represents a reader action to set the reader display
313 314 315 |
# File 'lib/stripe/resources/terminal/reader.rb', line 313 def set_reader_display @set_reader_display end |
#status ⇒ Object (readonly)
Status of the action performed by the reader.
316 317 318 |
# File 'lib/stripe/resources/terminal/reader.rb', line 316 def status @status end |
#type ⇒ Object (readonly)
Type of action performed by the reader.
319 320 321 |
# File 'lib/stripe/resources/terminal/reader.rb', line 319 def type @type end |