Class: Stripe::Terminal::Reader::Action::CollectInputs::Input
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::CollectInputs::Input
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CustomText, Email, Numeric, Phone, Selection, Signature, Text, Toggle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_text ⇒ Object
readonly
Default text of input being collected.
-
#email ⇒ Object
readonly
Information about a email being collected using a reader.
-
#numeric ⇒ Object
readonly
Information about a number being collected using a reader.
-
#phone ⇒ Object
readonly
Information about a phone number being collected using a reader.
-
#required ⇒ Object
readonly
Indicate that this input is required, disabling the skip button.
-
#selection ⇒ Object
readonly
Information about a selection being collected using a reader.
-
#signature ⇒ Object
readonly
Information about a signature being collected using a reader.
-
#skipped ⇒ Object
readonly
Indicate that this input was skipped by the user.
-
#text ⇒ Object
readonly
Information about text being collected using a reader.
-
#toggles ⇒ Object
readonly
List of toggles being collected.
-
#type ⇒ Object
readonly
Type of input being collected.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_text ⇒ Object (readonly)
Default text of input being collected.
284 285 286 |
# File 'lib/stripe/resources/terminal/reader.rb', line 284 def custom_text @custom_text end |
#email ⇒ Object (readonly)
Information about a email being collected using a reader
286 287 288 |
# File 'lib/stripe/resources/terminal/reader.rb', line 286 def email @email end |
#numeric ⇒ Object (readonly)
Information about a number being collected using a reader
288 289 290 |
# File 'lib/stripe/resources/terminal/reader.rb', line 288 def numeric @numeric end |
#phone ⇒ Object (readonly)
Information about a phone number being collected using a reader
290 291 292 |
# File 'lib/stripe/resources/terminal/reader.rb', line 290 def phone @phone end |
#required ⇒ Object (readonly)
Indicate that this input is required, disabling the skip button.
292 293 294 |
# File 'lib/stripe/resources/terminal/reader.rb', line 292 def required @required end |
#selection ⇒ Object (readonly)
Information about a selection being collected using a reader
294 295 296 |
# File 'lib/stripe/resources/terminal/reader.rb', line 294 def selection @selection end |
#signature ⇒ Object (readonly)
Information about a signature being collected using a reader
296 297 298 |
# File 'lib/stripe/resources/terminal/reader.rb', line 296 def signature @signature end |
#skipped ⇒ Object (readonly)
Indicate that this input was skipped by the user.
298 299 300 |
# File 'lib/stripe/resources/terminal/reader.rb', line 298 def skipped @skipped end |
#text ⇒ Object (readonly)
Information about text being collected using a reader
300 301 302 |
# File 'lib/stripe/resources/terminal/reader.rb', line 300 def text @text end |
#toggles ⇒ Object (readonly)
List of toggles being collected. Values are present if collection is complete.
302 303 304 |
# File 'lib/stripe/resources/terminal/reader.rb', line 302 def toggles @toggles end |
#type ⇒ Object (readonly)
Type of input being collected.
304 305 306 |
# File 'lib/stripe/resources/terminal/reader.rb', line 304 def type @type end |
Class Method Details
.field_remappings ⇒ Object
319 320 321 |
# File 'lib/stripe/resources/terminal/reader.rb', line 319 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/stripe/resources/terminal/reader.rb', line 306 def self.inner_class_types @inner_class_types = { custom_text: CustomText, email: Email, numeric: Numeric, phone: Phone, selection: Selection, signature: Signature, text: Text, toggles: Toggle, } end |