Class: Stripe::Terminal::Reader::Action::CollectInputs::Input
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::CollectInputs::Input
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CustomText, Email, Numeric, Phone, Selection, Signature, Text, Toggle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_text ⇒ Object
readonly
Default text of input being collected.
-
#email ⇒ Object
readonly
Information about a email being collected using a reader.
-
#numeric ⇒ Object
readonly
Information about a number being collected using a reader.
-
#phone ⇒ Object
readonly
Information about a phone number being collected using a reader.
-
#required ⇒ Object
readonly
Indicate that this input is required, disabling the skip button.
-
#selection ⇒ Object
readonly
Information about a selection being collected using a reader.
-
#signature ⇒ Object
readonly
Information about a signature being collected using a reader.
-
#skipped ⇒ Object
readonly
Indicate that this input was skipped by the user.
-
#text ⇒ Object
readonly
Information about text being collected using a reader.
-
#toggles ⇒ Object
readonly
List of toggles being collected.
-
#type ⇒ Object
readonly
Type of input being collected.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_text ⇒ Object (readonly)
Default text of input being collected.
236 237 238 |
# File 'lib/stripe/resources/terminal/reader.rb', line 236 def custom_text @custom_text end |
#email ⇒ Object (readonly)
Information about a email being collected using a reader
238 239 240 |
# File 'lib/stripe/resources/terminal/reader.rb', line 238 def email @email end |
#numeric ⇒ Object (readonly)
Information about a number being collected using a reader
240 241 242 |
# File 'lib/stripe/resources/terminal/reader.rb', line 240 def numeric @numeric end |
#phone ⇒ Object (readonly)
Information about a phone number being collected using a reader
242 243 244 |
# File 'lib/stripe/resources/terminal/reader.rb', line 242 def phone @phone end |
#required ⇒ Object (readonly)
Indicate that this input is required, disabling the skip button.
244 245 246 |
# File 'lib/stripe/resources/terminal/reader.rb', line 244 def required @required end |
#selection ⇒ Object (readonly)
Information about a selection being collected using a reader
246 247 248 |
# File 'lib/stripe/resources/terminal/reader.rb', line 246 def selection @selection end |
#signature ⇒ Object (readonly)
Information about a signature being collected using a reader
248 249 250 |
# File 'lib/stripe/resources/terminal/reader.rb', line 248 def signature @signature end |
#skipped ⇒ Object (readonly)
Indicate that this input was skipped by the user.
250 251 252 |
# File 'lib/stripe/resources/terminal/reader.rb', line 250 def skipped @skipped end |
#text ⇒ Object (readonly)
Information about text being collected using a reader
252 253 254 |
# File 'lib/stripe/resources/terminal/reader.rb', line 252 def text @text end |
#toggles ⇒ Object (readonly)
List of toggles being collected. Values are present if collection is complete.
254 255 256 |
# File 'lib/stripe/resources/terminal/reader.rb', line 254 def toggles @toggles end |
#type ⇒ Object (readonly)
Type of input being collected.
256 257 258 |
# File 'lib/stripe/resources/terminal/reader.rb', line 256 def type @type end |
Class Method Details
.field_remappings ⇒ Object
271 272 273 |
# File 'lib/stripe/resources/terminal/reader.rb', line 271 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/stripe/resources/terminal/reader.rb', line 258 def self.inner_class_types @inner_class_types = { custom_text: CustomText, email: Email, numeric: Numeric, phone: Phone, selection: Selection, signature: Signature, text: Text, toggles: Toggle, } end |