Class: Stripe::Terminal::Reader::Action::CollectInputs::Input
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::CollectInputs::Input
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CustomText, Email, Numeric, Phone, Selection, Signature, Text, Toggle
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom_text ⇒ Object
readonly
Default text of input being collected.
-
#email ⇒ Object
readonly
Information about a email being collected using a reader.
-
#numeric ⇒ Object
readonly
Information about a number being collected using a reader.
-
#phone ⇒ Object
readonly
Information about a phone number being collected using a reader.
-
#required ⇒ Object
readonly
Indicate that this input is required, disabling the skip button.
-
#selection ⇒ Object
readonly
Information about a selection being collected using a reader.
-
#signature ⇒ Object
readonly
Information about a signature being collected using a reader.
-
#skipped ⇒ Object
readonly
Indicate that this input was skipped by the user.
-
#text ⇒ Object
readonly
Information about text being collected using a reader.
-
#toggles ⇒ Object
readonly
List of toggles being collected.
-
#type ⇒ Object
readonly
Type of input being collected.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom_text ⇒ Object (readonly)
Default text of input being collected.
91 92 93 |
# File 'lib/stripe/resources/terminal/reader.rb', line 91 def custom_text @custom_text end |
#email ⇒ Object (readonly)
Information about a email being collected using a reader
94 95 96 |
# File 'lib/stripe/resources/terminal/reader.rb', line 94 def email @email end |
#numeric ⇒ Object (readonly)
Information about a number being collected using a reader
97 98 99 |
# File 'lib/stripe/resources/terminal/reader.rb', line 97 def numeric @numeric end |
#phone ⇒ Object (readonly)
Information about a phone number being collected using a reader
100 101 102 |
# File 'lib/stripe/resources/terminal/reader.rb', line 100 def phone @phone end |
#required ⇒ Object (readonly)
Indicate that this input is required, disabling the skip button.
103 104 105 |
# File 'lib/stripe/resources/terminal/reader.rb', line 103 def required @required end |
#selection ⇒ Object (readonly)
Information about a selection being collected using a reader
106 107 108 |
# File 'lib/stripe/resources/terminal/reader.rb', line 106 def selection @selection end |
#signature ⇒ Object (readonly)
Information about a signature being collected using a reader
109 110 111 |
# File 'lib/stripe/resources/terminal/reader.rb', line 109 def signature @signature end |
#skipped ⇒ Object (readonly)
Indicate that this input was skipped by the user.
112 113 114 |
# File 'lib/stripe/resources/terminal/reader.rb', line 112 def skipped @skipped end |
#text ⇒ Object (readonly)
Information about text being collected using a reader
115 116 117 |
# File 'lib/stripe/resources/terminal/reader.rb', line 115 def text @text end |
#toggles ⇒ Object (readonly)
List of toggles being collected. Values are present if collection is complete.
118 119 120 |
# File 'lib/stripe/resources/terminal/reader.rb', line 118 def toggles @toggles end |
#type ⇒ Object (readonly)
Type of input being collected.
121 122 123 |
# File 'lib/stripe/resources/terminal/reader.rb', line 121 def type @type end |