Class: Stripe::Terminal::Reader::Action::ConfirmPaymentIntent::ConfirmConfig
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::ConfirmPaymentIntent::ConfirmConfig
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#return_url ⇒ Object
readonly
If the customer does not abandon authenticating the payment, they will be redirected to this specified URL after completion.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#return_url ⇒ Object (readonly)
If the customer does not abandon authenticating the payment, they will be redirected to this specified URL after completion.
145 146 147 |
# File 'lib/stripe/resources/terminal/reader.rb', line 145 def return_url @return_url end |