Class: Stripe::Terminal::Reader::Action::RefundPayment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::RefundPayment
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: RefundPaymentConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
Account the payment intent belongs to.
-
#amount ⇒ Object
readonly
The amount being refunded.
-
#charge ⇒ Object
readonly
Charge that is being refunded.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_intent ⇒ Object
readonly
Payment intent that is being refunded.
-
#reason ⇒ Object
readonly
The reason for the refund.
-
#refund ⇒ Object
readonly
Unique identifier for the refund object.
-
#refund_application_fee ⇒ Object
readonly
Boolean indicating whether the application fee should be refunded when refunding this charge.
-
#refund_payment_config ⇒ Object
readonly
Represents a per-transaction override of a reader configuration.
-
#reverse_transfer ⇒ Object
readonly
Boolean indicating whether the transfer should be reversed when refunding this charge.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
Account the payment intent belongs to.
492 493 494 |
# File 'lib/stripe/resources/terminal/reader.rb', line 492 def account @account end |
#amount ⇒ Object (readonly)
The amount being refunded.
494 495 496 |
# File 'lib/stripe/resources/terminal/reader.rb', line 494 def amount @amount end |
#charge ⇒ Object (readonly)
Charge that is being refunded.
496 497 498 |
# File 'lib/stripe/resources/terminal/reader.rb', line 496 def charge @charge end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
498 499 500 |
# File 'lib/stripe/resources/terminal/reader.rb', line 498 def @metadata end |
#payment_intent ⇒ Object (readonly)
Payment intent that is being refunded.
500 501 502 |
# File 'lib/stripe/resources/terminal/reader.rb', line 500 def payment_intent @payment_intent end |
#reason ⇒ Object (readonly)
The reason for the refund.
502 503 504 |
# File 'lib/stripe/resources/terminal/reader.rb', line 502 def reason @reason end |
#refund ⇒ Object (readonly)
Unique identifier for the refund object.
504 505 506 |
# File 'lib/stripe/resources/terminal/reader.rb', line 504 def refund @refund end |
#refund_application_fee ⇒ Object (readonly)
Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.
506 507 508 |
# File 'lib/stripe/resources/terminal/reader.rb', line 506 def refund_application_fee @refund_application_fee end |
#refund_payment_config ⇒ Object (readonly)
Represents a per-transaction override of a reader configuration
508 509 510 |
# File 'lib/stripe/resources/terminal/reader.rb', line 508 def refund_payment_config @refund_payment_config end |
#reverse_transfer ⇒ Object (readonly)
Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.
510 511 512 |
# File 'lib/stripe/resources/terminal/reader.rb', line 510 def reverse_transfer @reverse_transfer end |
Class Method Details
.field_remappings ⇒ Object
516 517 518 |
# File 'lib/stripe/resources/terminal/reader.rb', line 516 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
512 513 514 |
# File 'lib/stripe/resources/terminal/reader.rb', line 512 def self.inner_class_types @inner_class_types = { refund_payment_config: RefundPaymentConfig } end |