Class: Stripe::Terminal::Reader::Action::RefundPayment

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: RefundPaymentConfig

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

Account the payment intent belongs to.



415
416
417
# File 'lib/stripe/resources/terminal/reader.rb', line 415

def 
  @account
end

#amountObject (readonly)

The amount being refunded.



417
418
419
# File 'lib/stripe/resources/terminal/reader.rb', line 417

def amount
  @amount
end

#chargeObject (readonly)

Charge that is being refunded.



419
420
421
# File 'lib/stripe/resources/terminal/reader.rb', line 419

def charge
  @charge
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



421
422
423
# File 'lib/stripe/resources/terminal/reader.rb', line 421

def 
  @metadata
end

#payment_intentObject (readonly)

Payment intent that is being refunded.



423
424
425
# File 'lib/stripe/resources/terminal/reader.rb', line 423

def payment_intent
  @payment_intent
end

#reasonObject (readonly)

The reason for the refund.



425
426
427
# File 'lib/stripe/resources/terminal/reader.rb', line 425

def reason
  @reason
end

#refundObject (readonly)

Unique identifier for the refund object.



427
428
429
# File 'lib/stripe/resources/terminal/reader.rb', line 427

def refund
  @refund
end

#refund_application_feeObject (readonly)

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



429
430
431
# File 'lib/stripe/resources/terminal/reader.rb', line 429

def refund_application_fee
  @refund_application_fee
end

#refund_payment_configObject (readonly)

Represents a per-transaction override of a reader configuration



431
432
433
# File 'lib/stripe/resources/terminal/reader.rb', line 431

def refund_payment_config
  @refund_payment_config
end

#reverse_transferObject (readonly)

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.



433
434
435
# File 'lib/stripe/resources/terminal/reader.rb', line 433

def reverse_transfer
  @reverse_transfer
end

Class Method Details

.field_remappingsObject



439
440
441
# File 'lib/stripe/resources/terminal/reader.rb', line 439

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



435
436
437
# File 'lib/stripe/resources/terminal/reader.rb', line 435

def self.inner_class_types
  @inner_class_types = { refund_payment_config: RefundPaymentConfig }
end