Class: Stripe::Terminal::Reader::Action::RefundPayment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::RefundPayment
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: RefundPaymentConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount being refunded.
-
#charge ⇒ Object
readonly
Charge that is being refunded.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_intent ⇒ Object
readonly
Payment intent that is being refunded.
-
#reason ⇒ Object
readonly
The reason for the refund.
-
#refund ⇒ Object
readonly
Unique identifier for the refund object.
-
#refund_application_fee ⇒ Object
readonly
Boolean indicating whether the application fee should be refunded when refunding this charge.
-
#refund_payment_config ⇒ Object
readonly
Represents a per-transaction override of a reader configuration.
-
#reverse_transfer ⇒ Object
readonly
Boolean indicating whether the transfer should be reversed when refunding this charge.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount being refunded.
155 156 157 |
# File 'lib/stripe/resources/terminal/reader.rb', line 155 def amount @amount end |
#charge ⇒ Object (readonly)
Charge that is being refunded.
157 158 159 |
# File 'lib/stripe/resources/terminal/reader.rb', line 157 def charge @charge end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
159 160 161 |
# File 'lib/stripe/resources/terminal/reader.rb', line 159 def @metadata end |
#payment_intent ⇒ Object (readonly)
Payment intent that is being refunded.
161 162 163 |
# File 'lib/stripe/resources/terminal/reader.rb', line 161 def payment_intent @payment_intent end |
#reason ⇒ Object (readonly)
The reason for the refund.
163 164 165 |
# File 'lib/stripe/resources/terminal/reader.rb', line 163 def reason @reason end |
#refund ⇒ Object (readonly)
Unique identifier for the refund object.
165 166 167 |
# File 'lib/stripe/resources/terminal/reader.rb', line 165 def refund @refund end |
#refund_application_fee ⇒ Object (readonly)
Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.
167 168 169 |
# File 'lib/stripe/resources/terminal/reader.rb', line 167 def refund_application_fee @refund_application_fee end |
#refund_payment_config ⇒ Object (readonly)
Represents a per-transaction override of a reader configuration
169 170 171 |
# File 'lib/stripe/resources/terminal/reader.rb', line 169 def refund_payment_config @refund_payment_config end |
#reverse_transfer ⇒ Object (readonly)
Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.
171 172 173 |
# File 'lib/stripe/resources/terminal/reader.rb', line 171 def reverse_transfer @reverse_transfer end |