Class: Stripe::Terminal::Reader::Action::RefundPayment

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: RefundPaymentConfig

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

Account the payment intent belongs to.



189
190
191
# File 'lib/stripe/resources/terminal/reader.rb', line 189

def 
  @account
end

#amountObject (readonly)

The amount being refunded.



191
192
193
# File 'lib/stripe/resources/terminal/reader.rb', line 191

def amount
  @amount
end

#chargeObject (readonly)

Charge that is being refunded.



193
194
195
# File 'lib/stripe/resources/terminal/reader.rb', line 193

def charge
  @charge
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



195
196
197
# File 'lib/stripe/resources/terminal/reader.rb', line 195

def 
  @metadata
end

#payment_intentObject (readonly)

Payment intent that is being refunded.



197
198
199
# File 'lib/stripe/resources/terminal/reader.rb', line 197

def payment_intent
  @payment_intent
end

#reasonObject (readonly)

The reason for the refund.



199
200
201
# File 'lib/stripe/resources/terminal/reader.rb', line 199

def reason
  @reason
end

#refundObject (readonly)

Unique identifier for the refund object.



201
202
203
# File 'lib/stripe/resources/terminal/reader.rb', line 201

def refund
  @refund
end

#refund_application_feeObject (readonly)

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



203
204
205
# File 'lib/stripe/resources/terminal/reader.rb', line 203

def refund_application_fee
  @refund_application_fee
end

#refund_payment_configObject (readonly)

Represents a per-transaction override of a reader configuration



205
206
207
# File 'lib/stripe/resources/terminal/reader.rb', line 205

def refund_payment_config
  @refund_payment_config
end

#reverse_transferObject (readonly)

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.



207
208
209
# File 'lib/stripe/resources/terminal/reader.rb', line 207

def reverse_transfer
  @reverse_transfer
end