Class: Stripe::Terminal::Reader::Action::RefundPayment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Terminal::Reader::Action::RefundPayment
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: RefundPaymentConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
Account the payment intent belongs to.
-
#amount ⇒ Object
readonly
The amount being refunded.
-
#charge ⇒ Object
readonly
Charge that is being refunded.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_intent ⇒ Object
readonly
Payment intent that is being refunded.
-
#reason ⇒ Object
readonly
The reason for the refund.
-
#refund ⇒ Object
readonly
Unique identifier for the refund object.
-
#refund_application_fee ⇒ Object
readonly
Boolean indicating whether the application fee should be refunded when refunding this charge.
-
#refund_payment_config ⇒ Object
readonly
Represents a per-transaction override of a reader configuration.
-
#reverse_transfer ⇒ Object
readonly
Boolean indicating whether the transfer should be reversed when refunding this charge.
-
#stripe_account ⇒ Object
readonly
This field will be deprecated.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
Account the payment intent belongs to.
225 226 227 |
# File 'lib/stripe/resources/terminal/reader.rb', line 225 def account @account end |
#amount ⇒ Object (readonly)
The amount being refunded.
228 229 230 |
# File 'lib/stripe/resources/terminal/reader.rb', line 228 def amount @amount end |
#charge ⇒ Object (readonly)
Charge that is being refunded.
231 232 233 |
# File 'lib/stripe/resources/terminal/reader.rb', line 231 def charge @charge end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
234 235 236 |
# File 'lib/stripe/resources/terminal/reader.rb', line 234 def @metadata end |
#payment_intent ⇒ Object (readonly)
Payment intent that is being refunded.
237 238 239 |
# File 'lib/stripe/resources/terminal/reader.rb', line 237 def payment_intent @payment_intent end |
#reason ⇒ Object (readonly)
The reason for the refund.
240 241 242 |
# File 'lib/stripe/resources/terminal/reader.rb', line 240 def reason @reason end |
#refund ⇒ Object (readonly)
Unique identifier for the refund object.
243 244 245 |
# File 'lib/stripe/resources/terminal/reader.rb', line 243 def refund @refund end |
#refund_application_fee ⇒ Object (readonly)
Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.
246 247 248 |
# File 'lib/stripe/resources/terminal/reader.rb', line 246 def refund_application_fee @refund_application_fee end |
#refund_payment_config ⇒ Object (readonly)
Represents a per-transaction override of a reader configuration
249 250 251 |
# File 'lib/stripe/resources/terminal/reader.rb', line 249 def refund_payment_config @refund_payment_config end |
#reverse_transfer ⇒ Object (readonly)
Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.
252 253 254 |
# File 'lib/stripe/resources/terminal/reader.rb', line 252 def reverse_transfer @reverse_transfer end |
#stripe_account ⇒ Object (readonly)
This field will be deprecated. Please use ‘account` instead.
255 256 257 |
# File 'lib/stripe/resources/terminal/reader.rb', line 255 def stripe_account @stripe_account end |