Class: Stripe::Terminal::Reader::CollectInputsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: Input

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams

Returns a new instance of CollectInputsParams.



393
394
395
396
397
# File 'lib/stripe/resources/terminal/reader.rb', line 393

def initialize(expand: nil, inputs: nil, metadata: nil)
  @expand = expand
  @inputs = inputs
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



387
388
389
# File 'lib/stripe/resources/terminal/reader.rb', line 387

def expand
  @expand
end

#inputsObject

List of inputs to be collected using the Reader



389
390
391
# File 'lib/stripe/resources/terminal/reader.rb', line 389

def inputs
  @inputs
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



391
392
393
# File 'lib/stripe/resources/terminal/reader.rb', line 391

def 
  @metadata
end