Class: Stripe::Terminal::Reader::CollectInputsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Input
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inputs ⇒ Object
List of inputs to be collected using the Reader.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams
constructor
A new instance of CollectInputsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams
Returns a new instance of CollectInputsParams.
393 394 395 396 397 |
# File 'lib/stripe/resources/terminal/reader.rb', line 393 def initialize(expand: nil, inputs: nil, metadata: nil) @expand = @inputs = inputs @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
387 388 389 |
# File 'lib/stripe/resources/terminal/reader.rb', line 387 def @expand end |
#inputs ⇒ Object
List of inputs to be collected using the Reader
389 390 391 |
# File 'lib/stripe/resources/terminal/reader.rb', line 389 def inputs @inputs end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
391 392 393 |
# File 'lib/stripe/resources/terminal/reader.rb', line 391 def @metadata end |