Class: Stripe::Terminal::Reader::CollectInputsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Input
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#inputs ⇒ Object
List of inputs to be collected using the Reader.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams
constructor
A new instance of CollectInputsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams
Returns a new instance of CollectInputsParams.
434 435 436 437 438 |
# File 'lib/stripe/resources/terminal/reader.rb', line 434 def initialize(expand: nil, inputs: nil, metadata: nil) @expand = @inputs = inputs @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
428 429 430 |
# File 'lib/stripe/resources/terminal/reader.rb', line 428 def @expand end |
#inputs ⇒ Object
List of inputs to be collected using the Reader
430 431 432 |
# File 'lib/stripe/resources/terminal/reader.rb', line 430 def inputs @inputs end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
432 433 434 |
# File 'lib/stripe/resources/terminal/reader.rb', line 432 def @metadata end |