Class: Stripe::Terminal::Reader::CollectInputsParams::Input
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CustomText, Selection, Toggle
Instance Attribute Summary collapse
-
#custom_text ⇒ Object
Customize the text which will be displayed while collecting this input.
-
#required ⇒ Object
Indicate that this input is required, disabling the skip button.
-
#selection ⇒ Object
Options for the ‘selection` input.
-
#toggles ⇒ Object
List of toggles to be displayed and customization for the toggles.
-
#type ⇒ Object
The type of input to collect.
Instance Method Summary collapse
-
#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input
constructor
A new instance of Input.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input
Returns a new instance of Input.
659 660 661 662 663 664 665 |
# File 'lib/stripe/resources/terminal/reader.rb', line 659 def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) @custom_text = custom_text @required = required @selection = selection @toggles = toggles @type = type end |
Instance Attribute Details
#custom_text ⇒ Object
Customize the text which will be displayed while collecting this input
649 650 651 |
# File 'lib/stripe/resources/terminal/reader.rb', line 649 def custom_text @custom_text end |
#required ⇒ Object
Indicate that this input is required, disabling the skip button
651 652 653 |
# File 'lib/stripe/resources/terminal/reader.rb', line 651 def required @required end |
#selection ⇒ Object
Options for the ‘selection` input
653 654 655 |
# File 'lib/stripe/resources/terminal/reader.rb', line 653 def selection @selection end |
#toggles ⇒ Object
List of toggles to be displayed and customization for the toggles
655 656 657 |
# File 'lib/stripe/resources/terminal/reader.rb', line 655 def toggles @toggles end |
#type ⇒ Object
The type of input to collect
657 658 659 |
# File 'lib/stripe/resources/terminal/reader.rb', line 657 def type @type end |