Class: Stripe::Terminal::Reader::CollectInputsParams::Input

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CustomText, Selection, Toggle

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input

Returns a new instance of Input.



426
427
428
429
430
431
432
# File 'lib/stripe/resources/terminal/reader.rb', line 426

def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil)
  @custom_text = custom_text
  @required = required
  @selection = selection
  @toggles = toggles
  @type = type
end

Instance Attribute Details

#custom_textObject

Customize the text which will be displayed while collecting this input



416
417
418
# File 'lib/stripe/resources/terminal/reader.rb', line 416

def custom_text
  @custom_text
end

#requiredObject

Indicate that this input is required, disabling the skip button



418
419
420
# File 'lib/stripe/resources/terminal/reader.rb', line 418

def required
  @required
end

#selectionObject

Options for the ‘selection` input



420
421
422
# File 'lib/stripe/resources/terminal/reader.rb', line 420

def selection
  @selection
end

#togglesObject

List of toggles to be displayed and customization for the toggles



422
423
424
# File 'lib/stripe/resources/terminal/reader.rb', line 422

def toggles
  @toggles
end

#typeObject

The type of input to collect



424
425
426
# File 'lib/stripe/resources/terminal/reader.rb', line 424

def type
  @type
end