Class: Stripe::Terminal::Reader::CollectInputsParams::Input

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CustomText, Selection, Toggle

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input

Returns a new instance of Input.



378
379
380
381
382
383
384
# File 'lib/stripe/resources/terminal/reader.rb', line 378

def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil)
  @custom_text = custom_text
  @required = required
  @selection = selection
  @toggles = toggles
  @type = type
end

Instance Attribute Details

#custom_textObject

Customize the text which will be displayed while collecting this input



368
369
370
# File 'lib/stripe/resources/terminal/reader.rb', line 368

def custom_text
  @custom_text
end

#requiredObject

Indicate that this input is required, disabling the skip button



370
371
372
# File 'lib/stripe/resources/terminal/reader.rb', line 370

def required
  @required
end

#selectionObject

Options for the ‘selection` input



372
373
374
# File 'lib/stripe/resources/terminal/reader.rb', line 372

def selection
  @selection
end

#togglesObject

List of toggles to be displayed and customization for the toggles



374
375
376
# File 'lib/stripe/resources/terminal/reader.rb', line 374

def toggles
  @toggles
end

#typeObject

The type of input to collect



376
377
378
# File 'lib/stripe/resources/terminal/reader.rb', line 376

def type
  @type
end