Class: Stripe::Terminal::Reader::CollectInputsParams::Input

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CustomText, Selection, Toggle

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input

Returns a new instance of Input.



419
420
421
422
423
424
425
# File 'lib/stripe/resources/terminal/reader.rb', line 419

def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil)
  @custom_text = custom_text
  @required = required
  @selection = selection
  @toggles = toggles
  @type = type
end

Instance Attribute Details

#custom_textObject

Customize the text which will be displayed while collecting this input



409
410
411
# File 'lib/stripe/resources/terminal/reader.rb', line 409

def custom_text
  @custom_text
end

#requiredObject

Indicate that this input is required, disabling the skip button



411
412
413
# File 'lib/stripe/resources/terminal/reader.rb', line 411

def required
  @required
end

#selectionObject

Options for the ‘selection` input



413
414
415
# File 'lib/stripe/resources/terminal/reader.rb', line 413

def selection
  @selection
end

#togglesObject

List of toggles to be displayed and customization for the toggles



415
416
417
# File 'lib/stripe/resources/terminal/reader.rb', line 415

def toggles
  @toggles
end

#typeObject

The type of input to collect



417
418
419
# File 'lib/stripe/resources/terminal/reader.rb', line 417

def type
  @type
end