Class: Stripe::Terminal::Reader::CollectInputsParams::Input
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CustomText, Selection, Toggle
Instance Attribute Summary collapse
-
#custom_text ⇒ Object
Customize the text which will be displayed while collecting this input.
-
#required ⇒ Object
Indicate that this input is required, disabling the skip button.
-
#selection ⇒ Object
Options for the ‘selection` input.
-
#toggles ⇒ Object
List of toggles to be displayed and customization for the toggles.
-
#type ⇒ Object
The type of input to collect.
Instance Method Summary collapse
-
#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input
constructor
A new instance of Input.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input
Returns a new instance of Input.
421 422 423 424 425 426 427 |
# File 'lib/stripe/resources/terminal/reader.rb', line 421 def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) @custom_text = custom_text @required = required @selection = selection @toggles = toggles @type = type end |
Instance Attribute Details
#custom_text ⇒ Object
Customize the text which will be displayed while collecting this input
411 412 413 |
# File 'lib/stripe/resources/terminal/reader.rb', line 411 def custom_text @custom_text end |
#required ⇒ Object
Indicate that this input is required, disabling the skip button
413 414 415 |
# File 'lib/stripe/resources/terminal/reader.rb', line 413 def required @required end |
#selection ⇒ Object
Options for the ‘selection` input
415 416 417 |
# File 'lib/stripe/resources/terminal/reader.rb', line 415 def selection @selection end |
#toggles ⇒ Object
List of toggles to be displayed and customization for the toggles
417 418 419 |
# File 'lib/stripe/resources/terminal/reader.rb', line 417 def toggles @toggles end |
#type ⇒ Object
The type of input to collect
419 420 421 |
# File 'lib/stripe/resources/terminal/reader.rb', line 419 def type @type end |