Class: Stripe::Terminal::Reader::CollectInputsParams::Input

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: CustomText, Selection, Toggle

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input

Returns a new instance of Input.



429
430
431
432
433
434
435
# File 'lib/stripe/resources/terminal/reader.rb', line 429

def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil)
  @custom_text = custom_text
  @required = required
  @selection = selection
  @toggles = toggles
  @type = type
end

Instance Attribute Details

#custom_textObject

Customize the text which will be displayed while collecting this input



419
420
421
# File 'lib/stripe/resources/terminal/reader.rb', line 419

def custom_text
  @custom_text
end

#requiredObject

Indicate that this input is required, disabling the skip button



421
422
423
# File 'lib/stripe/resources/terminal/reader.rb', line 421

def required
  @required
end

#selectionObject

Options for the ‘selection` input



423
424
425
# File 'lib/stripe/resources/terminal/reader.rb', line 423

def selection
  @selection
end

#togglesObject

List of toggles to be displayed and customization for the toggles



425
426
427
# File 'lib/stripe/resources/terminal/reader.rb', line 425

def toggles
  @toggles
end

#typeObject

The type of input to collect



427
428
429
# File 'lib/stripe/resources/terminal/reader.rb', line 427

def type
  @type
end