Class: Stripe::Terminal::Reader::CollectInputsParams::Input::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input::CustomText
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The description which will be displayed when collecting this input.
-
#skip_button ⇒ Object
The skip button text.
-
#submit_button ⇒ Object
The submit button text.
-
#title ⇒ Object
The title which will be displayed when collecting this input.
Instance Method Summary collapse
-
#initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) ⇒ CustomText
Returns a new instance of CustomText.
603 604 605 606 607 608 |
# File 'lib/stripe/resources/terminal/reader.rb', line 603 def initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) @description = description @skip_button = @submit_button = @title = title end |
Instance Attribute Details
#description ⇒ Object
The description which will be displayed when collecting this input
595 596 597 |
# File 'lib/stripe/resources/terminal/reader.rb', line 595 def description @description end |
#skip_button ⇒ Object
The skip button text
597 598 599 |
# File 'lib/stripe/resources/terminal/reader.rb', line 597 def @skip_button end |
#submit_button ⇒ Object
The submit button text
599 600 601 |
# File 'lib/stripe/resources/terminal/reader.rb', line 599 def @submit_button end |
#title ⇒ Object
The title which will be displayed when collecting this input
601 602 603 |
# File 'lib/stripe/resources/terminal/reader.rb', line 601 def title @title end |