Class: Stripe::Terminal::Reader::CollectInputsParams::Input::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) ⇒ CustomText

Returns a new instance of CustomText.



363
364
365
366
367
368
# File 'lib/stripe/resources/terminal/reader.rb', line 363

def initialize(description: nil, skip_button: nil, submit_button: nil, title: nil)
  @description = description
  @skip_button = skip_button
  @submit_button = submit_button
  @title = title
end

Instance Attribute Details

#descriptionObject

The description which will be displayed when collecting this input



355
356
357
# File 'lib/stripe/resources/terminal/reader.rb', line 355

def description
  @description
end

#skip_buttonObject

The skip button text



357
358
359
# File 'lib/stripe/resources/terminal/reader.rb', line 357

def skip_button
  @skip_button
end

#submit_buttonObject

The submit button text



359
360
361
# File 'lib/stripe/resources/terminal/reader.rb', line 359

def submit_button
  @submit_button
end

#titleObject

The title which will be displayed when collecting this input



361
362
363
# File 'lib/stripe/resources/terminal/reader.rb', line 361

def title
  @title
end