Class: Stripe::Terminal::Reader::CollectInputsParams::Input::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) ⇒ CustomText

Returns a new instance of CustomText.



376
377
378
379
380
381
# File 'lib/stripe/resources/terminal/reader.rb', line 376

def initialize(description: nil, skip_button: nil, submit_button: nil, title: nil)
  @description = description
  @skip_button = skip_button
  @submit_button = submit_button
  @title = title
end

Instance Attribute Details

#descriptionObject

The description which will be displayed when collecting this input



368
369
370
# File 'lib/stripe/resources/terminal/reader.rb', line 368

def description
  @description
end

#skip_buttonObject

The skip button text



370
371
372
# File 'lib/stripe/resources/terminal/reader.rb', line 370

def skip_button
  @skip_button
end

#submit_buttonObject

The submit button text



372
373
374
# File 'lib/stripe/resources/terminal/reader.rb', line 372

def submit_button
  @submit_button
end

#titleObject

The title which will be displayed when collecting this input



374
375
376
# File 'lib/stripe/resources/terminal/reader.rb', line 374

def title
  @title
end