Class: Stripe::Terminal::Reader::CollectInputsParams::Input::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input::CustomText
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The description which will be displayed when collecting this input.
-
#skip_button ⇒ Object
The skip button text.
-
#submit_button ⇒ Object
The submit button text.
-
#title ⇒ Object
The title which will be displayed when collecting this input.
Instance Method Summary collapse
-
#initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) ⇒ CustomText
Returns a new instance of CustomText.
368 369 370 371 372 373 |
# File 'lib/stripe/resources/terminal/reader.rb', line 368 def initialize(description: nil, skip_button: nil, submit_button: nil, title: nil) @description = description @skip_button = @submit_button = @title = title end |
Instance Attribute Details
#description ⇒ Object
The description which will be displayed when collecting this input
360 361 362 |
# File 'lib/stripe/resources/terminal/reader.rb', line 360 def description @description end |
#skip_button ⇒ Object
The skip button text
362 363 364 |
# File 'lib/stripe/resources/terminal/reader.rb', line 362 def @skip_button end |
#submit_button ⇒ Object
The submit button text
364 365 366 |
# File 'lib/stripe/resources/terminal/reader.rb', line 364 def @submit_button end |
#title ⇒ Object
The title which will be displayed when collecting this input
366 367 368 |
# File 'lib/stripe/resources/terminal/reader.rb', line 366 def title @title end |