Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier for this choice.
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#text ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
Returns a new instance of Choice.
620 621 622 623 624 |
# File 'lib/stripe/resources/terminal/reader.rb', line 620 def initialize(id: nil, style: nil, text: nil) @id = id @style = style @text = text end |
Instance Attribute Details
#id ⇒ Object
The unique identifier for this choice
614 615 616 |
# File 'lib/stripe/resources/terminal/reader.rb', line 614 def id @id end |
#style ⇒ Object
The style of the button which will be shown for this choice
616 617 618 |
# File 'lib/stripe/resources/terminal/reader.rb', line 616 def style @style end |
#text ⇒ Object
The text which will be shown on the button for this choice
618 619 620 |
# File 'lib/stripe/resources/terminal/reader.rb', line 618 def text @text end |