Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, style: nil, text: nil) ⇒ Choice

Returns a new instance of Choice.



379
380
381
382
383
# File 'lib/stripe/resources/terminal/reader.rb', line 379

def initialize(id: nil, style: nil, text: nil)
  @id = id
  @style = style
  @text = text
end

Instance Attribute Details

#idObject

The unique identifier for this choice



373
374
375
# File 'lib/stripe/resources/terminal/reader.rb', line 373

def id
  @id
end

#styleObject

The style of the button which will be shown for this choice



375
376
377
# File 'lib/stripe/resources/terminal/reader.rb', line 375

def style
  @style
end

#textObject

The text which will be shown on the button for this choice



377
378
379
# File 'lib/stripe/resources/terminal/reader.rb', line 377

def text
  @text
end