Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier for this choice.
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#text ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
Returns a new instance of Choice.
387 388 389 390 391 |
# File 'lib/stripe/resources/terminal/reader.rb', line 387 def initialize(id: nil, style: nil, text: nil) @id = id @style = style @text = text end |
Instance Attribute Details
#id ⇒ Object
The unique identifier for this choice
381 382 383 |
# File 'lib/stripe/resources/terminal/reader.rb', line 381 def id @id end |
#style ⇒ Object
The style of the button which will be shown for this choice
383 384 385 |
# File 'lib/stripe/resources/terminal/reader.rb', line 383 def style @style end |
#text ⇒ Object
The text which will be shown on the button for this choice
385 386 387 |
# File 'lib/stripe/resources/terminal/reader.rb', line 385 def text @text end |