Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(style: nil, value: nil) ⇒ Choice

Returns a new instance of Choice.



383
384
385
386
# File 'lib/stripe/resources/terminal/reader.rb', line 383

def initialize(style: nil, value: nil)
  @style = style
  @value = value
end

Instance Attribute Details

#styleObject

The style of the button which will be shown for this choice



379
380
381
# File 'lib/stripe/resources/terminal/reader.rb', line 379

def style
  @style
end

#valueObject

The text which will be shown on the button for this choice



381
382
383
# File 'lib/stripe/resources/terminal/reader.rb', line 381

def value
  @value
end