Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(style: nil, value: nil) ⇒ Choice

Returns a new instance of Choice.



468
469
470
471
# File 'lib/stripe/resources/terminal/reader.rb', line 468

def initialize(style: nil, value: nil)
  @style = style
  @value = value
end

Instance Attribute Details

#styleObject

The style of the button which will be shown for this choice



463
464
465
# File 'lib/stripe/resources/terminal/reader.rb', line 463

def style
  @style
end

#valueObject

The text which will be shown on the button for this choice



466
467
468
# File 'lib/stripe/resources/terminal/reader.rb', line 466

def value
  @value
end