Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(style: nil, value: nil) ⇒ Choice

Returns a new instance of Choice.



391
392
393
394
# File 'lib/stripe/resources/terminal/reader.rb', line 391

def initialize(style: nil, value: nil)
  @style = style
  @value = value
end

Instance Attribute Details

#styleObject

The style of the button which will be shown for this choice



387
388
389
# File 'lib/stripe/resources/terminal/reader.rb', line 387

def style
  @style
end

#valueObject

The text which will be shown on the button for this choice



389
390
391
# File 'lib/stripe/resources/terminal/reader.rb', line 389

def value
  @value
end