Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#value ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(style: nil, value: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(style: nil, value: nil) ⇒ Choice
Returns a new instance of Choice.
391 392 393 394 |
# File 'lib/stripe/resources/terminal/reader.rb', line 391 def initialize(style: nil, value: nil) @style = style @value = value end |
Instance Attribute Details
#style ⇒ Object
The style of the button which will be shown for this choice
387 388 389 |
# File 'lib/stripe/resources/terminal/reader.rb', line 387 def style @style end |
#value ⇒ Object
The text which will be shown on the button for this choice
389 390 391 |
# File 'lib/stripe/resources/terminal/reader.rb', line 389 def value @value end |