Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Toggle

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle

Returns a new instance of Toggle.



361
362
363
364
365
# File 'lib/stripe/resources/terminal/reader.rb', line 361

def initialize(default_value: nil, description: nil, title: nil)
  @default_value = default_value
  @description = description
  @title = title
end

Instance Attribute Details

#default_valueObject

The default value of the toggle



355
356
357
# File 'lib/stripe/resources/terminal/reader.rb', line 355

def default_value
  @default_value
end

#descriptionObject

The description which will be displayed for the toggle



357
358
359
# File 'lib/stripe/resources/terminal/reader.rb', line 357

def description
  @description
end

#titleObject

The title which will be displayed for the toggle



359
360
361
# File 'lib/stripe/resources/terminal/reader.rb', line 359

def title
  @title
end