Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Toggle

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle

Returns a new instance of Toggle.



491
492
493
494
495
# File 'lib/stripe/resources/terminal/reader.rb', line 491

def initialize(default_value: nil, description: nil, title: nil)
  @default_value = default_value
  @description = description
  @title = title
end

Instance Attribute Details

#default_valueObject

The default value of the toggle



483
484
485
# File 'lib/stripe/resources/terminal/reader.rb', line 483

def default_value
  @default_value
end

#descriptionObject

The description which will be displayed for the toggle



486
487
488
# File 'lib/stripe/resources/terminal/reader.rb', line 486

def description
  @description
end

#titleObject

The title which will be displayed for the toggle



489
490
491
# File 'lib/stripe/resources/terminal/reader.rb', line 489

def title
  @title
end