Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Toggle

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle

Returns a new instance of Toggle.



404
405
406
407
408
# File 'lib/stripe/resources/terminal/reader.rb', line 404

def initialize(default_value: nil, description: nil, title: nil)
  @default_value = default_value
  @description = description
  @title = title
end

Instance Attribute Details

#default_valueObject

The default value of the toggle



398
399
400
# File 'lib/stripe/resources/terminal/reader.rb', line 398

def default_value
  @default_value
end

#descriptionObject

The description which will be displayed for the toggle



400
401
402
# File 'lib/stripe/resources/terminal/reader.rb', line 400

def description
  @description
end

#titleObject

The title which will be displayed for the toggle



402
403
404
# File 'lib/stripe/resources/terminal/reader.rb', line 402

def title
  @title
end