Class: Stripe::Terminal::Reader::CollectInputsParams::Input::Toggle
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectInputsParams::Input::Toggle
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#default_value ⇒ Object
The default value of the toggle.
-
#description ⇒ Object
The description which will be displayed for the toggle.
-
#title ⇒ Object
The title which will be displayed for the toggle.
Instance Method Summary collapse
-
#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle
constructor
A new instance of Toggle.
Methods inherited from RequestParams
Constructor Details
#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle
Returns a new instance of Toggle.
491 492 493 494 495 |
# File 'lib/stripe/resources/terminal/reader.rb', line 491 def initialize(default_value: nil, description: nil, title: nil) @default_value = default_value @description = description @title = title end |
Instance Attribute Details
#default_value ⇒ Object
The default value of the toggle
483 484 485 |
# File 'lib/stripe/resources/terminal/reader.rb', line 483 def default_value @default_value end |
#description ⇒ Object
The description which will be displayed for the toggle
486 487 488 |
# File 'lib/stripe/resources/terminal/reader.rb', line 486 def description @description end |
#title ⇒ Object
The title which will be displayed for the toggle
489 490 491 |
# File 'lib/stripe/resources/terminal/reader.rb', line 489 def title @title end |