Class: Stripe::Terminal::Reader::CollectPaymentMethodParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectPaymentMethodParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CollectConfig
Instance Attribute Summary collapse
-
#collect_config ⇒ Object
Configuration overrides.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
PaymentIntent ID.
Instance Method Summary collapse
-
#initialize(collect_config: nil, expand: nil, payment_intent: nil) ⇒ CollectPaymentMethodParams
constructor
A new instance of CollectPaymentMethodParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collect_config: nil, expand: nil, payment_intent: nil) ⇒ CollectPaymentMethodParams
Returns a new instance of CollectPaymentMethodParams.
479 480 481 482 483 |
# File 'lib/stripe/resources/terminal/reader.rb', line 479 def initialize(collect_config: nil, expand: nil, payment_intent: nil) @collect_config = collect_config @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#collect_config ⇒ Object
Configuration overrides
473 474 475 |
# File 'lib/stripe/resources/terminal/reader.rb', line 473 def collect_config @collect_config end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
475 476 477 |
# File 'lib/stripe/resources/terminal/reader.rb', line 475 def @expand end |
#payment_intent ⇒ Object
PaymentIntent ID
477 478 479 |
# File 'lib/stripe/resources/terminal/reader.rb', line 477 def payment_intent @payment_intent end |