Class: Stripe::Terminal::Reader::CollectPaymentMethodParams::CollectConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CollectPaymentMethodParams::CollectConfig
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Tipping
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
-
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
-
#tipping ⇒ Object
Tipping configuration for this transaction.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ CollectConfig
constructor
A new instance of CollectConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ CollectConfig
Returns a new instance of CollectConfig.
467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/stripe/resources/terminal/reader.rb', line 467 def initialize( allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil ) @allow_redisplay = allow_redisplay @enable_customer_cancellation = enable_customer_cancellation @skip_tipping = skip_tipping @tipping = tipping end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
459 460 461 |
# File 'lib/stripe/resources/terminal/reader.rb', line 459 def allow_redisplay @allow_redisplay end |
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
461 462 463 |
# File 'lib/stripe/resources/terminal/reader.rb', line 461 def enable_customer_cancellation @enable_customer_cancellation end |
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
463 464 465 |
# File 'lib/stripe/resources/terminal/reader.rb', line 463 def skip_tipping @skip_tipping end |
#tipping ⇒ Object
Tipping configuration for this transaction.
465 466 467 |
# File 'lib/stripe/resources/terminal/reader.rb', line 465 def tipping @tipping end |