Class: Stripe::Terminal::Reader::ConfirmPaymentIntentParams::ConfirmConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(return_url: nil) ⇒ ConfirmConfig

Returns a new instance of ConfirmConfig.



498
499
500
# File 'lib/stripe/resources/terminal/reader.rb', line 498

def initialize(return_url: nil)
  @return_url = return_url
end

Instance Attribute Details

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.



496
497
498
# File 'lib/stripe/resources/terminal/reader.rb', line 496

def return_url
  @return_url
end