Class: Stripe::Terminal::Reader::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/stripe/resources/terminal/reader.rb', line 286

def initialize(
  expand: nil,
  label: nil,
  location: nil,
  metadata: nil,
  registration_code: nil
)
  @expand = expand
  @label = label
  @location = location
  @metadata = 
  @registration_code = registration_code
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



276
277
278
# File 'lib/stripe/resources/terminal/reader.rb', line 276

def expand
  @expand
end

#labelObject

Custom label given to the reader for easier identification. If no label is specified, the registration code will be used.



278
279
280
# File 'lib/stripe/resources/terminal/reader.rb', line 278

def label
  @label
end

#locationObject

The location to assign the reader to.



280
281
282
# File 'lib/stripe/resources/terminal/reader.rb', line 280

def location
  @location
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



282
283
284
# File 'lib/stripe/resources/terminal/reader.rb', line 282

def 
  @metadata
end

#registration_codeObject

A code generated by the reader used for registering to an account.



284
285
286
# File 'lib/stripe/resources/terminal/reader.rb', line 284

def registration_code
  @registration_code
end