Class: Stripe::Terminal::Reader::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/stripe/resources/terminal/reader.rb', line 189

def initialize(
  expand: nil,
  label: nil,
  location: nil,
  metadata: nil,
  registration_code: nil
)
  @expand = expand
  @label = label
  @location = location
  @metadata = 
  @registration_code = registration_code
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



179
180
181
# File 'lib/stripe/resources/terminal/reader.rb', line 179

def expand
  @expand
end

#labelObject

Custom label given to the reader for easier identification. If no label is specified, the registration code will be used.



181
182
183
# File 'lib/stripe/resources/terminal/reader.rb', line 181

def label
  @label
end

#locationObject

The location to assign the reader to.



183
184
185
# File 'lib/stripe/resources/terminal/reader.rb', line 183

def location
  @location
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



185
186
187
# File 'lib/stripe/resources/terminal/reader.rb', line 185

def 
  @metadata
end

#registration_codeObject

A code generated by the reader used for registering to an account.



187
188
189
# File 'lib/stripe/resources/terminal/reader.rb', line 187

def registration_code
  @registration_code
end