Class: Stripe::Terminal::Reader::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CreateParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#label ⇒ Object
Custom label given to the reader for easier identification.
-
#location ⇒ Object
The location to assign the reader to.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#registration_code ⇒ Object
A code generated by the reader used for registering to an account.
Instance Method Summary collapse
-
#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/stripe/resources/terminal/reader.rb', line 413 def initialize( expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil ) @expand = @label = label @location = location @metadata = @registration_code = registration_code end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
399 400 401 |
# File 'lib/stripe/resources/terminal/reader.rb', line 399 def @expand end |
#label ⇒ Object
Custom label given to the reader for easier identification. If no label is specified, the registration code will be used.
402 403 404 |
# File 'lib/stripe/resources/terminal/reader.rb', line 402 def label @label end |
#location ⇒ Object
The location to assign the reader to.
405 406 407 |
# File 'lib/stripe/resources/terminal/reader.rb', line 405 def location @location end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
408 409 410 |
# File 'lib/stripe/resources/terminal/reader.rb', line 408 def @metadata end |
#registration_code ⇒ Object
A code generated by the reader used for registering to an account.
411 412 413 |
# File 'lib/stripe/resources/terminal/reader.rb', line 411 def registration_code @registration_code end |