Class: Stripe::Terminal::Reader::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::CreateParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#label ⇒ Object
Custom label given to the reader for easier identification.
-
#location ⇒ Object
The location to assign the reader to.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#registration_code ⇒ Object
A code generated by the reader used for registering to an account.
Instance Method Summary collapse
-
#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/stripe/resources/terminal/reader.rb', line 340 def initialize( expand: nil, label: nil, location: nil, metadata: nil, registration_code: nil ) @expand = @label = label @location = location @metadata = @registration_code = registration_code end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
330 331 332 |
# File 'lib/stripe/resources/terminal/reader.rb', line 330 def @expand end |
#label ⇒ Object
Custom label given to the reader for easier identification. If no label is specified, the registration code will be used.
332 333 334 |
# File 'lib/stripe/resources/terminal/reader.rb', line 332 def label @label end |
#location ⇒ Object
The location to assign the reader to.
334 335 336 |
# File 'lib/stripe/resources/terminal/reader.rb', line 334 def location @location end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
336 337 338 |
# File 'lib/stripe/resources/terminal/reader.rb', line 336 def @metadata end |
#registration_code ⇒ Object
A code generated by the reader used for registering to an account.
338 339 340 |
# File 'lib/stripe/resources/terminal/reader.rb', line 338 def registration_code @registration_code end |