Class: Stripe::Terminal::Reader::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/stripe/resources/terminal/reader.rb', line 301

def initialize(
  device_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  location: nil,
  serial_number: nil,
  starting_after: nil,
  status: nil
)
  @device_type = device_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @location = location
  @serial_number = serial_number
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#device_typeObject

Filters readers by device type



285
286
287
# File 'lib/stripe/resources/terminal/reader.rb', line 285

def device_type
  @device_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



287
288
289
# File 'lib/stripe/resources/terminal/reader.rb', line 287

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



289
290
291
# File 'lib/stripe/resources/terminal/reader.rb', line 289

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



291
292
293
# File 'lib/stripe/resources/terminal/reader.rb', line 291

def limit
  @limit
end

#locationObject

A location ID to filter the response list to only readers at the specific location



293
294
295
# File 'lib/stripe/resources/terminal/reader.rb', line 293

def location
  @location
end

#serial_numberObject

Filters readers by serial number



295
296
297
# File 'lib/stripe/resources/terminal/reader.rb', line 295

def serial_number
  @serial_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



297
298
299
# File 'lib/stripe/resources/terminal/reader.rb', line 297

def starting_after
  @starting_after
end

#statusObject

A status filter to filter readers to only offline or online readers



299
300
301
# File 'lib/stripe/resources/terminal/reader.rb', line 299

def status
  @status
end