Class: Stripe::Terminal::Reader::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/stripe/resources/terminal/reader.rb', line 253

def initialize(
  device_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  location: nil,
  serial_number: nil,
  starting_after: nil,
  status: nil
)
  @device_type = device_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @location = location
  @serial_number = serial_number
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#device_typeObject

Filters readers by device type



237
238
239
# File 'lib/stripe/resources/terminal/reader.rb', line 237

def device_type
  @device_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



239
240
241
# File 'lib/stripe/resources/terminal/reader.rb', line 239

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



241
242
243
# File 'lib/stripe/resources/terminal/reader.rb', line 241

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



243
244
245
# File 'lib/stripe/resources/terminal/reader.rb', line 243

def limit
  @limit
end

#locationObject

A location ID to filter the response list to only readers at the specific location



245
246
247
# File 'lib/stripe/resources/terminal/reader.rb', line 245

def location
  @location
end

#serial_numberObject

Filters readers by serial number



247
248
249
# File 'lib/stripe/resources/terminal/reader.rb', line 247

def serial_number
  @serial_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



249
250
251
# File 'lib/stripe/resources/terminal/reader.rb', line 249

def starting_after
  @starting_after
end

#statusObject

A status filter to filter readers to only offline or online readers



251
252
253
# File 'lib/stripe/resources/terminal/reader.rb', line 251

def status
  @status
end