Class: Stripe::Terminal::Reader::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/stripe/resources/terminal/reader.rb', line 156

def initialize(
  device_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  location: nil,
  serial_number: nil,
  starting_after: nil,
  status: nil
)
  @device_type = device_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @location = location
  @serial_number = serial_number
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#device_typeObject

Filters readers by device type



140
141
142
# File 'lib/stripe/resources/terminal/reader.rb', line 140

def device_type
  @device_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



142
143
144
# File 'lib/stripe/resources/terminal/reader.rb', line 142

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



144
145
146
# File 'lib/stripe/resources/terminal/reader.rb', line 144

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



146
147
148
# File 'lib/stripe/resources/terminal/reader.rb', line 146

def limit
  @limit
end

#locationObject

A location ID to filter the response list to only readers at the specific location



148
149
150
# File 'lib/stripe/resources/terminal/reader.rb', line 148

def location
  @location
end

#serial_numberObject

Filters readers by serial number



150
151
152
# File 'lib/stripe/resources/terminal/reader.rb', line 150

def serial_number
  @serial_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



152
153
154
# File 'lib/stripe/resources/terminal/reader.rb', line 152

def starting_after
  @starting_after
end

#statusObject

A status filter to filter readers to only offline or online readers



154
155
156
# File 'lib/stripe/resources/terminal/reader.rb', line 154

def status
  @status
end