Class: Stripe::Terminal::Reader::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ListParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#device_type ⇒ Object
Filters readers by device type.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#location ⇒ Object
A location ID to filter the response list to only readers at the specific location.
-
#serial_number ⇒ Object
Filters readers by serial number.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
A status filter to filter readers to only offline or online readers.
Instance Method Summary collapse
-
#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/stripe/resources/terminal/reader.rb', line 294 def initialize( device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil ) @device_type = device_type @ending_before = ending_before @expand = @limit = limit @location = location @serial_number = serial_number @starting_after = starting_after @status = status end |
Instance Attribute Details
#device_type ⇒ Object
Filters readers by device type
278 279 280 |
# File 'lib/stripe/resources/terminal/reader.rb', line 278 def device_type @device_type end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
280 281 282 |
# File 'lib/stripe/resources/terminal/reader.rb', line 280 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
282 283 284 |
# File 'lib/stripe/resources/terminal/reader.rb', line 282 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
284 285 286 |
# File 'lib/stripe/resources/terminal/reader.rb', line 284 def limit @limit end |
#location ⇒ Object
A location ID to filter the response list to only readers at the specific location
286 287 288 |
# File 'lib/stripe/resources/terminal/reader.rb', line 286 def location @location end |
#serial_number ⇒ Object
Filters readers by serial number
288 289 290 |
# File 'lib/stripe/resources/terminal/reader.rb', line 288 def serial_number @serial_number end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
290 291 292 |
# File 'lib/stripe/resources/terminal/reader.rb', line 290 def starting_after @starting_after end |
#status ⇒ Object
A status filter to filter readers to only offline or online readers
292 293 294 |
# File 'lib/stripe/resources/terminal/reader.rb', line 292 def status @status end |