Class: Stripe::Terminal::Reader::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/stripe/resources/terminal/reader.rb', line 376

def initialize(
  device_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  location: nil,
  serial_number: nil,
  starting_after: nil,
  status: nil
)
  @device_type = device_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @location = location
  @serial_number = serial_number
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#device_typeObject

Filters readers by device type



353
354
355
# File 'lib/stripe/resources/terminal/reader.rb', line 353

def device_type
  @device_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



356
357
358
# File 'lib/stripe/resources/terminal/reader.rb', line 356

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



359
360
361
# File 'lib/stripe/resources/terminal/reader.rb', line 359

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



362
363
364
# File 'lib/stripe/resources/terminal/reader.rb', line 362

def limit
  @limit
end

#locationObject

A location ID to filter the response list to only readers at the specific location



365
366
367
# File 'lib/stripe/resources/terminal/reader.rb', line 365

def location
  @location
end

#serial_numberObject

Filters readers by serial number



368
369
370
# File 'lib/stripe/resources/terminal/reader.rb', line 368

def serial_number
  @serial_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



371
372
373
# File 'lib/stripe/resources/terminal/reader.rb', line 371

def starting_after
  @starting_after
end

#statusObject

A status filter to filter readers to only offline or online readers



374
375
376
# File 'lib/stripe/resources/terminal/reader.rb', line 374

def status
  @status
end