Class: Stripe::Terminal::Reader::PresentPaymentMethodParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::PresentPaymentMethodParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Card, CardPresent, InteracPresent
Instance Attribute Summary collapse
-
#amount_tip ⇒ Object
Simulated on-reader tip amount.
-
#card ⇒ Object
Simulated data for the card payment method.
-
#card_present ⇒ Object
Simulated data for the card_present payment method.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#interac_present ⇒ Object
Simulated data for the interac_present payment method.
-
#type ⇒ Object
Simulated payment type.
Instance Method Summary collapse
-
#initialize(amount_tip: nil, card: nil, card_present: nil, expand: nil, interac_present: nil, type: nil) ⇒ PresentPaymentMethodParams
constructor
A new instance of PresentPaymentMethodParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tip: nil, card: nil, card_present: nil, expand: nil, interac_present: nil, type: nil) ⇒ PresentPaymentMethodParams
Returns a new instance of PresentPaymentMethodParams.
725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/stripe/resources/terminal/reader.rb', line 725 def initialize( amount_tip: nil, card: nil, card_present: nil, expand: nil, interac_present: nil, type: nil ) @amount_tip = amount_tip @card = card @card_present = card_present @expand = @interac_present = interac_present @type = type end |
Instance Attribute Details
#amount_tip ⇒ Object
Simulated on-reader tip amount.
713 714 715 |
# File 'lib/stripe/resources/terminal/reader.rb', line 713 def amount_tip @amount_tip end |
#card ⇒ Object
Simulated data for the card payment method.
715 716 717 |
# File 'lib/stripe/resources/terminal/reader.rb', line 715 def card @card end |
#card_present ⇒ Object
Simulated data for the card_present payment method.
717 718 719 |
# File 'lib/stripe/resources/terminal/reader.rb', line 717 def card_present @card_present end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
719 720 721 |
# File 'lib/stripe/resources/terminal/reader.rb', line 719 def @expand end |
#interac_present ⇒ Object
Simulated data for the interac_present payment method.
721 722 723 |
# File 'lib/stripe/resources/terminal/reader.rb', line 721 def interac_present @interac_present end |
#type ⇒ Object
Simulated payment type.
723 724 725 |
# File 'lib/stripe/resources/terminal/reader.rb', line 723 def type @type end |