Class: Stripe::Terminal::Reader::PresentPaymentMethodParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::PresentPaymentMethodParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: CardPresent, InteracPresent
Instance Attribute Summary collapse
-
#amount_tip ⇒ Object
Simulated on-reader tip amount.
-
#card_present ⇒ Object
Simulated data for the card_present payment method.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#interac_present ⇒ Object
Simulated data for the interac_present payment method.
-
#type ⇒ Object
Simulated payment type.
Instance Method Summary collapse
-
#initialize(amount_tip: nil, card_present: nil, expand: nil, interac_present: nil, type: nil) ⇒ PresentPaymentMethodParams
constructor
A new instance of PresentPaymentMethodParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tip: nil, card_present: nil, expand: nil, interac_present: nil, type: nil) ⇒ PresentPaymentMethodParams
Returns a new instance of PresentPaymentMethodParams.
693 694 695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/stripe/resources/terminal/reader.rb', line 693 def initialize( amount_tip: nil, card_present: nil, expand: nil, interac_present: nil, type: nil ) @amount_tip = amount_tip @card_present = card_present @expand = @interac_present = interac_present @type = type end |
Instance Attribute Details
#amount_tip ⇒ Object
Simulated on-reader tip amount.
683 684 685 |
# File 'lib/stripe/resources/terminal/reader.rb', line 683 def amount_tip @amount_tip end |
#card_present ⇒ Object
Simulated data for the card_present payment method.
685 686 687 |
# File 'lib/stripe/resources/terminal/reader.rb', line 685 def card_present @card_present end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
687 688 689 |
# File 'lib/stripe/resources/terminal/reader.rb', line 687 def @expand end |
#interac_present ⇒ Object
Simulated data for the interac_present payment method.
689 690 691 |
# File 'lib/stripe/resources/terminal/reader.rb', line 689 def interac_present @interac_present end |
#type ⇒ Object
Simulated payment type.
691 692 693 |
# File 'lib/stripe/resources/terminal/reader.rb', line 691 def type @type end |