Class: Stripe::Terminal::Reader::PresentPaymentMethodParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::PresentPaymentMethodParams::Card
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#cvc ⇒ Object
Card security code.
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
-
#number ⇒ Object
The card number, as a string without any separators.
Instance Method Summary collapse
-
#initialize(cvc: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(cvc: nil, exp_month: nil, exp_year: nil, number: nil) ⇒ Card
Returns a new instance of Card.
695 696 697 698 699 700 |
# File 'lib/stripe/resources/terminal/reader.rb', line 695 def initialize(cvc: nil, exp_month: nil, exp_year: nil, number: nil) @cvc = cvc @exp_month = exp_month @exp_year = exp_year @number = number end |
Instance Attribute Details
#cvc ⇒ Object
Card security code.
687 688 689 |
# File 'lib/stripe/resources/terminal/reader.rb', line 687 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
689 690 691 |
# File 'lib/stripe/resources/terminal/reader.rb', line 689 def exp_month @exp_month end |
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
691 692 693 |
# File 'lib/stripe/resources/terminal/reader.rb', line 691 def exp_year @exp_year end |
#number ⇒ Object
The card number, as a string without any separators.
693 694 695 |
# File 'lib/stripe/resources/terminal/reader.rb', line 693 def number @number end |