Class: Stripe::Terminal::Reader::ProcessPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ProcessPaymentIntentParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: ProcessConfig
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
PaymentIntent ID.
-
#process_config ⇒ Object
Configuration overrides.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil, process_config: nil) ⇒ ProcessPaymentIntentParams
constructor
A new instance of ProcessPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil, process_config: nil) ⇒ ProcessPaymentIntentParams
Returns a new instance of ProcessPaymentIntentParams.
442 443 444 445 446 |
# File 'lib/stripe/resources/terminal/reader.rb', line 442 def initialize(expand: nil, payment_intent: nil, process_config: nil) @expand = @payment_intent = payment_intent @process_config = process_config end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
436 437 438 |
# File 'lib/stripe/resources/terminal/reader.rb', line 436 def @expand end |
#payment_intent ⇒ Object
PaymentIntent ID
438 439 440 |
# File 'lib/stripe/resources/terminal/reader.rb', line 438 def payment_intent @payment_intent end |
#process_config ⇒ Object
Configuration overrides
440 441 442 |
# File 'lib/stripe/resources/terminal/reader.rb', line 440 def process_config @process_config end |