Class: Stripe::Terminal::Reader::ProcessPaymentIntentParams::ProcessConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: Tipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, return_url: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig

Returns a new instance of ProcessConfig.



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/stripe/resources/terminal/reader.rb', line 537

def initialize(
  allow_redisplay: nil,
  enable_customer_cancellation: nil,
  return_url: nil,
  skip_tipping: nil,
  tipping: nil
)
  @allow_redisplay = allow_redisplay
  @enable_customer_cancellation = enable_customer_cancellation
  @return_url = return_url
  @skip_tipping = skip_tipping
  @tipping = tipping
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



527
528
529
# File 'lib/stripe/resources/terminal/reader.rb', line 527

def allow_redisplay
  @allow_redisplay
end

#enable_customer_cancellationObject

Enables cancel button on transaction screens.



529
530
531
# File 'lib/stripe/resources/terminal/reader.rb', line 529

def enable_customer_cancellation
  @enable_customer_cancellation
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.



531
532
533
# File 'lib/stripe/resources/terminal/reader.rb', line 531

def return_url
  @return_url
end

#skip_tippingObject

Override showing a tipping selection screen on this transaction.



533
534
535
# File 'lib/stripe/resources/terminal/reader.rb', line 533

def skip_tipping
  @skip_tipping
end

#tippingObject

Tipping configuration for this transaction.



535
536
537
# File 'lib/stripe/resources/terminal/reader.rb', line 535

def tipping
  @tipping
end