Class: Stripe::Terminal::Reader::ProcessPaymentIntentParams::ProcessConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ProcessPaymentIntentParams::ProcessConfig
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Tipping
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
-
#tipping ⇒ Object
Tipping configuration for this transaction.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, return_url: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig
constructor
A new instance of ProcessConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, return_url: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig
Returns a new instance of ProcessConfig.
770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'lib/stripe/resources/terminal/reader.rb', line 770 def initialize( allow_redisplay: nil, enable_customer_cancellation: nil, return_url: nil, skip_tipping: nil, tipping: nil ) @allow_redisplay = allow_redisplay @enable_customer_cancellation = enable_customer_cancellation @return_url = return_url @skip_tipping = skip_tipping @tipping = tipping end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
760 761 762 |
# File 'lib/stripe/resources/terminal/reader.rb', line 760 def allow_redisplay @allow_redisplay end |
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
762 763 764 |
# File 'lib/stripe/resources/terminal/reader.rb', line 762 def enable_customer_cancellation @enable_customer_cancellation end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.
764 765 766 |
# File 'lib/stripe/resources/terminal/reader.rb', line 764 def return_url @return_url end |
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
766 767 768 |
# File 'lib/stripe/resources/terminal/reader.rb', line 766 def skip_tipping @skip_tipping end |
#tipping ⇒ Object
Tipping configuration for this transaction.
768 769 770 |
# File 'lib/stripe/resources/terminal/reader.rb', line 768 def tipping @tipping end |