Class: Stripe::Terminal::Reader::ProcessPaymentIntentParams::ProcessConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: Tipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig

Returns a new instance of ProcessConfig.



232
233
234
235
236
237
238
239
240
241
242
# File 'lib/stripe/resources/terminal/reader.rb', line 232

def initialize(
  allow_redisplay: nil,
  enable_customer_cancellation: nil,
  skip_tipping: nil,
  tipping: nil
)
  @allow_redisplay = allow_redisplay
  @enable_customer_cancellation = enable_customer_cancellation
  @skip_tipping = skip_tipping
  @tipping = tipping
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



224
225
226
# File 'lib/stripe/resources/terminal/reader.rb', line 224

def allow_redisplay
  @allow_redisplay
end

#enable_customer_cancellationObject

Enables cancel button on transaction screens.



226
227
228
# File 'lib/stripe/resources/terminal/reader.rb', line 226

def enable_customer_cancellation
  @enable_customer_cancellation
end

#skip_tippingObject

Override showing a tipping selection screen on this transaction.



228
229
230
# File 'lib/stripe/resources/terminal/reader.rb', line 228

def skip_tipping
  @skip_tipping
end

#tippingObject

Tipping configuration for this transaction.



230
231
232
# File 'lib/stripe/resources/terminal/reader.rb', line 230

def tipping
  @tipping
end