Class: Stripe::Terminal::Reader::ProcessPaymentIntentParams::ProcessConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ProcessPaymentIntentParams::ProcessConfig
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Tipping
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
-
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
-
#tipping ⇒ Object
Tipping configuration for this transaction.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig
constructor
A new instance of ProcessConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig
Returns a new instance of ProcessConfig.
232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/stripe/resources/terminal/reader.rb', line 232 def initialize( allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil ) @allow_redisplay = allow_redisplay @enable_customer_cancellation = enable_customer_cancellation @skip_tipping = skip_tipping @tipping = tipping end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
224 225 226 |
# File 'lib/stripe/resources/terminal/reader.rb', line 224 def allow_redisplay @allow_redisplay end |
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
226 227 228 |
# File 'lib/stripe/resources/terminal/reader.rb', line 226 def enable_customer_cancellation @enable_customer_cancellation end |
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
228 229 230 |
# File 'lib/stripe/resources/terminal/reader.rb', line 228 def skip_tipping @skip_tipping end |
#tipping ⇒ Object
Tipping configuration for this transaction.
230 231 232 |
# File 'lib/stripe/resources/terminal/reader.rb', line 230 def tipping @tipping end |