Class: Stripe::Terminal::Reader::ProcessSetupIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ProcessSetupIntentParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: ProcessConfig
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#process_config ⇒ Object
Configuration overrides.
-
#setup_intent ⇒ Object
SetupIntent ID.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams
constructor
A new instance of ProcessSetupIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams
Returns a new instance of ProcessSetupIntentParams.
563 564 565 566 567 568 |
# File 'lib/stripe/resources/terminal/reader.rb', line 563 def initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) @allow_redisplay = allow_redisplay @expand = @process_config = process_config @setup_intent = setup_intent end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
555 556 557 |
# File 'lib/stripe/resources/terminal/reader.rb', line 555 def allow_redisplay @allow_redisplay end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
557 558 559 |
# File 'lib/stripe/resources/terminal/reader.rb', line 557 def @expand end |
#process_config ⇒ Object
Configuration overrides
559 560 561 |
# File 'lib/stripe/resources/terminal/reader.rb', line 559 def process_config @process_config end |
#setup_intent ⇒ Object
SetupIntent ID
561 562 563 |
# File 'lib/stripe/resources/terminal/reader.rb', line 561 def setup_intent @setup_intent end |