Class: Stripe::Terminal::Reader::ProcessSetupIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::ProcessSetupIntentParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: ProcessConfig
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#process_config ⇒ Object
Configuration overrides.
-
#setup_intent ⇒ Object
SetupIntent ID.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams
constructor
A new instance of ProcessSetupIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams
Returns a new instance of ProcessSetupIntentParams.
670 671 672 673 674 675 |
# File 'lib/stripe/resources/terminal/reader.rb', line 670 def initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) @allow_redisplay = allow_redisplay @expand = @process_config = process_config @setup_intent = setup_intent end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
659 660 661 |
# File 'lib/stripe/resources/terminal/reader.rb', line 659 def allow_redisplay @allow_redisplay end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
662 663 664 |
# File 'lib/stripe/resources/terminal/reader.rb', line 662 def @expand end |
#process_config ⇒ Object
Configuration overrides
665 666 667 |
# File 'lib/stripe/resources/terminal/reader.rb', line 665 def process_config @process_config end |
#setup_intent ⇒ Object
SetupIntent ID
668 669 670 |
# File 'lib/stripe/resources/terminal/reader.rb', line 668 def setup_intent @setup_intent end |