Class: Stripe::Terminal::Reader::RefundPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::RefundPaymentParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: RefundPaymentConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer in __cents__ representing how much of this charge to refund.
-
#charge ⇒ Object
ID of the Charge to refund.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_intent ⇒ Object
ID of the PaymentIntent to refund.
-
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when refunding this charge.
-
#refund_payment_config ⇒ Object
Configuration overrides.
-
#reverse_transfer ⇒ Object
Boolean indicating whether the transfer should be reversed when refunding this charge.
Instance Method Summary collapse
-
#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams
constructor
A new instance of RefundPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams
Returns a new instance of RefundPaymentParams.
850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/stripe/resources/terminal/reader.rb', line 850 def initialize( amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil ) @amount = amount @charge = charge @expand = @metadata = @payment_intent = payment_intent @refund_application_fee = refund_application_fee @refund_payment_config = refund_payment_config @reverse_transfer = reverse_transfer end |
Instance Attribute Details
#amount ⇒ Object
A positive integer in __cents__ representing how much of this charge to refund.
834 835 836 |
# File 'lib/stripe/resources/terminal/reader.rb', line 834 def amount @amount end |
#charge ⇒ Object
ID of the Charge to refund.
836 837 838 |
# File 'lib/stripe/resources/terminal/reader.rb', line 836 def charge @charge end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
838 839 840 |
# File 'lib/stripe/resources/terminal/reader.rb', line 838 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
840 841 842 |
# File 'lib/stripe/resources/terminal/reader.rb', line 840 def @metadata end |
#payment_intent ⇒ Object
ID of the PaymentIntent to refund.
842 843 844 |
# File 'lib/stripe/resources/terminal/reader.rb', line 842 def payment_intent @payment_intent end |
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.
844 845 846 |
# File 'lib/stripe/resources/terminal/reader.rb', line 844 def refund_application_fee @refund_application_fee end |
#refund_payment_config ⇒ Object
Configuration overrides
846 847 848 |
# File 'lib/stripe/resources/terminal/reader.rb', line 846 def refund_payment_config @refund_payment_config end |
#reverse_transfer ⇒ Object
Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.
848 849 850 |
# File 'lib/stripe/resources/terminal/reader.rb', line 848 def reverse_transfer @reverse_transfer end |