Class: Stripe::Terminal::Reader::RefundPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Defined Under Namespace

Classes: RefundPaymentConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams

Returns a new instance of RefundPaymentParams.



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/stripe/resources/terminal/reader.rb', line 310

def initialize(
  amount: nil,
  charge: nil,
  expand: nil,
  metadata: nil,
  payment_intent: nil,
  refund_application_fee: nil,
  refund_payment_config: nil,
  reverse_transfer: nil
)
  @amount = amount
  @charge = charge
  @expand = expand
  @metadata = 
  @payment_intent = payment_intent
  @refund_application_fee = refund_application_fee
  @refund_payment_config = refund_payment_config
  @reverse_transfer = reverse_transfer
end

Instance Attribute Details

#amountObject

A positive integer in __cents__ representing how much of this charge to refund.



294
295
296
# File 'lib/stripe/resources/terminal/reader.rb', line 294

def amount
  @amount
end

#chargeObject

ID of the Charge to refund.



296
297
298
# File 'lib/stripe/resources/terminal/reader.rb', line 296

def charge
  @charge
end

#expandObject

Specifies which fields in the response should be expanded.



298
299
300
# File 'lib/stripe/resources/terminal/reader.rb', line 298

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



300
301
302
# File 'lib/stripe/resources/terminal/reader.rb', line 300

def 
  @metadata
end

#payment_intentObject

ID of the PaymentIntent to refund.



302
303
304
# File 'lib/stripe/resources/terminal/reader.rb', line 302

def payment_intent
  @payment_intent
end

#refund_application_feeObject

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



304
305
306
# File 'lib/stripe/resources/terminal/reader.rb', line 304

def refund_application_fee
  @refund_application_fee
end

#refund_payment_configObject

Configuration overrides



306
307
308
# File 'lib/stripe/resources/terminal/reader.rb', line 306

def refund_payment_config
  @refund_payment_config
end

#reverse_transferObject

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.



308
309
310
# File 'lib/stripe/resources/terminal/reader.rb', line 308

def reverse_transfer
  @reverse_transfer
end