Class: Stripe::Terminal::Reader::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::SetReaderDisplayParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
677 678 679 680 681 |
# File 'lib/stripe/resources/terminal/reader.rb', line 677 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
671 672 673 |
# File 'lib/stripe/resources/terminal/reader.rb', line 671 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
673 674 675 |
# File 'lib/stripe/resources/terminal/reader.rb', line 673 def @expand end |
#type ⇒ Object
Type
675 676 677 |
# File 'lib/stripe/resources/terminal/reader.rb', line 675 def type @type end |