Class: Stripe::Terminal::Reader::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::SetReaderDisplayParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
561 562 563 564 565 |
# File 'lib/stripe/resources/terminal/reader.rb', line 561 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
555 556 557 |
# File 'lib/stripe/resources/terminal/reader.rb', line 555 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
557 558 559 |
# File 'lib/stripe/resources/terminal/reader.rb', line 557 def @expand end |
#type ⇒ Object
Type
559 560 561 |
# File 'lib/stripe/resources/terminal/reader.rb', line 559 def type @type end |