Class: Stripe::Terminal::Reader::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::SetReaderDisplayParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
657 658 659 660 661 |
# File 'lib/stripe/resources/terminal/reader.rb', line 657 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
651 652 653 |
# File 'lib/stripe/resources/terminal/reader.rb', line 651 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
653 654 655 |
# File 'lib/stripe/resources/terminal/reader.rb', line 653 def @expand end |
#type ⇒ Object
Type
655 656 657 |
# File 'lib/stripe/resources/terminal/reader.rb', line 655 def type @type end |