Class: Stripe::Terminal::Reader::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::Reader::UpdateParams
- Defined in:
- lib/stripe/resources/terminal/reader.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#label ⇒ Object
The new label of the reader.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, label: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, label: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
268 269 270 271 272 |
# File 'lib/stripe/resources/terminal/reader.rb', line 268 def initialize(expand: nil, label: nil, metadata: nil) @expand = @label = label @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
262 263 264 |
# File 'lib/stripe/resources/terminal/reader.rb', line 262 def @expand end |
#label ⇒ Object
The new label of the reader.
264 265 266 |
# File 'lib/stripe/resources/terminal/reader.rb', line 264 def label @label end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
266 267 268 |
# File 'lib/stripe/resources/terminal/reader.rb', line 266 def @metadata end |