Class: Stripe::Terminal::Reader::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



228
229
230
231
232
# File 'lib/stripe/resources/terminal/reader.rb', line 228

def initialize(expand: nil, label: nil, metadata: nil)
  @expand = expand
  @label = label
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



222
223
224
# File 'lib/stripe/resources/terminal/reader.rb', line 222

def expand
  @expand
end

#labelObject

The new label of the reader.



224
225
226
# File 'lib/stripe/resources/terminal/reader.rb', line 224

def label
  @label
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



226
227
228
# File 'lib/stripe/resources/terminal/reader.rb', line 226

def 
  @metadata
end