Class: Stripe::Terminal::Reader::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/terminal/reader.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, label: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



269
270
271
272
273
# File 'lib/stripe/resources/terminal/reader.rb', line 269

def initialize(expand: nil, label: nil, metadata: nil)
  @expand = expand
  @label = label
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



263
264
265
# File 'lib/stripe/resources/terminal/reader.rb', line 263

def expand
  @expand
end

#labelObject

The new label of the reader.



265
266
267
# File 'lib/stripe/resources/terminal/reader.rb', line 265

def label
  @label
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



267
268
269
# File 'lib/stripe/resources/terminal/reader.rb', line 267

def 
  @metadata
end