Class: Stripe::Terminal::ReaderActivateGiftCardParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderActivateGiftCardParams
- Defined in:
- lib/stripe/params/terminal/reader_activate_gift_card_params.rb
Defined Under Namespace
Classes: Balance
Instance Attribute Summary collapse
-
#balance ⇒ Object
The initial balance to set on the gift card.
-
#brand ⇒ Object
The brand of the gift card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
Instance Method Summary collapse
-
#initialize(balance: nil, brand: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderActivateGiftCardParams
constructor
A new instance of ReaderActivateGiftCardParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(balance: nil, brand: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderActivateGiftCardParams
Returns a new instance of ReaderActivateGiftCardParams.
27 28 29 30 31 32 |
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 27 def initialize(balance: nil, brand: nil, expand: nil, on_behalf_of: nil) @balance = balance @brand = brand @expand = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#balance ⇒ Object
The initial balance to set on the gift card.
19 20 21 |
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 19 def balance @balance end |
#brand ⇒ Object
The brand of the gift card.
21 22 23 |
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 21 def brand @brand end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
23 24 25 |
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 23 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
25 26 27 |
# File 'lib/stripe/params/terminal/reader_activate_gift_card_params.rb', line 25 def on_behalf_of @on_behalf_of end |