Class: Stripe::Terminal::ReaderCollectedData
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::ReaderCollectedData
- Defined in:
- lib/stripe/resources/terminal/reader_collected_data.rb
Overview
Returns data collected by Terminal readers. This data is only stored for 24 hours.
Defined Under Namespace
Classes: Magstripe
Constant Summary collapse
- OBJECT_NAME =
"terminal.reader_collected_data"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#magstripe ⇒ Object
readonly
The magstripe data collected by the reader.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#type ⇒ Object
readonly
The type of data collected by the reader.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
26 27 28 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 26 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
28 29 30 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 28 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
30 31 32 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 30 def livemode @livemode end |
#magstripe ⇒ Object (readonly)
The magstripe data collected by the reader.
32 33 34 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 32 def magstripe @magstripe end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
34 35 36 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 34 def object @object end |
#type ⇒ Object (readonly)
The type of data collected by the reader.
36 37 38 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 36 def type @type end |
Class Method Details
.field_remappings ⇒ Object
42 43 44 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 42 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
38 39 40 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 38 def self.inner_class_types @inner_class_types = { magstripe: Magstripe } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 9 def self.object_name "terminal.reader_collected_data" end |