Class: Stripe::Terminal::ReaderCollectedData

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/terminal/reader_collected_data.rb

Overview

Returns data collected by Terminal readers. This data is only stored for 24 hours.

Defined Under Namespace

Classes: Magstripe

Constant Summary collapse

OBJECT_NAME =
"terminal.reader_collected_data"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



18
19
20
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 18

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



20
21
22
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 20

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



22
23
24
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 22

def livemode
  @livemode
end

#magstripeObject (readonly)

The magstripe data collected by the reader.



24
25
26
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 24

def magstripe
  @magstripe
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



26
27
28
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 26

def object
  @object
end

#typeObject (readonly)

The type of data collected by the reader.



28
29
30
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 28

def type
  @type
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 9

def self.object_name
  "terminal.reader_collected_data"
end