Class: Stripe::Terminal::ReaderCollectedData
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Terminal::ReaderCollectedData
- Defined in:
- lib/stripe/resources/terminal/reader_collected_data.rb
Overview
Returns data collected by Terminal readers. This data is only stored for 24 hours.
Defined Under Namespace
Classes: Magstripe, RetrieveParams
Constant Summary collapse
- OBJECT_NAME =
"terminal.reader_collected_data"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#magstripe ⇒ Object
readonly
The magstripe data collected by the reader.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#type ⇒ Object
readonly
The type of data collected by the reader.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
27 28 29 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 27 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
30 31 32 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 30 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
33 34 35 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 33 def livemode @livemode end |
#magstripe ⇒ Object (readonly)
The magstripe data collected by the reader.
36 37 38 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 36 def magstripe @magstripe end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
39 40 41 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 39 def object @object end |
#type ⇒ Object (readonly)
The type of data collected by the reader.
42 43 44 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 42 def type @type end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/terminal/reader_collected_data.rb', line 9 def self.object_name "terminal.reader_collected_data" end |