Class: Stripe::Terminal::ReaderReloadGiftCardParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderReloadGiftCardParams
- Defined in:
- lib/stripe/params/terminal/reader_reload_gift_card_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to add to the gift card balance, in the smallest currency unit.
-
#brand ⇒ Object
The brand of the gift card.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
Instance Method Summary collapse
-
#initialize(amount: nil, brand: nil, currency: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderReloadGiftCardParams
constructor
A new instance of ReaderReloadGiftCardParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, brand: nil, currency: nil, expand: nil, on_behalf_of: nil) ⇒ ReaderReloadGiftCardParams
Returns a new instance of ReaderReloadGiftCardParams.
18 19 20 21 22 23 24 |
# File 'lib/stripe/params/terminal/reader_reload_gift_card_params.rb', line 18 def initialize(amount: nil, brand: nil, currency: nil, expand: nil, on_behalf_of: nil) @amount = amount @brand = brand @currency = currency @expand = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#amount ⇒ Object
The amount to add to the gift card balance, in the smallest currency unit.
8 9 10 |
# File 'lib/stripe/params/terminal/reader_reload_gift_card_params.rb', line 8 def amount @amount end |
#brand ⇒ Object
The brand of the gift card.
10 11 12 |
# File 'lib/stripe/params/terminal/reader_reload_gift_card_params.rb', line 10 def brand @brand end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
12 13 14 |
# File 'lib/stripe/params/terminal/reader_reload_gift_card_params.rb', line 12 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
14 15 16 |
# File 'lib/stripe/params/terminal/reader_reload_gift_card_params.rb', line 14 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
16 17 18 |
# File 'lib/stripe/params/terminal/reader_reload_gift_card_params.rb', line 16 def on_behalf_of @on_behalf_of end |