Class: Stripe::Terminal::ReaderService::CollectInputsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: Input

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, inputs: nil, metadata: nil) ⇒ CollectInputsParams

Returns a new instance of CollectInputsParams.



214
215
216
217
218
# File 'lib/stripe/services/terminal/reader_service.rb', line 214

def initialize(expand: nil, inputs: nil, metadata: nil)
  @expand = expand
  @inputs = inputs
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



206
207
208
# File 'lib/stripe/services/terminal/reader_service.rb', line 206

def expand
  @expand
end

#inputsObject

List of inputs to be collected using the Reader



209
210
211
# File 'lib/stripe/services/terminal/reader_service.rb', line 209

def inputs
  @inputs
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



212
213
214
# File 'lib/stripe/services/terminal/reader_service.rb', line 212

def 
  @metadata
end