Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: CustomText, Selection, Toggle
Instance Attribute Summary collapse
-
#custom_text ⇒ Object
Customize the text which will be displayed while collecting this input.
-
#required ⇒ Object
Indicate that this input is required, disabling the skip button.
-
#selection ⇒ Object
Options for the ‘selection` input.
-
#toggles ⇒ Object
List of toggles to be displayed and customization for the toggles.
-
#type ⇒ Object
The type of input to collect.
Instance Method Summary collapse
-
#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input
constructor
A new instance of Input.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) ⇒ Input
Returns a new instance of Input.
197 198 199 200 201 202 203 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 197 def initialize(custom_text: nil, required: nil, selection: nil, toggles: nil, type: nil) @custom_text = custom_text @required = required @selection = selection @toggles = toggles @type = type end |
Instance Attribute Details
#custom_text ⇒ Object
Customize the text which will be displayed while collecting this input
183 184 185 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 183 def custom_text @custom_text end |
#required ⇒ Object
Indicate that this input is required, disabling the skip button
186 187 188 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 186 def required @required end |
#selection ⇒ Object
Options for the ‘selection` input
189 190 191 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 189 def selection @selection end |
#toggles ⇒ Object
List of toggles to be displayed and customization for the toggles
192 193 194 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 192 def toggles @toggles end |
#type ⇒ Object
The type of input to collect
195 196 197 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 195 def type @type end |