Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier for this choice.
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#text ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
Returns a new instance of Choice.
137 138 139 140 141 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 137 def initialize(id: nil, style: nil, text: nil) @id = id @style = style @text = text end |
Instance Attribute Details
#id ⇒ Object
The unique identifier for this choice
131 132 133 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 131 def id @id end |
#style ⇒ Object
The style of the button which will be shown for this choice
133 134 135 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 133 def style @style end |
#text ⇒ Object
The text which will be shown on the button for this choice
135 136 137 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 135 def text @text end |