Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The unique identifier for this choice.
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#text ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, style: nil, text: nil) ⇒ Choice
Returns a new instance of Choice.
138 139 140 141 142 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 138 def initialize(id: nil, style: nil, text: nil) @id = id @style = style @text = text end |
Instance Attribute Details
#id ⇒ Object
The unique identifier for this choice
132 133 134 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 132 def id @id end |
#style ⇒ Object
The style of the button which will be shown for this choice
134 135 136 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 134 def style @style end |
#text ⇒ Object
The text which will be shown on the button for this choice
136 137 138 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 136 def text @text end |