Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#value ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(style: nil, value: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(style: nil, value: nil) ⇒ Choice
Returns a new instance of Choice.
153 154 155 156 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 153 def initialize(style: nil, value: nil) @style = style @value = value end |
Instance Attribute Details
#style ⇒ Object
The style of the button which will be shown for this choice
148 149 150 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 148 def style @style end |
#value ⇒ Object
The text which will be shown on the button for this choice
151 152 153 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 151 def value @value end |