Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input::Selection::Choice
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#style ⇒ Object
The style of the button which will be shown for this choice.
-
#value ⇒ Object
The text which will be shown on the button for this choice.
Instance Method Summary collapse
-
#initialize(style: nil, value: nil) ⇒ Choice
constructor
A new instance of Choice.
Methods inherited from RequestParams
Constructor Details
#initialize(style: nil, value: nil) ⇒ Choice
Returns a new instance of Choice.
136 137 138 139 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 136 def initialize(style: nil, value: nil) @style = style @value = value end |
Instance Attribute Details
#style ⇒ Object
The style of the button which will be shown for this choice
132 133 134 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 132 def style @style end |
#value ⇒ Object
The text which will be shown on the button for this choice
134 135 136 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 134 def value @value end |