Class: Stripe::Terminal::ReaderService::CollectInputsParams::Input::Toggle
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::CollectInputsParams::Input::Toggle
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#default_value ⇒ Object
The default value of the toggle.
-
#description ⇒ Object
The description which will be displayed for the toggle.
-
#title ⇒ Object
The title which will be displayed for the toggle.
Instance Method Summary collapse
-
#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle
constructor
A new instance of Toggle.
Methods inherited from RequestParams
Constructor Details
#initialize(default_value: nil, description: nil, title: nil) ⇒ Toggle
Returns a new instance of Toggle.
176 177 178 179 180 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 176 def initialize(default_value: nil, description: nil, title: nil) @default_value = default_value @description = description @title = title end |
Instance Attribute Details
#default_value ⇒ Object
The default value of the toggle
168 169 170 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 168 def default_value @default_value end |
#description ⇒ Object
The description which will be displayed for the toggle
171 172 173 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 171 def description @description end |
#title ⇒ Object
The title which will be displayed for the toggle
174 175 176 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 174 def title @title end |