Class: Stripe::Terminal::ReaderService::ConfirmPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::ConfirmPaymentIntentParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
PaymentIntent ID.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ ConfirmPaymentIntentParams
constructor
A new instance of ConfirmPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ ConfirmPaymentIntentParams
Returns a new instance of ConfirmPaymentIntentParams.
278 279 280 281 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 278 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
273 274 275 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 273 def @expand end |
#payment_intent ⇒ Object
PaymentIntent ID
276 277 278 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 276 def payment_intent @payment_intent end |