Class: Stripe::Terminal::ReaderService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(device_type: nil, ending_before: nil, expand: nil, limit: nil, location: nil, serial_number: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/stripe/services/terminal/reader_service.rb', line 61

def initialize(
  device_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  location: nil,
  serial_number: nil,
  starting_after: nil,
  status: nil
)
  @device_type = device_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @location = location
  @serial_number = serial_number
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#device_typeObject

Filters readers by device type



38
39
40
# File 'lib/stripe/services/terminal/reader_service.rb', line 38

def device_type
  @device_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



41
42
43
# File 'lib/stripe/services/terminal/reader_service.rb', line 41

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



44
45
46
# File 'lib/stripe/services/terminal/reader_service.rb', line 44

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



47
48
49
# File 'lib/stripe/services/terminal/reader_service.rb', line 47

def limit
  @limit
end

#locationObject

A location ID to filter the response list to only readers at the specific location



50
51
52
# File 'lib/stripe/services/terminal/reader_service.rb', line 50

def location
  @location
end

#serial_numberObject

Filters readers by serial number



53
54
55
# File 'lib/stripe/services/terminal/reader_service.rb', line 53

def serial_number
  @serial_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



56
57
58
# File 'lib/stripe/services/terminal/reader_service.rb', line 56

def starting_after
  @starting_after
end

#statusObject

A status filter to filter readers to only offline or online readers



59
60
61
# File 'lib/stripe/services/terminal/reader_service.rb', line 59

def status
  @status
end