Class: Stripe::Terminal::ReaderService::ProcessPaymentIntentParams::ProcessConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::ProcessPaymentIntentParams::ProcessConfig
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: Tipping
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
-
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
-
#tipping ⇒ Object
Tipping configuration for this transaction.
Instance Method Summary collapse
-
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig
constructor
A new instance of ProcessConfig.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil) ⇒ ProcessConfig
Returns a new instance of ProcessConfig.
306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 306 def initialize( allow_redisplay: nil, enable_customer_cancellation: nil, skip_tipping: nil, tipping: nil ) @allow_redisplay = allow_redisplay @enable_customer_cancellation = enable_customer_cancellation @skip_tipping = skip_tipping @tipping = tipping end |
Instance Attribute Details
#allow_redisplay ⇒ Object
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.
295 296 297 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 295 def allow_redisplay @allow_redisplay end |
#enable_customer_cancellation ⇒ Object
Enables cancel button on transaction screens.
298 299 300 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 298 def enable_customer_cancellation @enable_customer_cancellation end |
#skip_tipping ⇒ Object
Override showing a tipping selection screen on this transaction.
301 302 303 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 301 def skip_tipping @skip_tipping end |
#tipping ⇒ Object
Tipping configuration for this transaction.
304 305 306 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 304 def tipping @tipping end |