Class: Stripe::Terminal::ReaderService::ProcessSetupIntentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: ProcessConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams

Returns a new instance of ProcessSetupIntentParams.



355
356
357
358
359
360
# File 'lib/stripe/services/terminal/reader_service.rb', line 355

def initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil)
  @allow_redisplay = allow_redisplay
  @expand = expand
  @process_config = process_config
  @setup_intent = setup_intent
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



344
345
346
# File 'lib/stripe/services/terminal/reader_service.rb', line 344

def allow_redisplay
  @allow_redisplay
end

#expandObject

Specifies which fields in the response should be expanded.



347
348
349
# File 'lib/stripe/services/terminal/reader_service.rb', line 347

def expand
  @expand
end

#process_configObject

Configuration overrides



350
351
352
# File 'lib/stripe/services/terminal/reader_service.rb', line 350

def process_config
  @process_config
end

#setup_intentObject

SetupIntent ID



353
354
355
# File 'lib/stripe/services/terminal/reader_service.rb', line 353

def setup_intent
  @setup_intent
end