Class: Stripe::Terminal::ReaderService::ProcessSetupIntentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: ProcessConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil) ⇒ ProcessSetupIntentParams

Returns a new instance of ProcessSetupIntentParams.



316
317
318
319
320
321
# File 'lib/stripe/services/terminal/reader_service.rb', line 316

def initialize(allow_redisplay: nil, expand: nil, process_config: nil, setup_intent: nil)
  @allow_redisplay = allow_redisplay
  @expand = expand
  @process_config = process_config
  @setup_intent = setup_intent
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow.



308
309
310
# File 'lib/stripe/services/terminal/reader_service.rb', line 308

def allow_redisplay
  @allow_redisplay
end

#expandObject

Specifies which fields in the response should be expanded.



310
311
312
# File 'lib/stripe/services/terminal/reader_service.rb', line 310

def expand
  @expand
end

#process_configObject

Configuration overrides



312
313
314
# File 'lib/stripe/services/terminal/reader_service.rb', line 312

def process_config
  @process_config
end

#setup_intentObject

SetupIntent ID



314
315
316
# File 'lib/stripe/services/terminal/reader_service.rb', line 314

def setup_intent
  @setup_intent
end