Class: Stripe::Terminal::ReaderService::RefundPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: RefundPaymentConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams

Returns a new instance of RefundPaymentParams.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/stripe/services/terminal/reader_service.rb', line 206

def initialize(
  amount: nil,
  charge: nil,
  expand: nil,
  metadata: nil,
  payment_intent: nil,
  refund_application_fee: nil,
  refund_payment_config: nil,
  reverse_transfer: nil
)
  @amount = amount
  @charge = charge
  @expand = expand
  @metadata = 
  @payment_intent = payment_intent
  @refund_application_fee = refund_application_fee
  @refund_payment_config = refund_payment_config
  @reverse_transfer = reverse_transfer
end

Instance Attribute Details

#amountObject

A positive integer in __cents__ representing how much of this charge to refund.



190
191
192
# File 'lib/stripe/services/terminal/reader_service.rb', line 190

def amount
  @amount
end

#chargeObject

ID of the Charge to refund.



192
193
194
# File 'lib/stripe/services/terminal/reader_service.rb', line 192

def charge
  @charge
end

#expandObject

Specifies which fields in the response should be expanded.



194
195
196
# File 'lib/stripe/services/terminal/reader_service.rb', line 194

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



196
197
198
# File 'lib/stripe/services/terminal/reader_service.rb', line 196

def 
  @metadata
end

#payment_intentObject

ID of the PaymentIntent to refund.



198
199
200
# File 'lib/stripe/services/terminal/reader_service.rb', line 198

def payment_intent
  @payment_intent
end

#refund_application_feeObject

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



200
201
202
# File 'lib/stripe/services/terminal/reader_service.rb', line 200

def refund_application_fee
  @refund_application_fee
end

#refund_payment_configObject

Configuration overrides



202
203
204
# File 'lib/stripe/services/terminal/reader_service.rb', line 202

def refund_payment_config
  @refund_payment_config
end

#reverse_transferObject

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.



204
205
206
# File 'lib/stripe/services/terminal/reader_service.rb', line 204

def reverse_transfer
  @reverse_transfer
end