Class: Stripe::Terminal::ReaderService::RefundPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/terminal/reader_service.rb

Defined Under Namespace

Classes: RefundPaymentConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams

Returns a new instance of RefundPaymentParams.



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/stripe/services/terminal/reader_service.rb', line 350

def initialize(
  amount: nil,
  charge: nil,
  expand: nil,
  metadata: nil,
  payment_intent: nil,
  refund_application_fee: nil,
  refund_payment_config: nil,
  reverse_transfer: nil
)
  @amount = amount
  @charge = charge
  @expand = expand
  @metadata = 
  @payment_intent = payment_intent
  @refund_application_fee = refund_application_fee
  @refund_payment_config = refund_payment_config
  @reverse_transfer = reverse_transfer
end

Instance Attribute Details

#amountObject

A positive integer in __cents__ representing how much of this charge to refund.



334
335
336
# File 'lib/stripe/services/terminal/reader_service.rb', line 334

def amount
  @amount
end

#chargeObject

ID of the Charge to refund.



336
337
338
# File 'lib/stripe/services/terminal/reader_service.rb', line 336

def charge
  @charge
end

#expandObject

Specifies which fields in the response should be expanded.



338
339
340
# File 'lib/stripe/services/terminal/reader_service.rb', line 338

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



340
341
342
# File 'lib/stripe/services/terminal/reader_service.rb', line 340

def 
  @metadata
end

#payment_intentObject

ID of the PaymentIntent to refund.



342
343
344
# File 'lib/stripe/services/terminal/reader_service.rb', line 342

def payment_intent
  @payment_intent
end

#refund_application_feeObject

Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.



344
345
346
# File 'lib/stripe/services/terminal/reader_service.rb', line 344

def refund_application_fee
  @refund_application_fee
end

#refund_payment_configObject

Configuration overrides



346
347
348
# File 'lib/stripe/services/terminal/reader_service.rb', line 346

def refund_payment_config
  @refund_payment_config
end

#reverse_transferObject

Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.



348
349
350
# File 'lib/stripe/services/terminal/reader_service.rb', line 348

def reverse_transfer
  @reverse_transfer
end