Class: Stripe::Terminal::ReaderService::RefundPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::RefundPaymentParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: RefundPaymentConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer in __cents__ representing how much of this charge to refund.
-
#charge ⇒ Object
ID of the Charge to refund.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_intent ⇒ Object
ID of the PaymentIntent to refund.
-
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when refunding this charge.
-
#refund_payment_config ⇒ Object
Configuration overrides.
-
#reverse_transfer ⇒ Object
Boolean indicating whether the transfer should be reversed when refunding this charge.
Instance Method Summary collapse
-
#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams
constructor
A new instance of RefundPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil) ⇒ RefundPaymentParams
Returns a new instance of RefundPaymentParams.
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 396 def initialize( amount: nil, charge: nil, expand: nil, metadata: nil, payment_intent: nil, refund_application_fee: nil, refund_payment_config: nil, reverse_transfer: nil ) @amount = amount @charge = charge @expand = @metadata = @payment_intent = payment_intent @refund_application_fee = refund_application_fee @refund_payment_config = refund_payment_config @reverse_transfer = reverse_transfer end |
Instance Attribute Details
#amount ⇒ Object
A positive integer in __cents__ representing how much of this charge to refund.
373 374 375 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 373 def amount @amount end |
#charge ⇒ Object
ID of the Charge to refund.
376 377 378 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 376 def charge @charge end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
379 380 381 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 379 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
382 383 384 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 382 def @metadata end |
#payment_intent ⇒ Object
ID of the PaymentIntent to refund.
385 386 387 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 385 def payment_intent @payment_intent end |
#refund_application_fee ⇒ Object
Boolean indicating whether the application fee should be refunded when refunding this charge. If a full charge refund is given, the full application fee will be refunded. Otherwise, the application fee will be refunded in an amount proportional to the amount of the charge refunded. An application fee can be refunded only by the application that created the charge.
388 389 390 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 388 def refund_application_fee @refund_application_fee end |
#refund_payment_config ⇒ Object
Configuration overrides
391 392 393 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 391 def refund_payment_config @refund_payment_config end |
#reverse_transfer ⇒ Object
Boolean indicating whether the transfer should be reversed when refunding this charge. The transfer will be reversed proportionally to the amount being refunded (either the entire or partial amount). A transfer can be reversed only by the application that created the charge.
394 395 396 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 394 def reverse_transfer @reverse_transfer end |