Class: Stripe::Terminal::ReaderService::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::SetReaderDisplayParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
413 414 415 416 417 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 413 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
407 408 409 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 407 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
409 410 411 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 409 def @expand end |
#type ⇒ Object
Type
411 412 413 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 411 def type @type end |