Class: Stripe::Terminal::ReaderService::SetReaderDisplayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Terminal::ReaderService::SetReaderDisplayParams
- Defined in:
- lib/stripe/services/terminal/reader_service.rb
Defined Under Namespace
Classes: Cart
Instance Attribute Summary collapse
-
#cart ⇒ Object
Cart.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Type.
Instance Method Summary collapse
-
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
constructor
A new instance of SetReaderDisplayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cart: nil, expand: nil, type: nil) ⇒ SetReaderDisplayParams
Returns a new instance of SetReaderDisplayParams.
410 411 412 413 414 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 410 def initialize(cart: nil, expand: nil, type: nil) @cart = cart @expand = @type = type end |
Instance Attribute Details
#cart ⇒ Object
Cart
404 405 406 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 404 def cart @cart end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
406 407 408 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 406 def @expand end |
#type ⇒ Object
Type
408 409 410 |
# File 'lib/stripe/services/terminal/reader_service.rb', line 408 def type @type end |