Class: Stripe::TestHelpers::Capital::FinancingOfferService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::TestHelpers::Capital::FinancingOfferService
- Defined in:
- lib/stripe/services/test_helpers/capital/financing_offer_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a test financing offer for a connected account.
-
#refill(financing_offer, params = {}, opts = {}) ⇒ Object
Refills a test financing offer for a connected account.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a test financing offer for a connected account.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/test_helpers/capital/financing_offer_service.rb', line 9 def create(params = {}, opts = {}) request( method: :post, path: "/v1/test_helpers/capital/financing_offers", params: params, opts: opts, base_address: :api ) end |
#refill(financing_offer, params = {}, opts = {}) ⇒ Object
Refills a test financing offer for a connected account.
20 21 22 23 24 25 26 27 28 |
# File 'lib/stripe/services/test_helpers/capital/financing_offer_service.rb', line 20 def refill(financing_offer, params = {}, opts = {}) request( method: :post, path: format("/v1/test_helpers/capital/financing_offers/%<financing_offer>s/refill", { financing_offer: CGI.escape(financing_offer) }), params: params, opts: opts, base_address: :api ) end |