Class: Stripe::TestHelpers::ConfirmationTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenCreateParams
- Defined in:
- lib/stripe/params/test_helpers/confirmation_token_create_params.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions, Shipping
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
ID of an existing PaymentMethod.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this ConfirmationToken.
-
#return_url ⇒ Object
Return URL used to confirm the Intent.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken's payment method.
-
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams
constructor
A new instance of ConfirmationTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams
Returns a new instance of ConfirmationTokenCreateParams.
799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 799 def initialize( expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil ) @expand = @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
783 784 785 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 783 def @expand end |
#payment_method ⇒ Object
ID of an existing PaymentMethod.
785 786 787 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 785 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
787 788 789 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 787 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this ConfirmationToken.
789 790 791 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 789 def @payment_method_options end |
#return_url ⇒ Object
Return URL used to confirm the Intent.
791 792 793 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 791 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken's payment method.
The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.
795 796 797 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 795 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
797 798 799 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 797 def shipping @shipping end |