Class: Stripe::TestHelpers::ConfirmationTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 776

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



760
761
762
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 760

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



762
763
764
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 762

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



764
765
766
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 764

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



766
767
768
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 766

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



768
769
770
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 768

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken's payment method.

The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



772
773
774
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 772

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



774
775
776
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 774

def shipping
  @shipping
end