Class: Stripe::TestHelpers::ConfirmationTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 698

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



682
683
684
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 682

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



684
685
686
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 684

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



686
687
688
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 686

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



688
689
690
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 688

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



690
691
692
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 690

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



694
695
696
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 694

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



696
697
698
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 696

def shipping
  @shipping
end