Class: Stripe::TestHelpers::ConfirmationTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 766

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



750
751
752
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 750

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



752
753
754
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 752

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



754
755
756
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 754

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



756
757
758
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 756

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



758
759
760
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 758

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



762
763
764
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 762

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



764
765
766
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 764

def shipping
  @shipping
end