Class: Stripe::TestHelpers::ConfirmationTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenCreateParams
- Defined in:
- lib/stripe/params/test_helpers/confirmation_token_create_params.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions, Shipping
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
ID of an existing PaymentMethod.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this ConfirmationToken.
-
#return_url ⇒ Object
Return URL used to confirm the Intent.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
-
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams
constructor
A new instance of ConfirmationTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams
Returns a new instance of ConfirmationTokenCreateParams.
688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 688 def initialize( expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil ) @expand = @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
672 673 674 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 672 def @expand end |
#payment_method ⇒ Object
ID of an existing PaymentMethod.
674 675 676 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 674 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
676 677 678 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 676 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this ConfirmationToken.
678 679 680 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 678 def @payment_method_options end |
#return_url ⇒ Object
Return URL used to confirm the Intent.
680 681 682 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 680 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.
684 685 686 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 684 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
686 687 688 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 686 def shipping @shipping end |