Class: Stripe::TestHelpers::ConfirmationTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 730

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



714
715
716
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 714

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



716
717
718
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 716

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



718
719
720
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 718

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



720
721
722
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 720

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



722
723
724
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 722

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



726
727
728
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 726

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



728
729
730
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 728

def shipping
  @shipping
end