Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 222

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



210
211
212
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 210

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



212
213
214
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 212

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



214
215
216
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 214

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



216
217
218
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 216

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



218
219
220
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 218

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



220
221
222
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 220

def suffix
  @suffix
end