Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 212

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



200
201
202
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 200

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



202
203
204
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 202

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



204
205
206
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 204

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



206
207
208
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 206

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



208
209
210
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 208

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



210
211
212
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 210

def suffix
  @suffix
end