Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 221

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



209
210
211
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 209

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



211
212
213
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 211

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



213
214
215
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 213

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



215
216
217
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 215

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



217
218
219
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 217

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



219
220
221
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 219

def suffix
  @suffix
end