Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/params/test_helpers/confirmation_token_create_params.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For
fixed_countinstallment plans, this is required. -
#interval ⇒ Object
For
fixed_countinstallment plans, this is required. -
#type ⇒ Object
Type of installment plan, one of
fixed_count,bonus, orrevolving.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
608 609 610 611 612 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 608 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
601 602 603 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 601 def count @count end |
#interval ⇒ Object
For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card.
One of month.
604 605 606 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 604 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of fixed_count, bonus, or revolving.
606 607 608 |
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 606 def type @type end |