Class: Stripe::TestHelpers::ConfirmationTokenCreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



676
677
678
679
680
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 676

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



669
670
671
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 669

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



672
673
674
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 672

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



674
675
676
# File 'lib/stripe/params/test_helpers/confirmation_token_create_params.rb', line 674

def type
  @type
end