Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/confirmation_token_service.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 624

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



608
609
610
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 608

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



610
611
612
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 610

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



612
613
614
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 612

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



614
615
616
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 614

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



616
617
618
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 616

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



620
621
622
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 620

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



622
623
624
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 622

def shipping
  @shipping
end