Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 241 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
229 230 231 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 229 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
231 232 233 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 231 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
233 234 235 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 233 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
235 236 237 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 235 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
237 238 239 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 237 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
239 240 241 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 239 def suffix @suffix end |