Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/confirmation_token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 256

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



244
245
246
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 244

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



246
247
248
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 246

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



248
249
250
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 248

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



250
251
252
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 250

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



252
253
254
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 252

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



254
255
256
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 254

def suffix
  @suffix
end