Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 253 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
241 242 243 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 241 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
243 244 245 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 243 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
245 246 247 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 245 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
247 248 249 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 247 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
249 250 251 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 249 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
251 252 253 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 251 def suffix @suffix end |