Class: Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::ConfirmationTokenService::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/services/test_helpers/confirmation_token_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
631 632 633 634 635 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 631 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
624 625 626 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 624 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
627 628 629 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 627 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
629 630 631 |
# File 'lib/stripe/services/test_helpers/confirmation_token_service.rb', line 629 def type @type end |