Class: Stripe::TestHelpers::Issuing::AuthorizationCaptureParams::PurchaseDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb

Defined Under Namespace

Classes: Fleet, Flight, Fuel, Lodging, Receipt

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails

Returns a new instance of PurchaseDetails.



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 287

def initialize(
  fleet: nil,
  flight: nil,
  fuel: nil,
  lodging: nil,
  receipt: nil,
  reference: nil
)
  @fleet = fleet
  @flight = flight
  @fuel = fuel
  @lodging = lodging
  @receipt = receipt
  @reference = reference
end

Instance Attribute Details

#fleetObject

Fleet-specific information for transactions using Fleet cards.



275
276
277
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 275

def fleet
  @fleet
end

#flightObject

Information about the flight that was purchased with this transaction.



277
278
279
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 277

def flight
  @flight
end

#fuelObject

Information about fuel that was purchased with this transaction.



279
280
281
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 279

def fuel
  @fuel
end

#lodgingObject

Information about lodging that was purchased with this transaction.



281
282
283
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 281

def lodging
  @lodging
end

#receiptObject

The line items in the purchase.



283
284
285
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 283

def receipt
  @receipt
end

#referenceObject

A merchant-specific order number.



285
286
287
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 285

def reference
  @reference
end

Class Method Details

.field_encodingsObject



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/stripe/params/test_helpers/issuing/authorization_capture_params.rb', line 303

def self.field_encodings
  @field_encodings = {
    fleet: {
      kind: :object,
      fields: {
        reported_breakdown: {
          kind: :object,
          fields: {
            fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            tax: {
              kind: :object,
              fields: {
                local_amount_decimal: :decimal_string,
                national_amount_decimal: :decimal_string,
              },
            },
          },
        },
      },
    },
    fuel: {
      kind: :object,
      fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string },
    },
    receipt: {
      kind: :array,
      element: { kind: :object, fields: { quantity: :decimal_string } },
    },
  }
end