Class: Stripe::TestHelpers::Issuing::AuthorizationService::CaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Defined Under Namespace

Classes: PurchaseDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



633
634
635
636
637
638
639
640
641
642
643
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 633

def initialize(
  capture_amount: nil,
  close_authorization: nil,
  expand: nil,
  purchase_details: nil
)
  @capture_amount = capture_amount
  @close_authorization = close_authorization
  @expand = expand
  @purchase_details = purchase_details
end

Instance Attribute Details

#capture_amountObject

The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



622
623
624
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 622

def capture_amount
  @capture_amount
end

#close_authorizationObject

Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.



625
626
627
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 625

def close_authorization
  @close_authorization
end

#expandObject

Specifies which fields in the response should be expanded.



628
629
630
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 628

def expand
  @expand
end

#purchase_detailsObject

Additional purchase information that is optionally provided by the merchant.



631
632
633
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 631

def purchase_details
  @purchase_details
end