Class: Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::Fleet
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationService::CreateParams::Fleet
- Defined in:
- lib/stripe/services/test_helpers/issuing/authorization_service.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
The type of purchase.
-
#reported_breakdown ⇒ Object
More information about the total amount.
-
#service_type ⇒ Object
The type of fuel service.
Instance Method Summary collapse
-
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
constructor
A new instance of Fleet.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
Returns a new instance of Fleet.
112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 112 def initialize( cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil ) @cardholder_prompt_data = cardholder_prompt_data @purchase_type = purchase_type @reported_breakdown = reported_breakdown @service_type = service_type end |
Instance Attribute Details
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
101 102 103 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 101 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object
The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.
104 105 106 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 104 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object
More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
107 108 109 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 107 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object
The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.
110 111 112 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 110 def service_type @service_type end |