Class: Stripe::TestHelpers::Issuing::AuthorizationService::FinalizeAmountParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::AuthorizationService::FinalizeAmountParams
- Defined in:
- lib/stripe/services/test_helpers/issuing/authorization_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
Instance Method Summary collapse
-
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ FinalizeAmountParams
constructor
A new instance of FinalizeAmountParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ FinalizeAmountParams
Returns a new instance of FinalizeAmountParams.
706 707 708 709 710 711 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 706 def initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) @expand = @final_amount = final_amount @fleet = fleet @fuel = fuel end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
698 699 700 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 698 def @expand end |
#final_amount ⇒ Object
The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
700 701 702 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 700 def final_amount @final_amount end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
702 703 704 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 702 def fleet @fleet end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
704 705 706 |
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 704 def fuel @fuel end |