Class: Stripe::TestHelpers::Issuing::AuthorizationService::FinalizeAmountParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Defined Under Namespace

Classes: Fleet, Fuel

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil) ⇒ FinalizeAmountParams

Returns a new instance of FinalizeAmountParams.



801
802
803
804
805
806
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 801

def initialize(expand: nil, final_amount: nil, fleet: nil, fuel: nil)
  @expand = expand
  @final_amount = final_amount
  @fleet = fleet
  @fuel = fuel
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



790
791
792
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 790

def expand
  @expand
end

#final_amountObject

The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



793
794
795
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 793

def final_amount
  @final_amount
end

#fleetObject

Fleet-specific information for authorizations using Fleet cards.



796
797
798
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 796

def fleet
  @fleet
end

#fuelObject

Information about fuel that was purchased with this transaction.



799
800
801
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 799

def fuel
  @fuel
end