Class: Stripe::TestHelpers::Issuing::AuthorizationService::RespondParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/authorization_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmed: nil, expand: nil) ⇒ RespondParams

Returns a new instance of RespondParams.



816
817
818
819
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 816

def initialize(confirmed: nil, expand: nil)
  @confirmed = confirmed
  @expand = expand
end

Instance Attribute Details

#confirmedObject

Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).



811
812
813
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 811

def confirmed
  @confirmed
end

#expandObject

Specifies which fields in the response should be expanded.



814
815
816
# File 'lib/stripe/services/test_helpers/issuing/authorization_service.rb', line 814

def expand
  @expand
end