Class: Stripe::TestHelpers::Issuing::TransactionCreateForceCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionCreateForceCaptureParams
- Defined in:
- lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb
Defined Under Namespace
Classes: MerchantData, NetworkData, PurchaseDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total amount to attempt to capture.
-
#card ⇒ Object
Card associated with this transaction.
-
#currency ⇒ Object
The currency of the capture.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
-
#network_data ⇒ Object
Details about the transaction, such as processing dates, set by the card network.
-
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, network_data: nil, purchase_details: nil) ⇒ TransactionCreateForceCaptureParams
constructor
A new instance of TransactionCreateForceCaptureParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, network_data: nil, purchase_details: nil) ⇒ TransactionCreateForceCaptureParams
Returns a new instance of TransactionCreateForceCaptureParams.
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 453 def initialize( amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, network_data: nil, purchase_details: nil ) @amount = amount @card = card @currency = currency @expand = @merchant_data = merchant_data @network_data = network_data @purchase_details = purchase_details end |
Instance Attribute Details
#amount ⇒ Object
The total amount to attempt to capture. This amount is in the provided currency, or defaults to the cards currency, and in the smallest currency unit.
439 440 441 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 439 def amount @amount end |
#card ⇒ Object
Card associated with this transaction.
441 442 443 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 441 def card @card end |
#currency ⇒ Object
The currency of the capture. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
443 444 445 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 443 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
445 446 447 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 445 def @expand end |
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
447 448 449 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 447 def merchant_data @merchant_data end |
#network_data ⇒ Object
Details about the transaction, such as processing dates, set by the card network.
449 450 451 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 449 def network_data @network_data end |
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
451 452 453 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 451 def purchase_details @purchase_details end |
Class Method Details
.field_encodings ⇒ Object
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 471 def self.field_encodings @field_encodings = { purchase_details: { kind: :object, fields: { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, receipt: { kind: :array, element: { kind: :object, fields: { quantity: :decimal_string } }, }, }, }, } end |