Class: Stripe::TestHelpers::Issuing::TransactionCreateForceCaptureParams::PurchaseDetails::Fleet
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionCreateForceCaptureParams::PurchaseDetails::Fleet
- Defined in:
- lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
The type of purchase.
-
#reported_breakdown ⇒ Object
More information about the total amount.
-
#service_type ⇒ Object
The type of fuel service.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
constructor
A new instance of Fleet.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
Returns a new instance of Fleet.
178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 178 def initialize( cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil ) @cardholder_prompt_data = cardholder_prompt_data @purchase_type = purchase_type @reported_breakdown = reported_breakdown @service_type = service_type end |
Instance Attribute Details
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
170 171 172 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 170 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object
The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase.
172 173 174 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 172 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object
More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
174 175 176 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 174 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object
The type of fuel service. One of non_fuel_transaction, full_service, or self_service.
176 177 178 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 176 def service_type @service_type end |
Class Method Details
.field_encodings ⇒ Object
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_force_capture_params.rb', line 190 def self.field_encodings @field_encodings = { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, } end |