Class: Stripe::TestHelpers::Issuing::TransactionCreateUnlinkedRefundParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionCreateUnlinkedRefundParams::PurchaseDetails
- Defined in:
- lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 338 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
326 327 328 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 326 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
328 329 330 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 328 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
330 331 332 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 330 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
332 333 334 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 332 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
334 335 336 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 334 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
336 337 338 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 336 def reference @reference end |
Class Method Details
.field_encodings ⇒ Object
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/stripe/params/test_helpers/issuing/transaction_create_unlinked_refund_params.rb', line 354 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, receipt: { kind: :array, element: { kind: :object, fields: { quantity: :decimal_string } }, }, } end |