Class: Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams::PurchaseDetails
- Defined in:
- lib/stripe/services/test_helpers/issuing/transaction_service.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 680 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
663 664 665 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 663 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
666 667 668 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 666 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
669 670 671 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 669 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
672 673 674 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 672 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
675 676 677 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 675 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
678 679 680 |
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 678 def reference @reference end |