Class: Stripe::TestHelpers::Issuing::TransactionService::CreateUnlinkedRefundParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/test_helpers/issuing/transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax

Returns a new instance of Tax.



487
488
489
490
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 487

def initialize(local_amount_decimal: nil, national_amount_decimal: nil)
  @local_amount_decimal = local_amount_decimal
  @national_amount_decimal = national_amount_decimal
end

Instance Attribute Details

#local_amount_decimalObject

Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.



482
483
484
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 482

def local_amount_decimal
  @local_amount_decimal
end

#national_amount_decimalObject

Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.



485
486
487
# File 'lib/stripe/services/test_helpers/issuing/transaction_service.rb', line 485

def national_amount_decimal
  @national_amount_decimal
end