Class: Stripe::TestHelpers::SharedPayment::GrantedTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::SharedPayment::GrantedTokenCreateParams
- Defined in:
- lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb
Defined Under Namespace
Classes: UsageLimits
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer that the SharedPaymentGrantedToken belongs to.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
The PaymentMethod that is going to be shared by the SharedPaymentGrantedToken.
-
#shared_metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to the SharedPaymentGrantedToken.
-
#usage_limits ⇒ Object
Limits on how this SharedPaymentGrantedToken can be used.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, payment_method: nil, shared_metadata: nil, usage_limits: nil) ⇒ GrantedTokenCreateParams
constructor
A new instance of GrantedTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, expand: nil, payment_method: nil, shared_metadata: nil, usage_limits: nil) ⇒ GrantedTokenCreateParams
Returns a new instance of GrantedTokenCreateParams.
33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 33 def initialize( customer: nil, expand: nil, payment_method: nil, shared_metadata: nil, usage_limits: nil ) @customer = customer @expand = @payment_method = payment_method @shared_metadata = @usage_limits = usage_limits end |
Instance Attribute Details
#customer ⇒ Object
The Customer that the SharedPaymentGrantedToken belongs to. Should match the Customer that the PaymentMethod is attached to if any.
23 24 25 |
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 23 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
25 26 27 |
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 25 def @expand end |
#payment_method ⇒ Object
The PaymentMethod that is going to be shared by the SharedPaymentGrantedToken.
27 28 29 |
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 27 def payment_method @payment_method end |
#shared_metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to the SharedPaymentGrantedToken.
29 30 31 |
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 29 def @shared_metadata end |
#usage_limits ⇒ Object
Limits on how this SharedPaymentGrantedToken can be used.
31 32 33 |
# File 'lib/stripe/params/test_helpers/shared_payment/granted_token_create_params.rb', line 31 def usage_limits @usage_limits end |