Class: Stripe::TestHelpers::TestClockCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TestHelpers::TestClockCreateParams
- Defined in:
- lib/stripe/params/test_helpers/test_clock_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
Existing customer this test clock will be attached to.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#frozen_time ⇒ Object
The initial frozen time for this test clock.
-
#name ⇒ Object
The name for this test clock.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, frozen_time: nil, name: nil) ⇒ TestClockCreateParams
constructor
A new instance of TestClockCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, expand: nil, frozen_time: nil, name: nil) ⇒ TestClockCreateParams
Returns a new instance of TestClockCreateParams.
16 17 18 19 20 21 |
# File 'lib/stripe/params/test_helpers/test_clock_create_params.rb', line 16 def initialize(customer: nil, expand: nil, frozen_time: nil, name: nil) @customer = customer @expand = @frozen_time = frozen_time @name = name end |
Instance Attribute Details
#customer ⇒ Object
Existing customer this test clock will be attached to. Once attached, customers can’t be removed from a test clock.
8 9 10 |
# File 'lib/stripe/params/test_helpers/test_clock_create_params.rb', line 8 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10 11 12 |
# File 'lib/stripe/params/test_helpers/test_clock_create_params.rb', line 10 def @expand end |
#frozen_time ⇒ Object
The initial frozen time for this test clock.
12 13 14 |
# File 'lib/stripe/params/test_helpers/test_clock_create_params.rb', line 12 def frozen_time @frozen_time end |
#name ⇒ Object
The name for this test clock.
14 15 16 |
# File 'lib/stripe/params/test_helpers/test_clock_create_params.rb', line 14 def name @name end |