Class: Stripe::ThreeDSecure::Authentication::Channel
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ThreeDSecure::Authentication::Channel
- Defined in:
- lib/stripe/resources/three_d_secure/authentication.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#browser ⇒ Object
readonly
Contains details on the browser for a standalone 3DS Authentication.
-
#three_r_i ⇒ Object
readonly
Contains details for a 3RI standalone 3DS Authentication.
-
#type ⇒ Object
readonly
Type of channel you would prefer to use for this 3DS Authentication.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#browser ⇒ Object (readonly)
Contains details on the browser for a standalone 3DS Authentication.
88 89 90 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 88 def browser @browser end |
#three_r_i ⇒ Object (readonly)
Contains details for a 3RI standalone 3DS Authentication.
90 91 92 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 90 def three_r_i @three_r_i end |
#type ⇒ Object (readonly)
Type of channel you would prefer to use for this 3DS Authentication. Only browser.
92 93 94 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 92 def type @type end |
Class Method Details
.field_remappings ⇒ Object
98 99 100 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 98 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
94 95 96 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 94 def self.inner_class_types @inner_class_types = { browser: Browser, three_r_i: ThreeRI } end |