Class: Stripe::ThreeDSecure::Authentication::OutcomeDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ThreeDSecure::Authentication::OutcomeDetails
- Defined in:
- lib/stripe/resources/three_d_secure/authentication.rb
Defined Under Namespace
Classes: NetworkDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acs_transaction_id ⇒ Object
readonly
Universally unique transaction identifier assigned by the issuer to identify the transaction.
-
#ares ⇒ Object
readonly
The Authentication Response Message (ARes) is the issuer's response to the AReq message.
-
#ares_trans_status ⇒ Object
readonly
TransStatus field on the ARes.
-
#cryptogram ⇒ Object
readonly
A 28-character Base64 string proving that 3DS was completed.
-
#ds_transaction_id ⇒ Object
readonly
The 3DS2 Directory Server Transaction ID.
-
#eci ⇒ Object
readonly
Electronic Commerce Indicator provided by the issuer to indicate the result of this 3DS Authentication.
-
#network_details ⇒ Object
readonly
Contains details specific to the individual network.
-
#protocol_version ⇒ Object
readonly
The 3DS protocol version used for this 3DS Authentication.
-
#requestor_challenge_indicator ⇒ Object
readonly
The indicator provided to the issuer by Stripe in the AReq that indicates whether a challenge is requested for this Authentication.
-
#rreq ⇒ Object
readonly
The Results Request Message (RReq) communicates the results of the authentication or verification.
-
#rreq_trans_status ⇒ Object
readonly
TransStatus field on the RReq.
-
#three_ds_server_transaction_id ⇒ Object
readonly
Universally unique transaction identifier assigned by Stripe to identify the transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acs_transaction_id ⇒ Object (readonly)
Universally unique transaction identifier assigned by the issuer to identify the transaction.
278 279 280 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 278 def acs_transaction_id @acs_transaction_id end |
#ares ⇒ Object (readonly)
The Authentication Response Message (ARes) is the issuer's response to the AReq message.
280 281 282 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 280 def ares @ares end |
#ares_trans_status ⇒ Object (readonly)
TransStatus field on the ARes
282 283 284 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 282 def ares_trans_status @ares_trans_status end |
#cryptogram ⇒ Object (readonly)
A 28-character Base64 string proving that 3DS was completed. Store this value securely, and don’t reuse it for multiple authorizations.
284 285 286 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 284 def cryptogram @cryptogram end |
#ds_transaction_id ⇒ Object (readonly)
The 3DS2 Directory Server Transaction ID.
286 287 288 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 286 def ds_transaction_id @ds_transaction_id end |
#eci ⇒ Object (readonly)
Electronic Commerce Indicator provided by the issuer to indicate the result of this 3DS Authentication.
288 289 290 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 288 def eci @eci end |
#network_details ⇒ Object (readonly)
Contains details specific to the individual network.
290 291 292 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 290 def network_details @network_details end |
#protocol_version ⇒ Object (readonly)
The 3DS protocol version used for this 3DS Authentication.
292 293 294 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 292 def protocol_version @protocol_version end |
#requestor_challenge_indicator ⇒ Object (readonly)
The indicator provided to the issuer by Stripe in the AReq that indicates whether a challenge is requested for this Authentication. This indicator should match the flow_preference you specified but may be overridden (for compliance reasons for example).
294 295 296 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 294 def requestor_challenge_indicator @requestor_challenge_indicator end |
#rreq ⇒ Object (readonly)
The Results Request Message (RReq) communicates the results of the authentication or verification.
296 297 298 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 296 def rreq @rreq end |
#rreq_trans_status ⇒ Object (readonly)
TransStatus field on the RReq
298 299 300 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 298 def rreq_trans_status @rreq_trans_status end |
#three_ds_server_transaction_id ⇒ Object (readonly)
Universally unique transaction identifier assigned by Stripe to identify the transaction.
300 301 302 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 300 def three_ds_server_transaction_id @three_ds_server_transaction_id end |
Class Method Details
.field_remappings ⇒ Object
306 307 308 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 306 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
302 303 304 |
# File 'lib/stripe/resources/three_d_secure/authentication.rb', line 302 def self.inner_class_types @inner_class_types = { network_details: NetworkDetails } end |