Class: Stripe::ThreeDSecure::AuthenticationCreateParams::Channel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::Channel
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#browser ⇒ Object
Contains additional details about the browser details you collected.
-
#three_r_i ⇒ Object
Contains additional details about the 3DS Requestor Initiated (3RI) channel.
-
#type ⇒ Object
Type of channel you would prefer to use for this 3DS Authentication.
Instance Method Summary collapse
-
#initialize(browser: nil, three_r_i: nil, type: nil) ⇒ Channel
constructor
A new instance of Channel.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(browser: nil, three_r_i: nil, type: nil) ⇒ Channel
Returns a new instance of Channel.
120 121 122 123 124 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 120 def initialize(browser: nil, three_r_i: nil, type: nil) @browser = browser @three_r_i = three_r_i @type = type end |
Instance Attribute Details
#browser ⇒ Object
Contains additional details about the browser details you collected.
114 115 116 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 114 def browser @browser end |
#three_r_i ⇒ Object
Contains additional details about the 3DS Requestor Initiated (3RI) channel.
116 117 118 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 116 def three_r_i @three_r_i end |
#type ⇒ Object
Type of channel you would prefer to use for this 3DS Authentication.
118 119 120 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 118 def type @type end |