Class: Stripe::ThreeDSecure::AuthenticationCreateParams::Channel::ThreeRI
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::Channel::ThreeRI
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Instance Attribute Summary collapse
-
#previous_authentication ⇒ Object
ID of a prior
Authentication. -
#type ⇒ Object
It provides additional information to the ACS to determine the best approach for handling a 3RI request.
Instance Method Summary collapse
-
#initialize(previous_authentication: nil, type: nil) ⇒ ThreeRI
constructor
A new instance of ThreeRI.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(previous_authentication: nil, type: nil) ⇒ ThreeRI
Returns a new instance of ThreeRI.
108 109 110 111 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 108 def initialize(previous_authentication: nil, type: nil) @previous_authentication = previous_authentication @type = type end |
Instance Attribute Details
#previous_authentication ⇒ Object
ID of a prior Authentication. For example, the first recurring transaction that was authenticated by the cardholder.
104 105 106 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 104 def previous_authentication @previous_authentication end |
#type ⇒ Object
It provides additional information to the ACS to determine the best approach for handling a 3RI request.
106 107 108 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 106 def type @type end |