Class: Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ThreeDSecure::AuthenticationCreateParams::FlowPreference
- Defined in:
- lib/stripe/params/three_d_secure/authentication_create_params.rb
Defined Under Namespace
Classes: Challenge, DataShare, Frictionless
Instance Attribute Summary collapse
-
#challenge ⇒ Object
Contains additional details about your challenge flow preference for this 3DS Authentication.
-
#data_share ⇒ Object
Contains additional details about your data share only flow preference for this 3DS Authentication.
-
#frictionless ⇒ Object
Contains additional details about your frictionless flow preference for this 3DS Authentication.
-
#type ⇒ Object
Type of flow you requested for this 3DS Authentication.
Instance Method Summary collapse
-
#initialize(challenge: nil, data_share: nil, frictionless: nil, type: nil) ⇒ FlowPreference
constructor
A new instance of FlowPreference.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(challenge: nil, data_share: nil, frictionless: nil, type: nil) ⇒ FlowPreference
163 164 165 166 167 168 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 163 def initialize(challenge: nil, data_share: nil, frictionless: nil, type: nil) @challenge = challenge @data_share = data_share @frictionless = frictionless @type = type end |
Instance Attribute Details
#challenge ⇒ Object
Contains additional details about your challenge flow preference for this 3DS Authentication.
155 156 157 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 155 def challenge @challenge end |
#data_share ⇒ Object
Contains additional details about your data share only flow preference for this 3DS Authentication.
157 158 159 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 157 def data_share @data_share end |
#frictionless ⇒ Object
Contains additional details about your frictionless flow preference for this 3DS Authentication.
159 160 161 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 159 def frictionless @frictionless end |
#type ⇒ Object
Type of flow you requested for this 3DS Authentication.
161 162 163 |
# File 'lib/stripe/params/three_d_secure/authentication_create_params.rb', line 161 def type @type end |