Class: Stripe::Token

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/token.rb

Overview

Tokenization is the process Stripe uses to collect sensitive card or bank account details, or personally identifiable information (PII), directly from your customers in a secure manner. A token representing this information is returned to your server to use. Use our [recommended payments integrations](stripe.com/docs/payments) to perform this process on the client-side. This guarantees that no sensitive card data touches your server, and allows your integration to operate in a PCI-compliant way.

If you can’t use client-side tokenization, you can also create tokens using the API with either your publishable or secret API key. If your integration uses this method, you’re responsible for any PCI compliance that it might require, and you must keep your secret API key safe. Unlike with client-side tokenization, your customer’s information isn’t sent directly to Stripe, so we can’t determine how it’s handled or stored.

You can’t store or use tokens more than once. To store card or bank account information for later use, create [Customer](stripe.com/docs/api#customers) objects or [External accounts](stripe.com/api#external_accounts). [Radar](stripe.com/docs/radar), our integrated solution for automatic fraud protection, performs best with integrations that use client-side tokenization.

Defined Under Namespace

Classes: CreateParams, RetrieveParams

Constant Summary collapse

OBJECT_NAME =
"token"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_accountObject (readonly)

These bank accounts are payment methods on ‘Customer` objects.

On the other hand [External Accounts](/api#external_accounts) are transfer destinations on ‘Account` objects for connected accounts. They can be bank accounts or debit cards as well, and are documented in the links above.

Related guide: [Bank debits and transfers](/payments/bank-debits-transfers)



1340
1341
1342
# File 'lib/stripe/resources/token.rb', line 1340

def 
  @bank_account
end

#cardObject (readonly)

You can store multiple cards on a customer in order to charge the customer later. You can also store multiple debit cards on a recipient in order to transfer to those cards later.

Related guide: [Card payments with Sources](stripe.com/docs/sources/cards)



1347
1348
1349
# File 'lib/stripe/resources/token.rb', line 1347

def card
  @card
end

#client_ipObject (readonly)

IP address of the client that generates the token.



1350
1351
1352
# File 'lib/stripe/resources/token.rb', line 1350

def client_ip
  @client_ip
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1353
1354
1355
# File 'lib/stripe/resources/token.rb', line 1353

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



1356
1357
1358
# File 'lib/stripe/resources/token.rb', line 1356

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1359
1360
1361
# File 'lib/stripe/resources/token.rb', line 1359

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1362
1363
1364
# File 'lib/stripe/resources/token.rb', line 1362

def object
  @object
end

#typeObject (readonly)

Type of the token: ‘account`, `bank_account`, `card`, or `pii`.



1365
1366
1367
# File 'lib/stripe/resources/token.rb', line 1365

def type
  @type
end

#usedObject (readonly)

Determines if you have already used this token (you can only use tokens once).



1368
1369
1370
# File 'lib/stripe/resources/token.rb', line 1368

def used
  @used
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a single-use token that represents a bank account’s details. You can use this token with any v1 API method in place of a bank account dictionary. You can only use this token once. To do so, attach it to a [connected account](stripe.com/docs/api#accounts) where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts.



1372
1373
1374
# File 'lib/stripe/resources/token.rb', line 1372

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/tokens", params: params, opts: opts)
end

.object_nameObject



29
30
31
# File 'lib/stripe/resources/token.rb', line 29

def self.object_name
  "token"
end