Class: Stripe::Token::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii
Instance Attribute Summary collapse
-
#account ⇒ Object
Information for the account this token represents.
-
#bank_account ⇒ Object
The bank account this token will represent.
-
#card ⇒ Object
The card this token will represent.
-
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account.
-
#cvc_update ⇒ Object
The updated CVC value this token represents.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#person ⇒ Object
Information for the person this token represents.
-
#pii ⇒ Object
The PII this token represents.
Instance Method Summary collapse
-
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 |
# File 'lib/stripe/resources/token.rb', line 1152 def initialize( account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil ) @account = account @bank_account = bank_account @card = card @customer = customer @cvc_update = cvc_update @expand = @person = person @pii = pii end |
Instance Attribute Details
#account ⇒ Object
Information for the account this token represents.
1136 1137 1138 |
# File 'lib/stripe/resources/token.rb', line 1136 def account @account end |
#bank_account ⇒ Object
The bank account this token will represent.
1138 1139 1140 |
# File 'lib/stripe/resources/token.rb', line 1138 def bank_account @bank_account end |
#card ⇒ Object
The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.
1140 1141 1142 |
# File 'lib/stripe/resources/token.rb', line 1140 def card @card end |
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).
1142 1143 1144 |
# File 'lib/stripe/resources/token.rb', line 1142 def customer @customer end |
#cvc_update ⇒ Object
The updated CVC value this token represents.
1144 1145 1146 |
# File 'lib/stripe/resources/token.rb', line 1144 def cvc_update @cvc_update end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1146 1147 1148 |
# File 'lib/stripe/resources/token.rb', line 1146 def @expand end |
#person ⇒ Object
Information for the person this token represents.
1148 1149 1150 |
# File 'lib/stripe/resources/token.rb', line 1148 def person @person end |
#pii ⇒ Object
The PII this token represents.
1150 1151 1152 |
# File 'lib/stripe/resources/token.rb', line 1150 def pii @pii end |