Class: Stripe::Token::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
# File 'lib/stripe/resources/token.rb', line 1152

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1136
1137
1138
# File 'lib/stripe/resources/token.rb', line 1136

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1138
1139
1140
# File 'lib/stripe/resources/token.rb', line 1138

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.



1140
1141
1142
# File 'lib/stripe/resources/token.rb', line 1140

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).



1142
1143
1144
# File 'lib/stripe/resources/token.rb', line 1142

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1144
1145
1146
# File 'lib/stripe/resources/token.rb', line 1144

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1146
1147
1148
# File 'lib/stripe/resources/token.rb', line 1146

def expand
  @expand
end

#personObject

Information for the person this token represents.



1148
1149
1150
# File 'lib/stripe/resources/token.rb', line 1148

def person
  @person
end

#piiObject

The PII this token represents.



1150
1151
1152
# File 'lib/stripe/resources/token.rb', line 1150

def pii
  @pii
end