Class: Stripe::Token::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii
Instance Attribute Summary collapse
-
#account ⇒ Object
Information for the account this token represents.
-
#bank_account ⇒ Object
The bank account this token will represent.
-
#card ⇒ Object
The card this token will represent.
-
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account.
-
#cvc_update ⇒ Object
The updated CVC value this token represents.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#person ⇒ Object
Information for the person this token represents.
-
#pii ⇒ Object
The PII this token represents.
Instance Method Summary collapse
-
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 |
# File 'lib/stripe/resources/token.rb', line 1313 def initialize( account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil ) @account = account @bank_account = bank_account @card = card @customer = customer @cvc_update = cvc_update @expand = @person = person @pii = pii end |
Instance Attribute Details
#account ⇒ Object
Information for the account this token represents.
1290 1291 1292 |
# File 'lib/stripe/resources/token.rb', line 1290 def account @account end |
#bank_account ⇒ Object
The bank account this token will represent.
1293 1294 1295 |
# File 'lib/stripe/resources/token.rb', line 1293 def bank_account @bank_account end |
#card ⇒ Object
The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.
1296 1297 1298 |
# File 'lib/stripe/resources/token.rb', line 1296 def card @card end |
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).
1299 1300 1301 |
# File 'lib/stripe/resources/token.rb', line 1299 def customer @customer end |
#cvc_update ⇒ Object
The updated CVC value this token represents.
1302 1303 1304 |
# File 'lib/stripe/resources/token.rb', line 1302 def cvc_update @cvc_update end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1305 1306 1307 |
# File 'lib/stripe/resources/token.rb', line 1305 def @expand end |
#person ⇒ Object
Information for the person this token represents.
1308 1309 1310 |
# File 'lib/stripe/resources/token.rb', line 1308 def person @person end |
#pii ⇒ Object
The PII this token represents.
1311 1312 1313 |
# File 'lib/stripe/resources/token.rb', line 1311 def pii @pii end |