Class: Stripe::Token::CreateParams::Account

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



614
615
616
617
618
619
620
621
622
623
624
# File 'lib/stripe/resources/token.rb', line 614

def initialize(
  business_type: nil,
  company: nil,
  individual: nil,
  tos_shown_and_accepted: nil
)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



606
607
608
# File 'lib/stripe/resources/token.rb', line 606

def business_type
  @business_type
end

#companyObject

Information about the company or business.



608
609
610
# File 'lib/stripe/resources/token.rb', line 608

def company
  @company
end

#individualObject

Information about the person represented by the account.



610
611
612
# File 'lib/stripe/resources/token.rb', line 610

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.



612
613
614
# File 'lib/stripe/resources/token.rb', line 612

def tos_shown_and_accepted
  @tos_shown_and_accepted
end