Class: Stripe::Token::CreateParams::Account

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



595
596
597
598
599
600
601
602
603
604
605
# File 'lib/stripe/resources/token.rb', line 595

def initialize(
  business_type: nil,
  company: nil,
  individual: nil,
  tos_shown_and_accepted: nil
)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



587
588
589
# File 'lib/stripe/resources/token.rb', line 587

def business_type
  @business_type
end

#companyObject

Information about the company or business.



589
590
591
# File 'lib/stripe/resources/token.rb', line 589

def company
  @company
end

#individualObject

Information about the person represented by the account.



591
592
593
# File 'lib/stripe/resources/token.rb', line 591

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.



593
594
595
# File 'lib/stripe/resources/token.rb', line 593

def tos_shown_and_accepted
  @tos_shown_and_accepted
end