Class: Stripe::Token::CreateParams::Account

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



585
586
587
588
589
590
591
592
593
594
595
# File 'lib/stripe/resources/token.rb', line 585

def initialize(
  business_type: nil,
  company: nil,
  individual: nil,
  tos_shown_and_accepted: nil
)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



577
578
579
# File 'lib/stripe/resources/token.rb', line 577

def business_type
  @business_type
end

#companyObject

Information about the company or business.



579
580
581
# File 'lib/stripe/resources/token.rb', line 579

def company
  @company
end

#individualObject

Information about the person represented by the account.



581
582
583
# File 'lib/stripe/resources/token.rb', line 581

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.



583
584
585
# File 'lib/stripe/resources/token.rb', line 583

def tos_shown_and_accepted
  @tos_shown_and_accepted
end