Class: Stripe::Token::CreateParams::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Account
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: Company, Individual
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type.
-
#company ⇒ Object
Information about the company or business.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#tos_shown_and_accepted ⇒ Object
Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement).
Instance Method Summary collapse
-
#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account
Returns a new instance of Account.
676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/stripe/resources/token.rb', line 676 def initialize( business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil ) @business_type = business_type @company = company @individual = individual @tos_shown_and_accepted = tos_shown_and_accepted end |
Instance Attribute Details
#business_type ⇒ Object
The business type.
665 666 667 |
# File 'lib/stripe/resources/token.rb', line 665 def business_type @business_type end |
#company ⇒ Object
Information about the company or business.
668 669 670 |
# File 'lib/stripe/resources/token.rb', line 668 def company @company end |
#individual ⇒ Object
Information about the person represented by the account.
671 672 673 |
# File 'lib/stripe/resources/token.rb', line 671 def individual @individual end |
#tos_shown_and_accepted ⇒ Object
Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.
674 675 676 |
# File 'lib/stripe/resources/token.rb', line 674 def tos_shown_and_accepted @tos_shown_and_accepted end |