Class: Stripe::Token::CreateParams::Account::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Account::Company
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
-
#directors_provided ⇒ Object
Whether the company’s directors have been provided.
-
#executives_provided ⇒ Object
Whether the company’s executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company’s legal name.
-
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_declaration_shown_and_signed ⇒ Object
Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.
-
#phone ⇒ Object
The company’s phone number (used for verification).
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
-
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_declaration_shown_and_signed: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/stripe/resources/token.rb', line 260 def initialize( address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_declaration_shown_and_signed: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @directors_provided = directors_provided @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @ownership_declaration_shown_and_signed = ownership_declaration_shown_and_signed @phone = phone @registration_number = registration_number @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company’s primary address.
201 202 203 |
# File 'lib/stripe/resources/token.rb', line 201 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
204 205 206 |
# File 'lib/stripe/resources/token.rb', line 204 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
207 208 209 |
# File 'lib/stripe/resources/token.rb', line 207 def address_kanji @address_kanji end |
#directors_provided ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.
210 211 212 |
# File 'lib/stripe/resources/token.rb', line 210 def directors_provided @directors_provided end |
#executives_provided ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.
213 214 215 |
# File 'lib/stripe/resources/token.rb', line 213 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
216 217 218 |
# File 'lib/stripe/resources/token.rb', line 216 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
219 220 221 |
# File 'lib/stripe/resources/token.rb', line 219 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company’s legal name.
222 223 224 |
# File 'lib/stripe/resources/token.rb', line 222 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
225 226 227 |
# File 'lib/stripe/resources/token.rb', line 225 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
228 229 230 |
# File 'lib/stripe/resources/token.rb', line 228 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.
231 232 233 |
# File 'lib/stripe/resources/token.rb', line 231 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
234 235 236 |
# File 'lib/stripe/resources/token.rb', line 234 def ownership_declaration @ownership_declaration end |
#ownership_declaration_shown_and_signed ⇒ Object
Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.
237 238 239 |
# File 'lib/stripe/resources/token.rb', line 237 def ownership_declaration_shown_and_signed @ownership_declaration_shown_and_signed end |
#phone ⇒ Object
The company’s phone number (used for verification).
240 241 242 |
# File 'lib/stripe/resources/token.rb', line 240 def phone @phone end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
243 244 245 |
# File 'lib/stripe/resources/token.rb', line 243 def registration_number @registration_number end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.
246 247 248 |
# File 'lib/stripe/resources/token.rb', line 246 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
249 250 251 |
# File 'lib/stripe/resources/token.rb', line 249 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
252 253 254 |
# File 'lib/stripe/resources/token.rb', line 252 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
255 256 257 |
# File 'lib/stripe/resources/token.rb', line 255 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
258 259 260 |
# File 'lib/stripe/resources/token.rb', line 258 def verification @verification end |