Class: Stripe::Token::CreateParams::Account::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



145
146
147
148
149
# File 'lib/stripe/resources/token.rb', line 145

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



139
140
141
# File 'lib/stripe/resources/token.rb', line 139

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



141
142
143
# File 'lib/stripe/resources/token.rb', line 141

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



143
144
145
# File 'lib/stripe/resources/token.rb', line 143

def user_agent
  @user_agent
end