Class: Stripe::Token::CreateParams::Account::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
# File 'lib/stripe/resources/token.rb', line 526

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



480
481
482
# File 'lib/stripe/resources/token.rb', line 480

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



482
483
484
# File 'lib/stripe/resources/token.rb', line 482

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



484
485
486
# File 'lib/stripe/resources/token.rb', line 484

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



486
487
488
# File 'lib/stripe/resources/token.rb', line 486

def dob
  @dob
end

#emailObject

The individual’s email address.



488
489
490
# File 'lib/stripe/resources/token.rb', line 488

def email
  @email
end

#first_nameObject

The individual’s first name.



490
491
492
# File 'lib/stripe/resources/token.rb', line 490

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



492
493
494
# File 'lib/stripe/resources/token.rb', line 492

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



494
495
496
# File 'lib/stripe/resources/token.rb', line 494

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



496
497
498
# File 'lib/stripe/resources/token.rb', line 496

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



498
499
500
# File 'lib/stripe/resources/token.rb', line 498

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



500
501
502
# File 'lib/stripe/resources/token.rb', line 500

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



502
503
504
# File 'lib/stripe/resources/token.rb', line 502

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



504
505
506
# File 'lib/stripe/resources/token.rb', line 504

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



506
507
508
# File 'lib/stripe/resources/token.rb', line 506

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



508
509
510
# File 'lib/stripe/resources/token.rb', line 508

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



510
511
512
# File 'lib/stripe/resources/token.rb', line 510

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



512
513
514
# File 'lib/stripe/resources/token.rb', line 512

def 
  @metadata
end

#phoneObject

The individual’s phone number.



514
515
516
# File 'lib/stripe/resources/token.rb', line 514

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



516
517
518
# File 'lib/stripe/resources/token.rb', line 516

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



518
519
520
# File 'lib/stripe/resources/token.rb', line 518

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



520
521
522
# File 'lib/stripe/resources/token.rb', line 520

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



522
523
524
# File 'lib/stripe/resources/token.rb', line 522

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



524
525
526
# File 'lib/stripe/resources/token.rb', line 524

def verification
  @verification
end