Class: Stripe::Token::CreateParams::Account::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/stripe/resources/token.rb', line 614

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



546
547
548
# File 'lib/stripe/resources/token.rb', line 546

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



549
550
551
# File 'lib/stripe/resources/token.rb', line 549

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



552
553
554
# File 'lib/stripe/resources/token.rb', line 552

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



555
556
557
# File 'lib/stripe/resources/token.rb', line 555

def dob
  @dob
end

#emailObject

The individual’s email address.



558
559
560
# File 'lib/stripe/resources/token.rb', line 558

def email
  @email
end

#first_nameObject

The individual’s first name.



561
562
563
# File 'lib/stripe/resources/token.rb', line 561

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



564
565
566
# File 'lib/stripe/resources/token.rb', line 564

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



567
568
569
# File 'lib/stripe/resources/token.rb', line 567

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



570
571
572
# File 'lib/stripe/resources/token.rb', line 570

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



573
574
575
# File 'lib/stripe/resources/token.rb', line 573

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



576
577
578
# File 'lib/stripe/resources/token.rb', line 576

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



579
580
581
# File 'lib/stripe/resources/token.rb', line 579

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



582
583
584
# File 'lib/stripe/resources/token.rb', line 582

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



585
586
587
# File 'lib/stripe/resources/token.rb', line 585

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



588
589
590
# File 'lib/stripe/resources/token.rb', line 588

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



591
592
593
# File 'lib/stripe/resources/token.rb', line 591

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



594
595
596
# File 'lib/stripe/resources/token.rb', line 594

def 
  @metadata
end

#phoneObject

The individual’s phone number.



597
598
599
# File 'lib/stripe/resources/token.rb', line 597

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



600
601
602
# File 'lib/stripe/resources/token.rb', line 600

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



603
604
605
# File 'lib/stripe/resources/token.rb', line 603

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



606
607
608
# File 'lib/stripe/resources/token.rb', line 606

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



609
610
611
# File 'lib/stripe/resources/token.rb', line 609

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



612
613
614
# File 'lib/stripe/resources/token.rb', line 612

def verification
  @verification
end