Class: Stripe::Token::CreateParams::BankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::BankAccount
- Defined in:
- lib/stripe/resources/token.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name of the person or business that owns the bank account.
-
#account_holder_type ⇒ Object
The type of entity that holds the account.
-
#account_number ⇒ Object
The account number for the bank account, in string form.
-
#account_type ⇒ Object
The bank account type.
-
#country ⇒ Object
The country in which the bank account is located.
-
#currency ⇒ Object
The currency the bank account is in.
-
#payment_method ⇒ Object
The ID of a Payment Method with a ‘type` of `us_bank_account`.
-
#routing_number ⇒ Object
The routing number, sort code, or other country-appropriate institution number for the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil) ⇒ BankAccount
constructor
A new instance of BankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil) ⇒ BankAccount
Returns a new instance of BankAccount.
714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/stripe/resources/token.rb', line 714 def initialize( account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil ) @account_holder_name = account_holder_name @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @country = country @currency = currency @payment_method = payment_method @routing_number = routing_number end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name of the person or business that owns the bank account. This field is required when attaching the bank account to a ‘Customer` object.
691 692 693 |
# File 'lib/stripe/resources/token.rb', line 691 def account_holder_name @account_holder_name end |
#account_holder_type ⇒ Object
The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.
694 695 696 |
# File 'lib/stripe/resources/token.rb', line 694 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
The account number for the bank account, in string form. Must be a checking account.
697 698 699 |
# File 'lib/stripe/resources/token.rb', line 697 def account_number @account_number end |
#account_type ⇒ Object
The bank account type. This can only be ‘checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.
700 701 702 |
# File 'lib/stripe/resources/token.rb', line 700 def account_type @account_type end |
#country ⇒ Object
The country in which the bank account is located.
703 704 705 |
# File 'lib/stripe/resources/token.rb', line 703 def country @country end |
#currency ⇒ Object
The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](stripe.com/docs/payouts)
706 707 708 |
# File 'lib/stripe/resources/token.rb', line 706 def currency @currency end |
#payment_method ⇒ Object
The ID of a Payment Method with a ‘type` of `us_bank_account`. The Payment Method’s bank account information will be copied and returned as a Bank Account Token. This parameter is exclusive with respect to all other parameters in the ‘bank_account` hash. You must include the top-level `customer` parameter if the Payment Method is attached to a `Customer` object. If the Payment Method is not attached to a `Customer` object, it will be consumed and cannot be used again. You may not use Payment Methods which were created by a Setup Intent with `attach_to_self=true`.
709 710 711 |
# File 'lib/stripe/resources/token.rb', line 709 def payment_method @payment_method end |
#routing_number ⇒ Object
The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.
712 713 714 |
# File 'lib/stripe/resources/token.rb', line 712 def routing_number @routing_number end |