Class: Stripe::Token::CreateParams::Person

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Person

Returns a new instance of Person.



1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
# File 'lib/stripe/resources/token.rb', line 1224

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  documents: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @documents = documents
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.



1147
1148
1149
# File 'lib/stripe/resources/token.rb', line 1147

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person’s address.



1150
1151
1152
# File 'lib/stripe/resources/token.rb', line 1150

def address
  @address
end

#address_kanaObject

The Kana variation of the person’s address (Japan only).



1153
1154
1155
# File 'lib/stripe/resources/token.rb', line 1153

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person’s address (Japan only).



1156
1157
1158
# File 'lib/stripe/resources/token.rb', line 1156

def address_kanji
  @address_kanji
end

#dobObject

The person’s date of birth.



1159
1160
1161
# File 'lib/stripe/resources/token.rb', line 1159

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



1162
1163
1164
# File 'lib/stripe/resources/token.rb', line 1162

def documents
  @documents
end

#emailObject

The person’s email address.



1165
1166
1167
# File 'lib/stripe/resources/token.rb', line 1165

def email
  @email
end

#first_nameObject

The person’s first name.



1168
1169
1170
# File 'lib/stripe/resources/token.rb', line 1168

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person’s first name (Japan only).



1171
1172
1173
# File 'lib/stripe/resources/token.rb', line 1171

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person’s first name (Japan only).



1174
1175
1176
# File 'lib/stripe/resources/token.rb', line 1174

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



1177
1178
1179
# File 'lib/stripe/resources/token.rb', line 1177

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person’s gender (International regulations require either “male” or “female”).



1180
1181
1182
# File 'lib/stripe/resources/token.rb', line 1180

def gender
  @gender
end

#id_numberObject

The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1183
1184
1185
# File 'lib/stripe/resources/token.rb', line 1183

def id_number
  @id_number
end

#id_number_secondaryObject

The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1186
1187
1188
# File 'lib/stripe/resources/token.rb', line 1186

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person’s last name.



1189
1190
1191
# File 'lib/stripe/resources/token.rb', line 1189

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person’s last name (Japan only).



1192
1193
1194
# File 'lib/stripe/resources/token.rb', line 1192

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person’s last name (Japan only).



1195
1196
1197
# File 'lib/stripe/resources/token.rb', line 1195

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person’s maiden name.



1198
1199
1200
# File 'lib/stripe/resources/token.rb', line 1198

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1201
1202
1203
# File 'lib/stripe/resources/token.rb', line 1201

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.



1204
1205
1206
# File 'lib/stripe/resources/token.rb', line 1204

def nationality
  @nationality
end

#phoneObject

The person’s phone number.



1207
1208
1209
# File 'lib/stripe/resources/token.rb', line 1207

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1210
1211
1212
# File 'lib/stripe/resources/token.rb', line 1210

def political_exposure
  @political_exposure
end

#registered_addressObject

The person’s registered address.



1213
1214
1215
# File 'lib/stripe/resources/token.rb', line 1213

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account’s legal entity.



1216
1217
1218
# File 'lib/stripe/resources/token.rb', line 1216

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the person’s Social Security number (U.S. only).



1219
1220
1221
# File 'lib/stripe/resources/token.rb', line 1219

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The person’s verification status.



1222
1223
1224
# File 'lib/stripe/resources/token.rb', line 1222

def verification
  @verification
end