Class: Stripe::Token::CreateParams::Person
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Person
- Defined in:
- lib/stripe/resources/token.rb
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
-
#address ⇒ Object
The person’s address.
-
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
-
#dob ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The person’s email address.
-
#first_name ⇒ Object
The person’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
-
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#id_number ⇒ Object
The person’s ID number, as appropriate for their country.
-
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The person’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
The person’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
The country where the person is a national.
-
#phone ⇒ Object
The person’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The person’s registered address.
-
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
-
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
-
#verification ⇒ Object
The person’s verification status.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Person
Returns a new instance of Person.
1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/stripe/resources/token.rb', line 1070 def initialize( additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @additional_tos_acceptances = additional_tos_acceptances @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @documents = documents @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @nationality = nationality @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
1018 1019 1020 |
# File 'lib/stripe/resources/token.rb', line 1018 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object
The person’s address.
1020 1021 1022 |
# File 'lib/stripe/resources/token.rb', line 1020 def address @address end |
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
1022 1023 1024 |
# File 'lib/stripe/resources/token.rb', line 1022 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
1024 1025 1026 |
# File 'lib/stripe/resources/token.rb', line 1024 def address_kanji @address_kanji end |
#dob ⇒ Object
The person’s date of birth.
1026 1027 1028 |
# File 'lib/stripe/resources/token.rb', line 1026 def dob @dob end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
1028 1029 1030 |
# File 'lib/stripe/resources/token.rb', line 1028 def documents @documents end |
#email ⇒ Object
The person’s email address.
1030 1031 1032 |
# File 'lib/stripe/resources/token.rb', line 1030 def email @email end |
#first_name ⇒ Object
The person’s first name.
1032 1033 1034 |
# File 'lib/stripe/resources/token.rb', line 1032 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
1034 1035 1036 |
# File 'lib/stripe/resources/token.rb', line 1034 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
1036 1037 1038 |
# File 'lib/stripe/resources/token.rb', line 1036 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
1038 1039 1040 |
# File 'lib/stripe/resources/token.rb', line 1038 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
1040 1041 1042 |
# File 'lib/stripe/resources/token.rb', line 1040 def gender @gender end |
#id_number ⇒ Object
The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
1042 1043 1044 |
# File 'lib/stripe/resources/token.rb', line 1042 def id_number @id_number end |
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
1044 1045 1046 |
# File 'lib/stripe/resources/token.rb', line 1044 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The person’s last name.
1046 1047 1048 |
# File 'lib/stripe/resources/token.rb', line 1046 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
1048 1049 1050 |
# File 'lib/stripe/resources/token.rb', line 1048 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
1050 1051 1052 |
# File 'lib/stripe/resources/token.rb', line 1050 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The person’s maiden name.
1052 1053 1054 |
# File 'lib/stripe/resources/token.rb', line 1052 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1054 1055 1056 |
# File 'lib/stripe/resources/token.rb', line 1054 def @metadata end |
#nationality ⇒ Object
The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.
1056 1057 1058 |
# File 'lib/stripe/resources/token.rb', line 1056 def nationality @nationality end |
#phone ⇒ Object
The person’s phone number.
1058 1059 1060 |
# File 'lib/stripe/resources/token.rb', line 1058 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1060 1061 1062 |
# File 'lib/stripe/resources/token.rb', line 1060 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The person’s registered address.
1062 1063 1064 |
# File 'lib/stripe/resources/token.rb', line 1062 def registered_address @registered_address end |
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
1064 1065 1066 |
# File 'lib/stripe/resources/token.rb', line 1064 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
1066 1067 1068 |
# File 'lib/stripe/resources/token.rb', line 1066 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The person’s verification status.
1068 1069 1070 |
# File 'lib/stripe/resources/token.rb', line 1068 def verification @verification end |