Class: Stripe::Token::CreateParams::Person::AdditionalTosAcceptances::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Person::AdditionalTosAcceptances::Account
- Defined in:
- lib/stripe/resources/token.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
733 734 735 736 737 |
# File 'lib/stripe/resources/token.rb', line 733 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
727 728 729 |
# File 'lib/stripe/resources/token.rb', line 727 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
729 730 731 |
# File 'lib/stripe/resources/token.rb', line 729 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
731 732 733 |
# File 'lib/stripe/resources/token.rb', line 731 def user_agent @user_agent end |