Class: Stripe::Token::CreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



897
898
899
900
901
# File 'lib/stripe/resources/token.rb', line 897

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



891
892
893
# File 'lib/stripe/resources/token.rb', line 891

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



893
894
895
# File 'lib/stripe/resources/token.rb', line 893

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



895
896
897
# File 'lib/stripe/resources/token.rb', line 895

def visa
  @visa
end