Class: Stripe::Token::CreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



906
907
908
909
910
# File 'lib/stripe/resources/token.rb', line 906

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



900
901
902
# File 'lib/stripe/resources/token.rb', line 900

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



902
903
904
# File 'lib/stripe/resources/token.rb', line 902

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



904
905
906
# File 'lib/stripe/resources/token.rb', line 904

def visa
  @visa
end