Class: Stripe::Token::CreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



887
888
889
890
891
# File 'lib/stripe/resources/token.rb', line 887

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



881
882
883
# File 'lib/stripe/resources/token.rb', line 881

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



883
884
885
# File 'lib/stripe/resources/token.rb', line 883

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



885
886
887
# File 'lib/stripe/resources/token.rb', line 885

def visa
  @visa
end