Class: Stripe::Token::CreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
# File 'lib/stripe/resources/token.rb', line 972

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



956
957
958
# File 'lib/stripe/resources/token.rb', line 956

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



958
959
960
# File 'lib/stripe/resources/token.rb', line 958

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



960
961
962
# File 'lib/stripe/resources/token.rb', line 960

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



962
963
964
# File 'lib/stripe/resources/token.rb', line 962

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



964
965
966
# File 'lib/stripe/resources/token.rb', line 964

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



966
967
968
# File 'lib/stripe/resources/token.rb', line 966

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



968
969
970
# File 'lib/stripe/resources/token.rb', line 968

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



970
971
972
# File 'lib/stripe/resources/token.rb', line 970

def title
  @title
end