Class: Stripe::Token::CreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
# File 'lib/stripe/resources/token.rb', line 1088

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



1065
1066
1067
# File 'lib/stripe/resources/token.rb', line 1065

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1068
1069
1070
# File 'lib/stripe/resources/token.rb', line 1068

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1071
1072
1073
# File 'lib/stripe/resources/token.rb', line 1071

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



1074
1075
1076
# File 'lib/stripe/resources/token.rb', line 1074

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1077
1078
1079
# File 'lib/stripe/resources/token.rb', line 1077

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1080
1081
1082
# File 'lib/stripe/resources/token.rb', line 1080

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



1083
1084
1085
# File 'lib/stripe/resources/token.rb', line 1083

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1086
1087
1088
# File 'lib/stripe/resources/token.rb', line 1086

def title
  @title
end