Class: Stripe::Token::CreateParams::Person::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Token::CreateParams::Person::Relationship
- Defined in:
- lib/stripe/resources/token.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
Whether the person is the authorizer of the account’s representative.
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
Whether the person is the legal guardian of the account’s representative.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#representative ⇒ Object
Whether the person is authorized as the primary representative of the account.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 |
# File 'lib/stripe/resources/token.rb', line 943 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @percent_ownership = percent_ownership @representative = representative @title = title end |
Instance Attribute Details
#authorizer ⇒ Object
Whether the person is the authorizer of the account’s representative.
927 928 929 |
# File 'lib/stripe/resources/token.rb', line 927 def @authorizer end |
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
929 930 931 |
# File 'lib/stripe/resources/token.rb', line 929 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
931 932 933 |
# File 'lib/stripe/resources/token.rb', line 931 def executive @executive end |
#legal_guardian ⇒ Object
Whether the person is the legal guardian of the account’s representative.
933 934 935 |
# File 'lib/stripe/resources/token.rb', line 933 def legal_guardian @legal_guardian end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
935 936 937 |
# File 'lib/stripe/resources/token.rb', line 935 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
937 938 939 |
# File 'lib/stripe/resources/token.rb', line 937 def percent_ownership @percent_ownership end |
#representative ⇒ Object
Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
939 940 941 |
# File 'lib/stripe/resources/token.rb', line 939 def representative @representative end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
941 942 943 |
# File 'lib/stripe/resources/token.rb', line 941 def title @title end |