Class: Stripe::TokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams

Returns a new instance of TokenCreateParams.



1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
# File 'lib/stripe/params/token_create_params.rb', line 1268

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1252
1253
1254
# File 'lib/stripe/params/token_create_params.rb', line 1252

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1254
1255
1256
# File 'lib/stripe/params/token_create_params.rb', line 1254

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user's credit card details, with the options described below.



1256
1257
1258
# File 'lib/stripe/params/token_create_params.rb', line 1256

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application's account. You can only use this with an OAuth access token or Stripe-Account header. Learn more about cloning saved payment methods.



1258
1259
1260
# File 'lib/stripe/params/token_create_params.rb', line 1258

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1260
1261
1262
# File 'lib/stripe/params/token_create_params.rb', line 1260

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1262
1263
1264
# File 'lib/stripe/params/token_create_params.rb', line 1262

def expand
  @expand
end

#personObject

Information for the person this token represents.



1264
1265
1266
# File 'lib/stripe/params/token_create_params.rb', line 1264

def person
  @person
end

#piiObject

The PII this token represents.



1266
1267
1268
# File 'lib/stripe/params/token_create_params.rb', line 1266

def pii
  @pii
end