Class: Stripe::TokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams

Returns a new instance of TokenCreateParams.



1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
# File 'lib/stripe/params/token_create_params.rb', line 1324

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1308
1309
1310
# File 'lib/stripe/params/token_create_params.rb', line 1308

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1310
1311
1312
# File 'lib/stripe/params/token_create_params.rb', line 1310

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.



1312
1313
1314
# File 'lib/stripe/params/token_create_params.rb', line 1312

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](docs.stripe.com/connect/standard-accounts) or [Stripe-Account header](docs.stripe.com/connect/authentication). Learn more about [cloning saved payment methods](docs.stripe.com/connect/cloning-saved-payment-methods).



1314
1315
1316
# File 'lib/stripe/params/token_create_params.rb', line 1314

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1316
1317
1318
# File 'lib/stripe/params/token_create_params.rb', line 1316

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1318
1319
1320
# File 'lib/stripe/params/token_create_params.rb', line 1318

def expand
  @expand
end

#personObject

Information for the person this token represents.



1320
1321
1322
# File 'lib/stripe/params/token_create_params.rb', line 1320

def person
  @person
end

#piiObject

The PII this token represents.



1322
1323
1324
# File 'lib/stripe/params/token_create_params.rb', line 1322

def pii
  @pii
end