Class: Stripe::TokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii
Instance Attribute Summary collapse
-
#account ⇒ Object
Information for the account this token represents.
-
#bank_account ⇒ Object
The bank account this token will represent.
-
#card ⇒ Object
The card this token will represent.
-
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account.
-
#cvc_update ⇒ Object
The updated CVC value this token represents.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#person ⇒ Object
Information for the person this token represents.
-
#pii ⇒ Object
The PII this token represents.
Instance Method Summary collapse
-
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams
constructor
A new instance of TokenCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams
Returns a new instance of TokenCreateParams.
1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/stripe/params/token_create_params.rb', line 1254 def initialize( account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil ) @account = account @bank_account = bank_account @card = card @customer = customer @cvc_update = cvc_update @expand = @person = person @pii = pii end |
Instance Attribute Details
#account ⇒ Object
Information for the account this token represents.
1238 1239 1240 |
# File 'lib/stripe/params/token_create_params.rb', line 1238 def account @account end |
#bank_account ⇒ Object
The bank account this token will represent.
1240 1241 1242 |
# File 'lib/stripe/params/token_create_params.rb', line 1240 def bank_account @bank_account end |
#card ⇒ Object
The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.
1242 1243 1244 |
# File 'lib/stripe/params/token_create_params.rb', line 1242 def card @card end |
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).
1244 1245 1246 |
# File 'lib/stripe/params/token_create_params.rb', line 1244 def customer @customer end |
#cvc_update ⇒ Object
The updated CVC value this token represents.
1246 1247 1248 |
# File 'lib/stripe/params/token_create_params.rb', line 1246 def cvc_update @cvc_update end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1248 1249 1250 |
# File 'lib/stripe/params/token_create_params.rb', line 1248 def @expand end |
#person ⇒ Object
Information for the person this token represents.
1250 1251 1252 |
# File 'lib/stripe/params/token_create_params.rb', line 1250 def person @person end |
#pii ⇒ Object
The PII this token represents.
1252 1253 1254 |
# File 'lib/stripe/params/token_create_params.rb', line 1252 def pii @pii end |