Class: Stripe::TokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii
Instance Attribute Summary collapse
-
#account ⇒ Object
Information for the account this token represents.
-
#bank_account ⇒ Object
The bank account this token will represent.
-
#card ⇒ Object
The card this token will represent.
-
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account.
-
#cvc_update ⇒ Object
The updated CVC value this token represents.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#person ⇒ Object
Information for the person this token represents.
-
#pii ⇒ Object
The PII this token represents.
Instance Method Summary collapse
-
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams
constructor
A new instance of TokenCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ TokenCreateParams
Returns a new instance of TokenCreateParams.
1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/stripe/params/token_create_params.rb', line 1171 def initialize( account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil ) @account = account @bank_account = bank_account @card = card @customer = customer @cvc_update = cvc_update @expand = @person = person @pii = pii end |
Instance Attribute Details
#account ⇒ Object
Information for the account this token represents.
1155 1156 1157 |
# File 'lib/stripe/params/token_create_params.rb', line 1155 def account @account end |
#bank_account ⇒ Object
The bank account this token will represent.
1157 1158 1159 |
# File 'lib/stripe/params/token_create_params.rb', line 1157 def bank_account @bank_account end |
#card ⇒ Object
The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.
1159 1160 1161 |
# File 'lib/stripe/params/token_create_params.rb', line 1159 def card @card end |
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).
1161 1162 1163 |
# File 'lib/stripe/params/token_create_params.rb', line 1161 def customer @customer end |
#cvc_update ⇒ Object
The updated CVC value this token represents.
1163 1164 1165 |
# File 'lib/stripe/params/token_create_params.rb', line 1163 def cvc_update @cvc_update end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1165 1166 1167 |
# File 'lib/stripe/params/token_create_params.rb', line 1165 def @expand end |
#person ⇒ Object
Information for the person this token represents.
1167 1168 1169 |
# File 'lib/stripe/params/token_create_params.rb', line 1167 def person @person end |
#pii ⇒ Object
The PII this token represents.
1169 1170 1171 |
# File 'lib/stripe/params/token_create_params.rb', line 1169 def pii @pii end |