Class: Stripe::TokenCreateParams::Account

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



677
678
679
680
681
682
# File 'lib/stripe/params/token_create_params.rb', line 677

def initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



669
670
671
# File 'lib/stripe/params/token_create_params.rb', line 669

def business_type
  @business_type
end

#companyObject

Information about the company or business.



671
672
673
# File 'lib/stripe/params/token_create_params.rb', line 671

def company
  @company
end

#individualObject

Information about the person represented by the account.



673
674
675
# File 'lib/stripe/params/token_create_params.rb', line 673

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown the Stripe Connected Account Agreement. When creating an account token to create a new Connect account, this value must be true.



675
676
677
# File 'lib/stripe/params/token_create_params.rb', line 675

def tos_shown_and_accepted
  @tos_shown_and_accepted
end