Class: Stripe::TokenCreateParams::Account

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



672
673
674
675
676
677
# File 'lib/stripe/params/token_create_params.rb', line 672

def initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



664
665
666
# File 'lib/stripe/params/token_create_params.rb', line 664

def business_type
  @business_type
end

#companyObject

Information about the company or business.



666
667
668
# File 'lib/stripe/params/token_create_params.rb', line 666

def company
  @company
end

#individualObject

Information about the person represented by the account.



668
669
670
# File 'lib/stripe/params/token_create_params.rb', line 668

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.



670
671
672
# File 'lib/stripe/params/token_create_params.rb', line 670

def tos_shown_and_accepted
  @tos_shown_and_accepted
end