Class: Stripe::TokenCreateParams::Account

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: Company, Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account

Returns a new instance of Account.



637
638
639
640
641
642
# File 'lib/stripe/params/token_create_params.rb', line 637

def initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil)
  @business_type = business_type
  @company = company
  @individual = individual
  @tos_shown_and_accepted = tos_shown_and_accepted
end

Instance Attribute Details

#business_typeObject

The business type.



629
630
631
# File 'lib/stripe/params/token_create_params.rb', line 629

def business_type
  @business_type
end

#companyObject

Information about the company or business.



631
632
633
# File 'lib/stripe/params/token_create_params.rb', line 631

def company
  @company
end

#individualObject

Information about the person represented by the account.



633
634
635
# File 'lib/stripe/params/token_create_params.rb', line 633

def individual
  @individual
end

#tos_shown_and_acceptedObject

Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.



635
636
637
# File 'lib/stripe/params/token_create_params.rb', line 635

def tos_shown_and_accepted
  @tos_shown_and_accepted
end