Class: Stripe::TokenCreateParams::Account::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Account::Company
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, AdministrativeAddress, DirectorshipDeclaration, OwnershipDeclaration, PrincipalPlaceOfBusiness, RegistrationDate, RepresentativeDeclaration, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company's primary address.
-
#address_kana ⇒ Object
The Kana variation of the company's primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company's primary address (Japan only).
-
#administrative_address ⇒ Object
Attribute for param field administrative_address.
-
#directors_provided ⇒ Object
Whether the company's directors have been provided.
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
Whether the company's executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company's legal name.
-
#name_kana ⇒ Object
The Kana variation of the company's legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company's legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company's owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_declaration_shown_and_signed ⇒ Object
Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.
-
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners.
-
#phone ⇒ Object
The company's phone number (used for verification).
-
#principal_place_of_business ⇒ Object
Attribute for param field principal_place_of_business.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the
tax_idis registered (Germany-based companies only). -
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, administrative_address: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_declaration_shown_and_signed: nil, ownership_exemption_reason: nil, phone: nil, principal_place_of_business: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/stripe/params/token_create_params.rb', line 305 def initialize( address: nil, address_kana: nil, address_kanji: nil, administrative_address: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_declaration_shown_and_signed: nil, ownership_exemption_reason: nil, phone: nil, principal_place_of_business: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @administrative_address = administrative_address @directors_provided = directors_provided @directorship_declaration = directorship_declaration @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @ownership_declaration_shown_and_signed = ownership_declaration_shown_and_signed @ownership_exemption_reason = ownership_exemption_reason @phone = phone @principal_place_of_business = principal_place_of_business @registration_date = registration_date @registration_number = registration_number @representative_declaration = representative_declaration @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company's primary address.
251 252 253 |
# File 'lib/stripe/params/token_create_params.rb', line 251 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company's primary address (Japan only).
253 254 255 |
# File 'lib/stripe/params/token_create_params.rb', line 253 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company's primary address (Japan only).
255 256 257 |
# File 'lib/stripe/params/token_create_params.rb', line 255 def address_kanji @address_kanji end |
#administrative_address ⇒ Object
Attribute for param field administrative_address
257 258 259 |
# File 'lib/stripe/params/token_create_params.rb', line 257 def administrative_address @administrative_address end |
#directors_provided ⇒ Object
Whether the company's directors have been provided. Set this Boolean to true after creating all the company's directors with the Persons API for accounts with a relationship.director requirement. This value is not automatically set to true after creating directors, so it needs to be updated to indicate all directors have been provided.
259 260 261 |
# File 'lib/stripe/params/token_create_params.rb', line 259 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
261 262 263 |
# File 'lib/stripe/params/token_create_params.rb', line 261 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object
Whether the company's executives have been provided. Set this Boolean to true after creating all the company's executives with the Persons API for accounts with a relationship.executive requirement.
263 264 265 |
# File 'lib/stripe/params/token_create_params.rb', line 263 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
265 266 267 |
# File 'lib/stripe/params/token_create_params.rb', line 265 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
267 268 269 |
# File 'lib/stripe/params/token_create_params.rb', line 267 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company's legal name.
269 270 271 |
# File 'lib/stripe/params/token_create_params.rb', line 269 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company's legal name (Japan only).
271 272 273 |
# File 'lib/stripe/params/token_create_params.rb', line 271 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company's legal name (Japan only).
273 274 275 |
# File 'lib/stripe/params/token_create_params.rb', line 273 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company's owners have been provided. Set this Boolean to true after creating all the company's owners with the Persons API for accounts with a relationship.owner requirement.
275 276 277 |
# File 'lib/stripe/params/token_create_params.rb', line 275 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
277 278 279 |
# File 'lib/stripe/params/token_create_params.rb', line 277 def ownership_declaration @ownership_declaration end |
#ownership_declaration_shown_and_signed ⇒ Object
Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.
279 280 281 |
# File 'lib/stripe/params/token_create_params.rb', line 279 def ownership_declaration_shown_and_signed @ownership_declaration_shown_and_signed end |
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details.
281 282 283 |
# File 'lib/stripe/params/token_create_params.rb', line 281 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object
The company's phone number (used for verification).
283 284 285 |
# File 'lib/stripe/params/token_create_params.rb', line 283 def phone @phone end |
#principal_place_of_business ⇒ Object
Attribute for param field principal_place_of_business
285 286 287 |
# File 'lib/stripe/params/token_create_params.rb', line 285 def principal_place_of_business @principal_place_of_business end |
#registration_date ⇒ Object
When the business was incorporated or registered.
287 288 289 |
# File 'lib/stripe/params/token_create_params.rb', line 287 def registration_date @registration_date end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
289 290 291 |
# File 'lib/stripe/params/token_create_params.rb', line 289 def registration_number @registration_number end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
291 292 293 |
# File 'lib/stripe/params/token_create_params.rb', line 291 def representative_declaration @representative_declaration end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See Business structure for more details. Pass an empty string to unset this value.
293 294 295 |
# File 'lib/stripe/params/token_create_params.rb', line 293 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
Changing this value requires that the account re-accept the terms of service.
297 298 299 |
# File 'lib/stripe/params/token_create_params.rb', line 297 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the tax_id is registered (Germany-based companies only).
299 300 301 |
# File 'lib/stripe/params/token_create_params.rb', line 299 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
301 302 303 |
# File 'lib/stripe/params/token_create_params.rb', line 301 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
303 304 305 |
# File 'lib/stripe/params/token_create_params.rb', line 303 def verification @verification end |