Class: Stripe::TokenCreateParams::Account::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Account::Individual
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, BirthAddress, Dob, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual's primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual's primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual's primary address (Japan only).
-
#birth_address ⇒ Object
Attribute for param field birth_address.
-
#dob ⇒ Object
The individual's date of birth.
-
#email ⇒ Object
The individual's email address.
-
#first_name ⇒ Object
The individual's first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual's first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual's first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual's gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative's country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative's country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual's last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual's last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual's last name (Japan only).
-
#maiden_name ⇒ Object
The individual's maiden name.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#phone ⇒ Object
The individual's phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual's registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#self_reported_income ⇒ Object
The credit applicant's self-reported yearly income in minor units.
-
#self_reported_monthly_housing_payment ⇒ Object
The credit applicant's self-reported monthly housing payment in minor units.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual's Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual's verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, birth_address: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 |
# File 'lib/stripe/params/token_create_params.rb', line 679 def initialize( address: nil, address_kana: nil, address_kanji: nil, birth_address: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @birth_address = birth_address @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @self_reported_income = self_reported_income @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual's primary address.
627 628 629 |
# File 'lib/stripe/params/token_create_params.rb', line 627 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual's primary address (Japan only).
629 630 631 |
# File 'lib/stripe/params/token_create_params.rb', line 629 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual's primary address (Japan only).
631 632 633 |
# File 'lib/stripe/params/token_create_params.rb', line 631 def address_kanji @address_kanji end |
#birth_address ⇒ Object
Attribute for param field birth_address
633 634 635 |
# File 'lib/stripe/params/token_create_params.rb', line 633 def birth_address @birth_address end |
#dob ⇒ Object
The individual's date of birth.
635 636 637 |
# File 'lib/stripe/params/token_create_params.rb', line 635 def dob @dob end |
#email ⇒ Object
The individual's email address.
637 638 639 |
# File 'lib/stripe/params/token_create_params.rb', line 637 def email @email end |
#first_name ⇒ Object
The individual's first name.
639 640 641 |
# File 'lib/stripe/params/token_create_params.rb', line 639 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual's first name (Japan only).
641 642 643 |
# File 'lib/stripe/params/token_create_params.rb', line 641 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual's first name (Japan only).
643 644 645 |
# File 'lib/stripe/params/token_create_params.rb', line 643 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
645 646 647 |
# File 'lib/stripe/params/token_create_params.rb', line 645 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual's gender
647 648 649 |
# File 'lib/stripe/params/token_create_params.rb', line 647 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative's country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a PII token created with Stripe.js.
649 650 651 |
# File 'lib/stripe/params/token_create_params.rb', line 649 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative's country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a PII token created with Stripe.js.
651 652 653 |
# File 'lib/stripe/params/token_create_params.rb', line 651 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual's last name.
653 654 655 |
# File 'lib/stripe/params/token_create_params.rb', line 653 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual's last name (Japan only).
655 656 657 |
# File 'lib/stripe/params/token_create_params.rb', line 655 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual's last name (Japan only).
657 658 659 |
# File 'lib/stripe/params/token_create_params.rb', line 657 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual's maiden name.
659 660 661 |
# File 'lib/stripe/params/token_create_params.rb', line 659 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
661 662 663 |
# File 'lib/stripe/params/token_create_params.rb', line 661 def @metadata end |
#phone ⇒ Object
The individual's phone number.
663 664 665 |
# File 'lib/stripe/params/token_create_params.rb', line 663 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
665 666 667 |
# File 'lib/stripe/params/token_create_params.rb', line 665 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual's registered address.
667 668 669 |
# File 'lib/stripe/params/token_create_params.rb', line 667 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
669 670 671 |
# File 'lib/stripe/params/token_create_params.rb', line 669 def relationship @relationship end |
#self_reported_income ⇒ Object
The credit applicant's self-reported yearly income in minor units.
671 672 673 |
# File 'lib/stripe/params/token_create_params.rb', line 671 def self_reported_income @self_reported_income end |
#self_reported_monthly_housing_payment ⇒ Object
The credit applicant's self-reported monthly housing payment in minor units.
673 674 675 |
# File 'lib/stripe/params/token_create_params.rb', line 673 def self_reported_monthly_housing_payment @self_reported_monthly_housing_payment end |
#ssn_last_4 ⇒ Object
The last four digits of the individual's Social Security Number (U.S. only).
675 676 677 |
# File 'lib/stripe/params/token_create_params.rb', line 675 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual's verification document information.
677 678 679 |
# File 'lib/stripe/params/token_create_params.rb', line 677 def verification @verification end |