Class: Stripe::TokenCreateParams::Account::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Account::Individual
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual's primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual's primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual's primary address (Japan only).
-
#dob ⇒ Object
The individual's date of birth.
-
#email ⇒ Object
The individual's email address.
-
#first_name ⇒ Object
The individual's first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual's first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual's first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual's gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative's country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative's country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual's last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual's last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual's last name (Japan only).
-
#maiden_name ⇒ Object
The individual's maiden name.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#phone ⇒ Object
The individual's phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual's registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual's Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual's verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'lib/stripe/params/token_create_params.rb', line 618 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual's primary address.
572 573 574 |
# File 'lib/stripe/params/token_create_params.rb', line 572 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual's primary address (Japan only).
574 575 576 |
# File 'lib/stripe/params/token_create_params.rb', line 574 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual's primary address (Japan only).
576 577 578 |
# File 'lib/stripe/params/token_create_params.rb', line 576 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual's date of birth.
578 579 580 |
# File 'lib/stripe/params/token_create_params.rb', line 578 def dob @dob end |
#email ⇒ Object
The individual's email address.
580 581 582 |
# File 'lib/stripe/params/token_create_params.rb', line 580 def email @email end |
#first_name ⇒ Object
The individual's first name.
582 583 584 |
# File 'lib/stripe/params/token_create_params.rb', line 582 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual's first name (Japan only).
584 585 586 |
# File 'lib/stripe/params/token_create_params.rb', line 584 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual's first name (Japan only).
586 587 588 |
# File 'lib/stripe/params/token_create_params.rb', line 586 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
588 589 590 |
# File 'lib/stripe/params/token_create_params.rb', line 588 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual's gender
590 591 592 |
# File 'lib/stripe/params/token_create_params.rb', line 590 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative's country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a PII token created with Stripe.js.
592 593 594 |
# File 'lib/stripe/params/token_create_params.rb', line 592 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative's country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a PII token created with Stripe.js.
594 595 596 |
# File 'lib/stripe/params/token_create_params.rb', line 594 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual's last name.
596 597 598 |
# File 'lib/stripe/params/token_create_params.rb', line 596 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual's last name (Japan only).
598 599 600 |
# File 'lib/stripe/params/token_create_params.rb', line 598 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual's last name (Japan only).
600 601 602 |
# File 'lib/stripe/params/token_create_params.rb', line 600 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual's maiden name.
602 603 604 |
# File 'lib/stripe/params/token_create_params.rb', line 602 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
604 605 606 |
# File 'lib/stripe/params/token_create_params.rb', line 604 def @metadata end |
#phone ⇒ Object
The individual's phone number.
606 607 608 |
# File 'lib/stripe/params/token_create_params.rb', line 606 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
608 609 610 |
# File 'lib/stripe/params/token_create_params.rb', line 608 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual's registered address.
610 611 612 |
# File 'lib/stripe/params/token_create_params.rb', line 610 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
612 613 614 |
# File 'lib/stripe/params/token_create_params.rb', line 612 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual's Social Security Number (U.S. only).
614 615 616 |
# File 'lib/stripe/params/token_create_params.rb', line 614 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual's verification document information.
616 617 618 |
# File 'lib/stripe/params/token_create_params.rb', line 616 def verification @verification end |