Class: Stripe::TokenCreateParams::Account::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Account::Individual
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#self_reported_income ⇒ Object
The credit applicant’s self-reported yearly income in minor units.
-
#self_reported_monthly_housing_payment ⇒ Object
The credit applicant’s self-reported monthly housing payment in minor units.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/stripe/params/token_create_params.rb', line 574 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @self_reported_income = self_reported_income @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
524 525 526 |
# File 'lib/stripe/params/token_create_params.rb', line 524 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
526 527 528 |
# File 'lib/stripe/params/token_create_params.rb', line 526 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
528 529 530 |
# File 'lib/stripe/params/token_create_params.rb', line 528 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
530 531 532 |
# File 'lib/stripe/params/token_create_params.rb', line 530 def dob @dob end |
#email ⇒ Object
The individual’s email address.
532 533 534 |
# File 'lib/stripe/params/token_create_params.rb', line 532 def email @email end |
#first_name ⇒ Object
The individual’s first name.
534 535 536 |
# File 'lib/stripe/params/token_create_params.rb', line 534 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
536 537 538 |
# File 'lib/stripe/params/token_create_params.rb', line 536 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
538 539 540 |
# File 'lib/stripe/params/token_create_params.rb', line 538 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
540 541 542 |
# File 'lib/stripe/params/token_create_params.rb', line 540 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
542 543 544 |
# File 'lib/stripe/params/token_create_params.rb', line 542 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
544 545 546 |
# File 'lib/stripe/params/token_create_params.rb', line 544 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
546 547 548 |
# File 'lib/stripe/params/token_create_params.rb', line 546 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
548 549 550 |
# File 'lib/stripe/params/token_create_params.rb', line 548 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
550 551 552 |
# File 'lib/stripe/params/token_create_params.rb', line 550 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
552 553 554 |
# File 'lib/stripe/params/token_create_params.rb', line 552 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
554 555 556 |
# File 'lib/stripe/params/token_create_params.rb', line 554 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
556 557 558 |
# File 'lib/stripe/params/token_create_params.rb', line 556 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
558 559 560 |
# File 'lib/stripe/params/token_create_params.rb', line 558 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
560 561 562 |
# File 'lib/stripe/params/token_create_params.rb', line 560 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
562 563 564 |
# File 'lib/stripe/params/token_create_params.rb', line 562 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
564 565 566 |
# File 'lib/stripe/params/token_create_params.rb', line 564 def relationship @relationship end |
#self_reported_income ⇒ Object
The credit applicant’s self-reported yearly income in minor units.
566 567 568 |
# File 'lib/stripe/params/token_create_params.rb', line 566 def self_reported_income @self_reported_income end |
#self_reported_monthly_housing_payment ⇒ Object
The credit applicant’s self-reported monthly housing payment in minor units.
568 569 570 |
# File 'lib/stripe/params/token_create_params.rb', line 568 def self_reported_monthly_housing_payment @self_reported_monthly_housing_payment end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
570 571 572 |
# File 'lib/stripe/params/token_create_params.rb', line 570 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
572 573 574 |
# File 'lib/stripe/params/token_create_params.rb', line 572 def verification @verification end |