Class: Stripe::TokenCreateParams::BankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::BankAccount
- Defined in:
- lib/stripe/params/token_create_params.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name of the person or business that owns the bank account.
-
#account_holder_type ⇒ Object
The type of entity that holds the account.
-
#account_number ⇒ Object
The account number for the bank account, in string form.
-
#account_type ⇒ Object
The bank account type.
-
#country ⇒ Object
The country in which the bank account is located.
-
#currency ⇒ Object
The currency the bank account is in.
-
#payment_method ⇒ Object
The ID of a Payment Method with a
typeofus_bank_account. -
#routing_number ⇒ Object
The routing number, sort code, or other country-appropriate institution number for the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil) ⇒ BankAccount
constructor
A new instance of BankAccount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil) ⇒ BankAccount
Returns a new instance of BankAccount.
770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/stripe/params/token_create_params.rb', line 770 def initialize( account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil ) @account_holder_name = account_holder_name @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @country = country @currency = currency @payment_method = payment_method @routing_number = routing_number end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name of the person or business that owns the bank account. This field is required when attaching the bank account to a Customer object.
754 755 756 |
# File 'lib/stripe/params/token_create_params.rb', line 754 def account_holder_name @account_holder_name end |
#account_holder_type ⇒ Object
The type of entity that holds the account. It can be company or individual. This field is required when attaching the bank account to a Customer object.
756 757 758 |
# File 'lib/stripe/params/token_create_params.rb', line 756 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
The account number for the bank account, in string form. Must be a checking account.
758 759 760 |
# File 'lib/stripe/params/token_create_params.rb', line 758 def account_number @account_number end |
#account_type ⇒ Object
The bank account type. This can only be checking or savings in most countries. In Japan, this can only be futsu or toza.
760 761 762 |
# File 'lib/stripe/params/token_create_params.rb', line 760 def account_type @account_type end |
#country ⇒ Object
The country in which the bank account is located.
762 763 764 |
# File 'lib/stripe/params/token_create_params.rb', line 762 def country @country end |
#currency ⇒ Object
The currency the bank account is in. This must be a country/currency pairing that Stripe supports.
764 765 766 |
# File 'lib/stripe/params/token_create_params.rb', line 764 def currency @currency end |
#payment_method ⇒ Object
The ID of a Payment Method with a type of us_bank_account. The Payment Method's bank account information will be copied and returned as a Bank Account Token. This parameter is exclusive with respect to all other parameters in the bank_account hash. You must include the top-level customer parameter if the Payment Method is attached to a Customer object. If the Payment Method is not attached to a Customer object, it will be consumed and cannot be used again. You may not use Payment Methods which were created by a Setup Intent with attach_to_self=true.
766 767 768 |
# File 'lib/stripe/params/token_create_params.rb', line 766 def payment_method @payment_method end |
#routing_number ⇒ Object
The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for account_number, this field is not required.
768 769 770 |
# File 'lib/stripe/params/token_create_params.rb', line 768 def routing_number @routing_number end |