Class: Stripe::TokenCreateParams::BankAccount

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_holder_name: nil, account_holder_type: nil, account_number: nil, account_type: nil, country: nil, currency: nil, payment_method: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
# File 'lib/stripe/params/token_create_params.rb', line 663

def initialize(
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  account_type: nil,
  country: nil,
  currency: nil,
  payment_method: nil,
  routing_number: nil
)
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @account_type = 
  @country = country
  @currency = currency
  @payment_method = payment_method
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account. This field is required when attaching the bank account to a ‘Customer` object.



647
648
649
# File 'lib/stripe/params/token_create_params.rb', line 647

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



649
650
651
# File 'lib/stripe/params/token_create_params.rb', line 649

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



651
652
653
# File 'lib/stripe/params/token_create_params.rb', line 651

def 
  @account_number
end

#account_typeObject

The bank account type. This can only be ‘checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.



653
654
655
# File 'lib/stripe/params/token_create_params.rb', line 653

def 
  @account_type
end

#countryObject

The country in which the bank account is located.



655
656
657
# File 'lib/stripe/params/token_create_params.rb', line 655

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs.stripe.com/payouts)



657
658
659
# File 'lib/stripe/params/token_create_params.rb', line 657

def currency
  @currency
end

#payment_methodObject

The ID of a Payment Method with a ‘type` of `us_bank_account`. The Payment Method’s bank account information will be copied and returned as a Bank Account Token. This parameter is exclusive with respect to all other parameters in the ‘bank_account` hash. You must include the top-level `customer` parameter if the Payment Method is attached to a `Customer` object. If the Payment Method is not attached to a `Customer` object, it will be consumed and cannot be used again. You may not use Payment Methods which were created by a Setup Intent with `attach_to_self=true`.



659
660
661
# File 'lib/stripe/params/token_create_params.rb', line 659

def payment_method
  @payment_method
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



661
662
663
# File 'lib/stripe/params/token_create_params.rb', line 661

def routing_number
  @routing_number
end