Class: Stripe::TokenCreateParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Card
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Networks
Instance Attribute Summary collapse
-
#address_city ⇒ Object
City / District / Suburb / Town / Village.
-
#address_country ⇒ Object
Billing address country, if provided.
-
#address_line1 ⇒ Object
Address line 1 (Street address / PO Box / Company name).
-
#address_line2 ⇒ Object
Address line 2 (Apartment / Suite / Unit / Building).
-
#address_state ⇒ Object
State / County / Province / Region.
-
#address_zip ⇒ Object
ZIP or postal code.
-
#currency ⇒ Object
Required in order to add the card to an account; in all other cases, this parameter is not used.
-
#cvc ⇒ Object
Card security code.
-
#exp_month ⇒ Object
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
Two- or four-digit number representing the card's expiration year.
-
#name ⇒ Object
Cardholder's full name.
-
#networks ⇒ Object
Contains information about card networks used to process the payment.
-
#number ⇒ Object
The card number, as a string without any separators.
Instance Method Summary collapse
-
#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card
Returns a new instance of Card.
760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/stripe/params/token_create_params.rb', line 760 def initialize( address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil ) @address_city = address_city @address_country = address_country @address_line1 = address_line1 @address_line2 = address_line2 @address_state = address_state @address_zip = address_zip @currency = currency @cvc = cvc @exp_month = exp_month @exp_year = exp_year @name = name @networks = networks @number = number end |
Instance Attribute Details
#address_city ⇒ Object
City / District / Suburb / Town / Village.
734 735 736 |
# File 'lib/stripe/params/token_create_params.rb', line 734 def address_city @address_city end |
#address_country ⇒ Object
Billing address country, if provided.
736 737 738 |
# File 'lib/stripe/params/token_create_params.rb', line 736 def address_country @address_country end |
#address_line1 ⇒ Object
Address line 1 (Street address / PO Box / Company name).
738 739 740 |
# File 'lib/stripe/params/token_create_params.rb', line 738 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
Address line 2 (Apartment / Suite / Unit / Building).
740 741 742 |
# File 'lib/stripe/params/token_create_params.rb', line 740 def address_line2 @address_line2 end |
#address_state ⇒ Object
State / County / Province / Region.
742 743 744 |
# File 'lib/stripe/params/token_create_params.rb', line 742 def address_state @address_state end |
#address_zip ⇒ Object
ZIP or postal code.
744 745 746 |
# File 'lib/stripe/params/token_create_params.rb', line 744 def address_zip @address_zip end |
#currency ⇒ Object
Required in order to add the card to an account; in all other cases, this parameter is not used. When added to an account, the card (which must be a debit card) can be used as a transfer destination for funds in this currency.
746 747 748 |
# File 'lib/stripe/params/token_create_params.rb', line 746 def currency @currency end |
#cvc ⇒ Object
Card security code. Highly recommended to always include this value.
748 749 750 |
# File 'lib/stripe/params/token_create_params.rb', line 748 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card's expiration month.
750 751 752 |
# File 'lib/stripe/params/token_create_params.rb', line 750 def exp_month @exp_month end |
#exp_year ⇒ Object
Two- or four-digit number representing the card's expiration year.
752 753 754 |
# File 'lib/stripe/params/token_create_params.rb', line 752 def exp_year @exp_year end |
#name ⇒ Object
Cardholder's full name.
754 755 756 |
# File 'lib/stripe/params/token_create_params.rb', line 754 def name @name end |
#networks ⇒ Object
Contains information about card networks used to process the payment.
756 757 758 |
# File 'lib/stripe/params/token_create_params.rb', line 756 def networks @networks end |
#number ⇒ Object
The card number, as a string without any separators.
758 759 760 |
# File 'lib/stripe/params/token_create_params.rb', line 758 def number @number end |