Class: Stripe::TokenCreateParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Card
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: Networks
Instance Attribute Summary collapse
-
#address_city ⇒ Object
City / District / Suburb / Town / Village.
-
#address_country ⇒ Object
Billing address country, if provided.
-
#address_line1 ⇒ Object
Address line 1 (Street address / PO Box / Company name).
-
#address_line2 ⇒ Object
Address line 2 (Apartment / Suite / Unit / Building).
-
#address_state ⇒ Object
State / County / Province / Region.
-
#address_zip ⇒ Object
ZIP or postal code.
-
#currency ⇒ Object
Required in order to add the card to an account; in all other cases, this parameter is not used.
-
#cvc ⇒ Object
Card security code.
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
-
#name ⇒ Object
Cardholder’s full name.
-
#networks ⇒ Object
Contains information about card networks used to process the payment.
-
#number ⇒ Object
The card number, as a string without any separators.
Instance Method Summary collapse
-
#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card
Returns a new instance of Card.
720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 |
# File 'lib/stripe/params/token_create_params.rb', line 720 def initialize( address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil ) @address_city = address_city @address_country = address_country @address_line1 = address_line1 @address_line2 = address_line2 @address_state = address_state @address_zip = address_zip @currency = currency @cvc = cvc @exp_month = exp_month @exp_year = exp_year @name = name @networks = networks @number = number end |
Instance Attribute Details
#address_city ⇒ Object
City / District / Suburb / Town / Village.
694 695 696 |
# File 'lib/stripe/params/token_create_params.rb', line 694 def address_city @address_city end |
#address_country ⇒ Object
Billing address country, if provided.
696 697 698 |
# File 'lib/stripe/params/token_create_params.rb', line 696 def address_country @address_country end |
#address_line1 ⇒ Object
Address line 1 (Street address / PO Box / Company name).
698 699 700 |
# File 'lib/stripe/params/token_create_params.rb', line 698 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
Address line 2 (Apartment / Suite / Unit / Building).
700 701 702 |
# File 'lib/stripe/params/token_create_params.rb', line 700 def address_line2 @address_line2 end |
#address_state ⇒ Object
State / County / Province / Region.
702 703 704 |
# File 'lib/stripe/params/token_create_params.rb', line 702 def address_state @address_state end |
#address_zip ⇒ Object
ZIP or postal code.
704 705 706 |
# File 'lib/stripe/params/token_create_params.rb', line 704 def address_zip @address_zip end |
#currency ⇒ Object
Required in order to add the card to an account; in all other cases, this parameter is not used. When added to an account, the card (which must be a debit card) can be used as a transfer destination for funds in this currency.
706 707 708 |
# File 'lib/stripe/params/token_create_params.rb', line 706 def currency @currency end |
#cvc ⇒ Object
Card security code. Highly recommended to always include this value.
708 709 710 |
# File 'lib/stripe/params/token_create_params.rb', line 708 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
710 711 712 |
# File 'lib/stripe/params/token_create_params.rb', line 710 def exp_month @exp_month end |
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
712 713 714 |
# File 'lib/stripe/params/token_create_params.rb', line 712 def exp_year @exp_year end |
#name ⇒ Object
Cardholder’s full name.
714 715 716 |
# File 'lib/stripe/params/token_create_params.rb', line 714 def name @name end |
#networks ⇒ Object
Contains information about card networks used to process the payment.
716 717 718 |
# File 'lib/stripe/params/token_create_params.rb', line 716 def networks @networks end |
#number ⇒ Object
The card number, as a string without any separators.
718 719 720 |
# File 'lib/stripe/params/token_create_params.rb', line 718 def number @number end |