Class: Stripe::TokenCreateParams::Person

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, BirthAddress, Dob, Documents, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, UsCfpbData, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, birth_address: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ Person

Returns a new instance of Person.



1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/stripe/params/token_create_params.rb', line 1234

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  birth_address: nil,
  dob: nil,
  documents: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  self_reported_income: nil,
  self_reported_monthly_housing_payment: nil,
  ssn_last_4: nil,
  us_cfpb_data: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @birth_address = birth_address
  @dob = dob
  @documents = documents
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @self_reported_income = self_reported_income
  @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment
  @ssn_last_4 = ssn_last_4
  @us_cfpb_data = us_cfpb_data
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.



1174
1175
1176
# File 'lib/stripe/params/token_create_params.rb', line 1174

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person’s address.



1176
1177
1178
# File 'lib/stripe/params/token_create_params.rb', line 1176

def address
  @address
end

#address_kanaObject

The Kana variation of the person’s address (Japan only).



1178
1179
1180
# File 'lib/stripe/params/token_create_params.rb', line 1178

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person’s address (Japan only).



1180
1181
1182
# File 'lib/stripe/params/token_create_params.rb', line 1180

def address_kanji
  @address_kanji
end

#birth_addressObject

The person’s place of birth.



1182
1183
1184
# File 'lib/stripe/params/token_create_params.rb', line 1182

def birth_address
  @birth_address
end

#dobObject

The person’s date of birth.



1184
1185
1186
# File 'lib/stripe/params/token_create_params.rb', line 1184

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



1186
1187
1188
# File 'lib/stripe/params/token_create_params.rb', line 1186

def documents
  @documents
end

#emailObject

The person’s email address.



1188
1189
1190
# File 'lib/stripe/params/token_create_params.rb', line 1188

def email
  @email
end

#first_nameObject

The person’s first name.



1190
1191
1192
# File 'lib/stripe/params/token_create_params.rb', line 1190

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person’s first name (Japan only).



1192
1193
1194
# File 'lib/stripe/params/token_create_params.rb', line 1192

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person’s first name (Japan only).



1194
1195
1196
# File 'lib/stripe/params/token_create_params.rb', line 1194

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



1196
1197
1198
# File 'lib/stripe/params/token_create_params.rb', line 1196

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person’s gender (International regulations require either “male” or “female”).



1198
1199
1200
# File 'lib/stripe/params/token_create_params.rb', line 1198

def gender
  @gender
end

#id_numberObject

The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1200
1201
1202
# File 'lib/stripe/params/token_create_params.rb', line 1200

def id_number
  @id_number
end

#id_number_secondaryObject

The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1202
1203
1204
# File 'lib/stripe/params/token_create_params.rb', line 1202

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person’s last name.



1204
1205
1206
# File 'lib/stripe/params/token_create_params.rb', line 1204

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person’s last name (Japan only).



1206
1207
1208
# File 'lib/stripe/params/token_create_params.rb', line 1206

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person’s last name (Japan only).



1208
1209
1210
# File 'lib/stripe/params/token_create_params.rb', line 1208

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person’s maiden name.



1210
1211
1212
# File 'lib/stripe/params/token_create_params.rb', line 1210

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1212
1213
1214
# File 'lib/stripe/params/token_create_params.rb', line 1212

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.



1214
1215
1216
# File 'lib/stripe/params/token_create_params.rb', line 1214

def nationality
  @nationality
end

#phoneObject

The person’s phone number.



1216
1217
1218
# File 'lib/stripe/params/token_create_params.rb', line 1216

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1218
1219
1220
# File 'lib/stripe/params/token_create_params.rb', line 1218

def political_exposure
  @political_exposure
end

#registered_addressObject

The person’s registered address.



1220
1221
1222
# File 'lib/stripe/params/token_create_params.rb', line 1220

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account’s legal entity.



1222
1223
1224
# File 'lib/stripe/params/token_create_params.rb', line 1222

def relationship
  @relationship
end

#self_reported_incomeObject

The credit applicant’s self-reported yearly income in minor units.



1224
1225
1226
# File 'lib/stripe/params/token_create_params.rb', line 1224

def self_reported_income
  @self_reported_income
end

#self_reported_monthly_housing_paymentObject

The credit applicant’s self-reported monthly housing payment in minor units.



1226
1227
1228
# File 'lib/stripe/params/token_create_params.rb', line 1226

def self_reported_monthly_housing_payment
  @self_reported_monthly_housing_payment
end

#ssn_last_4Object

The last four digits of the person’s Social Security number (U.S. only).



1228
1229
1230
# File 'lib/stripe/params/token_create_params.rb', line 1228

def ssn_last_4
  @ssn_last_4
end

#us_cfpb_dataObject

Demographic data related to the person.



1230
1231
1232
# File 'lib/stripe/params/token_create_params.rb', line 1230

def us_cfpb_data
  @us_cfpb_data
end

#verificationObject

The person’s verification status.



1232
1233
1234
# File 'lib/stripe/params/token_create_params.rb', line 1232

def verification
  @verification
end