Class: Stripe::TokenCreateParams::Person

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, UsCfpbData, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ Person

Returns a new instance of Person.



1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'lib/stripe/params/token_create_params.rb', line 1166

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  documents: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  self_reported_income: nil,
  self_reported_monthly_housing_payment: nil,
  ssn_last_4: nil,
  us_cfpb_data: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @documents = documents
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @self_reported_income = self_reported_income
  @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment
  @ssn_last_4 = ssn_last_4
  @us_cfpb_data = us_cfpb_data
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.



1108
1109
1110
# File 'lib/stripe/params/token_create_params.rb', line 1108

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person’s address.



1110
1111
1112
# File 'lib/stripe/params/token_create_params.rb', line 1110

def address
  @address
end

#address_kanaObject

The Kana variation of the person’s address (Japan only).



1112
1113
1114
# File 'lib/stripe/params/token_create_params.rb', line 1112

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person’s address (Japan only).



1114
1115
1116
# File 'lib/stripe/params/token_create_params.rb', line 1114

def address_kanji
  @address_kanji
end

#dobObject

The person’s date of birth.



1116
1117
1118
# File 'lib/stripe/params/token_create_params.rb', line 1116

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



1118
1119
1120
# File 'lib/stripe/params/token_create_params.rb', line 1118

def documents
  @documents
end

#emailObject

The person’s email address.



1120
1121
1122
# File 'lib/stripe/params/token_create_params.rb', line 1120

def email
  @email
end

#first_nameObject

The person’s first name.



1122
1123
1124
# File 'lib/stripe/params/token_create_params.rb', line 1122

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person’s first name (Japan only).



1124
1125
1126
# File 'lib/stripe/params/token_create_params.rb', line 1124

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person’s first name (Japan only).



1126
1127
1128
# File 'lib/stripe/params/token_create_params.rb', line 1126

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



1128
1129
1130
# File 'lib/stripe/params/token_create_params.rb', line 1128

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person’s gender (International regulations require either “male” or “female”).



1130
1131
1132
# File 'lib/stripe/params/token_create_params.rb', line 1130

def gender
  @gender
end

#id_numberObject

The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1132
1133
1134
# File 'lib/stripe/params/token_create_params.rb', line 1132

def id_number
  @id_number
end

#id_number_secondaryObject

The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



1134
1135
1136
# File 'lib/stripe/params/token_create_params.rb', line 1134

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person’s last name.



1136
1137
1138
# File 'lib/stripe/params/token_create_params.rb', line 1136

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person’s last name (Japan only).



1138
1139
1140
# File 'lib/stripe/params/token_create_params.rb', line 1138

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person’s last name (Japan only).



1140
1141
1142
# File 'lib/stripe/params/token_create_params.rb', line 1140

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person’s maiden name.



1142
1143
1144
# File 'lib/stripe/params/token_create_params.rb', line 1142

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1144
1145
1146
# File 'lib/stripe/params/token_create_params.rb', line 1144

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.



1146
1147
1148
# File 'lib/stripe/params/token_create_params.rb', line 1146

def nationality
  @nationality
end

#phoneObject

The person’s phone number.



1148
1149
1150
# File 'lib/stripe/params/token_create_params.rb', line 1148

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1150
1151
1152
# File 'lib/stripe/params/token_create_params.rb', line 1150

def political_exposure
  @political_exposure
end

#registered_addressObject

The person’s registered address.



1152
1153
1154
# File 'lib/stripe/params/token_create_params.rb', line 1152

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account’s legal entity.



1154
1155
1156
# File 'lib/stripe/params/token_create_params.rb', line 1154

def relationship
  @relationship
end

#self_reported_incomeObject

The credit applicant’s self-reported yearly income in minor units.



1156
1157
1158
# File 'lib/stripe/params/token_create_params.rb', line 1156

def self_reported_income
  @self_reported_income
end

#self_reported_monthly_housing_paymentObject

The credit applicant’s self-reported monthly housing payment in minor units.



1158
1159
1160
# File 'lib/stripe/params/token_create_params.rb', line 1158

def self_reported_monthly_housing_payment
  @self_reported_monthly_housing_payment
end

#ssn_last_4Object

The last four digits of the person’s Social Security number (U.S. only).



1160
1161
1162
# File 'lib/stripe/params/token_create_params.rb', line 1160

def ssn_last_4
  @ssn_last_4
end

#us_cfpb_dataObject

Demographic data related to the person.



1162
1163
1164
# File 'lib/stripe/params/token_create_params.rb', line 1162

def us_cfpb_data
  @us_cfpb_data
end

#verificationObject

The person’s verification status.



1164
1165
1166
# File 'lib/stripe/params/token_create_params.rb', line 1164

def verification
  @verification
end