Class: Stripe::TokenCreateParams::Person::AdditionalTosAcceptances::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Person::AdditionalTosAcceptances::Account
- Defined in:
- lib/stripe/params/token_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
877 878 879 880 881 |
# File 'lib/stripe/params/token_create_params.rb', line 877 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
871 872 873 |
# File 'lib/stripe/params/token_create_params.rb', line 871 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
873 874 875 |
# File 'lib/stripe/params/token_create_params.rb', line 873 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
875 876 877 |
# File 'lib/stripe/params/token_create_params.rb', line 875 def user_agent @user_agent end |