Class: Stripe::TokenCreateParams::Person::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



770
771
772
773
774
# File 'lib/stripe/params/token_create_params.rb', line 770

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



764
765
766
# File 'lib/stripe/params/token_create_params.rb', line 764

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



766
767
768
# File 'lib/stripe/params/token_create_params.rb', line 766

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



768
769
770
# File 'lib/stripe/params/token_create_params.rb', line 768

def user_agent
  @user_agent
end