Class: Stripe::TokenCreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



1000
1001
1002
1003
1004
# File 'lib/stripe/params/token_create_params.rb', line 1000

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



994
995
996
# File 'lib/stripe/params/token_create_params.rb', line 994

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



996
997
998
# File 'lib/stripe/params/token_create_params.rb', line 996

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



998
999
1000
# File 'lib/stripe/params/token_create_params.rb', line 998

def visa
  @visa
end