Class: Stripe::TokenCreateParams::Person::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenCreateParams::Person::Documents
- Defined in:
- lib/stripe/params/token_create_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
934 935 936 937 938 |
# File 'lib/stripe/params/token_create_params.rb', line 934 def initialize(company_authorization: nil, passport: nil, visa: nil) @company_authorization = @passport = passport @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
928 929 930 |
# File 'lib/stripe/params/token_create_params.rb', line 928 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
930 931 932 |
# File 'lib/stripe/params/token_create_params.rb', line 930 def passport @passport end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
932 933 934 |
# File 'lib/stripe/params/token_create_params.rb', line 932 def visa @visa end |