Class: Stripe::TokenCreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
# File 'lib/stripe/params/token_create_params.rb', line 1030

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account's representative.



1014
1015
1016
# File 'lib/stripe/params/token_create_params.rb', line 1014

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1016
1017
1018
# File 'lib/stripe/params/token_create_params.rb', line 1016

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1018
1019
1020
# File 'lib/stripe/params/token_create_params.rb', line 1018

def executive
  @executive
end

Whether the person is the legal guardian of the account's representative.



1020
1021
1022
# File 'lib/stripe/params/token_create_params.rb', line 1020

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1022
1023
1024
# File 'lib/stripe/params/token_create_params.rb', line 1022

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account's legal entity.



1024
1025
1026
# File 'lib/stripe/params/token_create_params.rb', line 1024

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



1026
1027
1028
# File 'lib/stripe/params/token_create_params.rb', line 1026

def representative
  @representative
end

#titleObject

The person's title (e.g., CEO, Support Engineer).



1028
1029
1030
# File 'lib/stripe/params/token_create_params.rb', line 1028

def title
  @title
end