Class: Stripe::TokenCreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
# File 'lib/stripe/params/token_create_params.rb', line 990

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



974
975
976
# File 'lib/stripe/params/token_create_params.rb', line 974

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



976
977
978
# File 'lib/stripe/params/token_create_params.rb', line 976

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



978
979
980
# File 'lib/stripe/params/token_create_params.rb', line 978

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



980
981
982
# File 'lib/stripe/params/token_create_params.rb', line 980

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



982
983
984
# File 'lib/stripe/params/token_create_params.rb', line 982

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



984
985
986
# File 'lib/stripe/params/token_create_params.rb', line 984

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



986
987
988
# File 'lib/stripe/params/token_create_params.rb', line 986

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



988
989
990
# File 'lib/stripe/params/token_create_params.rb', line 988

def title
  @title
end