Class: Stripe::TokenCreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
# File 'lib/stripe/params/token_create_params.rb', line 939

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



923
924
925
# File 'lib/stripe/params/token_create_params.rb', line 923

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



925
926
927
# File 'lib/stripe/params/token_create_params.rb', line 925

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



927
928
929
# File 'lib/stripe/params/token_create_params.rb', line 927

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



929
930
931
# File 'lib/stripe/params/token_create_params.rb', line 929

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



931
932
933
# File 'lib/stripe/params/token_create_params.rb', line 931

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



933
934
935
# File 'lib/stripe/params/token_create_params.rb', line 933

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



935
936
937
# File 'lib/stripe/params/token_create_params.rb', line 935

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



937
938
939
# File 'lib/stripe/params/token_create_params.rb', line 937

def title
  @title
end