Class: Stripe::TokenService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
# File 'lib/stripe/services/token_service.rb', line 1186

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1170
1171
1172
# File 'lib/stripe/services/token_service.rb', line 1170

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1172
1173
1174
# File 'lib/stripe/services/token_service.rb', line 1172

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.



1174
1175
1176
# File 'lib/stripe/services/token_service.rb', line 1174

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).



1176
1177
1178
# File 'lib/stripe/services/token_service.rb', line 1176

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1178
1179
1180
# File 'lib/stripe/services/token_service.rb', line 1178

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1180
1181
1182
# File 'lib/stripe/services/token_service.rb', line 1180

def expand
  @expand
end

#personObject

Information for the person this token represents.



1182
1183
1184
# File 'lib/stripe/services/token_service.rb', line 1182

def person
  @person
end

#piiObject

The PII this token represents.



1184
1185
1186
# File 'lib/stripe/services/token_service.rb', line 1184

def pii
  @pii
end