Class: Stripe::TokenService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
# File 'lib/stripe/services/token_service.rb', line 1286

def initialize(
  account: nil,
  bank_account: nil,
  card: nil,
  customer: nil,
  cvc_update: nil,
  expand: nil,
  person: nil,
  pii: nil
)
  @account = 
  @bank_account = 
  @card = card
  @customer = customer
  @cvc_update = cvc_update
  @expand = expand
  @person = person
  @pii = pii
end

Instance Attribute Details

#accountObject

Information for the account this token represents.



1263
1264
1265
# File 'lib/stripe/services/token_service.rb', line 1263

def 
  @account
end

#bank_accountObject

The bank account this token will represent.



1266
1267
1268
# File 'lib/stripe/services/token_service.rb', line 1266

def 
  @bank_account
end

#cardObject

The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.



1269
1270
1271
# File 'lib/stripe/services/token_service.rb', line 1269

def card
  @card
end

#customerObject

Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).



1272
1273
1274
# File 'lib/stripe/services/token_service.rb', line 1272

def customer
  @customer
end

#cvc_updateObject

The updated CVC value this token represents.



1275
1276
1277
# File 'lib/stripe/services/token_service.rb', line 1275

def cvc_update
  @cvc_update
end

#expandObject

Specifies which fields in the response should be expanded.



1278
1279
1280
# File 'lib/stripe/services/token_service.rb', line 1278

def expand
  @expand
end

#personObject

Information for the person this token represents.



1281
1282
1283
# File 'lib/stripe/services/token_service.rb', line 1281

def person
  @person
end

#piiObject

The PII this token represents.



1284
1285
1286
# File 'lib/stripe/services/token_service.rb', line 1284

def pii
  @pii
end