Class: Stripe::TokenService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams
- Defined in:
- lib/stripe/services/token_service.rb
Defined Under Namespace
Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii
Instance Attribute Summary collapse
-
#account ⇒ Object
Information for the account this token represents.
-
#bank_account ⇒ Object
The bank account this token will represent.
-
#card ⇒ Object
The card this token will represent.
-
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account.
-
#cvc_update ⇒ Object
The updated CVC value this token represents.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#person ⇒ Object
Information for the person this token represents.
-
#pii ⇒ Object
The PII this token represents.
Instance Method Summary collapse
-
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 |
# File 'lib/stripe/services/token_service.rb', line 1106 def initialize( account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil ) @account = account @bank_account = bank_account @card = card @customer = customer @cvc_update = cvc_update @expand = @person = person @pii = pii end |
Instance Attribute Details
#account ⇒ Object
Information for the account this token represents.
1090 1091 1092 |
# File 'lib/stripe/services/token_service.rb', line 1090 def account @account end |
#bank_account ⇒ Object
The bank account this token will represent.
1092 1093 1094 |
# File 'lib/stripe/services/token_service.rb', line 1092 def bank_account @bank_account end |
#card ⇒ Object
The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.
1094 1095 1096 |
# File 'lib/stripe/services/token_service.rb', line 1094 def card @card end |
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).
1096 1097 1098 |
# File 'lib/stripe/services/token_service.rb', line 1096 def customer @customer end |
#cvc_update ⇒ Object
The updated CVC value this token represents.
1098 1099 1100 |
# File 'lib/stripe/services/token_service.rb', line 1098 def cvc_update @cvc_update end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1100 1101 1102 |
# File 'lib/stripe/services/token_service.rb', line 1100 def @expand end |
#person ⇒ Object
Information for the person this token represents.
1102 1103 1104 |
# File 'lib/stripe/services/token_service.rb', line 1102 def person @person end |
#pii ⇒ Object
The PII this token represents.
1104 1105 1106 |
# File 'lib/stripe/services/token_service.rb', line 1104 def pii @pii end |