Class: Stripe::TokenService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams
- Defined in:
- lib/stripe/services/token_service.rb
Defined Under Namespace
Classes: Account, BankAccount, Card, CvcUpdate, Person, Pii
Instance Attribute Summary collapse
-
#account ⇒ Object
Information for the account this token represents.
-
#bank_account ⇒ Object
The bank account this token will represent.
-
#card ⇒ Object
The card this token will represent.
-
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account.
-
#cvc_update ⇒ Object
The updated CVC value this token represents.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#person ⇒ Object
Information for the person this token represents.
-
#pii ⇒ Object
The PII this token represents.
Instance Method Summary collapse
-
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 |
# File 'lib/stripe/services/token_service.rb', line 1286 def initialize( account: nil, bank_account: nil, card: nil, customer: nil, cvc_update: nil, expand: nil, person: nil, pii: nil ) @account = account @bank_account = bank_account @card = card @customer = customer @cvc_update = cvc_update @expand = @person = person @pii = pii end |
Instance Attribute Details
#account ⇒ Object
Information for the account this token represents.
1263 1264 1265 |
# File 'lib/stripe/services/token_service.rb', line 1263 def account @account end |
#bank_account ⇒ Object
The bank account this token will represent.
1266 1267 1268 |
# File 'lib/stripe/services/token_service.rb', line 1266 def bank_account @bank_account end |
#card ⇒ Object
The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user’s credit card details, with the options described below.
1269 1270 1271 |
# File 'lib/stripe/services/token_service.rb', line 1269 def card @card end |
#customer ⇒ Object
Create a token for the customer, which is owned by the application’s account. You can only use this with an [OAuth access token](stripe.com/docs/connect/standard-accounts) or [Stripe-Account header](stripe.com/docs/connect/authentication). Learn more about [cloning saved payment methods](stripe.com/docs/connect/cloning-saved-payment-methods).
1272 1273 1274 |
# File 'lib/stripe/services/token_service.rb', line 1272 def customer @customer end |
#cvc_update ⇒ Object
The updated CVC value this token represents.
1275 1276 1277 |
# File 'lib/stripe/services/token_service.rb', line 1275 def cvc_update @cvc_update end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1278 1279 1280 |
# File 'lib/stripe/services/token_service.rb', line 1278 def @expand end |
#person ⇒ Object
Information for the person this token represents.
1281 1282 1283 |
# File 'lib/stripe/services/token_service.rb', line 1281 def person @person end |
#pii ⇒ Object
The PII this token represents.
1284 1285 1286 |
# File 'lib/stripe/services/token_service.rb', line 1284 def pii @pii end |