Class: Stripe::TokenService::CreateParams::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams::Account
- Defined in:
- lib/stripe/services/token_service.rb
Defined Under Namespace
Classes: Company, Individual
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type.
-
#company ⇒ Object
Information about the company or business.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#tos_shown_and_accepted ⇒ Object
Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement).
Instance Method Summary collapse
-
#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil) ⇒ Account
Returns a new instance of Account.
649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/stripe/services/token_service.rb', line 649 def initialize( business_type: nil, company: nil, individual: nil, tos_shown_and_accepted: nil ) @business_type = business_type @company = company @individual = individual @tos_shown_and_accepted = tos_shown_and_accepted end |
Instance Attribute Details
#business_type ⇒ Object
The business type.
638 639 640 |
# File 'lib/stripe/services/token_service.rb', line 638 def business_type @business_type end |
#company ⇒ Object
Information about the company or business.
641 642 643 |
# File 'lib/stripe/services/token_service.rb', line 641 def company @company end |
#individual ⇒ Object
Information about the person represented by the account.
644 645 646 |
# File 'lib/stripe/services/token_service.rb', line 644 def individual @individual end |
#tos_shown_and_accepted ⇒ Object
Whether the user described by the data in the token has been shown [the Stripe Connected Account Agreement](/connect/account-tokens#stripe-connected-account-agreement). When creating an account token to create a new Connect account, this value must be ‘true`.
647 648 649 |
# File 'lib/stripe/services/token_service.rb', line 647 def tos_shown_and_accepted @tos_shown_and_accepted end |