Class: Stripe::TokenService::CreateParams::Account::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_declaration_shown_and_signed: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/stripe/services/token_service.rb', line 230

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_declaration_shown_and_signed: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_declaration_shown_and_signed = ownership_declaration_shown_and_signed
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



184
185
186
# File 'lib/stripe/services/token_service.rb', line 184

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



186
187
188
# File 'lib/stripe/services/token_service.rb', line 186

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



188
189
190
# File 'lib/stripe/services/token_service.rb', line 188

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



190
191
192
# File 'lib/stripe/services/token_service.rb', line 190

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



192
193
194
# File 'lib/stripe/services/token_service.rb', line 192

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



194
195
196
# File 'lib/stripe/services/token_service.rb', line 194

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



196
197
198
# File 'lib/stripe/services/token_service.rb', line 196

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



198
199
200
# File 'lib/stripe/services/token_service.rb', line 198

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



200
201
202
# File 'lib/stripe/services/token_service.rb', line 200

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



202
203
204
# File 'lib/stripe/services/token_service.rb', line 202

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



204
205
206
# File 'lib/stripe/services/token_service.rb', line 204

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



206
207
208
# File 'lib/stripe/services/token_service.rb', line 206

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



208
209
210
# File 'lib/stripe/services/token_service.rb', line 208

def ownership_declaration
  @ownership_declaration
end

#ownership_declaration_shown_and_signedObject

Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.



210
211
212
# File 'lib/stripe/services/token_service.rb', line 210

def ownership_declaration_shown_and_signed
  @ownership_declaration_shown_and_signed
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



212
213
214
# File 'lib/stripe/services/token_service.rb', line 212

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



214
215
216
# File 'lib/stripe/services/token_service.rb', line 214

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



216
217
218
# File 'lib/stripe/services/token_service.rb', line 216

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



218
219
220
# File 'lib/stripe/services/token_service.rb', line 218

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



220
221
222
# File 'lib/stripe/services/token_service.rb', line 220

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



222
223
224
# File 'lib/stripe/services/token_service.rb', line 222

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



224
225
226
# File 'lib/stripe/services/token_service.rb', line 224

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



226
227
228
# File 'lib/stripe/services/token_service.rb', line 226

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



228
229
230
# File 'lib/stripe/services/token_service.rb', line 228

def verification
  @verification
end