Class: Stripe::TokenService::CreateParams::Account::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/stripe/services/token_service.rb', line 499

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



453
454
455
# File 'lib/stripe/services/token_service.rb', line 453

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



455
456
457
# File 'lib/stripe/services/token_service.rb', line 455

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



457
458
459
# File 'lib/stripe/services/token_service.rb', line 457

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



459
460
461
# File 'lib/stripe/services/token_service.rb', line 459

def dob
  @dob
end

#emailObject

The individual’s email address.



461
462
463
# File 'lib/stripe/services/token_service.rb', line 461

def email
  @email
end

#first_nameObject

The individual’s first name.



463
464
465
# File 'lib/stripe/services/token_service.rb', line 463

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



465
466
467
# File 'lib/stripe/services/token_service.rb', line 465

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



467
468
469
# File 'lib/stripe/services/token_service.rb', line 467

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



469
470
471
# File 'lib/stripe/services/token_service.rb', line 469

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



471
472
473
# File 'lib/stripe/services/token_service.rb', line 471

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



473
474
475
# File 'lib/stripe/services/token_service.rb', line 473

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



475
476
477
# File 'lib/stripe/services/token_service.rb', line 475

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



477
478
479
# File 'lib/stripe/services/token_service.rb', line 477

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



479
480
481
# File 'lib/stripe/services/token_service.rb', line 479

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



481
482
483
# File 'lib/stripe/services/token_service.rb', line 481

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



483
484
485
# File 'lib/stripe/services/token_service.rb', line 483

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



485
486
487
# File 'lib/stripe/services/token_service.rb', line 485

def 
  @metadata
end

#phoneObject

The individual’s phone number.



487
488
489
# File 'lib/stripe/services/token_service.rb', line 487

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



489
490
491
# File 'lib/stripe/services/token_service.rb', line 489

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



491
492
493
# File 'lib/stripe/services/token_service.rb', line 491

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



493
494
495
# File 'lib/stripe/services/token_service.rb', line 493

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



495
496
497
# File 'lib/stripe/services/token_service.rb', line 495

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



497
498
499
# File 'lib/stripe/services/token_service.rb', line 497

def verification
  @verification
end