Class: Stripe::TokenService::CreateParams::Account::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/stripe/services/token_service.rb', line 466

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



452
453
454
# File 'lib/stripe/services/token_service.rb', line 452

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



455
456
457
# File 'lib/stripe/services/token_service.rb', line 455

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



458
459
460
# File 'lib/stripe/services/token_service.rb', line 458

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



461
462
463
# File 'lib/stripe/services/token_service.rb', line 461

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



464
465
466
# File 'lib/stripe/services/token_service.rb', line 464

def title
  @title
end