Class: Stripe::TokenService::CreateParams::Account::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/stripe/services/token_service.rb', line 403

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



393
394
395
# File 'lib/stripe/services/token_service.rb', line 393

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



395
396
397
# File 'lib/stripe/services/token_service.rb', line 395

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



397
398
399
# File 'lib/stripe/services/token_service.rb', line 397

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



399
400
401
# File 'lib/stripe/services/token_service.rb', line 399

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



401
402
403
# File 'lib/stripe/services/token_service.rb', line 401

def title
  @title
end