Class: Stripe::TokenService::CreateParams::Card

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card

Returns a new instance of Card.



756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
# File 'lib/stripe/services/token_service.rb', line 756

def initialize(
  address_city: nil,
  address_country: nil,
  address_line1: nil,
  address_line2: nil,
  address_state: nil,
  address_zip: nil,
  currency: nil,
  cvc: nil,
  exp_month: nil,
  exp_year: nil,
  name: nil,
  networks: nil,
  number: nil
)
  @address_city = address_city
  @address_country = address_country
  @address_line1 = address_line1
  @address_line2 = address_line2
  @address_state = address_state
  @address_zip = address_zip
  @currency = currency
  @cvc = cvc
  @exp_month = exp_month
  @exp_year = exp_year
  @name = name
  @networks = networks
  @number = number
end

Instance Attribute Details

#address_cityObject

City / District / Suburb / Town / Village.



718
719
720
# File 'lib/stripe/services/token_service.rb', line 718

def address_city
  @address_city
end

#address_countryObject

Billing address country, if provided.



721
722
723
# File 'lib/stripe/services/token_service.rb', line 721

def address_country
  @address_country
end

#address_line1Object

Address line 1 (Street address / PO Box / Company name).



724
725
726
# File 'lib/stripe/services/token_service.rb', line 724

def address_line1
  @address_line1
end

#address_line2Object

Address line 2 (Apartment / Suite / Unit / Building).



727
728
729
# File 'lib/stripe/services/token_service.rb', line 727

def address_line2
  @address_line2
end

#address_stateObject

State / County / Province / Region.



730
731
732
# File 'lib/stripe/services/token_service.rb', line 730

def address_state
  @address_state
end

#address_zipObject

ZIP or postal code.



733
734
735
# File 'lib/stripe/services/token_service.rb', line 733

def address_zip
  @address_zip
end

#currencyObject

Required in order to add the card to an account; in all other cases, this parameter is not used. When added to an account, the card (which must be a debit card) can be used as a transfer destination for funds in this currency.



736
737
738
# File 'lib/stripe/services/token_service.rb', line 736

def currency
  @currency
end

#cvcObject

Card security code. Highly recommended to always include this value.



739
740
741
# File 'lib/stripe/services/token_service.rb', line 739

def cvc
  @cvc
end

#exp_monthObject

Two-digit number representing the card’s expiration month.



742
743
744
# File 'lib/stripe/services/token_service.rb', line 742

def exp_month
  @exp_month
end

#exp_yearObject

Two- or four-digit number representing the card’s expiration year.



745
746
747
# File 'lib/stripe/services/token_service.rb', line 745

def exp_year
  @exp_year
end

#nameObject

Cardholder’s full name.



748
749
750
# File 'lib/stripe/services/token_service.rb', line 748

def name
  @name
end

#networksObject

Contains information about card networks used to process the payment.



751
752
753
# File 'lib/stripe/services/token_service.rb', line 751

def networks
  @networks
end

#numberObject

The card number, as a string without any separators.



754
755
756
# File 'lib/stripe/services/token_service.rb', line 754

def number
  @number
end