Class: Stripe::TokenService::CreateParams::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams::Card
- Defined in:
- lib/stripe/services/token_service.rb
Defined Under Namespace
Classes: Networks
Instance Attribute Summary collapse
-
#address_city ⇒ Object
City / District / Suburb / Town / Village.
-
#address_country ⇒ Object
Billing address country, if provided.
-
#address_line1 ⇒ Object
Address line 1 (Street address / PO Box / Company name).
-
#address_line2 ⇒ Object
Address line 2 (Apartment / Suite / Unit / Building).
-
#address_state ⇒ Object
State / County / Province / Region.
-
#address_zip ⇒ Object
ZIP or postal code.
-
#currency ⇒ Object
Required in order to add the card to an account; in all other cases, this parameter is not used.
-
#cvc ⇒ Object
Card security code.
-
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
-
#name ⇒ Object
Cardholder’s full name.
-
#networks ⇒ Object
Contains information about card networks used to process the payment.
-
#number ⇒ Object
The card number, as a string without any separators.
Instance Method Summary collapse
-
#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil) ⇒ Card
Returns a new instance of Card.
646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 |
# File 'lib/stripe/services/token_service.rb', line 646 def initialize( address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, currency: nil, cvc: nil, exp_month: nil, exp_year: nil, name: nil, networks: nil, number: nil ) @address_city = address_city @address_country = address_country @address_line1 = address_line1 @address_line2 = address_line2 @address_state = address_state @address_zip = address_zip @currency = currency @cvc = cvc @exp_month = exp_month @exp_year = exp_year @name = name @networks = networks @number = number end |
Instance Attribute Details
#address_city ⇒ Object
City / District / Suburb / Town / Village.
620 621 622 |
# File 'lib/stripe/services/token_service.rb', line 620 def address_city @address_city end |
#address_country ⇒ Object
Billing address country, if provided.
622 623 624 |
# File 'lib/stripe/services/token_service.rb', line 622 def address_country @address_country end |
#address_line1 ⇒ Object
Address line 1 (Street address / PO Box / Company name).
624 625 626 |
# File 'lib/stripe/services/token_service.rb', line 624 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
Address line 2 (Apartment / Suite / Unit / Building).
626 627 628 |
# File 'lib/stripe/services/token_service.rb', line 626 def address_line2 @address_line2 end |
#address_state ⇒ Object
State / County / Province / Region.
628 629 630 |
# File 'lib/stripe/services/token_service.rb', line 628 def address_state @address_state end |
#address_zip ⇒ Object
ZIP or postal code.
630 631 632 |
# File 'lib/stripe/services/token_service.rb', line 630 def address_zip @address_zip end |
#currency ⇒ Object
Required in order to add the card to an account; in all other cases, this parameter is not used. When added to an account, the card (which must be a debit card) can be used as a transfer destination for funds in this currency.
632 633 634 |
# File 'lib/stripe/services/token_service.rb', line 632 def currency @currency end |
#cvc ⇒ Object
Card security code. Highly recommended to always include this value.
634 635 636 |
# File 'lib/stripe/services/token_service.rb', line 634 def cvc @cvc end |
#exp_month ⇒ Object
Two-digit number representing the card’s expiration month.
636 637 638 |
# File 'lib/stripe/services/token_service.rb', line 636 def exp_month @exp_month end |
#exp_year ⇒ Object
Two- or four-digit number representing the card’s expiration year.
638 639 640 |
# File 'lib/stripe/services/token_service.rb', line 638 def exp_year @exp_year end |
#name ⇒ Object
Cardholder’s full name.
640 641 642 |
# File 'lib/stripe/services/token_service.rb', line 640 def name @name end |
#networks ⇒ Object
Contains information about card networks used to process the payment.
642 643 644 |
# File 'lib/stripe/services/token_service.rb', line 642 def networks @networks end |
#number ⇒ Object
The card number, as a string without any separators.
644 645 646 |
# File 'lib/stripe/services/token_service.rb', line 644 def number @number end |