Class: Stripe::TokenService::CreateParams::Person::AdditionalTosAcceptances::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::TokenService::CreateParams::Person::AdditionalTosAcceptances::Account
- Defined in:
- lib/stripe/services/token_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
715 716 717 718 719 |
# File 'lib/stripe/services/token_service.rb', line 715 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
709 710 711 |
# File 'lib/stripe/services/token_service.rb', line 709 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
711 712 713 |
# File 'lib/stripe/services/token_service.rb', line 711 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
713 714 715 |
# File 'lib/stripe/services/token_service.rb', line 713 def user_agent @user_agent end |