Class: Stripe::TokenService::CreateParams::Person::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



808
809
810
811
812
# File 'lib/stripe/services/token_service.rb', line 808

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



800
801
802
# File 'lib/stripe/services/token_service.rb', line 800

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



803
804
805
# File 'lib/stripe/services/token_service.rb', line 803

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



806
807
808
# File 'lib/stripe/services/token_service.rb', line 806

def user_agent
  @user_agent
end