Class: Stripe::TokenService::CreateParams::Person::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



993
994
995
996
997
# File 'lib/stripe/services/token_service.rb', line 993

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



985
986
987
# File 'lib/stripe/services/token_service.rb', line 985

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



988
989
990
# File 'lib/stripe/services/token_service.rb', line 988

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



991
992
993
# File 'lib/stripe/services/token_service.rb', line 991

def visa
  @visa
end