Class: Stripe::TokenService::CreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
# File 'lib/stripe/services/token_service.rb', line 954

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



938
939
940
# File 'lib/stripe/services/token_service.rb', line 938

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



940
941
942
# File 'lib/stripe/services/token_service.rb', line 940

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



942
943
944
# File 'lib/stripe/services/token_service.rb', line 942

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



944
945
946
# File 'lib/stripe/services/token_service.rb', line 944

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



946
947
948
# File 'lib/stripe/services/token_service.rb', line 946

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



948
949
950
# File 'lib/stripe/services/token_service.rb', line 948

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



950
951
952
# File 'lib/stripe/services/token_service.rb', line 950

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



952
953
954
# File 'lib/stripe/services/token_service.rb', line 952

def title
  @title
end