Class: Stripe::TokenService::CreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
# File 'lib/stripe/services/token_service.rb', line 1061

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



1038
1039
1040
# File 'lib/stripe/services/token_service.rb', line 1038

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1041
1042
1043
# File 'lib/stripe/services/token_service.rb', line 1041

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1044
1045
1046
# File 'lib/stripe/services/token_service.rb', line 1044

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



1047
1048
1049
# File 'lib/stripe/services/token_service.rb', line 1047

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1050
1051
1052
# File 'lib/stripe/services/token_service.rb', line 1050

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1053
1054
1055
# File 'lib/stripe/services/token_service.rb', line 1053

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



1056
1057
1058
# File 'lib/stripe/services/token_service.rb', line 1056

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1059
1060
1061
# File 'lib/stripe/services/token_service.rb', line 1059

def title
  @title
end