Class: Stripe::TokenService::CreateParams::Person::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/token_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
# File 'lib/stripe/services/token_service.rb', line 916

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



900
901
902
# File 'lib/stripe/services/token_service.rb', line 900

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



902
903
904
# File 'lib/stripe/services/token_service.rb', line 902

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



904
905
906
# File 'lib/stripe/services/token_service.rb', line 904

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



906
907
908
# File 'lib/stripe/services/token_service.rb', line 906

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



908
909
910
# File 'lib/stripe/services/token_service.rb', line 908

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



910
911
912
# File 'lib/stripe/services/token_service.rb', line 910

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



912
913
914
# File 'lib/stripe/services/token_service.rb', line 912

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



914
915
916
# File 'lib/stripe/services/token_service.rb', line 914

def title
  @title
end