Class: Stripe::Topup::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Topup::CreateParams
- Defined in:
- lib/stripe/resources/topup.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer representing how much to transfer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#source ⇒ Object
The ID of a source to transfer funds from.
-
#statement_descriptor ⇒ Object
Extra information about a top-up for the source’s bank statement.
-
#transfer_group ⇒ Object
A string that identifies this top-up as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, expand: nil, metadata: nil, source: nil, statement_descriptor: nil, transfer_group: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, expand: nil, metadata: nil, source: nil, statement_descriptor: nil, transfer_group: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/stripe/resources/topup.rb', line 127 def initialize( amount: nil, currency: nil, description: nil, expand: nil, metadata: nil, source: nil, statement_descriptor: nil, transfer_group: nil ) @amount = amount @currency = currency @description = description @expand = @metadata = @source = source @statement_descriptor = statement_descriptor @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
A positive integer representing how much to transfer.
104 105 106 |
# File 'lib/stripe/resources/topup.rb', line 104 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
107 108 109 |
# File 'lib/stripe/resources/topup.rb', line 107 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
110 111 112 |
# File 'lib/stripe/resources/topup.rb', line 110 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
113 114 115 |
# File 'lib/stripe/resources/topup.rb', line 113 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
116 117 118 |
# File 'lib/stripe/resources/topup.rb', line 116 def @metadata end |
#source ⇒ Object
The ID of a source to transfer funds from. For most users, this should be left unspecified which will use the bank account that was set up in the dashboard for the specified currency. In test mode, this can be a test bank token (see [Testing Top-ups](stripe.com/docs/connect/testing#testing-top-ups)).
119 120 121 |
# File 'lib/stripe/resources/topup.rb', line 119 def source @source end |
#statement_descriptor ⇒ Object
Extra information about a top-up for the source’s bank statement. Limited to 15 ASCII characters.
122 123 124 |
# File 'lib/stripe/resources/topup.rb', line 122 def statement_descriptor @statement_descriptor end |
#transfer_group ⇒ Object
A string that identifies this top-up as part of a group.
125 126 127 |
# File 'lib/stripe/resources/topup.rb', line 125 def transfer_group @transfer_group end |