Class: Stripe::Transfer::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/transfer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



159
160
161
162
163
# File 'lib/stripe/resources/transfer.rb', line 159

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



151
152
153
# File 'lib/stripe/resources/transfer.rb', line 151

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



154
155
156
# File 'lib/stripe/resources/transfer.rb', line 154

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



157
158
159
# File 'lib/stripe/resources/transfer.rb', line 157

def 
  @metadata
end