Class: Stripe::Treasury::CreditReversal::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::CreditReversal::CreateParams
- Defined in:
- lib/stripe/resources/treasury/credit_reversal.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#received_credit ⇒ Object
The ReceivedCredit to reverse.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil, received_credit: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil, received_credit: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
72 73 74 75 76 |
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 72 def initialize(expand: nil, metadata: nil, received_credit: nil) @expand = @metadata = @received_credit = received_credit end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
64 65 66 |
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 64 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
67 68 69 |
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 67 def @metadata end |
#received_credit ⇒ Object
The ReceivedCredit to reverse.
70 71 72 |
# File 'lib/stripe/resources/treasury/credit_reversal.rb', line 70 def received_credit @received_credit end |