Class: Stripe::Treasury::FinancialAccount

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Overview

Stripe Treasury provides users with a container for money called a FinancialAccount that is separate from their Payments balance. FinancialAccounts serve as the source and destination of Treasury’s money movement APIs.

Defined Under Namespace

Classes: Balance, CloseParams, CreateParams, FinancialAddress, ListParams, PlatformRestrictions, RetrieveFeaturesParams, StatusDetails, UpdateFeaturesParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"treasury.financial_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#active_featuresObject (readonly)

The array of paths to active Features in the Features hash.



726
727
728
# File 'lib/stripe/resources/treasury/financial_account.rb', line 726

def active_features
  @active_features
end

#balanceObject (readonly)

Balance information for the FinancialAccount



728
729
730
# File 'lib/stripe/resources/treasury/financial_account.rb', line 728

def balance
  @balance
end

#countryObject (readonly)

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



730
731
732
# File 'lib/stripe/resources/treasury/financial_account.rb', line 730

def country
  @country
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



732
733
734
# File 'lib/stripe/resources/treasury/financial_account.rb', line 732

def created
  @created
end

#display_nameObject (readonly)

The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.



734
735
736
# File 'lib/stripe/resources/treasury/financial_account.rb', line 734

def display_name
  @display_name
end

#featuresObject (readonly)

Encodes whether a FinancialAccount has access to a particular Feature, with a ‘status` enum and associated `status_details`. Stripe or the platform can control Features via the requested field.



737
738
739
# File 'lib/stripe/resources/treasury/financial_account.rb', line 737

def features
  @features
end

#financial_addressesObject (readonly)

The set of credentials that resolve to a FinancialAccount.



739
740
741
# File 'lib/stripe/resources/treasury/financial_account.rb', line 739

def financial_addresses
  @financial_addresses
end

#idObject (readonly)

Unique identifier for the object.



741
742
743
# File 'lib/stripe/resources/treasury/financial_account.rb', line 741

def id
  @id
end

#is_defaultObject (readonly)

Attribute for field is_default



743
744
745
# File 'lib/stripe/resources/treasury/financial_account.rb', line 743

def is_default
  @is_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



745
746
747
# File 'lib/stripe/resources/treasury/financial_account.rb', line 745

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



747
748
749
# File 'lib/stripe/resources/treasury/financial_account.rb', line 747

def 
  @metadata
end

#nicknameObject (readonly)

The nickname for the FinancialAccount.



749
750
751
# File 'lib/stripe/resources/treasury/financial_account.rb', line 749

def nickname
  @nickname
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



751
752
753
# File 'lib/stripe/resources/treasury/financial_account.rb', line 751

def object
  @object
end

#pending_featuresObject (readonly)

The array of paths to pending Features in the Features hash.



753
754
755
# File 'lib/stripe/resources/treasury/financial_account.rb', line 753

def pending_features
  @pending_features
end

#platform_restrictionsObject (readonly)

The set of functionalities that the platform can restrict on the FinancialAccount.



755
756
757
# File 'lib/stripe/resources/treasury/financial_account.rb', line 755

def platform_restrictions
  @platform_restrictions
end

#restricted_featuresObject (readonly)

The array of paths to restricted Features in the Features hash.



757
758
759
# File 'lib/stripe/resources/treasury/financial_account.rb', line 757

def restricted_features
  @restricted_features
end

#statusObject (readonly)

Status of this FinancialAccount.



759
760
761
# File 'lib/stripe/resources/treasury/financial_account.rb', line 759

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



761
762
763
# File 'lib/stripe/resources/treasury/financial_account.rb', line 761

def status_details
  @status_details
end

#supported_currenciesObject (readonly)

The currencies the FinancialAccount can hold a balance in. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



763
764
765
# File 'lib/stripe/resources/treasury/financial_account.rb', line 763

def supported_currencies
  @supported_currencies
end

Class Method Details

.close(financial_account, params = {}, opts = {}) ⇒ Object

Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.



776
777
778
779
780
781
782
783
# File 'lib/stripe/resources/treasury/financial_account.rb', line 776

def self.close(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s/close", { financial_account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a new FinancialAccount. Each connected account can have up to three FinancialAccounts by default.



786
787
788
789
790
791
792
793
# File 'lib/stripe/resources/treasury/financial_account.rb', line 786

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/treasury/financial_accounts",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of FinancialAccounts.



796
797
798
799
800
801
802
803
# File 'lib/stripe/resources/treasury/financial_account.rb', line 796

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/treasury/financial_accounts",
    params: params,
    opts: opts
  )
end

.object_nameObject



14
15
16
# File 'lib/stripe/resources/treasury/financial_account.rb', line 14

def self.object_name
  "treasury.financial_account"
end

.retrieve_features(financial_account, params = {}, opts = {}) ⇒ Object

Retrieves Features information associated with the FinancialAccount.



816
817
818
819
820
821
822
823
# File 'lib/stripe/resources/treasury/financial_account.rb', line 816

def self.retrieve_features(, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.update(financial_account, params = {}, opts = {}) ⇒ Object

Updates the details of a FinancialAccount.



826
827
828
829
830
831
832
833
# File 'lib/stripe/resources/treasury/financial_account.rb', line 826

def self.update(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s", { financial_account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.update_features(financial_account, params = {}, opts = {}) ⇒ Object

Updates the Features associated with a FinancialAccount.



846
847
848
849
850
851
852
853
# File 'lib/stripe/resources/treasury/financial_account.rb', line 846

def self.update_features(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#close(params = {}, opts = {}) ⇒ Object

Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.



766
767
768
769
770
771
772
773
# File 'lib/stripe/resources/treasury/financial_account.rb', line 766

def close(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s/close", { financial_account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#retrieve_features(params = {}, opts = {}) ⇒ Object

Retrieves Features information associated with the FinancialAccount.



806
807
808
809
810
811
812
813
# File 'lib/stripe/resources/treasury/financial_account.rb', line 806

def retrieve_features(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#update_features(params = {}, opts = {}) ⇒ Object

Updates the Features associated with a FinancialAccount.



836
837
838
839
840
841
842
843
# File 'lib/stripe/resources/treasury/financial_account.rb', line 836

def update_features(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end