Class: Stripe::Treasury::FinancialAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::FinancialAccount
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Overview
Stripe Treasury provides users with a container for money called a FinancialAccount that is separate from their Payments balance. FinancialAccounts serve as the source and destination of Treasury’s money movement APIs.
Defined Under Namespace
Classes: Balance, CloseParams, CreateParams, FinancialAddress, ListParams, PlatformRestrictions, RetrieveFeaturesParams, RetrieveParams, StatusDetails, UpdateFeaturesParams, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"treasury.financial_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active_features ⇒ Object
readonly
The array of paths to active Features in the Features hash.
-
#balance ⇒ Object
readonly
Balance information for the FinancialAccount.
-
#country ⇒ Object
readonly
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
The display name for the FinancialAccount.
-
#features ⇒ Object
readonly
Encodes whether a FinancialAccount has access to a particular Feature, with a ‘status` enum and associated `status_details`.
-
#financial_addresses ⇒ Object
readonly
The set of credentials that resolve to a FinancialAccount.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#is_default ⇒ Object
readonly
Attribute for field is_default.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
readonly
The nickname for the FinancialAccount.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pending_features ⇒ Object
readonly
The array of paths to pending Features in the Features hash.
-
#platform_restrictions ⇒ Object
readonly
The set of functionalities that the platform can restrict on the FinancialAccount.
-
#restricted_features ⇒ Object
readonly
The array of paths to restricted Features in the Features hash.
-
#status ⇒ Object
readonly
Status of this FinancialAccount.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
-
#supported_currencies ⇒ Object
readonly
The currencies the FinancialAccount can hold a balance in.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.close(financial_account, params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new FinancialAccount.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of FinancialAccounts.
- .object_name ⇒ Object
-
.retrieve_features(financial_account, params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
-
.update(financial_account, params = {}, opts = {}) ⇒ Object
Updates the details of a FinancialAccount.
-
.update_features(financial_account, params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
Instance Method Summary collapse
-
#close(params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount.
-
#retrieve_features(params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
-
#update_features(params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active_features ⇒ Object (readonly)
The array of paths to active Features in the Features hash.
731 732 733 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 731 def active_features @active_features end |
#balance ⇒ Object (readonly)
Balance information for the FinancialAccount
733 734 735 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 733 def balance @balance end |
#country ⇒ Object (readonly)
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
735 736 737 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 735 def country @country end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
737 738 739 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 737 def created @created end |
#display_name ⇒ Object (readonly)
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
739 740 741 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 739 def display_name @display_name end |
#features ⇒ Object (readonly)
Encodes whether a FinancialAccount has access to a particular Feature, with a ‘status` enum and associated `status_details`. Stripe or the platform can control Features via the requested field.
742 743 744 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 742 def features @features end |
#financial_addresses ⇒ Object (readonly)
The set of credentials that resolve to a FinancialAccount.
744 745 746 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 744 def financial_addresses @financial_addresses end |
#id ⇒ Object (readonly)
Unique identifier for the object.
746 747 748 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 746 def id @id end |
#is_default ⇒ Object (readonly)
Attribute for field is_default
748 749 750 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 748 def is_default @is_default end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
750 751 752 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 750 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
752 753 754 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 752 def @metadata end |
#nickname ⇒ Object (readonly)
The nickname for the FinancialAccount.
754 755 756 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 754 def nickname @nickname end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
756 757 758 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 756 def object @object end |
#pending_features ⇒ Object (readonly)
The array of paths to pending Features in the Features hash.
758 759 760 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 758 def pending_features @pending_features end |
#platform_restrictions ⇒ Object (readonly)
The set of functionalities that the platform can restrict on the FinancialAccount.
760 761 762 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 760 def platform_restrictions @platform_restrictions end |
#restricted_features ⇒ Object (readonly)
The array of paths to restricted Features in the Features hash.
762 763 764 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 762 def restricted_features @restricted_features end |
#status ⇒ Object (readonly)
Status of this FinancialAccount.
764 765 766 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 764 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
766 767 768 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 766 def status_details @status_details end |
#supported_currencies ⇒ Object (readonly)
The currencies the FinancialAccount can hold a balance in. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
768 769 770 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 768 def supported_currencies @supported_currencies end |
Class Method Details
.close(financial_account, params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
781 782 783 784 785 786 787 788 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 781 def self.close(financial_account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/close", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a new FinancialAccount. For now, each connected account can only have one FinancialAccount.
791 792 793 794 795 796 797 798 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 791 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/treasury/financial_accounts", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of FinancialAccounts.
801 802 803 804 805 806 807 808 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 801 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/financial_accounts", params: params, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 14 def self.object_name "treasury.financial_account" end |
.retrieve_features(financial_account, params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
821 822 823 824 825 826 827 828 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 821 def self.retrieve_features(financial_account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
.update(financial_account, params = {}, opts = {}) ⇒ Object
Updates the details of a FinancialAccount.
831 832 833 834 835 836 837 838 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 831 def self.update(financial_account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
.update_features(financial_account, params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
851 852 853 854 855 856 857 858 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 851 def self.update_features(financial_account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(financial_account) }), params: params, opts: opts ) end |
Instance Method Details
#close(params = {}, opts = {}) ⇒ Object
Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
771 772 773 774 775 776 777 778 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 771 def close(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/close", { financial_account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#retrieve_features(params = {}, opts = {}) ⇒ Object
Retrieves Features information associated with the FinancialAccount.
811 812 813 814 815 816 817 818 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 811 def retrieve_features(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#update_features(params = {}, opts = {}) ⇒ Object
Updates the Features associated with a FinancialAccount.
841 842 843 844 845 846 847 848 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 841 def update_features(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/financial_accounts/%<financial_account>s/features", { financial_account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |