Class: Stripe::Treasury::FinancialAccount::CloseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::CloseParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: ForwardingSettings
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0.
Instance Method Summary collapse
-
#initialize(expand: nil, forwarding_settings: nil) ⇒ CloseParams
constructor
A new instance of CloseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, forwarding_settings: nil) ⇒ CloseParams
Returns a new instance of CloseParams.
703 704 705 706 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 703 def initialize(expand: nil, forwarding_settings: nil) @expand = @forwarding_settings = forwarding_settings end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
699 700 701 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 699 def @expand end |
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0
701 702 703 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 701 def forwarding_settings @forwarding_settings end |