Class: Stripe::Treasury::FinancialAccount::CloseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Defined Under Namespace

Classes: ForwardingSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, forwarding_settings: nil) ⇒ CloseParams

Returns a new instance of CloseParams.



725
726
727
728
# File 'lib/stripe/resources/treasury/financial_account.rb', line 725

def initialize(expand: nil, forwarding_settings: nil)
  @expand = expand
  @forwarding_settings = forwarding_settings
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



721
722
723
# File 'lib/stripe/resources/treasury/financial_account.rb', line 721

def expand
  @expand
end

#forwarding_settingsObject

A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0



723
724
725
# File 'lib/stripe/resources/treasury/financial_account.rb', line 723

def forwarding_settings
  @forwarding_settings
end