Class: Stripe::Treasury::FinancialAccount::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::CreateParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Features, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
The nickname for the FinancialAccount.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
-
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 343 def initialize( display_name: nil, expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil ) @display_name = display_name @expand = @features = features @metadata = @nickname = nickname @platform_restrictions = platform_restrictions @supported_currencies = supported_currencies end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
329 330 331 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 329 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
331 332 333 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 331 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.
333 334 335 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 333 def features @features end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
335 336 337 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 335 def @metadata end |
#nickname ⇒ Object
The nickname for the FinancialAccount.
337 338 339 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 337 def nickname @nickname end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
339 340 341 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 339 def platform_restrictions @platform_restrictions end |
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
341 342 343 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 341 def supported_currencies @supported_currencies end |