Class: Stripe::Treasury::FinancialAccount::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::CreateParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Features, PlatformRestrictions
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
The nickname for the FinancialAccount.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
-
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 290 def initialize( expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil ) @expand = @features = features @metadata = @nickname = nickname @platform_restrictions = platform_restrictions @supported_currencies = supported_currencies end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
278 279 280 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 278 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.
280 281 282 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 280 def features @features end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
282 283 284 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 282 def @metadata end |
#nickname ⇒ Object
The nickname for the FinancialAccount.
284 285 286 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 284 def nickname @nickname end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
286 287 288 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 286 def platform_restrictions @platform_restrictions end |
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
288 289 290 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 288 def supported_currencies @supported_currencies end |