Class: Stripe::Treasury::FinancialAccount::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Defined Under Namespace

Classes: Features, PlatformRestrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/stripe/resources/treasury/financial_account.rb', line 286

def initialize(
  expand: nil,
  features: nil,
  metadata: nil,
  nickname: nil,
  platform_restrictions: nil,
  supported_currencies: nil
)
  @expand = expand
  @features = features
  @metadata = 
  @nickname = nickname
  @platform_restrictions = platform_restrictions
  @supported_currencies = supported_currencies
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



274
275
276
# File 'lib/stripe/resources/treasury/financial_account.rb', line 274

def expand
  @expand
end

#featuresObject

Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.



276
277
278
# File 'lib/stripe/resources/treasury/financial_account.rb', line 276

def features
  @features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



278
279
280
# File 'lib/stripe/resources/treasury/financial_account.rb', line 278

def 
  @metadata
end

#nicknameObject

The nickname for the FinancialAccount.



280
281
282
# File 'lib/stripe/resources/treasury/financial_account.rb', line 280

def nickname
  @nickname
end

#platform_restrictionsObject

The set of functionalities that the platform can restrict on the FinancialAccount.



282
283
284
# File 'lib/stripe/resources/treasury/financial_account.rb', line 282

def platform_restrictions
  @platform_restrictions
end

#supported_currenciesObject

The currencies the FinancialAccount can hold a balance in.



284
285
286
# File 'lib/stripe/resources/treasury/financial_account.rb', line 284

def supported_currencies
  @supported_currencies
end