Class: Stripe::Treasury::FinancialAccount::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::CreateParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Features, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
-
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 320 def initialize( display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil, supported_currencies: nil ) @display_name = display_name @expand = @features = features @metadata = @platform_restrictions = platform_restrictions @supported_currencies = supported_currencies end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
303 304 305 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 303 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
306 307 308 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 306 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.
309 310 311 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 309 def features @features end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
312 313 314 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 312 def @metadata end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
315 316 317 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 315 def platform_restrictions @platform_restrictions end |
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
318 319 320 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 318 def supported_currencies @supported_currencies end |