Class: Stripe::Treasury::FinancialAccount::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::ListParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
-
#ending_before ⇒ Object
An object ID cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
-
#starting_after ⇒ Object
An object ID cursor for use in pagination.
-
#status ⇒ Object
Only return FinancialAccounts that have the given status: ‘open` or `closed`.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 143 def initialize( created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil ) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status end |
Instance Attribute Details
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
131 132 133 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 131 def created @created end |
#ending_before ⇒ Object
An object ID cursor for use in pagination.
133 134 135 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 133 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
135 136 137 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 135 def @expand end |
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
137 138 139 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 137 def limit @limit end |
#starting_after ⇒ Object
An object ID cursor for use in pagination.
139 140 141 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 139 def starting_after @starting_after end |
#status ⇒ Object
Only return FinancialAccounts that have the given status: ‘open` or `closed`
141 142 143 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 141 def status @status end |