Class: Stripe::Treasury::FinancialAccount::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/stripe/resources/treasury/financial_account.rb', line 95

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#createdObject

Only return FinancialAccounts that were created during the given date interval.



83
84
85
# File 'lib/stripe/resources/treasury/financial_account.rb', line 83

def created
  @created
end

#ending_beforeObject

An object ID cursor for use in pagination.



85
86
87
# File 'lib/stripe/resources/treasury/financial_account.rb', line 85

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



87
88
89
# File 'lib/stripe/resources/treasury/financial_account.rb', line 87

def expand
  @expand
end

#limitObject

A limit ranging from 1 to 100 (defaults to 10).



89
90
91
# File 'lib/stripe/resources/treasury/financial_account.rb', line 89

def limit
  @limit
end

#starting_afterObject

An object ID cursor for use in pagination.



91
92
93
# File 'lib/stripe/resources/treasury/financial_account.rb', line 91

def starting_after
  @starting_after
end

#statusObject

Only return FinancialAccounts that have the given status: ‘open` or `closed`



93
94
95
# File 'lib/stripe/resources/treasury/financial_account.rb', line 93

def status
  @status
end