Class: Stripe::Treasury::FinancialAccount::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::ListParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
-
#ending_before ⇒ Object
An object ID cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
-
#starting_after ⇒ Object
An object ID cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 109 def initialize( created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
95 96 97 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 95 def created @created end |
#ending_before ⇒ Object
An object ID cursor for use in pagination.
98 99 100 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 98 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
101 102 103 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 101 def @expand end |
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
104 105 106 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 104 def limit @limit end |
#starting_after ⇒ Object
An object ID cursor for use in pagination.
107 108 109 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 107 def starting_after @starting_after end |