Class: Stripe::Treasury::FinancialAccount::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::ListParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
-
#ending_before ⇒ Object
An object ID cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
-
#starting_after ⇒ Object
An object ID cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 93 def initialize( created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
83 84 85 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 83 def created @created end |
#ending_before ⇒ Object
An object ID cursor for use in pagination.
85 86 87 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 85 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
87 88 89 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 87 def @expand end |
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
89 90 91 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 89 def limit @limit end |
#starting_after ⇒ Object
An object ID cursor for use in pagination.
91 92 93 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 91 def starting_after @starting_after end |