Class: Stripe::Treasury::FinancialAccount::UpdateFeaturesParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Defined Under Namespace

Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateFeaturesParams

Returns a new instance of UpdateFeaturesParams.



679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
# File 'lib/stripe/resources/treasury/financial_account.rb', line 679

def initialize(
  card_issuing: nil,
  deposit_insurance: nil,
  expand: nil,
  financial_addresses: nil,
  inbound_transfers: nil,
  intra_stripe_flows: nil,
  outbound_payments: nil,
  outbound_transfers: nil
)
  @card_issuing = card_issuing
  @deposit_insurance = deposit_insurance
  @expand = expand
  @financial_addresses = financial_addresses
  @inbound_transfers = inbound_transfers
  @intra_stripe_flows = intra_stripe_flows
  @outbound_payments = outbound_payments
  @outbound_transfers = outbound_transfers
end

Instance Attribute Details

#card_issuingObject

Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.



663
664
665
# File 'lib/stripe/resources/treasury/financial_account.rb', line 663

def card_issuing
  @card_issuing
end

#deposit_insuranceObject

Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.



665
666
667
# File 'lib/stripe/resources/treasury/financial_account.rb', line 665

def deposit_insurance
  @deposit_insurance
end

#expandObject

Specifies which fields in the response should be expanded.



667
668
669
# File 'lib/stripe/resources/treasury/financial_account.rb', line 667

def expand
  @expand
end

#financial_addressesObject

Contains Features that add FinancialAddresses to the FinancialAccount.



669
670
671
# File 'lib/stripe/resources/treasury/financial_account.rb', line 669

def financial_addresses
  @financial_addresses
end

#inbound_transfersObject

Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.



671
672
673
# File 'lib/stripe/resources/treasury/financial_account.rb', line 671

def inbound_transfers
  @inbound_transfers
end

#intra_stripe_flowsObject

Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).



673
674
675
# File 'lib/stripe/resources/treasury/financial_account.rb', line 673

def intra_stripe_flows
  @intra_stripe_flows
end

#outbound_paymentsObject

Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.



675
676
677
# File 'lib/stripe/resources/treasury/financial_account.rb', line 675

def outbound_payments
  @outbound_payments
end

#outbound_transfersObject

Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.



677
678
679
# File 'lib/stripe/resources/treasury/financial_account.rb', line 677

def outbound_transfers
  @outbound_transfers
end