Class: Stripe::Treasury::FinancialAccount::UpdateFeaturesParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/financial_account.rb

Defined Under Namespace

Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateFeaturesParams

Returns a new instance of UpdateFeaturesParams.



712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'lib/stripe/resources/treasury/financial_account.rb', line 712

def initialize(
  card_issuing: nil,
  deposit_insurance: nil,
  expand: nil,
  financial_addresses: nil,
  inbound_transfers: nil,
  intra_stripe_flows: nil,
  outbound_payments: nil,
  outbound_transfers: nil
)
  @card_issuing = card_issuing
  @deposit_insurance = deposit_insurance
  @expand = expand
  @financial_addresses = financial_addresses
  @inbound_transfers = inbound_transfers
  @intra_stripe_flows = intra_stripe_flows
  @outbound_payments = outbound_payments
  @outbound_transfers = outbound_transfers
end

Instance Attribute Details

#card_issuingObject

Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.



689
690
691
# File 'lib/stripe/resources/treasury/financial_account.rb', line 689

def card_issuing
  @card_issuing
end

#deposit_insuranceObject

Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.



692
693
694
# File 'lib/stripe/resources/treasury/financial_account.rb', line 692

def deposit_insurance
  @deposit_insurance
end

#expandObject

Specifies which fields in the response should be expanded.



695
696
697
# File 'lib/stripe/resources/treasury/financial_account.rb', line 695

def expand
  @expand
end

#financial_addressesObject

Contains Features that add FinancialAddresses to the FinancialAccount.



698
699
700
# File 'lib/stripe/resources/treasury/financial_account.rb', line 698

def financial_addresses
  @financial_addresses
end

#inbound_transfersObject

Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.



701
702
703
# File 'lib/stripe/resources/treasury/financial_account.rb', line 701

def inbound_transfers
  @inbound_transfers
end

#intra_stripe_flowsObject

Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).



704
705
706
# File 'lib/stripe/resources/treasury/financial_account.rb', line 704

def intra_stripe_flows
  @intra_stripe_flows
end

#outbound_paymentsObject

Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.



707
708
709
# File 'lib/stripe/resources/treasury/financial_account.rb', line 707

def outbound_payments
  @outbound_payments
end

#outbound_transfersObject

Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.



710
711
712
# File 'lib/stripe/resources/treasury/financial_account.rb', line 710

def outbound_transfers
  @outbound_transfers
end