Class: Stripe::Treasury::FinancialAccount::UpdateFeaturesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::UpdateFeaturesParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: CardIssuing, DepositInsurance, FinancialAddresses, InboundTransfers, IntraStripeFlows, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
-
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
-
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
-
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
-
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
-
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
Instance Method Summary collapse
-
#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateFeaturesParams
constructor
A new instance of UpdateFeaturesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ UpdateFeaturesParams
Returns a new instance of UpdateFeaturesParams.
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 684 def initialize( card_issuing: nil, deposit_insurance: nil, expand: nil, financial_addresses: nil, inbound_transfers: nil, intra_stripe_flows: nil, outbound_payments: nil, outbound_transfers: nil ) @card_issuing = card_issuing @deposit_insurance = deposit_insurance @expand = @financial_addresses = financial_addresses @inbound_transfers = inbound_transfers @intra_stripe_flows = intra_stripe_flows @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#card_issuing ⇒ Object
Encodes the FinancialAccount’s ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
668 669 670 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 668 def card_issuing @card_issuing end |
#deposit_insurance ⇒ Object
Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.
670 671 672 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 670 def deposit_insurance @deposit_insurance end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
672 673 674 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 672 def @expand end |
#financial_addresses ⇒ Object
Contains Features that add FinancialAddresses to the FinancialAccount.
674 675 676 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 674 def financial_addresses @financial_addresses end |
#inbound_transfers ⇒ Object
Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
676 677 678 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 676 def inbound_transfers @inbound_transfers end |
#intra_stripe_flows ⇒ Object
Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
678 679 680 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 678 def intra_stripe_flows @intra_stripe_flows end |
#outbound_payments ⇒ Object
Includes Features related to initiating money movement out of the FinancialAccount to someone else’s bucket of money.
680 681 682 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 680 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.
682 683 684 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 682 def outbound_transfers @outbound_transfers end |