Class: Stripe::Treasury::FinancialAccount::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::UpdateParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Features, ForwardingSettings, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`.
-
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
The nickname for the FinancialAccount.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 560 def initialize( display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil ) @display_name = display_name @expand = @features = features @forwarding_settings = forwarding_settings @metadata = @nickname = nickname @platform_restrictions = platform_restrictions end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
546 547 548 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 546 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
548 549 550 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 548 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`. Stripe or the platform may control features via the requested field.
550 551 552 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 550 def features @features end |
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0
552 553 554 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 552 def forwarding_settings @forwarding_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
554 555 556 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 554 def @metadata end |
#nickname ⇒ Object
The nickname for the FinancialAccount.
556 557 558 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 556 def nickname @nickname end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
558 559 560 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 558 def platform_restrictions @platform_restrictions end |