Class: Stripe::Treasury::FinancialAccount::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccount::UpdateParams
- Defined in:
- lib/stripe/resources/treasury/financial_account.rb
Defined Under Namespace
Classes: Features, ForwardingSettings, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`.
-
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nickname ⇒ Object
The nickname for the FinancialAccount.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 512 def initialize( display_name: nil, expand: nil, features: nil, forwarding_settings: nil, metadata: nil, nickname: nil, platform_restrictions: nil ) @display_name = display_name @expand = @features = features @forwarding_settings = forwarding_settings @metadata = @nickname = nickname @platform_restrictions = platform_restrictions end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
498 499 500 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 498 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
500 501 502 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 500 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`. Stripe or the platform may control features via the requested field.
502 503 504 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 502 def features @features end |
#forwarding_settings ⇒ Object
A different bank account where funds can be deposited/debited in order to get the closing FA’s balance to $0
504 505 506 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 504 def forwarding_settings @forwarding_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
506 507 508 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 506 def @metadata end |
#nickname ⇒ Object
The nickname for the FinancialAccount.
508 509 510 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 508 def nickname @nickname end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
510 511 512 |
# File 'lib/stripe/resources/treasury/financial_account.rb', line 510 def platform_restrictions @platform_restrictions end |