Class: Stripe::Treasury::FinancialAccountService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/financial_account_service.rb

Defined Under Namespace

Classes: Features, PlatformRestrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, nickname: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 241

def initialize(
  display_name: nil,
  expand: nil,
  features: nil,
  metadata: nil,
  nickname: nil,
  platform_restrictions: nil,
  supported_currencies: nil
)
  @display_name = display_name
  @expand = expand
  @features = features
  @metadata = 
  @nickname = nickname
  @platform_restrictions = platform_restrictions
  @supported_currencies = supported_currencies
end

Instance Attribute Details

#display_nameObject

The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.



227
228
229
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 227

def display_name
  @display_name
end

#expandObject

Specifies which fields in the response should be expanded.



229
230
231
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 229

def expand
  @expand
end

#featuresObject

Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.



231
232
233
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 231

def features
  @features
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



233
234
235
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 233

def 
  @metadata
end

#nicknameObject

The nickname for the FinancialAccount.



235
236
237
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 235

def nickname
  @nickname
end

#platform_restrictionsObject

The set of functionalities that the platform can restrict on the FinancialAccount.



237
238
239
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 237

def platform_restrictions
  @platform_restrictions
end

#supported_currenciesObject

The currencies the FinancialAccount can hold a balance in.



239
240
241
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 239

def supported_currencies
  @supported_currencies
end