Class: Stripe::Treasury::FinancialAccountService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccountService::CreateParams
- Defined in:
- lib/stripe/services/treasury/financial_account_service.rb
Defined Under Namespace
Classes: Features, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
-
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil, supported_currencies: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 261 def initialize( display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil, supported_currencies: nil ) @display_name = display_name @expand = @features = features @metadata = @platform_restrictions = platform_restrictions @supported_currencies = supported_currencies end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
244 245 246 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 244 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
247 248 249 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 247 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.
250 251 252 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 250 def features @features end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
253 254 255 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 253 def @metadata end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
256 257 258 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 256 def platform_restrictions @platform_restrictions end |
#supported_currencies ⇒ Object
The currencies the FinancialAccount can hold a balance in.
259 260 261 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 259 def supported_currencies @supported_currencies end |