Class: Stripe::Treasury::FinancialAccountService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/financial_account_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 50

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return FinancialAccounts that were created during the given date interval.



36
37
38
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 36

def created
  @created
end

#ending_beforeObject

An object ID cursor for use in pagination.



39
40
41
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 39

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



42
43
44
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 42

def expand
  @expand
end

#limitObject

A limit ranging from 1 to 100 (defaults to 10).



45
46
47
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 45

def limit
  @limit
end

#starting_afterObject

An object ID cursor for use in pagination.



48
49
50
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 48

def starting_after
  @starting_after
end