Class: Stripe::Treasury::FinancialAccountService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccountService::ListParams
- Defined in:
- lib/stripe/services/treasury/financial_account_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
-
#ending_before ⇒ Object
An object ID cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
-
#starting_after ⇒ Object
An object ID cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 50 def initialize( created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return FinancialAccounts that were created during the given date interval.
36 37 38 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 36 def created @created end |
#ending_before ⇒ Object
An object ID cursor for use in pagination.
39 40 41 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 39 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
42 43 44 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 42 def @expand end |
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
45 46 47 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 45 def limit @limit end |
#starting_after ⇒ Object
An object ID cursor for use in pagination.
48 49 50 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 48 def starting_after @starting_after end |