Class: Stripe::Treasury::FinancialAccountService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::FinancialAccountService::UpdateParams
- Defined in:
- lib/stripe/services/treasury/financial_account_service.rb
Defined Under Namespace
Classes: Features, PlatformRestrictions
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The display name for the FinancialAccount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
Instance Method Summary collapse
-
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 480 def initialize( display_name: nil, expand: nil, features: nil, metadata: nil, platform_restrictions: nil ) @display_name = display_name @expand = @features = features @metadata = @platform_restrictions = platform_restrictions end |
Instance Attribute Details
#display_name ⇒ Object
The display name for the FinancialAccount. Use this field to customize the names of the FinancialAccounts for your connected accounts. Unlike the ‘nickname` field, `display_name` is not internal metadata and will be exposed to connected accounts.
466 467 468 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 466 def display_name @display_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
469 470 471 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 469 def @expand end |
#features ⇒ Object
Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associated ‘status_details`. Stripe or the platform may control features via the requested field.
472 473 474 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 472 def features @features end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
475 476 477 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 475 def @metadata end |
#platform_restrictions ⇒ Object
The set of functionalities that the platform can restrict on the FinancialAccount.
478 479 480 |
# File 'lib/stripe/services/treasury/financial_account_service.rb', line 478 def platform_restrictions @platform_restrictions end |