Class: Stripe::Treasury::InboundTransfer::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::InboundTransfer::CreateParams
- Defined in:
- lib/stripe/resources/treasury/inbound_transfer.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to send funds to.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#origin_payment_method ⇒ Object
The origin payment method to be debited for the InboundTransfer.
-
#statement_descriptor ⇒ Object
The complete description that appears on your customers’ statements.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 192 def initialize( amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil ) @amount = amount @currency = currency @description = description @expand = @financial_account = financial_account @metadata = @origin_payment_method = origin_payment_method @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
176 177 178 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 176 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
178 179 180 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 178 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
180 181 182 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 180 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
182 183 184 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 182 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to send funds to.
184 185 186 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 184 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
186 187 188 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 186 def @metadata end |
#origin_payment_method ⇒ Object
The origin payment method to be debited for the InboundTransfer.
188 189 190 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 188 def origin_payment_method @origin_payment_method end |
#statement_descriptor ⇒ Object
The complete description that appears on your customers’ statements. Maximum 10 characters.
190 191 192 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 190 def statement_descriptor @statement_descriptor end |