Class: Stripe::Treasury::InboundTransfer::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::InboundTransfer::CreateParams
- Defined in:
- lib/stripe/resources/treasury/inbound_transfer.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to send funds to.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#origin_payment_method ⇒ Object
The origin payment method to be debited for the InboundTransfer.
-
#statement_descriptor ⇒ Object
The complete description that appears on your customers’ statements.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 166 def initialize( amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, metadata: nil, origin_payment_method: nil, statement_descriptor: nil ) @amount = amount @currency = currency @description = description @expand = @financial_account = financial_account @metadata = @origin_payment_method = origin_payment_method @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
143 144 145 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 143 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
146 147 148 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 146 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
149 150 151 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 149 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
152 153 154 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 152 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to send funds to.
155 156 157 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 155 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
158 159 160 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 158 def @metadata end |
#origin_payment_method ⇒ Object
The origin payment method to be debited for the InboundTransfer.
161 162 163 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 161 def origin_payment_method @origin_payment_method end |
#statement_descriptor ⇒ Object
The complete description that appears on your customers’ statements. Maximum 10 characters.
164 165 166 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 164 def statement_descriptor @statement_descriptor end |