Class: Stripe::Treasury::InboundTransfer::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/inbound_transfer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 124

def initialize(
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



107
108
109
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 107

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



110
111
112
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 110

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



113
114
115
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 113

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



116
117
118
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 116

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



119
120
121
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 119

def starting_after
  @starting_after
end

#statusObject

Only return InboundTransfers that have the given status: ‘processing`, `succeeded`, `failed` or `canceled`.



122
123
124
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 122

def status
  @status
end