Class: Stripe::Treasury::InboundTransfer::OriginPaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Treasury::InboundTransfer::OriginPaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/treasury/inbound_transfer.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#network ⇒ Object
readonly
The network rails used.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
61 62 63 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 61 def account_holder_type @account_holder_type end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
64 65 66 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 64 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
67 68 69 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 67 def bank_name @bank_name end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
70 71 72 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 70 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
73 74 75 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 73 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
76 77 78 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 76 def mandate @mandate end |
#network ⇒ Object (readonly)
The network rails used. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.
79 80 81 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 79 def network @network end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
82 83 84 |
# File 'lib/stripe/resources/treasury/inbound_transfer.rb', line 82 def routing_number @routing_number end |