Class: Stripe::Treasury::OutboundPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::OutboundPayment
- Extended by:
- APIOperations::Create, APIOperations::List
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Overview
Use [OutboundPayments](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments) to send funds to another party’s external bank account or [FinancialAccount](stripe.com/docs/api#financial_accounts). To send money to an account belonging to the same user, use an [OutboundTransfer](stripe.com/docs/api#outbound_transfers).
Simulate OutboundPayment state changes with the ‘/v1/test_helpers/treasury/outbound_payments` endpoints. These methods can only be called on test mode objects.
Related guide: [Moving money with Treasury using OutboundPayment objects](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments)
Defined Under Namespace
Classes: CancelParams, CreateParams, DestinationPaymentMethodDetails, EndUserDetails, FailParams, ListParams, PostParams, ReturnOutboundPaymentParams, ReturnedDetails, StatusTransitions, TestHelpers, TrackingDetails, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"treasury.outbound_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount (in cents) transferred.
-
#cancelable ⇒ Object
readonly
Returns ‘true` if the object can be canceled, and `false` otherwise.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the [customer](stripe.com/docs/api/customers) to whom an OutboundPayment is sent.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
readonly
The PaymentMethod via which an OutboundPayment is sent.
-
#destination_payment_method_details ⇒ Object
readonly
Details about the PaymentMethod for an OutboundPayment.
-
#end_user_details ⇒ Object
readonly
Details about the end user.
-
#expected_arrival_date ⇒ Object
readonly
The date when funds are expected to arrive in the destination account.
-
#financial_account ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#hosted_regulatory_receipt_url ⇒ Object
readonly
A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#returned_details ⇒ Object
readonly
Details about a returned OutboundPayment.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
-
#status ⇒ Object
readonly
Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
-
#tracking_details ⇒ Object
readonly
Details about network-specific tracking information if available.
-
#transaction ⇒ Object
readonly
The Transaction associated with this object.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(id, params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
-
.create(params = {}, opts = {}) ⇒ Object
Creates an OutboundPayment.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of OutboundPayments sent from the specified FinancialAccount.
- .object_name ⇒ Object
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount (in cents) transferred.
465 466 467 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 465 def amount @amount end |
#cancelable ⇒ Object (readonly)
Returns ‘true` if the object can be canceled, and `false` otherwise.
467 468 469 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 467 def cancelable @cancelable end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
469 470 471 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 469 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
471 472 473 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 471 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the [customer](stripe.com/docs/api/customers) to whom an OutboundPayment is sent.
473 474 475 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 473 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
475 476 477 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 475 def description @description end |
#destination_payment_method ⇒ Object (readonly)
The PaymentMethod via which an OutboundPayment is sent. This field can be empty if the OutboundPayment was created using ‘destination_payment_method_data`.
477 478 479 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 477 def destination_payment_method @destination_payment_method end |
#destination_payment_method_details ⇒ Object (readonly)
Details about the PaymentMethod for an OutboundPayment.
479 480 481 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 479 def destination_payment_method_details @destination_payment_method_details end |
#end_user_details ⇒ Object (readonly)
Details about the end user.
481 482 483 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 481 def end_user_details @end_user_details end |
#expected_arrival_date ⇒ Object (readonly)
The date when funds are expected to arrive in the destination account.
483 484 485 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 483 def expected_arrival_date @expected_arrival_date end |
#financial_account ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
485 486 487 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 485 def financial_account @financial_account end |
#hosted_regulatory_receipt_url ⇒ Object (readonly)
A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
487 488 489 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 487 def hosted_regulatory_receipt_url @hosted_regulatory_receipt_url end |
#id ⇒ Object (readonly)
Unique identifier for the object.
489 490 491 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 489 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
491 492 493 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 491 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
493 494 495 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 493 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
495 496 497 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 495 def object @object end |
#returned_details ⇒ Object (readonly)
Details about a returned OutboundPayment. Only set when the status is ‘returned`.
497 498 499 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 497 def returned_details @returned_details end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
499 500 501 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 499 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is pending. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its destination, its status will change to `returned`.
501 502 503 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 501 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
503 504 505 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 503 def status_transitions @status_transitions end |
#tracking_details ⇒ Object (readonly)
Details about network-specific tracking information if available.
505 506 507 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 505 def tracking_details @tracking_details end |
#transaction ⇒ Object (readonly)
The Transaction associated with this object.
507 508 509 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 507 def transaction @transaction end |
Class Method Details
.cancel(id, params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
520 521 522 523 524 525 526 527 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 520 def self.cancel(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/outbound_payments/%<id>s/cancel", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates an OutboundPayment.
530 531 532 533 534 535 536 537 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 530 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/treasury/outbound_payments", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of OutboundPayments sent from the specified FinancialAccount.
540 541 542 543 544 545 546 547 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 540 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/outbound_payments", params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 16 def self.object_name "treasury.outbound_payment" end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
510 511 512 513 514 515 516 517 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 510 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/outbound_payments/%<id>s/cancel", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
549 550 551 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 549 def test_helpers TestHelpers.new(self) end |