Class: Stripe::Treasury::OutboundPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::OutboundPayment
- Extended by:
- APIOperations::Create, APIOperations::List
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Overview
Use [OutboundPayments](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments) to send funds to another party’s external bank account or [FinancialAccount](stripe.com/docs/api#financial_accounts). To send money to an account belonging to the same user, use an [OutboundTransfer](stripe.com/docs/api#outbound_transfers).
Simulate OutboundPayment state changes with the ‘/v1/test_helpers/treasury/outbound_payments` endpoints. These methods can only be called on test mode objects.
Related guide: [Moving money with Treasury using OutboundPayment objects](docs.stripe.com/docs/treasury/moving-money/financial-accounts/out-of/outbound-payments)
Defined Under Namespace
Classes: DestinationPaymentMethodDetails, EndUserDetails, ReturnedDetails, StatusTransitions, TestHelpers, TrackingDetails
Constant Summary collapse
- OBJECT_NAME =
"treasury.outbound_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount (in cents) transferred.
-
#cancelable ⇒ Object
readonly
Returns ‘true` if the object can be canceled, and `false` otherwise.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the [customer](stripe.com/docs/api/customers) to whom an OutboundPayment is sent.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
readonly
The PaymentMethod via which an OutboundPayment is sent.
-
#destination_payment_method_details ⇒ Object
readonly
Details about the PaymentMethod for an OutboundPayment.
-
#end_user_details ⇒ Object
readonly
Details about the end user.
-
#expected_arrival_date ⇒ Object
readonly
The date when funds are expected to arrive in the destination account.
-
#financial_account ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#hosted_regulatory_receipt_url ⇒ Object
readonly
A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#returned_details ⇒ Object
readonly
Details about a returned OutboundPayment.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
-
#status ⇒ Object
readonly
Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
-
#tracking_details ⇒ Object
readonly
Details about network-specific tracking information if available.
-
#transaction ⇒ Object
readonly
The Transaction associated with this object.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(id, params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
-
.create(params = {}, opts = {}) ⇒ Object
Creates an OutboundPayment.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of OutboundPayments sent from the specified FinancialAccount.
- .object_name ⇒ Object
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount (in cents) transferred.
61 62 63 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 61 def amount @amount end |
#cancelable ⇒ Object (readonly)
Returns ‘true` if the object can be canceled, and `false` otherwise.
63 64 65 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 63 def cancelable @cancelable end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
65 66 67 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 65 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
67 68 69 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 67 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the [customer](stripe.com/docs/api/customers) to whom an OutboundPayment is sent.
69 70 71 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 69 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
71 72 73 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 71 def description @description end |
#destination_payment_method ⇒ Object (readonly)
The PaymentMethod via which an OutboundPayment is sent. This field can be empty if the OutboundPayment was created using ‘destination_payment_method_data`.
73 74 75 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 73 def destination_payment_method @destination_payment_method end |
#destination_payment_method_details ⇒ Object (readonly)
Details about the PaymentMethod for an OutboundPayment.
75 76 77 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 75 def destination_payment_method_details @destination_payment_method_details end |
#end_user_details ⇒ Object (readonly)
Details about the end user.
77 78 79 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 77 def end_user_details @end_user_details end |
#expected_arrival_date ⇒ Object (readonly)
The date when funds are expected to arrive in the destination account.
79 80 81 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 79 def expected_arrival_date @expected_arrival_date end |
#financial_account ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
81 82 83 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 81 def financial_account @financial_account end |
#hosted_regulatory_receipt_url ⇒ Object (readonly)
A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
83 84 85 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 83 def hosted_regulatory_receipt_url @hosted_regulatory_receipt_url end |
#id ⇒ Object (readonly)
Unique identifier for the object.
85 86 87 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 85 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
87 88 89 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 87 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
89 90 91 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 89 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
91 92 93 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 91 def object @object end |
#returned_details ⇒ Object (readonly)
Details about a returned OutboundPayment. Only set when the status is ‘returned`.
93 94 95 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 93 def returned_details @returned_details end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
95 96 97 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 95 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is pending. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its destination, its status will change to `returned`.
97 98 99 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 97 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
99 100 101 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 99 def status_transitions @status_transitions end |
#tracking_details ⇒ Object (readonly)
Details about network-specific tracking information if available.
101 102 103 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 101 def tracking_details @tracking_details end |
#transaction ⇒ Object (readonly)
The Transaction associated with this object.
103 104 105 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 103 def transaction @transaction end |
Class Method Details
.cancel(id, params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
116 117 118 119 120 121 122 123 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 116 def self.cancel(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/outbound_payments/%<id>s/cancel", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates an OutboundPayment.
126 127 128 129 130 131 132 133 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 126 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/treasury/outbound_payments", params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of OutboundPayments sent from the specified FinancialAccount.
136 137 138 139 140 141 142 143 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 136 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/outbound_payments", params: filters, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 16 def self.object_name "treasury.outbound_payment" end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
Cancel an OutboundPayment.
106 107 108 109 110 111 112 113 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 106 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/treasury/outbound_payments/%<id>s/cancel", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
145 146 147 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 145 def test_helpers TestHelpers.new(self) end |