Class: Stripe::Treasury::OutboundPayment::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::CreateParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Defined Under Namespace
Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, EndUserDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment.
-
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment.
-
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
-
#end_user_details ⇒ Object
End user details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer).
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 340 def initialize( amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil ) @amount = amount @currency = currency @customer = customer @description = description @destination_payment_method = destination_payment_method @destination_payment_method_data = destination_payment_method_data @destination_payment_method_options = @end_user_details = end_user_details @expand = @financial_account = financial_account @metadata = @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
316 317 318 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 316 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
318 319 320 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 318 def currency @currency end |
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to the ‘destination_payment_method` passed in.
320 321 322 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 320 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
322 323 324 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 322 def description @description end |
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive with ‘destination_payment_method_data`.
324 325 326 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 324 def destination_payment_method @destination_payment_method end |
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive with ‘destination_payment_method`.
326 327 328 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 326 def destination_payment_method_data @destination_payment_method_data end |
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
328 329 330 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 328 def @destination_payment_method_options end |
#end_user_details ⇒ Object
End user details.
330 331 332 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 330 def end_user_details @end_user_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
332 333 334 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 332 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
334 335 336 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 334 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
336 337 338 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 336 def @metadata end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters for ‘ach` payments, 140 characters for `us_domestic_wire` payments, or 500 characters for `stripe` network transfers. The default value is “payment”.
338 339 340 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 338 def statement_descriptor @statement_descriptor end |