Class: Stripe::Treasury::OutboundPayment::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::CreateParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Defined Under Namespace
Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, EndUserDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment.
-
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment.
-
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
-
#end_user_details ⇒ Object
End user details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer).
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 402 def initialize( amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil ) @amount = amount @currency = currency @customer = customer @description = description @destination_payment_method = destination_payment_method @destination_payment_method_data = destination_payment_method_data @destination_payment_method_options = @end_user_details = end_user_details @expand = @financial_account = financial_account @metadata = @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
367 368 369 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 367 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
370 371 372 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 370 def currency @currency end |
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to the ‘destination_payment_method` passed in.
373 374 375 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 373 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
376 377 378 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 376 def description @description end |
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive with ‘destination_payment_method_data`.
379 380 381 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 379 def destination_payment_method @destination_payment_method end |
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive with ‘destination_payment_method`.
382 383 384 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 382 def destination_payment_method_data @destination_payment_method_data end |
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
385 386 387 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 385 def @destination_payment_method_options end |
#end_user_details ⇒ Object
End user details.
388 389 390 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 388 def end_user_details @end_user_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
391 392 393 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 391 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
394 395 396 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 394 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
397 398 399 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 397 def @metadata end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters for ‘ach` payments, 140 characters for `us_domestic_wire` payments, or 500 characters for `stripe` network transfers. The default value is “payment”.
400 401 402 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 400 def statement_descriptor @statement_descriptor end |