Class: Stripe::Treasury::OutboundPayment::CreateParams::DestinationPaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_payment.rb

Defined Under Namespace

Classes: BillingDetails, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, financial_account: nil, metadata: nil, type: nil, us_bank_account: nil) ⇒ DestinationPaymentMethodData

Returns a new instance of DestinationPaymentMethodData.



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 322

def initialize(
  billing_details: nil,
  financial_account: nil,
  metadata: nil,
  type: nil,
  us_bank_account: nil
)
  @billing_details = billing_details
  @financial_account = 
  @metadata = 
  @type = type
  @us_bank_account = 
end

Instance Attribute Details

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



308
309
310
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 308

def billing_details
  @billing_details
end

#financial_accountObject

Required if type is set to ‘financial_account`. The FinancialAccount ID to send funds to.



311
312
313
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 311

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



314
315
316
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 314

def 
  @metadata
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



317
318
319
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 317

def type
  @type
end

#us_bank_accountObject

Required hash if type is set to ‘us_bank_account`.



320
321
322
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 320

def 
  @us_bank_account
end