Class: Stripe::Treasury::OutboundPayment::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::ListParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return OutboundPayments that were created during the given date interval.
-
#customer ⇒ Object
Only return OutboundPayments sent to this customer.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
Returns objects associated with this FinancialAccount.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return OutboundPayments that have the given status: ‘processing`, `failed`, `posted`, `returned`, or `canceled`.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 253 def initialize( created: nil, customer: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil ) @created = created @customer = customer @ending_before = ending_before @expand = @financial_account = financial_account @limit = limit @starting_after = starting_after @status = status end |
Instance Attribute Details
#created ⇒ Object
Only return OutboundPayments that were created during the given date interval.
237 238 239 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 237 def created @created end |
#customer ⇒ Object
Only return OutboundPayments sent to this customer.
239 240 241 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 239 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
241 242 243 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 241 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
243 244 245 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 243 def @expand end |
#financial_account ⇒ Object
Returns objects associated with this FinancialAccount.
245 246 247 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 245 def financial_account @financial_account end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
247 248 249 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 247 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
249 250 251 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 249 def starting_after @starting_after end |
#status ⇒ Object
Only return OutboundPayments that have the given status: ‘processing`, `failed`, `posted`, `returned`, or `canceled`.
251 252 253 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 251 def status @status end |