Class: Stripe::Treasury::OutboundPayment::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_payment.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 198

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#createdObject

Only return OutboundPayments that were created during the given date interval.



175
176
177
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 175

def created
  @created
end

#customerObject

Only return OutboundPayments sent to this customer.



178
179
180
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 178

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



181
182
183
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 181

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



184
185
186
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 184

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



187
188
189
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 187

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



190
191
192
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 190

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



193
194
195
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 193

def starting_after
  @starting_after
end

#statusObject

Only return OutboundPayments that have the given status: ‘processing`, `failed`, `posted`, `returned`, or `canceled`.



196
197
198
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 196

def status
  @status
end