Class: Stripe::Treasury::OutboundPayment::ReturnOutboundPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::ReturnOutboundPaymentParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Defined Under Namespace
Classes: ReturnedDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#returned_details ⇒ Object
Optional hash to set the return code.
Instance Method Summary collapse
-
#initialize(expand: nil, returned_details: nil) ⇒ ReturnOutboundPaymentParams
constructor
A new instance of ReturnOutboundPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, returned_details: nil) ⇒ ReturnOutboundPaymentParams
Returns a new instance of ReturnOutboundPaymentParams.
459 460 461 462 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 459 def initialize(expand: nil, returned_details: nil) @expand = @returned_details = returned_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
455 456 457 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 455 def @expand end |
#returned_details ⇒ Object
Optional hash to set the return code.
457 458 459 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 457 def returned_details @returned_details end |