Class: Stripe::Treasury::OutboundPayment::ReturnOutboundPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPayment::ReturnOutboundPaymentParams
- Defined in:
- lib/stripe/resources/treasury/outbound_payment.rb
Defined Under Namespace
Classes: ReturnedDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#returned_details ⇒ Object
Optional hash to set the return code.
Instance Method Summary collapse
-
#initialize(expand: nil, returned_details: nil) ⇒ ReturnOutboundPaymentParams
constructor
A new instance of ReturnOutboundPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, returned_details: nil) ⇒ ReturnOutboundPaymentParams
Returns a new instance of ReturnOutboundPaymentParams.
465 466 467 468 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 465 def initialize(expand: nil, returned_details: nil) @expand = @returned_details = returned_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
461 462 463 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 461 def @expand end |
#returned_details ⇒ Object
Optional hash to set the return code.
463 464 465 |
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 463 def returned_details @returned_details end |