Class: Stripe::Treasury::OutboundPayment::TestHelpers

Inherits:
APIResourceTestHelpers show all
Defined in:
lib/stripe/resources/treasury/outbound_payment.rb

Constant Summary collapse

RESOURCE_CLASS =
OutboundPayment

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResourceTestHelpers

custom_method, #initialize, resource_url, #resource_url

Methods included from APIOperations::Request

included

Constructor Details

This class inherits a constructor from Stripe::APIResourceTestHelpers

Class Method Details

.fail(id, params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundPayment to the failed status. The OutboundPayment must already be in the processing state.



566
567
568
569
570
571
572
573
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 566

def self.fail(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s/fail", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.post(id, params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundPayment to the posted status. The OutboundPayment must already be in the processing state.



586
587
588
589
590
591
592
593
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 586

def self.post(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s/post", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.resource_classObject



561
562
563
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 561

def self.resource_class
  "OutboundPayment"
end

.return_outbound_payment(id, params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundPayment to the returned status. The OutboundPayment must already be in the processing state.



606
607
608
609
610
611
612
613
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 606

def self.return_outbound_payment(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s/return", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a test mode created OutboundPayment with tracking details. The OutboundPayment must not be cancelable, and cannot be in the canceled or failed states.



626
627
628
629
630
631
632
633
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 626

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#fail(params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundPayment to the failed status. The OutboundPayment must already be in the processing state.



576
577
578
579
580
581
582
583
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 576

def fail(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s/fail", { id: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#post(params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundPayment to the posted status. The OutboundPayment must already be in the processing state.



596
597
598
599
600
601
602
603
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 596

def post(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s/post", { id: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#return_outbound_payment(params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundPayment to the returned status. The OutboundPayment must already be in the processing state.



616
617
618
619
620
621
622
623
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 616

def return_outbound_payment(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s/return", { id: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#update(params = {}, opts = {}) ⇒ Object

Updates a test mode created OutboundPayment with tracking details. The OutboundPayment must not be cancelable, and cannot be in the canceled or failed states.



636
637
638
639
640
641
642
643
# File 'lib/stripe/resources/treasury/outbound_payment.rb', line 636

def update(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_payments/%<id>s", { id: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end