Class: Stripe::Treasury::OutboundPaymentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPaymentService::CreateParams
- Defined in:
- lib/stripe/services/treasury/outbound_payment_service.rb
Defined Under Namespace
Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, EndUserDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment.
-
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment.
-
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
-
#end_user_details ⇒ Object
End user details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer).
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 221 def initialize( amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil ) @amount = amount @currency = currency @customer = customer @description = description @destination_payment_method = destination_payment_method @destination_payment_method_data = destination_payment_method_data @destination_payment_method_options = @end_user_details = end_user_details @expand = @financial_account = financial_account @metadata = @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
197 198 199 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 197 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
199 200 201 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 199 def currency @currency end |
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to the ‘destination_payment_method` passed in.
201 202 203 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 201 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
203 204 205 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 203 def description @description end |
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive with ‘destination_payment_method_data`.
205 206 207 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 205 def destination_payment_method @destination_payment_method end |
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive with ‘destination_payment_method`.
207 208 209 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 207 def destination_payment_method_data @destination_payment_method_data end |
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
209 210 211 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 209 def @destination_payment_method_options end |
#end_user_details ⇒ Object
End user details.
211 212 213 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 211 def end_user_details @end_user_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
213 214 215 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 213 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
215 216 217 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 215 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
217 218 219 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 217 def @metadata end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters for ‘ach` payments, 140 characters for `us_domestic_wire` payments, or 500 characters for `stripe` network transfers. The default value is “payment”.
219 220 221 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 219 def statement_descriptor @statement_descriptor end |