Class: Stripe::Treasury::OutboundPaymentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundPaymentService::CreateParams
- Defined in:
- lib/stripe/services/treasury/outbound_payment_service.rb
Defined Under Namespace
Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, EndUserDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment.
-
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment.
-
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
-
#end_user_details ⇒ Object
End user details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer).
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 256 def initialize( amount: nil, currency: nil, customer: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, end_user_details: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil ) @amount = amount @currency = currency @customer = customer @description = description @destination_payment_method = destination_payment_method @destination_payment_method_data = destination_payment_method_data @destination_payment_method_options = @end_user_details = end_user_details @expand = @financial_account = financial_account @metadata = @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
221 222 223 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 221 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
224 225 226 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 224 def currency @currency end |
#customer ⇒ Object
ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to the ‘destination_payment_method` passed in.
227 228 229 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 227 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
230 231 232 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 230 def description @description end |
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive with ‘destination_payment_method_data`.
233 234 235 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 233 def destination_payment_method @destination_payment_method end |
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive with ‘destination_payment_method`.
236 237 238 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 236 def destination_payment_method_data @destination_payment_method_data end |
#destination_payment_method_options ⇒ Object
Payment method-specific configuration for this OutboundPayment.
239 240 241 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 239 def @destination_payment_method_options end |
#end_user_details ⇒ Object
End user details.
242 243 244 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 242 def end_user_details @end_user_details end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
245 246 247 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 245 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
248 249 250 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 248 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
251 252 253 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 251 def @metadata end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters for ‘ach` payments, 140 characters for `us_domestic_wire` payments, or 500 characters for `stripe` network transfers. The default value is “payment”.
254 255 256 |
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 254 def statement_descriptor @statement_descriptor end |