Class: Stripe::Treasury::OutboundPaymentService::CreateParams::DestinationPaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/outbound_payment_service.rb

Defined Under Namespace

Classes: BillingDetails, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_details: nil, financial_account: nil, metadata: nil, type: nil, us_bank_account: nil) ⇒ DestinationPaymentMethodData

Returns a new instance of DestinationPaymentMethodData.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 153

def initialize(
  billing_details: nil,
  financial_account: nil,
  metadata: nil,
  type: nil,
  us_bank_account: nil
)
  @billing_details = billing_details
  @financial_account = 
  @metadata = 
  @type = type
  @us_bank_account = 
end

Instance Attribute Details

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



143
144
145
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 143

def billing_details
  @billing_details
end

#financial_accountObject

Required if type is set to ‘financial_account`. The FinancialAccount ID to send funds to.



145
146
147
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 145

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



147
148
149
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 147

def 
  @metadata
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



149
150
151
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 149

def type
  @type
end

#us_bank_accountObject

Required hash if type is set to ‘us_bank_account`.



151
152
153
# File 'lib/stripe/services/treasury/outbound_payment_service.rb', line 151

def 
  @us_bank_account
end