Class: Stripe::Treasury::OutboundTransfer::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_transfer.rb

Defined Under Namespace

Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 200

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_data: nil,
  destination_payment_method_options: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_data = destination_payment_method_data
  @destination_payment_method_options = destination_payment_method_options
  @expand = expand
  @financial_account = 
  @metadata = 
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



180
181
182
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 180

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



182
183
184
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 182

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



184
185
186
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 184

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundTransfer.



186
187
188
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 186

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_dataObject

Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with ‘destination_payment_method`.



188
189
190
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 188

def destination_payment_method_data
  @destination_payment_method_data
end

#destination_payment_method_optionsObject

Hash describing payment method configuration details.



190
191
192
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 190

def destination_payment_method_options
  @destination_payment_method_options
end

#expandObject

Specifies which fields in the response should be expanded.



192
193
194
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 192

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



194
195
196
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 194

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



196
197
198
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 196

def 
  @metadata
end

#statement_descriptorObject

Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”.



198
199
200
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 198

def statement_descriptor
  @statement_descriptor
end