Class: Stripe::Treasury::OutboundTransfer::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_transfer.rb

Defined Under Namespace

Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 233

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_data: nil,
  destination_payment_method_options: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  network_details: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_data = destination_payment_method_data
  @destination_payment_method_options = destination_payment_method_options
  @expand = expand
  @financial_account = 
  @metadata = 
  @network_details = network_details
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



211
212
213
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 211

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



213
214
215
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 213

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



215
216
217
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 215

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundTransfer.



217
218
219
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 217

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_dataObject

Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with ‘destination_payment_method`.



219
220
221
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 219

def destination_payment_method_data
  @destination_payment_method_data
end

#destination_payment_method_optionsObject

Hash describing payment method configuration details.



221
222
223
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 221

def destination_payment_method_options
  @destination_payment_method_options
end

#expandObject

Specifies which fields in the response should be expanded.



223
224
225
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 223

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



225
226
227
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 225

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



227
228
229
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 227

def 
  @metadata
end

#network_detailsObject

Details about the network used for the OutboundTransfer.



229
230
231
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 229

def network_details
  @network_details
end

#statement_descriptorObject

Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”.



231
232
233
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 231

def statement_descriptor
  @statement_descriptor
end