Class: Stripe::Treasury::OutboundTransfer::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/outbound_transfer.rb

Defined Under Namespace

Classes: DestinationPaymentMethodOptions, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 250

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_options: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  network_details: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_options = destination_payment_method_options
  @expand = expand
  @financial_account = 
  @metadata = 
  @network_details = network_details
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



221
222
223
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 221

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



224
225
226
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 224

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



227
228
229
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 227

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundTransfer.



230
231
232
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 230

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_optionsObject

Hash describing payment method configuration details.



233
234
235
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 233

def destination_payment_method_options
  @destination_payment_method_options
end

#expandObject

Specifies which fields in the response should be expanded.



236
237
238
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 236

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



239
240
241
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 239

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



242
243
244
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 242

def 
  @metadata
end

#network_detailsObject

Details about the network used for the OutboundTransfer.



245
246
247
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 245

def network_details
  @network_details
end

#statement_descriptorObject

Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”.



248
249
250
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 248

def statement_descriptor
  @statement_descriptor
end