Class: Stripe::Treasury::OutboundTransfer::TestHelpers

Inherits:
APIResourceTestHelpers show all
Defined in:
lib/stripe/resources/treasury/outbound_transfer.rb

Constant Summary collapse

RESOURCE_CLASS =
OutboundTransfer

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResourceTestHelpers

custom_method, #initialize, resource_url, #resource_url

Methods included from APIOperations::Request

included

Constructor Details

This class inherits a constructor from Stripe::APIResourceTestHelpers

Class Method Details

.fail(outbound_transfer, params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundTransfer to the failed status. The OutboundTransfer must already be in the processing state.



449
450
451
452
453
454
455
456
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 449

def self.fail(outbound_transfer, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s/fail", { outbound_transfer: CGI.escape(outbound_transfer) }),
    params: params,
    opts: opts
  )
end

.post(outbound_transfer, params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundTransfer to the posted status. The OutboundTransfer must already be in the processing state.



469
470
471
472
473
474
475
476
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 469

def self.post(outbound_transfer, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s/post", { outbound_transfer: CGI.escape(outbound_transfer) }),
    params: params,
    opts: opts
  )
end

.resource_classObject



444
445
446
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 444

def self.resource_class
  "OutboundTransfer"
end

.return_outbound_transfer(outbound_transfer, params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundTransfer to the returned status. The OutboundTransfer must already be in the processing state.



489
490
491
492
493
494
495
496
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 489

def self.return_outbound_transfer(outbound_transfer, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s/return", { outbound_transfer: CGI.escape(outbound_transfer) }),
    params: params,
    opts: opts
  )
end

.update(outbound_transfer, params = {}, opts = {}) ⇒ Object

Updates a test mode created OutboundTransfer with tracking details. The OutboundTransfer must not be cancelable, and cannot be in the canceled or failed states.



509
510
511
512
513
514
515
516
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 509

def self.update(outbound_transfer, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s", { outbound_transfer: CGI.escape(outbound_transfer) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#fail(params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundTransfer to the failed status. The OutboundTransfer must already be in the processing state.



459
460
461
462
463
464
465
466
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 459

def fail(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s/fail", { outbound_transfer: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#post(params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundTransfer to the posted status. The OutboundTransfer must already be in the processing state.



479
480
481
482
483
484
485
486
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 479

def post(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s/post", { outbound_transfer: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#return_outbound_transfer(params = {}, opts = {}) ⇒ Object

Transitions a test mode created OutboundTransfer to the returned status. The OutboundTransfer must already be in the processing state.



499
500
501
502
503
504
505
506
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 499

def return_outbound_transfer(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s/return", { outbound_transfer: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#update(params = {}, opts = {}) ⇒ Object

Updates a test mode created OutboundTransfer with tracking details. The OutboundTransfer must not be cancelable, and cannot be in the canceled or failed states.



519
520
521
522
523
524
525
526
# File 'lib/stripe/resources/treasury/outbound_transfer.rb', line 519

def update(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/treasury/outbound_transfers/%<outbound_transfer>s", { outbound_transfer: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end