Class: Stripe::Treasury::OutboundTransferService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Treasury::OutboundTransferService
- Defined in:
- lib/stripe/services/treasury/outbound_transfer_service.rb
Defined Under Namespace
Classes: CancelParams, CreateParams, ListParams, RetrieveParams
Instance Method Summary collapse
-
#cancel(outbound_transfer, params = {}, opts = {}) ⇒ Object
An OutboundTransfer can be canceled if the funds have not yet been paid out.
-
#create(params = {}, opts = {}) ⇒ Object
Creates an OutboundTransfer.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of OutboundTransfers sent from the specified FinancialAccount.
-
#retrieve(outbound_transfer, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing OutboundTransfer by passing the unique OutboundTransfer ID from either the OutboundTransfer creation request or OutboundTransfer list.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#cancel(outbound_transfer, params = {}, opts = {}) ⇒ Object
An OutboundTransfer can be canceled if the funds have not yet been paid out.
155 156 157 158 159 160 161 162 163 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 155 def cancel(outbound_transfer, params = {}, opts = {}) request( method: :post, path: format("/v1/treasury/outbound_transfers/%<outbound_transfer>s/cancel", { outbound_transfer: CGI.escape(outbound_transfer) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates an OutboundTransfer.
166 167 168 169 170 171 172 173 174 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 166 def create(params = {}, opts = {}) request( method: :post, path: "/v1/treasury/outbound_transfers", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of OutboundTransfers sent from the specified FinancialAccount.
177 178 179 180 181 182 183 184 185 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 177 def list(params = {}, opts = {}) request( method: :get, path: "/v1/treasury/outbound_transfers", params: params, opts: opts, base_address: :api ) end |
#retrieve(outbound_transfer, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing OutboundTransfer by passing the unique OutboundTransfer ID from either the OutboundTransfer creation request or OutboundTransfer list.
188 189 190 191 192 193 194 195 196 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 188 def retrieve(outbound_transfer, params = {}, opts = {}) request( method: :get, path: format("/v1/treasury/outbound_transfers/%<outbound_transfer>s", { outbound_transfer: CGI.escape(outbound_transfer) }), params: params, opts: opts, base_address: :api ) end |