Class: Stripe::Treasury::OutboundTransferService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::OutboundTransferService::CreateParams
- Defined in:
- lib/stripe/services/treasury/outbound_transfer_service.rb
Defined Under Namespace
Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions, NetworkDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundTransfer.
-
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundTransfer.
-
#destination_payment_method_options ⇒ Object
Hash describing payment method configuration details.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#network_details ⇒ Object
Details about the network used for the OutboundTransfer.
-
#statement_descriptor ⇒ Object
Statement descriptor to be shown on the receiving end of an OutboundTransfer.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 110 def initialize( amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, network_details: nil, statement_descriptor: nil ) @amount = amount @currency = currency @description = description @destination_payment_method = destination_payment_method @destination_payment_method_data = destination_payment_method_data @destination_payment_method_options = @expand = @financial_account = financial_account @metadata = @network_details = network_details @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
88 89 90 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 88 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
90 91 92 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 90 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
92 93 94 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 92 def description @description end |
#destination_payment_method ⇒ Object
The PaymentMethod to use as the payment instrument for the OutboundTransfer.
94 95 96 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 94 def destination_payment_method @destination_payment_method end |
#destination_payment_method_data ⇒ Object
Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with ‘destination_payment_method`.
96 97 98 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 96 def destination_payment_method_data @destination_payment_method_data end |
#destination_payment_method_options ⇒ Object
Hash describing payment method configuration details.
98 99 100 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 98 def @destination_payment_method_options end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
100 101 102 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 100 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
102 103 104 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 102 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
104 105 106 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 104 def @metadata end |
#network_details ⇒ Object
Details about the network used for the OutboundTransfer.
106 107 108 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 106 def network_details @network_details end |
#statement_descriptor ⇒ Object
Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”.
108 109 110 |
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 108 def statement_descriptor @statement_descriptor end |