Class: Stripe::Treasury::OutboundTransferService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/outbound_transfer_service.rb

Defined Under Namespace

Classes: DestinationPaymentMethodData, DestinationPaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, destination_payment_method: nil, destination_payment_method_data: nil, destination_payment_method_options: nil, expand: nil, financial_account: nil, metadata: nil, statement_descriptor: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 88

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  destination_payment_method: nil,
  destination_payment_method_data: nil,
  destination_payment_method_options: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  statement_descriptor: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @destination_payment_method = destination_payment_method
  @destination_payment_method_data = destination_payment_method_data
  @destination_payment_method_options = destination_payment_method_options
  @expand = expand
  @financial_account = 
  @metadata = 
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



68
69
70
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 68

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



70
71
72
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 70

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



72
73
74
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 72

def description
  @description
end

#destination_payment_methodObject

The PaymentMethod to use as the payment instrument for the OutboundTransfer.



74
75
76
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 74

def destination_payment_method
  @destination_payment_method
end

#destination_payment_method_dataObject

Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive with ‘destination_payment_method`.



76
77
78
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 76

def destination_payment_method_data
  @destination_payment_method_data
end

#destination_payment_method_optionsObject

Hash describing payment method configuration details.



78
79
80
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 78

def destination_payment_method_options
  @destination_payment_method_options
end

#expandObject

Specifies which fields in the response should be expanded.



80
81
82
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 80

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to pull funds from.



82
83
84
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 82

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



84
85
86
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 84

def 
  @metadata
end

#statement_descriptorObject

Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters for ‘ach` transfers or 140 characters for `us_domestic_wire` transfers. The default value is “transfer”.



86
87
88
# File 'lib/stripe/services/treasury/outbound_transfer_service.rb', line 86

def statement_descriptor
  @statement_descriptor
end