Class: Stripe::Treasury::ReceivedCredit::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::ReceivedCredit::CreateParams
- Defined in:
- lib/stripe/resources/treasury/received_credit.rb
Defined Under Namespace
Classes: InitiatingPaymentMethodDetails, NetworkDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to send funds to.
-
#initiating_payment_method_details ⇒ Object
Initiating payment method details for the object.
-
#network ⇒ Object
Specifies the network rails to be used.
-
#network_details ⇒ Object
Details about the network used for the ReceivedCredit.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 234 def initialize( amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil ) @amount = amount @currency = currency @description = description @expand = @financial_account = financial_account @initiating_payment_method_details = initiating_payment_method_details @network = network @network_details = network_details end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
218 219 220 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 218 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
220 221 222 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 220 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
222 223 224 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 222 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
224 225 226 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 224 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to send funds to.
226 227 228 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 226 def financial_account @financial_account end |
#initiating_payment_method_details ⇒ Object
Initiating payment method details for the object.
228 229 230 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 228 def initiating_payment_method_details @initiating_payment_method_details end |
#network ⇒ Object
Specifies the network rails to be used. If not set, will default to the PaymentMethod’s preferred network. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.
230 231 232 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 230 def network @network end |
#network_details ⇒ Object
Details about the network used for the ReceivedCredit.
232 233 234 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 232 def network_details @network_details end |