Class: Stripe::Treasury::ReceivedCredit::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/treasury/received_credit.rb

Defined Under Namespace

Classes: InitiatingPaymentMethodDetails, NetworkDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil, network_details: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/stripe/resources/treasury/received_credit.rb', line 279

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  expand: nil,
  financial_account: nil,
  initiating_payment_method_details: nil,
  network: nil,
  network_details: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @expand = expand
  @financial_account = 
  @initiating_payment_method_details = initiating_payment_method_details
  @network = network
  @network_details = network_details
end

Instance Attribute Details

#amountObject

Amount (in cents) to be transferred.



256
257
258
# File 'lib/stripe/resources/treasury/received_credit.rb', line 256

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



259
260
261
# File 'lib/stripe/resources/treasury/received_credit.rb', line 259

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



262
263
264
# File 'lib/stripe/resources/treasury/received_credit.rb', line 262

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



265
266
267
# File 'lib/stripe/resources/treasury/received_credit.rb', line 265

def expand
  @expand
end

#financial_accountObject

The FinancialAccount to send funds to.



268
269
270
# File 'lib/stripe/resources/treasury/received_credit.rb', line 268

def 
  @financial_account
end

#initiating_payment_method_detailsObject

Initiating payment method details for the object.



271
272
273
# File 'lib/stripe/resources/treasury/received_credit.rb', line 271

def initiating_payment_method_details
  @initiating_payment_method_details
end

#networkObject

Specifies the network rails to be used. If not set, will default to the PaymentMethod’s preferred network. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.



274
275
276
# File 'lib/stripe/resources/treasury/received_credit.rb', line 274

def network
  @network
end

#network_detailsObject

Details about the network used for the ReceivedCredit.



277
278
279
# File 'lib/stripe/resources/treasury/received_credit.rb', line 277

def network_details
  @network_details
end