Class: Stripe::Treasury::ReceivedCredit::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::ReceivedCredit::ListParams
- Defined in:
- lib/stripe/resources/treasury/received_credit.rb
Defined Under Namespace
Classes: LinkedFlows
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount that received the funds.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#linked_flows ⇒ Object
Only return ReceivedCredits described by the flow.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return ReceivedCredits that have the given status: ‘succeeded` or `failed`.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, financial_account: nil, limit: nil, linked_flows: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, financial_account: nil, limit: nil, linked_flows: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 177 def initialize( ending_before: nil, expand: nil, financial_account: nil, limit: nil, linked_flows: nil, starting_after: nil, status: nil ) @ending_before = ending_before @expand = @financial_account = financial_account @limit = limit @linked_flows = linked_flows @starting_after = starting_after @status = status end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
157 158 159 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 157 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
160 161 162 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 160 def @expand end |
#financial_account ⇒ Object
The FinancialAccount that received the funds.
163 164 165 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 163 def financial_account @financial_account end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
166 167 168 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 166 def limit @limit end |
#linked_flows ⇒ Object
Only return ReceivedCredits described by the flow.
169 170 171 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 169 def linked_flows @linked_flows end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
172 173 174 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 172 def starting_after @starting_after end |
#status ⇒ Object
Only return ReceivedCredits that have the given status: ‘succeeded` or `failed`.
175 176 177 |
# File 'lib/stripe/resources/treasury/received_credit.rb', line 175 def status @status end |