Class: Stripe::Treasury::ReceivedDebit

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/treasury/received_debit.rb

Overview

ReceivedDebits represent funds pulled from a [FinancialAccount](stripe.com/docs/api#financial_accounts). These are not initiated from the FinancialAccount.

Defined Under Namespace

Classes: CreateParams, InitiatingPaymentMethodDetails, LinkedFlows, ListParams, NetworkDetails, RetrieveParams, ReversalDetails, TestHelpers

Constant Summary collapse

OBJECT_NAME =
"treasury.received_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount (in cents) transferred.



263
264
265
# File 'lib/stripe/resources/treasury/received_debit.rb', line 263

def amount
  @amount
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



266
267
268
# File 'lib/stripe/resources/treasury/received_debit.rb', line 266

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



269
270
271
# File 'lib/stripe/resources/treasury/received_debit.rb', line 269

def currency
  @currency
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



272
273
274
# File 'lib/stripe/resources/treasury/received_debit.rb', line 272

def description
  @description
end

#failure_codeObject (readonly)

Reason for the failure. A ReceivedDebit might fail because the FinancialAccount doesn’t have sufficient funds, is closed, or is frozen.



275
276
277
# File 'lib/stripe/resources/treasury/received_debit.rb', line 275

def failure_code
  @failure_code
end

#financial_accountObject (readonly)

The FinancialAccount that funds were pulled from.



278
279
280
# File 'lib/stripe/resources/treasury/received_debit.rb', line 278

def 
  @financial_account
end

#hosted_regulatory_receipt_urlObject (readonly)

A [hosted transaction receipt](stripe.com/docs/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.



281
282
283
# File 'lib/stripe/resources/treasury/received_debit.rb', line 281

def hosted_regulatory_receipt_url
  @hosted_regulatory_receipt_url
end

#idObject (readonly)

Unique identifier for the object.



284
285
286
# File 'lib/stripe/resources/treasury/received_debit.rb', line 284

def id
  @id
end

#initiating_payment_method_detailsObject (readonly)

Attribute for field initiating_payment_method_details



287
288
289
# File 'lib/stripe/resources/treasury/received_debit.rb', line 287

def initiating_payment_method_details
  @initiating_payment_method_details
end

#linked_flowsObject (readonly)

Attribute for field linked_flows



290
291
292
# File 'lib/stripe/resources/treasury/received_debit.rb', line 290

def linked_flows
  @linked_flows
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



293
294
295
# File 'lib/stripe/resources/treasury/received_debit.rb', line 293

def livemode
  @livemode
end

#networkObject (readonly)

The network used for the ReceivedDebit.



296
297
298
# File 'lib/stripe/resources/treasury/received_debit.rb', line 296

def network
  @network
end

#network_detailsObject (readonly)

Details specific to the money movement rails.



299
300
301
# File 'lib/stripe/resources/treasury/received_debit.rb', line 299

def network_details
  @network_details
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



302
303
304
# File 'lib/stripe/resources/treasury/received_debit.rb', line 302

def object
  @object
end

#reversal_detailsObject (readonly)

Details describing when a ReceivedDebit might be reversed.



305
306
307
# File 'lib/stripe/resources/treasury/received_debit.rb', line 305

def reversal_details
  @reversal_details
end

#statusObject (readonly)

Status of the ReceivedDebit. ReceivedDebits are created with a status of either ‘succeeded` (approved) or `failed` (declined). The failure reason can be found under the `failure_code`.



308
309
310
# File 'lib/stripe/resources/treasury/received_debit.rb', line 308

def status
  @status
end

#transactionObject (readonly)

The Transaction associated with this object.



311
312
313
# File 'lib/stripe/resources/treasury/received_debit.rb', line 311

def transaction
  @transaction
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Returns a list of ReceivedDebits.



314
315
316
317
318
319
320
321
# File 'lib/stripe/resources/treasury/received_debit.rb', line 314

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/treasury/received_debits",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/treasury/received_debit.rb', line 11

def self.object_name
  "treasury.received_debit"
end

Instance Method Details

#test_helpersObject



323
324
325
# File 'lib/stripe/resources/treasury/received_debit.rb', line 323

def test_helpers
  TestHelpers.new(self)
end