Class: Stripe::Treasury::ReceivedDebit::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::ReceivedDebit::CreateParams
- Defined in:
- lib/stripe/resources/treasury/received_debit.rb
Defined Under Namespace
Classes: InitiatingPaymentMethodDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount (in cents) to be transferred.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
-
#initiating_payment_method_details ⇒ Object
Initiating payment method details for the object.
-
#network ⇒ Object
Specifies the network rails to be used.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 160 def initialize( amount: nil, currency: nil, description: nil, expand: nil, financial_account: nil, initiating_payment_method_details: nil, network: nil ) @amount = amount @currency = currency @description = description @expand = @financial_account = financial_account @initiating_payment_method_details = initiating_payment_method_details @network = network end |
Instance Attribute Details
#amount ⇒ Object
Amount (in cents) to be transferred.
146 147 148 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 146 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
148 149 150 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 148 def currency @currency end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
150 151 152 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 150 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
152 153 154 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 152 def @expand end |
#financial_account ⇒ Object
The FinancialAccount to pull funds from.
154 155 156 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 154 def financial_account @financial_account end |
#initiating_payment_method_details ⇒ Object
Initiating payment method details for the object.
156 157 158 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 156 def initiating_payment_method_details @initiating_payment_method_details end |
#network ⇒ Object
Specifies the network rails to be used. If not set, will default to the PaymentMethod’s preferred network. See the [docs](stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.
158 159 160 |
# File 'lib/stripe/resources/treasury/received_debit.rb', line 158 def network @network end |