Class: Stripe::Treasury::Transaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Treasury::Transaction
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/treasury/transaction.rb
Overview
Transactions represent changes to a [FinancialAccount’s](stripe.com/docs/api#financial_accounts) balance.
Defined Under Namespace
Classes: BalanceImpact, FlowDetails, ListParams, RetrieveParams, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"treasury.transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount (in cents) transferred.
-
#balance_impact ⇒ Object
readonly
Change to a FinancialAccount’s balance.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#entries ⇒ Object
readonly
A list of TransactionEntries that are part of this Transaction.
-
#financial_account ⇒ Object
readonly
The FinancialAccount associated with this object.
-
#flow ⇒ Object
readonly
ID of the flow that created the Transaction.
-
#flow_details ⇒ Object
readonly
Details of the flow that created the Transaction.
-
#flow_type ⇒ Object
readonly
Type of the flow that created the Transaction.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Status of the Transaction.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Transaction objects.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount (in cents) transferred.
161 162 163 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 161 def amount @amount end |
#balance_impact ⇒ Object (readonly)
Change to a FinancialAccount’s balance
163 164 165 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 163 def balance_impact @balance_impact end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
165 166 167 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 165 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
167 168 169 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 167 def currency @currency end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
169 170 171 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 169 def description @description end |
#entries ⇒ Object (readonly)
A list of TransactionEntries that are part of this Transaction. This cannot be expanded in any list endpoints.
171 172 173 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 171 def entries @entries end |
#financial_account ⇒ Object (readonly)
The FinancialAccount associated with this object.
173 174 175 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 173 def financial_account @financial_account end |
#flow ⇒ Object (readonly)
ID of the flow that created the Transaction.
175 176 177 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 175 def flow @flow end |
#flow_details ⇒ Object (readonly)
Details of the flow that created the Transaction.
177 178 179 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 177 def flow_details @flow_details end |
#flow_type ⇒ Object (readonly)
Type of the flow that created the Transaction.
179 180 181 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 179 def flow_type @flow_type end |
#id ⇒ Object (readonly)
Unique identifier for the object.
181 182 183 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 181 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
183 184 185 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 183 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
185 186 187 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 185 def object @object end |
#status ⇒ Object (readonly)
Status of the Transaction.
187 188 189 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 187 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
189 190 191 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 189 def status_transitions @status_transitions end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Transaction objects.
192 193 194 195 196 197 198 199 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 192 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/treasury/transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/treasury/transaction.rb', line 11 def self.object_name "treasury.transaction" end |