Class: Stripe::Treasury::TransactionEntry

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/treasury/transaction_entry.rb

Overview

TransactionEntries represent individual units of money movements within a single [Transaction](stripe.com/docs/api#transactions).

Defined Under Namespace

Classes: BalanceImpact, FlowDetails, ListParams, RetrieveParams

Constant Summary collapse

OBJECT_NAME =
"treasury.transaction_entry"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balance_impactObject (readonly)

Change to a FinancialAccount’s balance



170
171
172
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 170

def balance_impact
  @balance_impact
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



173
174
175
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 173

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



176
177
178
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 176

def currency
  @currency
end

#effective_atObject (readonly)

When the TransactionEntry will impact the FinancialAccount’s balance.



179
180
181
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 179

def effective_at
  @effective_at
end

#financial_accountObject (readonly)

The FinancialAccount associated with this object.



182
183
184
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 182

def 
  @financial_account
end

#flowObject (readonly)

Token of the flow associated with the TransactionEntry.



185
186
187
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 185

def flow
  @flow
end

#flow_detailsObject (readonly)

Details of the flow associated with the TransactionEntry.



188
189
190
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 188

def flow_details
  @flow_details
end

#flow_typeObject (readonly)

Type of the flow associated with the TransactionEntry.



191
192
193
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 191

def flow_type
  @flow_type
end

#idObject (readonly)

Unique identifier for the object.



194
195
196
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 194

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



197
198
199
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 197

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



200
201
202
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 200

def object
  @object
end

#transactionObject (readonly)

The Transaction associated with this object.



203
204
205
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 203

def transaction
  @transaction
end

#typeObject (readonly)

The specific money movement that generated the TransactionEntry.



206
207
208
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 206

def type
  @type
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Retrieves a list of TransactionEntry objects.



209
210
211
212
213
214
215
216
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 209

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/treasury/transaction_entries",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 11

def self.object_name
  "treasury.transaction_entry"
end

.resource_urlObject



218
219
220
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 218

def self.resource_url
  "/v1/treasury/transaction_entries"
end