Class: Stripe::Treasury::TransactionEntry::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Treasury::TransactionEntry::ListParams
- Defined in:
- lib/stripe/resources/treasury/transaction_entry.rb
Defined Under Namespace
Classes: Created, EffectiveAt
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return TransactionEntries that were created during the given date interval.
-
#effective_at ⇒ Object
Attribute for param field effective_at.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
Returns objects associated with this FinancialAccount.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#order_by ⇒ Object
The results are in reverse chronological order by ‘created` or `effective_at`.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#transaction ⇒ Object
Only return TransactionEntries associated with this Transaction.
Instance Method Summary collapse
-
#initialize(created: nil, effective_at: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, transaction: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, effective_at: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, transaction: nil) ⇒ ListParams
Returns a new instance of ListParams.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 114 def initialize( created: nil, effective_at: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, transaction: nil ) @created = created @effective_at = effective_at @ending_before = ending_before @expand = @financial_account = financial_account @limit = limit @order_by = order_by @starting_after = starting_after @transaction = transaction end |
Instance Attribute Details
#created ⇒ Object
Only return TransactionEntries that were created during the given date interval.
96 97 98 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 96 def created @created end |
#effective_at ⇒ Object
Attribute for param field effective_at
98 99 100 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 98 def effective_at @effective_at end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
100 101 102 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 100 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
102 103 104 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 102 def @expand end |
#financial_account ⇒ Object
Returns objects associated with this FinancialAccount.
104 105 106 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 104 def financial_account @financial_account end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
106 107 108 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 106 def limit @limit end |
#order_by ⇒ Object
The results are in reverse chronological order by ‘created` or `effective_at`. The default is `created`.
108 109 110 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 108 def order_by @order_by end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
110 111 112 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 110 def starting_after @starting_after end |
#transaction ⇒ Object
Only return TransactionEntries associated with this Transaction.
112 113 114 |
# File 'lib/stripe/resources/treasury/transaction_entry.rb', line 112 def transaction @transaction end |