Class: Stripe::Treasury::TransactionEntryService::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/treasury/transaction_entry_service.rb

Defined Under Namespace

Classes: Created, EffectiveAt

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, effective_at: nil, ending_before: nil, expand: nil, financial_account: nil, limit: nil, order_by: nil, starting_after: nil, transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 76

def initialize(
  created: nil,
  effective_at: nil,
  ending_before: nil,
  expand: nil,
  financial_account: nil,
  limit: nil,
  order_by: nil,
  starting_after: nil,
  transaction: nil
)
  @created = created
  @effective_at = effective_at
  @ending_before = ending_before
  @expand = expand
  @financial_account = 
  @limit = limit
  @order_by = order_by
  @starting_after = starting_after
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Only return TransactionEntries that were created during the given date interval.



50
51
52
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 50

def created
  @created
end

#effective_atObject

Attribute for param field effective_at



53
54
55
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 53

def effective_at
  @effective_at
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



56
57
58
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 56

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



59
60
61
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 59

def expand
  @expand
end

#financial_accountObject

Returns objects associated with this FinancialAccount.



62
63
64
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 62

def 
  @financial_account
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



65
66
67
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 65

def limit
  @limit
end

#order_byObject

The results are in reverse chronological order by ‘created` or `effective_at`. The default is `created`.



68
69
70
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 68

def order_by
  @order_by
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



71
72
73
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 71

def starting_after
  @starting_after
end

#transactionObject

Only return TransactionEntries associated with this Transaction.



74
75
76
# File 'lib/stripe/services/treasury/transaction_entry_service.rb', line 74

def transaction
  @transaction
end