Class: Stripe::V2::Billing::BillSetting
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::BillSetting
- Defined in:
- lib/stripe/resources/v2/billing/bill_setting.rb
Overview
BillSetting is responsible for settings which dictate generating bills, which include settings for calculating totals on bills, tax on bill items, as well as how to generate and present invoices.
Defined Under Namespace
Classes: Calculation, Invoice
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.bill_setting"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#calculation ⇒ Object
readonly
Settings related to calculating a bill.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#display_name ⇒ Object
readonly
An optional field for adding a display name for the BillSetting object.
-
#id ⇒ Object
readonly
The ID of the BillSetting object.
-
#invoice ⇒ Object
readonly
Settings related to invoice behavior.
-
#invoice_rendering_template ⇒ Object
readonly
The ID of the invoice rendering template to be used when generating invoices.
-
#latest_version ⇒ Object
readonly
The latest version of the current settings object.
-
#live_version ⇒ Object
readonly
The current live version of the settings object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
A lookup key used to retrieve settings dynamically from a static string.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#calculation ⇒ Object (readonly)
Settings related to calculating a bill.
67 68 69 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 67 def calculation @calculation end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
69 70 71 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 69 def created @created end |
#display_name ⇒ Object (readonly)
An optional field for adding a display name for the BillSetting object.
71 72 73 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 71 def display_name @display_name end |
#id ⇒ Object (readonly)
The ID of the BillSetting object.
73 74 75 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 73 def id @id end |
#invoice ⇒ Object (readonly)
Settings related to invoice behavior.
75 76 77 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 75 def invoice @invoice end |
#invoice_rendering_template ⇒ Object (readonly)
The ID of the invoice rendering template to be used when generating invoices.
77 78 79 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 77 def invoice_rendering_template @invoice_rendering_template end |
#latest_version ⇒ Object (readonly)
The latest version of the current settings object. This will be Updated every time an attribute of the settings is updated.
80 81 82 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 80 def latest_version @latest_version end |
#live_version ⇒ Object (readonly)
The current live version of the settings object. This can be different from latest_version if settings are updated without setting live_version=‘latest’.
83 84 85 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 83 def live_version @live_version end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
85 86 87 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 85 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
88 89 90 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 88 def lookup_key @lookup_key end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
90 91 92 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 90 def object @object end |
Class Method Details
.field_remappings ⇒ Object
96 97 98 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 96 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 92 def self.inner_class_types @inner_class_types = { calculation: Calculation, invoice: Invoice } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/bill_setting.rb', line 10 def self.object_name "v2.billing.bill_setting" end |