Class: Stripe::V2::Billing::BillSettingCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingCreateParams
- Defined in:
- lib/stripe/params/v2/billing/bill_setting_create_params.rb
Defined Under Namespace
Classes: Calculation, Invoice
Instance Attribute Summary collapse
-
#calculation ⇒ Object
Settings related to calculating a bill.
-
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object.
-
#invoice ⇒ Object
Settings related to invoice behavior.
-
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
Instance Method Summary collapse
-
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, lookup_key: nil) ⇒ BillSettingCreateParams
constructor
A new instance of BillSettingCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, lookup_key: nil) ⇒ BillSettingCreateParams
Returns a new instance of BillSettingCreateParams.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 58 def initialize( calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, lookup_key: nil ) @calculation = calculation @display_name = display_name @invoice = invoice @invoice_rendering_template = invoice_rendering_template @lookup_key = lookup_key end |
Instance Attribute Details
#calculation ⇒ Object
Settings related to calculating a bill.
46 47 48 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 46 def calculation @calculation end |
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object. Maximum length of 250 characters.
49 50 51 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 49 def display_name @display_name end |
#invoice ⇒ Object
Settings related to invoice behavior.
51 52 53 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 51 def invoice @invoice end |
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
53 54 55 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 53 def invoice_rendering_template @invoice_rendering_template end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
56 57 58 |
# File 'lib/stripe/params/v2/billing/bill_setting_create_params.rb', line 56 def lookup_key @lookup_key end |