Class: Stripe::V2::Billing::BillSettingService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/bill_setting_service.rb
Defined Under Namespace
Classes: Calculation, Invoice
Instance Attribute Summary collapse
-
#calculation ⇒ Object
Settings related to calculating a bill.
-
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object.
-
#invoice ⇒ Object
Settings related to invoice behavior.
-
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
Instance Method Summary collapse
-
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, lookup_key: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, lookup_key: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 79 def initialize( calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, lookup_key: nil ) @calculation = calculation @display_name = display_name @invoice = invoice @invoice_rendering_template = invoice_rendering_template @lookup_key = lookup_key end |
Instance Attribute Details
#calculation ⇒ Object
Settings related to calculating a bill.
67 68 69 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 67 def calculation @calculation end |
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object. Maximum length of 250 characters.
70 71 72 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 70 def display_name @display_name end |
#invoice ⇒ Object
Settings related to invoice behavior.
72 73 74 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 72 def invoice @invoice end |
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
74 75 76 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 74 def invoice_rendering_template @invoice_rendering_template end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
77 78 79 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 77 def lookup_key @lookup_key end |