Class: Stripe::V2::Billing::BillSettingService::CreateParams::Calculation::Tax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingService::CreateParams::Calculation::Tax
- Defined in:
- lib/stripe/services/v2/billing/bill_setting_service.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Determines if tax will be calculated automatically based on a PTC or manually based on rules defined by the merchant.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Tax
constructor
A new instance of Tax.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ Tax
Returns a new instance of Tax.
34 35 36 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 34 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Determines if tax will be calculated automatically based on a PTC or manually based on rules defined by the merchant. Defaults to “manual”.
32 33 34 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 32 def type @type end |