Class: Stripe::V2::Billing::BillSettingService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingService::UpdateParams
- Defined in:
- lib/stripe/services/v2/billing/bill_setting_service.rb
Defined Under Namespace
Classes: Calculation, Invoice
Instance Attribute Summary collapse
-
#calculation ⇒ Object
Settings related to calculating a bill.
-
#display_name ⇒ Object
An optional customer-facing display name for the BillSetting object.
-
#invoice ⇒ Object
Settings related to invoice behavior.
-
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
-
#live_version ⇒ Object
Optionally change the live version of the BillSetting.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
Instance Method Summary collapse
-
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 151 def initialize( calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil ) @calculation = calculation @display_name = display_name @invoice = invoice @invoice_rendering_template = invoice_rendering_template @live_version = live_version @lookup_key = lookup_key end |
Instance Attribute Details
#calculation ⇒ Object
Settings related to calculating a bill.
135 136 137 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 135 def calculation @calculation end |
#display_name ⇒ Object
An optional customer-facing display name for the BillSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.
139 140 141 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 139 def display_name @display_name end |
#invoice ⇒ Object
Settings related to invoice behavior.
141 142 143 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 141 def invoice @invoice end |
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
143 144 145 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 143 def invoice_rendering_template @invoice_rendering_template end |
#live_version ⇒ Object
Optionally change the live version of the BillSetting. Providing ‘live_version = “latest”` will set the BillSetting’ ‘live_version` to its latest version.
146 147 148 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 146 def live_version @live_version end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
149 150 151 |
# File 'lib/stripe/services/v2/billing/bill_setting_service.rb', line 149 def lookup_key @lookup_key end |