Class: Stripe::V2::Billing::BillSettingUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::BillSettingUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/bill_setting_update_params.rb
Defined Under Namespace
Classes: Calculation, Invoice
Instance Attribute Summary collapse
-
#calculation ⇒ Object
Settings related to calculating a bill.
-
#display_name ⇒ Object
An optional customer-facing display name for the BillSetting object.
-
#invoice ⇒ Object
Settings related to invoice behavior.
-
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
-
#live_version ⇒ Object
Optionally change the live version of the BillSetting.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
Instance Method Summary collapse
-
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil) ⇒ BillSettingUpdateParams
constructor
A new instance of BillSettingUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil) ⇒ BillSettingUpdateParams
Returns a new instance of BillSettingUpdateParams.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 62 def initialize( calculation: nil, display_name: nil, invoice: nil, invoice_rendering_template: nil, live_version: nil, lookup_key: nil ) @calculation = calculation @display_name = display_name @invoice = invoice @invoice_rendering_template = invoice_rendering_template @live_version = live_version @lookup_key = lookup_key end |
Instance Attribute Details
#calculation ⇒ Object
Settings related to calculating a bill.
46 47 48 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 46 def calculation @calculation end |
#display_name ⇒ Object
An optional customer-facing display name for the BillSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.
50 51 52 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 50 def display_name @display_name end |
#invoice ⇒ Object
Settings related to invoice behavior.
52 53 54 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 52 def invoice @invoice end |
#invoice_rendering_template ⇒ Object
The ID of the invoice rendering template to be used when generating invoices.
54 55 56 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 54 def invoice_rendering_template @invoice_rendering_template end |
#live_version ⇒ Object
Optionally change the live version of the BillSetting. Providing ‘live_version = “latest”` will set the BillSetting’ ‘live_version` to its latest version.
57 58 59 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 57 def live_version @live_version end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
60 61 62 |
# File 'lib/stripe/params/v2/billing/bill_setting_update_params.rb', line 60 def lookup_key @lookup_key end |