Class: Stripe::V2::Billing::BillSettingVersion

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/bill_setting_version.rb

Defined Under Namespace

Classes: Calculation, Invoice

Constant Summary collapse

OBJECT_NAME =
"v2.billing.bill_setting_version"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#calculationObject (readonly)

Settings related to calculating a bill.



34
35
36
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 34

def calculation
  @calculation
end

#createdObject (readonly)

Timestamp of when the object was created.



36
37
38
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 36

def created
  @created
end

#idObject (readonly)

The ID of the BillSettingVersion object.



38
39
40
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 38

def id
  @id
end

#invoiceObject (readonly)

Settings related to invoice behavior.



40
41
42
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 40

def invoice
  @invoice
end

#invoice_rendering_templateObject (readonly)

The ID of the invoice rendering template to be used when generating invoices.



42
43
44
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 42

def invoice_rendering_template
  @invoice_rendering_template
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



46
47
48
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 46

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



44
45
46
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 44

def object
  @object
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 9

def self.object_name
  "v2.billing.bill_setting_version"
end