Class: Stripe::V2::Billing::BillSettingVersion

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/bill_setting_version.rb

Defined Under Namespace

Classes: Calculation, Invoice

Constant Summary collapse

OBJECT_NAME =
"v2.billing.bill_setting_version"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#calculationObject (readonly)

Settings related to calculating a bill.



66
67
68
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 66

def calculation
  @calculation
end

#createdObject (readonly)

Timestamp of when the object was created.



68
69
70
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 68

def created
  @created
end

#idObject (readonly)

The ID of the BillSettingVersion object.



70
71
72
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 70

def id
  @id
end

#invoiceObject (readonly)

Settings related to invoice behavior.



72
73
74
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 72

def invoice
  @invoice
end

#invoice_rendering_templateObject (readonly)

The ID of the invoice rendering template to be used when generating invoices.



74
75
76
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 74

def invoice_rendering_template
  @invoice_rendering_template
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



78
79
80
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 78

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



76
77
78
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 76

def object
  @object
end

Class Method Details

.field_remappingsObject



84
85
86
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 84

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



80
81
82
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 80

def self.inner_class_types
  @inner_class_types = { calculation: Calculation, invoice: Invoice }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/bill_setting_version.rb', line 9

def self.object_name
  "v2.billing.bill_setting_version"
end