Class: Stripe::V2::Billing::Cadence

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Overview

A Cadence represents a billing schedule applied to a customer, defining when and how often to generate invoices, such as on monthly or annual billing cycle.

Defined Under Namespace

Classes: BillingCycle, InvoiceDiscountRule, Payer, Settings, SettingsData

Constant Summary collapse

OBJECT_NAME =
"v2.billing.cadence"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycleObject (readonly)

The billing cycle is the object that defines future billing cycle dates.



612
613
614
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 612

def billing_cycle
  @billing_cycle
end

#createdObject (readonly)

Timestamp of when the object was created.



614
615
616
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 614

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



616
617
618
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 616

def id
  @id
end

#invoice_discount_rulesObject (readonly)

The discount rules applied to all invoices for the cadence.



618
619
620
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 618

def invoice_discount_rules
  @invoice_discount_rules
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



638
639
640
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 638

def livemode
  @livemode
end

#lookup_keyObject (readonly)

A lookup key used to retrieve cadences dynamically from a static string. Maximum length of 200 characters.



620
621
622
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 620

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



622
623
624
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 622

def 
  @metadata
end

#next_billing_dateObject (readonly)

The date that the billing cadence will next bill. Null if the cadence is not active.



624
625
626
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 624

def next_billing_date
  @next_billing_date
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



626
627
628
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 626

def object
  @object
end

#payerObject (readonly)

The payer determines the entity financially responsible for the bill.



628
629
630
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 628

def payer
  @payer
end

#settingsObject (readonly)

The settings associated with the cadence.



630
631
632
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 630

def settings
  @settings
end

#settings_dataObject (readonly)

Settings data that contains expanded billing settings configuration with actual values.



632
633
634
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 632

def settings_data
  @settings_data
end

#statusObject (readonly)

The current status of the cadence.



634
635
636
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 634

def status
  @status
end

#test_clockObject (readonly)

The ID of the Test Clock.



636
637
638
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 636

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



650
651
652
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 650

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



640
641
642
643
644
645
646
647
648
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 640

def self.inner_class_types
  @inner_class_types = {
    billing_cycle: BillingCycle,
    invoice_discount_rules: InvoiceDiscountRule,
    payer: Payer,
    settings: Settings,
    settings_data: SettingsData,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 10

def self.object_name
  "v2.billing.cadence"
end