Class: Stripe::V2::Billing::Cadence

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: BillingCycle, Payer, Settings, SettingsData

Constant Summary collapse

OBJECT_NAME =
"v2.billing.cadence"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycleObject (readonly)

The billing cycle is the object that defines future billing cycle dates.



568
569
570
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 568

def billing_cycle
  @billing_cycle
end

#createdObject (readonly)

Timestamp of when the object was created.



570
571
572
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 570

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



572
573
574
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 572

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



592
593
594
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 592

def livemode
  @livemode
end

#lookup_keyObject (readonly)

A lookup key used to retrieve cadences dynamically from a static string. Maximum length of 200 characters.



574
575
576
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 574

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



576
577
578
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 576

def 
  @metadata
end

#next_billing_dateObject (readonly)

The date that the billing cadence will next bill. Null if the cadence is not active.



578
579
580
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 578

def next_billing_date
  @next_billing_date
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



580
581
582
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 580

def object
  @object
end

#payerObject (readonly)

The payer determines the entity financially responsible for the bill.



582
583
584
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 582

def payer
  @payer
end

#settingsObject (readonly)

The settings associated with the cadence.



584
585
586
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 584

def settings
  @settings
end

#settings_dataObject (readonly)

Settings data that contains expanded billing settings configuration with actual values.



586
587
588
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 586

def settings_data
  @settings_data
end

#statusObject (readonly)

The current status of the cadence.



588
589
590
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 588

def status
  @status
end

#test_clockObject (readonly)

The ID of the Test Clock.



590
591
592
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 590

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



603
604
605
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 603

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



594
595
596
597
598
599
600
601
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 594

def self.inner_class_types
  @inner_class_types = {
    billing_cycle: BillingCycle,
    payer: Payer,
    settings: Settings,
    settings_data: SettingsData,
  }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 9

def self.object_name
  "v2.billing.cadence"
end