Class: Stripe::V2::Billing::Cadence

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: BillingCycle, InvoiceDiscountRule, Payer, Settings

Constant Summary collapse

OBJECT_NAME =
"v2.billing.cadence"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cycleObject (readonly)

The billing cycle is the object that defines future billing cycle dates.



156
157
158
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 156

def billing_cycle
  @billing_cycle
end

#createdObject (readonly)

Timestamp of when the object was created.



158
159
160
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 158

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



160
161
162
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 160

def id
  @id
end

#invoice_discount_rulesObject (readonly)

The discount rules applied to all invoices for the cadence.



162
163
164
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 162

def invoice_discount_rules
  @invoice_discount_rules
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



178
179
180
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 178

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



164
165
166
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 164

def 
  @metadata
end

#next_billing_dateObject (readonly)

The date that the billing cadence will next bill. Null if the cadence is not active.



166
167
168
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 166

def next_billing_date
  @next_billing_date
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



168
169
170
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 168

def object
  @object
end

#payerObject (readonly)

The payer determines the entity financially responsible for the bill.



170
171
172
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 170

def payer
  @payer
end

#settingsObject (readonly)

The settings associated with the cadence.



172
173
174
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 172

def settings
  @settings
end

#statusObject (readonly)

The current status of the cadence.



174
175
176
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 174

def status
  @status
end

#test_clockObject (readonly)

The ID of the Test Clock.



176
177
178
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 176

def test_clock
  @test_clock
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 9

def self.object_name
  "v2.billing.cadence"
end