Class: Stripe::V2::Billing::Cadence
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::Cadence
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: BillingCycle, InvoiceDiscountRule, Payer, Settings
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.cadence"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cycle ⇒ Object
readonly
The billing cycle is the object that defines future billing cycle dates.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice_discount_rules ⇒ Object
readonly
The discount rules applied to all invoices for the cadence.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#next_billing_date ⇒ Object
readonly
The date that the billing cadence will next bill.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payer ⇒ Object
readonly
The payer determines the entity financially responsible for the bill.
-
#settings ⇒ Object
readonly
The settings associated with the cadence.
-
#status ⇒ Object
readonly
The current status of the cadence.
-
#test_clock ⇒ Object
readonly
The ID of the Test Clock.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cycle ⇒ Object (readonly)
The billing cycle is the object that defines future billing cycle dates.
287 288 289 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 287 def billing_cycle @billing_cycle end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
289 290 291 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 289 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
291 292 293 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 291 def id @id end |
#invoice_discount_rules ⇒ Object (readonly)
The discount rules applied to all invoices for the cadence.
293 294 295 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 293 def invoice_discount_rules @invoice_discount_rules end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
309 310 311 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 309 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
295 296 297 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 295 def @metadata end |
#next_billing_date ⇒ Object (readonly)
The date that the billing cadence will next bill. Null if the cadence is not active.
297 298 299 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 297 def next_billing_date @next_billing_date end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
299 300 301 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 299 def object @object end |
#payer ⇒ Object (readonly)
The payer determines the entity financially responsible for the bill.
301 302 303 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 301 def payer @payer end |
#settings ⇒ Object (readonly)
The settings associated with the cadence.
303 304 305 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 303 def settings @settings end |
#status ⇒ Object (readonly)
The current status of the cadence.
305 306 307 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 305 def status @status end |
#test_clock ⇒ Object (readonly)
The ID of the Test Clock.
307 308 309 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 307 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
320 321 322 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 320 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
311 312 313 314 315 316 317 318 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 311 def self.inner_class_types @inner_class_types = { billing_cycle: BillingCycle, invoice_discount_rules: InvoiceDiscountRule, payer: Payer, settings: Settings, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 9 def self.object_name "v2.billing.cadence" end |