Class: Stripe::V2::Billing::Cadence::BillingCycle::Month
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::BillingCycle::Month
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: Time
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
readonly
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
readonly
The month to anchor the billing on for a type=“month” billing cycle from 1-12.
-
#time ⇒ Object
readonly
The time at which the billing cycle ends.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#day_of_month ⇒ Object (readonly)
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month.
72 73 74 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 72 def day_of_month @day_of_month end |
#month_of_year ⇒ Object (readonly)
The month to anchor the billing on for a type=“month” billing cycle from 1-12. Occurrences are calculated from the month anchor.
75 76 77 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 75 def month_of_year @month_of_year end |
#time ⇒ Object (readonly)
The time at which the billing cycle ends.
77 78 79 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 77 def time @time end |
Class Method Details
.field_remappings ⇒ Object
83 84 85 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 83 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
79 80 81 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 79 def self.inner_class_types @inner_class_types = { time: Time } end |