Class: Stripe::V2::Billing::Cadence::BillingCycle::Month
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::BillingCycle::Month
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: Time
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
readonly
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#time ⇒ Object
readonly
The time at which the billing cycle ends.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#day_of_month ⇒ Object (readonly)
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month.
47 48 49 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 47 def day_of_month @day_of_month end |
#time ⇒ Object (readonly)
The time at which the billing cycle ends.
49 50 51 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 49 def time @time end |