Class: Stripe::V2::Billing::Cadence::BillingCycle::Year

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: Time

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#day_of_monthObject (readonly)

The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month.



88
89
90
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 88

def day_of_month
  @day_of_month
end

#month_of_yearObject (readonly)

The month to bill on from 1-12. If not provided, this will default to the month the cadence was created.



90
91
92
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 90

def month_of_year
  @month_of_year
end

#timeObject (readonly)

The time at which the billing cycle ends.



92
93
94
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 92

def time
  @time
end