Class: Stripe::V2::Billing::Cadence::Settings
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::Settings
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: Bill, Collection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill ⇒ Object
readonly
Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices.
-
#collection ⇒ Object
readonly
Settings that configure and manage the behavior of collecting payments.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill ⇒ Object (readonly)
Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices.
151 152 153 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 151 def bill @bill end |
#collection ⇒ Object (readonly)
Settings that configure and manage the behavior of collecting payments.
153 154 155 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 153 def collection @collection end |