Class: Stripe::V2::Billing::Cadence::SettingsData::Collection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::SettingsData::Collection
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
readonly
Either automatic, or send_invoice.
-
#email_delivery ⇒ Object
readonly
Email delivery settings.
-
#payment_method_configuration ⇒ Object
readonly
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
readonly
Payment Method specific configuration stored on the object.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_method ⇒ Object (readonly)
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.
555 556 557 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 555 def collection_method @collection_method end |
#email_delivery ⇒ Object (readonly)
Email delivery settings.
557 558 559 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 557 def email_delivery @email_delivery end |
#payment_method_configuration ⇒ Object (readonly)
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
559 560 561 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 559 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object (readonly)
Payment Method specific configuration stored on the object.
561 562 563 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 561 def @payment_method_options end |
Class Method Details
.field_encodings ⇒ Object
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 574 def self.field_encodings @field_encodings = { payment_method_options: { kind: :object, fields: { card: { kind: :object, fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } }, }, }, }, } end |
.field_remappings ⇒ Object
570 571 572 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 570 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
563 564 565 566 567 568 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 563 def self.inner_class_types @inner_class_types = { email_delivery: EmailDelivery, payment_method_options: PaymentMethodOptions, } end |