Class: Stripe::V2::Billing::Cadence::SettingsData::Collection

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#collection_methodObject (readonly)

Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.



630
631
632
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 630

def collection_method
  @collection_method
end

#email_deliveryObject (readonly)

Email delivery settings.



632
633
634
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 632

def email_delivery
  @email_delivery
end

#payment_method_configurationObject (readonly)

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



634
635
636
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 634

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject (readonly)

Payment Method specific configuration stored on the object.



636
637
638
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 636

def payment_method_options
  @payment_method_options
end

Class Method Details

.field_encodingsObject



649
650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 649

def self.field_encodings
  @field_encodings = {
    payment_method_options: {
      kind: :object,
      fields: {
        card: {
          kind: :object,
          fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
        },
      },
    },
  }
end

.field_remappingsObject



645
646
647
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 645

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



638
639
640
641
642
643
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 638

def self.inner_class_types
  @inner_class_types = {
    email_delivery: EmailDelivery,
    payment_method_options: PaymentMethodOptions,
  }
end