Class: Stripe::V2::Billing::Cadence::SettingsData::Collection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::Cadence::SettingsData::Collection
- Defined in:
- lib/stripe/resources/v2/billing/cadence.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
readonly
Either automatic, or send_invoice.
-
#email_delivery ⇒ Object
readonly
Email delivery settings.
-
#payment_method_configuration ⇒ Object
readonly
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
readonly
Payment Method specific configuration stored on the object.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_method ⇒ Object (readonly)
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.
579 580 581 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 579 def collection_method @collection_method end |
#email_delivery ⇒ Object (readonly)
Email delivery settings.
581 582 583 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 581 def email_delivery @email_delivery end |
#payment_method_configuration ⇒ Object (readonly)
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
583 584 585 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 583 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object (readonly)
Payment Method specific configuration stored on the object.
585 586 587 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 585 def @payment_method_options end |
Class Method Details
.field_remappings ⇒ Object
594 595 596 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 594 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
587 588 589 590 591 592 |
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 587 def self.inner_class_types @inner_class_types = { email_delivery: EmailDelivery, payment_method_options: PaymentMethodOptions, } end |