Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::EmailDelivery::PaymentDue

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#enabledObject (readonly)

If true an email for the invoice would be generated and sent out.



319
320
321
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 319

def enabled
  @enabled
end

If true the payment link to hosted invoice page would be included in email and PDF of the invoice.



321
322
323
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 321

def include_payment_link
  @include_payment_link
end

Class Method Details

.field_remappingsObject



327
328
329
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 327

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



323
324
325
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 323

def self.inner_class_types
  @inner_class_types = {}
end