Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

This sub-hash contains details about the Canadian pre-authorized debit payment method options.



546
547
548
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 546

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

This sub-hash contains details about the Bancontact payment method.



548
549
550
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 548

def bancontact
  @bancontact
end

#cardObject (readonly)

This sub-hash contains details about the Card payment method options.



550
551
552
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 550

def card
  @card
end

#customer_balanceObject (readonly)

This sub-hash contains details about the Bank transfer payment method options.



552
553
554
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 552

def customer_balance
  @customer_balance
end

#konbiniObject (readonly)

This sub-hash contains details about the Konbini payment method options.



554
555
556
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 554

def konbini
  @konbini
end

#sepa_debitObject (readonly)

This sub-hash contains details about the SEPA Direct Debit payment method options.



556
557
558
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 556

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject (readonly)

This sub-hash contains details about the ACH direct debit payment method options.



558
559
560
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 558

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



570
571
572
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 570

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



560
561
562
563
564
565
566
567
568
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 560

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    card: Card,
    customer_balance: CustomerBalance,
    us_bank_account: UsBankAccount,
  }
end