Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#mandate_optionsObject (readonly)

Configuration options for setting up an eMandate for cards issued in India.



406
407
408
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 406

def mandate_options
  @mandate_options
end

#networkObject (readonly)

Selected network to process the payment on. Depends on the available networks of the card.



408
409
410
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 408

def network
  @network
end

#request_three_d_secureObject (readonly)

An advanced option 3D Secure. We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.



413
414
415
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 413

def request_three_d_secure
  @request_three_d_secure
end

Class Method Details

.field_encodingsObject



423
424
425
426
427
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 423

def self.field_encodings
  @field_encodings = {
    mandate_options: { kind: :object, fields: { amount: :int64_string } },
  }
end

.field_remappingsObject



419
420
421
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 419

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



415
416
417
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 415

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end