Class: Stripe::V2::Billing::Cadence::SettingsData::Collection::PaymentMethodOptions::CustomerBalance

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/cadence.rb

Defined Under Namespace

Classes: BankTransfer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_transferObject (readonly)

Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.



458
459
460
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 458

def bank_transfer
  @bank_transfer
end

#funding_typeObject (readonly)

The funding method type to be used when there are not enough funds in the customer balance. Currently the only supported value is ‘bank_transfer`.



460
461
462
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 460

def funding_type
  @funding_type
end

Class Method Details

.field_remappingsObject



466
467
468
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 466

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



462
463
464
# File 'lib/stripe/resources/v2/billing/cadence.rb', line 462

def self.inner_class_types
  @inner_class_types = { bank_transfer: BankTransfer }
end