Class: Stripe::V2::Billing::CadenceCreateParams::BillingCycle::Day
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceCreateParams::BillingCycle::Day
- Defined in:
- lib/stripe/params/v2/billing/cadence_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(time: nil) ⇒ Day
constructor
A new instance of Day.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(time: nil) ⇒ Day
Returns a new instance of Day.
33 34 35 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 33 def initialize(time: nil) @time = time end |
Instance Attribute Details
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
31 32 33 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 31 def time @time end |