Class: Stripe::V2::Billing::CadenceCreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceCreateParams::Settings
- Defined in:
- lib/stripe/params/v2/billing/cadence_create_params.rb
Defined Under Namespace
Classes: Bill, Collection
Instance Attribute Summary collapse
-
#bill ⇒ Object
Settings that configure bill generation, which includes calculating totals, tax, and presenting invoices.
-
#collection ⇒ Object
Settings that configure and manage the behavior of collecting payments.
Instance Method Summary collapse
-
#initialize(bill: nil, collection: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill: nil, collection: nil) ⇒ Settings
Returns a new instance of Settings.
221 222 223 224 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 221 def initialize(bill: nil, collection: nil) @bill = bill @collection = collection end |
Instance Attribute Details
#bill ⇒ Object
Settings that configure bill generation, which includes calculating totals, tax, and presenting invoices. If no setting is provided here, the settings from the customer referenced on the payer will be used. If no customer settings are present, the merchant default settings will be used.
215 216 217 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 215 def bill @bill end |
#collection ⇒ Object
Settings that configure and manage the behavior of collecting payments. If no setting is provided here, the settings from the customer referenced from the payer will be used if they exist. If no customer settings are present, the merchant default settings will be used.
219 220 221 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 219 def collection @collection end |