Class: Stripe::V2::Billing::CadenceCreateParams::Settings::Bill
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceCreateParams::Settings::Bill
- Defined in:
- lib/stripe/params/v2/billing/cadence_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of the Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Bill
constructor
A new instance of Bill.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(id: nil, version: nil) ⇒ Bill
Returns a new instance of Bill.
194 195 196 197 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 194 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
189 190 191 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 189 def id @id end |
#version ⇒ Object
An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.
192 193 194 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 192 def version @version end |