Class: Stripe::V2::Billing::CadenceCreateParams::Settings::Collection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceCreateParams::Settings::Collection
- Defined in:
- lib/stripe/params/v2/billing/cadence_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of the Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Collection
constructor
A new instance of Collection.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(id: nil, version: nil) ⇒ Collection
Returns a new instance of Collection.
207 208 209 210 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 207 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
202 203 204 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 202 def id @id end |
#version ⇒ Object
An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.
205 206 207 |
# File 'lib/stripe/params/v2/billing/cadence_create_params.rb', line 205 def version @version end |