Class: Stripe::V2::Billing::CadenceListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceListParams
- Defined in:
- lib/stripe/params/v2/billing/cadence_list_params.rb
Defined Under Namespace
Classes: Payer
Instance Attribute Summary collapse
-
#include ⇒ Object
Additional resource to include in the response.
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Only return the cadences with these lookup_keys, if any exist.
-
#payer ⇒ Object
If provided, only cadences that specifically reference the payer will be returned.
-
#test_clock ⇒ Object
If provided, only cadences that specifically reference the provided test clock ID (via the customer’s test clock) will be returned.
Instance Method Summary collapse
-
#initialize(include: nil, limit: nil, lookup_keys: nil, payer: nil, test_clock: nil) ⇒ CadenceListParams
constructor
A new instance of CadenceListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(include: nil, limit: nil, lookup_keys: nil, payer: nil, test_clock: nil) ⇒ CadenceListParams
Returns a new instance of CadenceListParams.
33 34 35 36 37 38 39 |
# File 'lib/stripe/params/v2/billing/cadence_list_params.rb', line 33 def initialize(include: nil, limit: nil, lookup_keys: nil, payer: nil, test_clock: nil) @include = include @limit = limit @lookup_keys = lookup_keys @payer = payer @test_clock = test_clock end |
Instance Attribute Details
#include ⇒ Object
Additional resource to include in the response.
20 21 22 |
# File 'lib/stripe/params/v2/billing/cadence_list_params.rb', line 20 def include @include end |
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
22 23 24 |
# File 'lib/stripe/params/v2/billing/cadence_list_params.rb', line 22 def limit @limit end |
#lookup_keys ⇒ Object
Only return the cadences with these lookup_keys, if any exist. You can specify up to 10 lookup_keys. Mutually exclusive with ‘test_clock` and `payer`.
25 26 27 |
# File 'lib/stripe/params/v2/billing/cadence_list_params.rb', line 25 def lookup_keys @lookup_keys end |
#payer ⇒ Object
If provided, only cadences that specifically reference the payer will be returned. Mutually exclusive with ‘test_clock` and `lookup_keys`.
27 28 29 |
# File 'lib/stripe/params/v2/billing/cadence_list_params.rb', line 27 def payer @payer end |
#test_clock ⇒ Object
If provided, only cadences that specifically reference the provided test clock ID (via the customer’s test clock) will be returned. Mutually exclusive with ‘payer`.
31 32 33 |
# File 'lib/stripe/params/v2/billing/cadence_list_params.rb', line 31 def test_clock @test_clock end |