Class: Stripe::V2::Billing::CadenceService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Defined Under Namespace
Classes: BillingCycle, Payer, Settings
Instance Attribute Summary collapse
-
#billing_cycle ⇒ Object
The billing cycle is the object that defines future billing cycle dates.
-
#include ⇒ Object
Additional resource to include in the response.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#payer ⇒ Object
The payer determines the entity financially responsible for the bill.
-
#settings ⇒ Object
The settings associated with the cadence.
Instance Method Summary collapse
-
#initialize(billing_cycle: nil, include: nil, metadata: nil, payer: nil, settings: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_cycle: nil, include: nil, metadata: nil, payer: nil, settings: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
283 284 285 286 287 288 289 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 283 def initialize(billing_cycle: nil, include: nil, metadata: nil, payer: nil, settings: nil) @billing_cycle = billing_cycle @include = include @metadata = @payer = payer @settings = settings end |
Instance Attribute Details
#billing_cycle ⇒ Object
The billing cycle is the object that defines future billing cycle dates.
273 274 275 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 273 def billing_cycle @billing_cycle end |
#include ⇒ Object
Additional resource to include in the response.
275 276 277 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 275 def include @include end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
277 278 279 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 277 def @metadata end |
#payer ⇒ Object
The payer determines the entity financially responsible for the bill.
279 280 281 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 279 def payer @payer end |
#settings ⇒ Object
The settings associated with the cadence.
281 282 283 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 281 def settings @settings end |