Class: Stripe::V2::Billing::CadenceService::CreateParams::BillingCycle::Month
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::CreateParams::BillingCycle::Month
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
The month to anchor the billing on for a type=“month” billing cycle from 1-12.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Month
constructor
A new instance of Month.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Month
Returns a new instance of Month.
104 105 106 107 108 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 104 def initialize(day_of_month: nil, month_of_year: nil, time: nil) @day_of_month = day_of_month @month_of_year = month_of_year @time = time end |
Instance Attribute Details
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month. If not provided, this will default to the day the cadence was created.
93 94 95 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 93 def day_of_month @day_of_month end |
#month_of_year ⇒ Object
The month to anchor the billing on for a type=“month” billing cycle from 1-12. If not provided, this will default to the month the cadence was created. This setting can only be used for monthly billing cycles with ‘interval_count` of 2, 3, 4 or 6. All occurrences will be calculated from month provided.
98 99 100 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 98 def month_of_year @month_of_year end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
102 103 104 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 102 def time @time end |