Class: Stripe::V2::Billing::CadenceService::CreateParams::Payer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::CreateParams::Payer
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Instance Attribute Summary collapse
-
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill will be paid.
-
#customer ⇒ Object
The ID of the Customer object.
-
#type ⇒ Object
A string identifying the type of the payer.
Instance Method Summary collapse
-
#initialize(billing_profile: nil, customer: nil, type: nil) ⇒ Payer
constructor
A new instance of Payer.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_profile: nil, customer: nil, type: nil) ⇒ Payer
Returns a new instance of Payer.
225 226 227 228 229 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 225 def initialize(billing_profile: nil, customer: nil, type: nil) @billing_profile = billing_profile @customer = customer @type = type end |
Instance Attribute Details
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill will be paid. If provided, the created cadence will be associated with the provided Billing Profile. If not provided, a new Billing Profile will be created and associated with the cadence.
219 220 221 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 219 def billing_profile @billing_profile end |
#customer ⇒ Object
The ID of the Customer object.
221 222 223 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 221 def customer @customer end |
#type ⇒ Object
A string identifying the type of the payer. Currently the only supported value is ‘customer`.
223 224 225 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 223 def type @type end |