Class: Stripe::V2::Billing::CadenceService::CreateParams::Settings::Bill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Bill

Returns a new instance of Bill.



234
235
236
237
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 234

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



229
230
231
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 229

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



232
233
234
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 232

def version
  @version
end