Class: Stripe::V2::Billing::CadenceService::CreateParams::Settings::Bill
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::CreateParams::Settings::Bill
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of the Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Bill
constructor
A new instance of Bill.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, version: nil) ⇒ Bill
Returns a new instance of Bill.
240 241 242 243 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 240 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
235 236 237 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 235 def id @id end |
#version ⇒ Object
An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.
238 239 240 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 238 def version @version end |