Class: Stripe::V2::Billing::CadenceService::CreateParams::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



247
248
249
250
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 247

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



242
243
244
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 242

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



245
246
247
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 245

def version
  @version
end