Class: Stripe::V2::Billing::CadenceService::CreateParams::Settings::Collection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::CreateParams::Settings::Collection
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of the Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Collection
constructor
A new instance of Collection.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, version: nil) ⇒ Collection
Returns a new instance of Collection.
247 248 249 250 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 247 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
242 243 244 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 242 def id @id end |
#version ⇒ Object
An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.
245 246 247 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 245 def version @version end |