Class: Stripe::V2::Billing::CadenceService::UpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::UpdateParams::Settings
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Defined Under Namespace
Classes: Bill, Collection
Instance Attribute Summary collapse
-
#bill ⇒ Object
Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices.
-
#collection ⇒ Object
Settings that configure and manage the behavior of collecting payments.
Instance Method Summary collapse
-
#initialize(bill: nil, collection: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bill: nil, collection: nil) ⇒ Settings
Returns a new instance of Settings.
340 341 342 343 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 340 def initialize(bill: nil, collection: nil) @bill = bill @collection = collection end |
Instance Attribute Details
#bill ⇒ Object
Settings that configure bills generation, which includes calculating totals, tax, and presenting invoices. If null is provided, the current bill settings will be removed from the billing cadence.
336 337 338 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 336 def bill @bill end |
#collection ⇒ Object
Settings that configure and manage the behavior of collecting payments. If null is provided, the current collection settings will be removed from the billing cadence.
338 339 340 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 338 def collection @collection end |