Class: Stripe::V2::Billing::CadenceService::UpdateParams::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/billing/cadence_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



336
337
338
339
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 336

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



329
330
331
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 329

def id
  @id
end

#versionObject

An optional field to specify the version of Settings to use. If not provided, this will always default to the ‘live_version` specified on the setting, any time the settings are used. Using a specific version here will prevent the settings from updating, and is discouraged for cadences. To clear a pinned version, set the version to null.



334
335
336
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 334

def version
  @version
end