Class: Stripe::V2::Billing::CadenceService::UpdateParams::Settings::Collection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceService::UpdateParams::Settings::Collection
- Defined in:
- lib/stripe/services/v2/billing/cadence_service.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Collection
constructor
A new instance of Collection.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, version: nil) ⇒ Collection
Returns a new instance of Collection.
336 337 338 339 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 336 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
329 330 331 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 329 def id @id end |
#version ⇒ Object
An optional field to specify the version of Settings to use. If not provided, this will always default to the ‘live_version` specified on the setting, any time the settings are used. Using a specific version here will prevent the settings from updating, and is discouraged for cadences. To clear a pinned version, set the version to null.
334 335 336 |
# File 'lib/stripe/services/v2/billing/cadence_service.rb', line 334 def version @version end |