Class: Stripe::V2::Billing::CadenceSpendModifier
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::CadenceSpendModifier
- Defined in:
- lib/stripe/resources/v2/billing/cadence_spend_modifier.rb
Overview
A Spend Modifier changes how spend is computed when billing for specific cadence.
Defined Under Namespace
Classes: MaxBillingPeriodSpend
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.cadence_spend_modifier"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
readonly
The ID of the Billing Cadence this spend modifier is associated with.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#max_billing_period_spend ⇒ Object
readonly
Max invoice spend details.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#type ⇒ Object
readonly
The type of the spend modifier.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence ⇒ Object (readonly)
The ID of the Billing Cadence this spend modifier is associated with.
79 80 81 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 79 def billing_cadence @billing_cadence end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
81 82 83 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 81 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
83 84 85 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 83 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
89 90 91 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 89 def livemode @livemode end |
#max_billing_period_spend ⇒ Object (readonly)
Max invoice spend details. Present if type is ‘max_billing_period_spend`.
91 92 93 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 91 def max_billing_period_spend @max_billing_period_spend end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
85 86 87 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 85 def object @object end |
#type ⇒ Object (readonly)
The type of the spend modifier.
87 88 89 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 87 def type @type end |
Class Method Details
.field_remappings ⇒ Object
97 98 99 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 97 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
93 94 95 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 93 def self.inner_class_types @inner_class_types = { max_billing_period_spend: MaxBillingPeriodSpend } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 10 def self.object_name "v2.billing.cadence_spend_modifier" end |