Class: Stripe::V2::Billing::CadenceSpendModifier::MaxBillingPeriodSpend
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::CadenceSpendModifier::MaxBillingPeriodSpend
- Defined in:
- lib/stripe/resources/v2/billing/cadence_spend_modifier.rb
Defined Under Namespace
Classes: Amount, CustomPricingUnitOverageRate
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alert ⇒ Object
readonly
The billing alert associated with the maximum spend threshold.
-
#amount ⇒ Object
readonly
The maximum amount of invoice spend.
-
#custom_pricing_unit_overage_rate ⇒ Object
readonly
The configuration for the overage rate for the custom pricing unit.
-
#effective_from ⇒ Object
readonly
The timestamp from which this spend modifier is effective.
-
#effective_until ⇒ Object
readonly
The timestamp until which this spend modifier is effective.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alert ⇒ Object (readonly)
The billing alert associated with the maximum spend threshold.
55 56 57 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 55 def alert @alert end |
#amount ⇒ Object (readonly)
The maximum amount of invoice spend.
57 58 59 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 57 def amount @amount end |
#custom_pricing_unit_overage_rate ⇒ Object (readonly)
The configuration for the overage rate for the custom pricing unit.
59 60 61 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 59 def custom_pricing_unit_overage_rate @custom_pricing_unit_overage_rate end |
#effective_from ⇒ Object (readonly)
The timestamp from which this spend modifier is effective.
61 62 63 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 61 def effective_from @effective_from end |
#effective_until ⇒ Object (readonly)
The timestamp until which this spend modifier is effective. If not set, the modifier is effective indefinitely.
63 64 65 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 63 def effective_until @effective_until end |
Class Method Details
.field_remappings ⇒ Object
72 73 74 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 72 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
65 66 67 68 69 70 |
# File 'lib/stripe/resources/v2/billing/cadence_spend_modifier.rb', line 65 def self.inner_class_types @inner_class_types = { amount: Amount, custom_pricing_unit_overage_rate: CustomPricingUnitOverageRate, } end |