Class: Stripe::V2::Billing::CadenceUpdateParams::Settings::Bill
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CadenceUpdateParams::Settings::Bill
- Defined in:
- lib/stripe/params/v2/billing/cadence_update_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Bill
constructor
A new instance of Bill.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(id: nil, version: nil) ⇒ Bill
Returns a new instance of Bill.
27 28 29 30 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 27 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
20 21 22 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 20 def id @id end |
#version ⇒ Object
An optional field to specify the version of Settings to use. If not provided, this will always default to the ‘live_version` specified on the setting, any time the settings are used. Using a specific version here will prevent the settings from updating, and is discouraged for cadences. To clear a pinned version, set the version to null.
25 26 27 |
# File 'lib/stripe/params/v2/billing/cadence_update_params.rb', line 25 def version @version end |