Class: Stripe::V2::Billing::Cadences::SpendModifierRuleListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::Cadences::SpendModifierRuleListParams
- Defined in:
- lib/stripe/params/v2/billing/cadences/spend_modifier_rule_list_params.rb
Instance Attribute Summary collapse
-
#effective_at ⇒ Object
Return only spend modifiers that are effective at the specified timestamp.
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
Instance Method Summary collapse
-
#initialize(effective_at: nil, limit: nil) ⇒ SpendModifierRuleListParams
constructor
A new instance of SpendModifierRuleListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(effective_at: nil, limit: nil) ⇒ SpendModifierRuleListParams
Returns a new instance of SpendModifierRuleListParams.
14 15 16 17 |
# File 'lib/stripe/params/v2/billing/cadences/spend_modifier_rule_list_params.rb', line 14 def initialize(effective_at: nil, limit: nil) @effective_at = effective_at @limit = limit end |
Instance Attribute Details
#effective_at ⇒ Object
Return only spend modifiers that are effective at the specified timestamp.
10 11 12 |
# File 'lib/stripe/params/v2/billing/cadences/spend_modifier_rule_list_params.rb', line 10 def effective_at @effective_at end |
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
12 13 14 |
# File 'lib/stripe/params/v2/billing/cadences/spend_modifier_rule_list_params.rb', line 12 def limit @limit end |