Class: Stripe::V2::Billing::CollectionSetting

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting.rb

Overview

Settings that configure and manage the behavior of collecting payments.

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.collection_setting"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#collection_methodObject (readonly)

Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.



251
252
253
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 251

def collection_method
  @collection_method
end

#createdObject (readonly)

Timestamp of when the object was created.



253
254
255
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 253

def created
  @created
end

#display_nameObject (readonly)

An optional field for adding a display name for the CollectionSetting object.



255
256
257
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 255

def display_name
  @display_name
end

#email_deliveryObject (readonly)

Email delivery settings.



257
258
259
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 257

def email_delivery
  @email_delivery
end

#idObject (readonly)

The ID of the CollectionSetting.



259
260
261
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 259

def id
  @id
end

#latest_versionObject (readonly)

The latest version of the current settings object. This will be Updated every time an attribute of the settings is updated.



262
263
264
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 262

def latest_version
  @latest_version
end

#live_versionObject (readonly)

The current live version of the settings object. This can be different from latest_version if settings are updated without setting live_version=‘latest’.



265
266
267
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 265

def live_version
  @live_version
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



267
268
269
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 267

def livemode
  @livemode
end

#lookup_keyObject (readonly)

A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.



270
271
272
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 270

def lookup_key
  @lookup_key
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



272
273
274
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 272

def object
  @object
end

#payment_method_configurationObject (readonly)

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



274
275
276
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 274

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject (readonly)

Payment Method specific configuration stored on the object.



276
277
278
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 276

def payment_method_options
  @payment_method_options
end

Class Method Details

.field_encodingsObject



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 289

def self.field_encodings
  @field_encodings = {
    payment_method_options: {
      kind: :object,
      fields: {
        card: {
          kind: :object,
          fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
        },
      },
    },
  }
end

.field_remappingsObject



285
286
287
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 285

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



278
279
280
281
282
283
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 278

def self.inner_class_types
  @inner_class_types = {
    email_delivery: EmailDelivery,
    payment_method_options: PaymentMethodOptions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 10

def self.object_name
  "v2.billing.collection_setting"
end