Class: Stripe::V2::Billing::CollectionSetting
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::CollectionSetting
- Defined in:
- lib/stripe/resources/v2/billing/collection_setting.rb
Overview
Settings that configure and manage the behavior of collecting payments.
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.collection_setting"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
readonly
Either automatic, or send_invoice.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#display_name ⇒ Object
readonly
An optional field for adding a display name for the CollectionSetting object.
-
#email_delivery ⇒ Object
readonly
Email delivery settings.
-
#id ⇒ Object
readonly
The ID of the CollectionSetting.
-
#latest_version ⇒ Object
readonly
The latest version of the current settings object.
-
#live_version ⇒ Object
readonly
The current live version of the settings object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
A lookup key used to retrieve settings dynamically from a static string.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_configuration ⇒ Object
readonly
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
readonly
Payment Method specific configuration stored on the object.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_method ⇒ Object (readonly)
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.
119 120 121 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 119 def collection_method @collection_method end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
121 122 123 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 121 def created @created end |
#display_name ⇒ Object (readonly)
An optional field for adding a display name for the CollectionSetting object.
123 124 125 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 123 def display_name @display_name end |
#email_delivery ⇒ Object (readonly)
Email delivery settings.
125 126 127 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 125 def email_delivery @email_delivery end |
#id ⇒ Object (readonly)
The ID of the CollectionSetting.
127 128 129 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 127 def id @id end |
#latest_version ⇒ Object (readonly)
The latest version of the current settings object. This will be Updated every time an attribute of the settings is updated.
130 131 132 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 130 def latest_version @latest_version end |
#live_version ⇒ Object (readonly)
The current live version of the settings object. This can be different from latest_version if settings are updated without setting live_version=‘latest’.
133 134 135 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 133 def live_version @live_version end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
144 145 146 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 144 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
136 137 138 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 136 def lookup_key @lookup_key end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
138 139 140 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 138 def object @object end |
#payment_method_configuration ⇒ Object (readonly)
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
140 141 142 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 140 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object (readonly)
Payment Method specific configuration stored on the object.
142 143 144 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 142 def @payment_method_options end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 10 def self.object_name "v2.billing.collection_setting" end |