Class: Stripe::V2::Billing::CollectionSetting::PaymentMethodOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::CollectionSetting::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/v2/billing/collection_setting.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, Konbini, SepaDebit, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
This sub-hash contains details about the Canadian pre-authorized debit payment method options.
-
#bancontact ⇒ Object
readonly
This sub-hash contains details about the Bancontact payment method.
-
#card ⇒ Object
readonly
This sub-hash contains details about the Card payment method options.
-
#customer_balance ⇒ Object
readonly
This sub-hash contains details about the Bank transfer payment method options.
-
#konbini ⇒ Object
readonly
This sub-hash contains details about the Konbini payment method options.
-
#sepa_debit ⇒ Object
readonly
This sub-hash contains details about the SEPA Direct Debit payment method options.
-
#us_bank_account ⇒ Object
readonly
This sub-hash contains details about the ACH direct debit payment method options.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
This sub-hash contains details about the Canadian pre-authorized debit payment method options.
101 102 103 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 101 def acss_debit @acss_debit end |
#bancontact ⇒ Object (readonly)
This sub-hash contains details about the Bancontact payment method.
103 104 105 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 103 def bancontact @bancontact end |
#card ⇒ Object (readonly)
This sub-hash contains details about the Card payment method options.
105 106 107 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 105 def card @card end |
#customer_balance ⇒ Object (readonly)
This sub-hash contains details about the Bank transfer payment method options.
107 108 109 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 107 def customer_balance @customer_balance end |
#konbini ⇒ Object (readonly)
This sub-hash contains details about the Konbini payment method options.
109 110 111 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 109 def konbini @konbini end |
#sepa_debit ⇒ Object (readonly)
This sub-hash contains details about the SEPA Direct Debit payment method options.
111 112 113 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 111 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object (readonly)
This sub-hash contains details about the ACH direct debit payment method options.
113 114 115 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 113 def us_bank_account @us_bank_account end |