Class: Stripe::V2::Billing::CollectionSetting::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::CollectionSetting::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/v2/billing/collection_setting.rb
Defined Under Namespace
Classes: MandateOptions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
readonly
Configuration options for setting up an eMandate for cards issued in India.
-
#network ⇒ Object
readonly
Selected network to process the payment on.
-
#request_three_d_secure ⇒ Object
readonly
An advanced option 3D Secure.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mandate_options ⇒ Object (readonly)
Configuration options for setting up an eMandate for cards issued in India.
52 53 54 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 52 def @mandate_options end |
#network ⇒ Object (readonly)
Selected network to process the payment on. Depends on the available networks of the card.
54 55 56 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 54 def network @network end |
#request_three_d_secure ⇒ Object (readonly)
An advanced option 3D Secure. We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.corp.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on [manually requesting 3D Secure](docs.corp.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
59 60 61 |
# File 'lib/stripe/resources/v2/billing/collection_setting.rb', line 59 def request_three_d_secure @request_three_d_secure end |