Class: Stripe::V2::Billing::CollectionSettingCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/collection_setting_create_params.rb

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(collection_method: nil, display_name: nil, email_delivery: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingCreateParams

Returns a new instance of CollectionSettingCreateParams.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 222

def initialize(
  collection_method: nil,
  display_name: nil,
  email_delivery: nil,
  lookup_key: nil,
  payment_method_configuration: nil,
  payment_method_options: nil
)
  @collection_method = collection_method
  @display_name = display_name
  @email_delivery = email_delivery
  @lookup_key = lookup_key
  @payment_method_configuration = payment_method_configuration
  @payment_method_options = payment_method_options
end

Instance Attribute Details

#collection_methodObject

Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.



208
209
210
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 208

def collection_method
  @collection_method
end

#display_nameObject

An optional customer-facing display name for the CollectionSetting object. Maximum length of 250 characters.



211
212
213
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 211

def display_name
  @display_name
end

#email_deliveryObject

Email delivery setting.



213
214
215
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 213

def email_delivery
  @email_delivery
end

#lookup_keyObject

A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.



216
217
218
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 216

def lookup_key
  @lookup_key
end

#payment_method_configurationObject

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



218
219
220
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 218

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject

Payment Method specific configuration to be stored on the object.



220
221
222
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 220

def payment_method_options
  @payment_method_options
end

Class Method Details

.field_encodingsObject



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 238

def self.field_encodings
  @field_encodings = {
    payment_method_options: {
      kind: :object,
      fields: {
        card: {
          kind: :object,
          fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
        },
      },
    },
  }
end