Class: Stripe::V2::Billing::CollectionSettingCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/collection_setting_create_params.rb

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(collection_method: nil, display_name: nil, email_delivery: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingCreateParams

Returns a new instance of CollectionSettingCreateParams.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 205

def initialize(
  collection_method: nil,
  display_name: nil,
  email_delivery: nil,
  lookup_key: nil,
  payment_method_configuration: nil,
  payment_method_options: nil
)
  @collection_method = collection_method
  @display_name = display_name
  @email_delivery = email_delivery
  @lookup_key = lookup_key
  @payment_method_configuration = payment_method_configuration
  @payment_method_options = payment_method_options
end

Instance Attribute Details

#collection_methodObject

Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.



191
192
193
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 191

def collection_method
  @collection_method
end

#display_nameObject

An optional customer-facing display name for the CollectionSetting object. Maximum length of 250 characters.



194
195
196
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 194

def display_name
  @display_name
end

#email_deliveryObject

Email delivery setting.



196
197
198
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 196

def email_delivery
  @email_delivery
end

#lookup_keyObject

A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.



199
200
201
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 199

def lookup_key
  @lookup_key
end

#payment_method_configurationObject

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



201
202
203
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 201

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject

Payment Method specific configuration to be stored on the object.



203
204
205
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 203

def payment_method_options
  @payment_method_options
end