Class: Stripe::V2::Billing::CollectionSettingCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingCreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_create_params.rb
Defined Under Namespace
Classes: EuBankTransfer
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
Configuration for ‘eu_bank_transfer` funding type.
-
#type ⇒ Object
The bank transfer type that can be used for funding.
Instance Method Summary collapse
-
#initialize(eu_bank_transfer: nil, type: nil) ⇒ BankTransfer
constructor
A new instance of BankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(eu_bank_transfer: nil, type: nil) ⇒ BankTransfer
Returns a new instance of BankTransfer.
105 106 107 108 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 105 def initialize(eu_bank_transfer: nil, type: nil) @eu_bank_transfer = eu_bank_transfer @type = type end |
Instance Attribute Details
#eu_bank_transfer ⇒ Object
Configuration for ‘eu_bank_transfer` funding type. Required if `type` is `eu_bank_transfer`.
101 102 103 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 101 def eu_bank_transfer @eu_bank_transfer end |
#type ⇒ Object
The bank transfer type that can be used for funding.
103 104 105 |
# File 'lib/stripe/params/v2/billing/collection_setting_create_params.rb', line 103 def type @type end |