Class: Stripe::V2::Billing::CollectionSettingService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/collection_setting_service.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
Either automatic, or send_invoice.
-
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object.
-
#email_delivery ⇒ Object
Email delivery setting.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
-
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
Instance Method Summary collapse
-
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 229 def initialize( collection_method: nil, display_name: nil, email_delivery: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil ) @collection_method = collection_method @display_name = display_name @email_delivery = email_delivery @lookup_key = lookup_key @payment_method_configuration = payment_method_configuration @payment_method_options = end |
Instance Attribute Details
#collection_method ⇒ Object
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.
215 216 217 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 215 def collection_method @collection_method end |
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object. Maximum length of 250 characters.
218 219 220 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 218 def display_name @display_name end |
#email_delivery ⇒ Object
Email delivery setting.
220 221 222 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 220 def email_delivery @email_delivery end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
223 224 225 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 223 def lookup_key @lookup_key end |
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
225 226 227 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 225 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
227 228 229 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 227 def @payment_method_options end |