Class: Stripe::V2::Billing::CollectionSettingService::CreateParams::EmailDelivery::PaymentDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingService::CreateParams::EmailDelivery::PaymentDue
- Defined in:
- lib/stripe/services/v2/billing/collection_setting_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
If true an email for the invoice would be generated and sent out.
-
#include_payment_link ⇒ Object
If true the payment link to hosted invocie page would be included in email and PDF of the invoice.
Instance Method Summary collapse
-
#initialize(enabled: nil, include_payment_link: nil) ⇒ PaymentDue
constructor
A new instance of PaymentDue.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, include_payment_link: nil) ⇒ PaymentDue
Returns a new instance of PaymentDue.
36 37 38 39 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 36 def initialize(enabled: nil, include_payment_link: nil) @enabled = enabled @include_payment_link = include_payment_link end |
Instance Attribute Details
#enabled ⇒ Object
If true an email for the invoice would be generated and sent out.
32 33 34 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 32 def enabled @enabled end |
#include_payment_link ⇒ Object
If true the payment link to hosted invocie page would be included in email and PDF of the invoice.
34 35 36 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 34 def include_payment_link @include_payment_link end |