Class: Stripe::V2::Billing::CollectionSettingService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingService::UpdateParams
- Defined in:
- lib/stripe/services/v2/billing/collection_setting_service.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
Either automatic, or send_invoice.
-
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object.
-
#email_delivery ⇒ Object
Email delivery settings.
-
#live_version ⇒ Object
Optionally change the live version of the CollectionSetting.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
-
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
Instance Method Summary collapse
-
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 453 def initialize( collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil ) @collection_method = collection_method @display_name = display_name @email_delivery = email_delivery @live_version = live_version @lookup_key = lookup_key @payment_method_configuration = payment_method_configuration @payment_method_options = end |
Instance Attribute Details
#collection_method ⇒ Object
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions.
434 435 436 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 434 def collection_method @collection_method end |
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.
438 439 440 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 438 def display_name @display_name end |
#email_delivery ⇒ Object
Email delivery settings.
440 441 442 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 440 def email_delivery @email_delivery end |
#live_version ⇒ Object
Optionally change the live version of the CollectionSetting. Billing Cadences and other objects that refer to this CollectionSetting will use this version when no overrides are set. Providing ‘live_version = “latest”` will set the CollectionSetting’s ‘live_version` to its latest version.
444 445 446 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 444 def live_version @live_version end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
447 448 449 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 447 def lookup_key @lookup_key end |
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
449 450 451 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 449 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
451 452 453 |
# File 'lib/stripe/services/v2/billing/collection_setting_service.rb', line 451 def @payment_method_options end |