Class: Stripe::V2::Billing::CollectionSettingUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_update_params.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
Either automatic, or send_invoice.
-
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object.
-
#email_delivery ⇒ Object
Email delivery settings.
-
#live_version ⇒ Object
Optionally change the live version of the CollectionSetting.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
-
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingUpdateParams
constructor
A new instance of CollectionSettingUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingUpdateParams
Returns a new instance of CollectionSettingUpdateParams.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 229 def initialize( collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil ) @collection_method = collection_method @display_name = display_name @email_delivery = email_delivery @live_version = live_version @lookup_key = lookup_key @payment_method_configuration = payment_method_configuration @payment_method_options = end |
Instance Attribute Details
#collection_method ⇒ Object
Either automatic, or send_invoice. When charging automatically, Stripe attempts to pay this bill at the end of the period using the payment method attached to the billing profile. When sending an invoice, Stripe emails your billing profile an invoice with payment instructions.
210 211 212 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 210 def collection_method @collection_method end |
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.
214 215 216 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 214 def display_name @display_name end |
#email_delivery ⇒ Object
Email delivery settings.
216 217 218 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 216 def email_delivery @email_delivery end |
#live_version ⇒ Object
Optionally change the live version of the CollectionSetting. Billing Cadences and other objects that refer to this CollectionSetting uses this version when no overrides are set. Providing ‘live_version = “latest”` sets the CollectionSetting’s ‘live_version` to its latest version.
220 221 222 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 220 def live_version @live_version end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
223 224 225 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 223 def lookup_key @lookup_key end |
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
225 226 227 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 225 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
227 228 229 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 227 def @payment_method_options end |
Class Method Details
.field_encodings ⇒ Object
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 247 def self.field_encodings @field_encodings = { payment_method_options: { kind: :object, fields: { card: { kind: :object, fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } }, }, }, }, } end |