Class: Stripe::V2::Billing::CollectionSettingUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/collection_setting_update_params.rb

Defined Under Namespace

Classes: EmailDelivery, PaymentMethodOptions

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingUpdateParams

Returns a new instance of CollectionSettingUpdateParams.



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 226

def initialize(
  collection_method: nil,
  display_name: nil,
  email_delivery: nil,
  live_version: nil,
  lookup_key: nil,
  payment_method_configuration: nil,
  payment_method_options: nil
)
  @collection_method = collection_method
  @display_name = display_name
  @email_delivery = email_delivery
  @live_version = live_version
  @lookup_key = lookup_key
  @payment_method_configuration = payment_method_configuration
  @payment_method_options = payment_method_options
end

Instance Attribute Details

#collection_methodObject

Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions.



207
208
209
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 207

def collection_method
  @collection_method
end

#display_nameObject

An optional customer-facing display name for the CollectionSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.



211
212
213
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 211

def display_name
  @display_name
end

#email_deliveryObject

Email delivery settings.



213
214
215
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 213

def email_delivery
  @email_delivery
end

#live_versionObject

Optionally change the live version of the CollectionSetting. Billing Cadences and other objects that refer to this CollectionSetting will use this version when no overrides are set. Providing ‘live_version = “latest”` will set the CollectionSetting’s ‘live_version` to its latest version.



217
218
219
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 217

def live_version
  @live_version
end

#lookup_keyObject

A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.



220
221
222
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 220

def lookup_key
  @lookup_key
end

#payment_method_configurationObject

The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.



222
223
224
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 222

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_optionsObject

Payment Method specific configuration to be stored on the object.



224
225
226
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 224

def payment_method_options
  @payment_method_options
end

Class Method Details

.field_encodingsObject



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 244

def self.field_encodings
  @field_encodings = {
    payment_method_options: {
      kind: :object,
      fields: {
        card: {
          kind: :object,
          fields: { mandate_options: { kind: :object, fields: { amount: :int64_string } } },
        },
      },
    },
  }
end