Class: Stripe::V2::Billing::CollectionSettingUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::CollectionSettingUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/collection_setting_update_params.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
Either automatic, or send_invoice.
-
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object.
-
#email_delivery ⇒ Object
Email delivery settings.
-
#live_version ⇒ Object
Optionally change the live version of the CollectionSetting.
-
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string.
-
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
Instance Method Summary collapse
-
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingUpdateParams
constructor
A new instance of CollectionSettingUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil) ⇒ CollectionSettingUpdateParams
Returns a new instance of CollectionSettingUpdateParams.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 209 def initialize( collection_method: nil, display_name: nil, email_delivery: nil, live_version: nil, lookup_key: nil, payment_method_configuration: nil, payment_method_options: nil ) @collection_method = collection_method @display_name = display_name @email_delivery = email_delivery @live_version = live_version @lookup_key = lookup_key @payment_method_configuration = payment_method_configuration @payment_method_options = end |
Instance Attribute Details
#collection_method ⇒ Object
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions.
190 191 192 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 190 def collection_method @collection_method end |
#display_name ⇒ Object
An optional customer-facing display name for the CollectionSetting object. To remove the display name, set it to an empty string in the request. Maximum length of 250 characters.
194 195 196 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 194 def display_name @display_name end |
#email_delivery ⇒ Object
Email delivery settings.
196 197 198 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 196 def email_delivery @email_delivery end |
#live_version ⇒ Object
Optionally change the live version of the CollectionSetting. Billing Cadences and other objects that refer to this CollectionSetting will use this version when no overrides are set. Providing ‘live_version = “latest”` will set the CollectionSetting’s ‘live_version` to its latest version.
200 201 202 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 200 def live_version @live_version end |
#lookup_key ⇒ Object
A lookup key used to retrieve settings dynamically from a static string. This may be up to 200 characters.
203 204 205 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 203 def lookup_key @lookup_key end |
#payment_method_configuration ⇒ Object
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
205 206 207 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 205 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object
Payment Method specific configuration to be stored on the object.
207 208 209 |
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 207 def @payment_method_options end |