Class: Stripe::V2::Billing::CollectionSettingUpdateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/collection_setting_update_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(mandate_options: nil, network: nil, request_three_d_secure: nil) ⇒ Card

Returns a new instance of Card.



83
84
85
86
87
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 83

def initialize(mandate_options: nil, network: nil, request_three_d_secure: nil)
  @mandate_options = mandate_options
  @network = network
  @request_three_d_secure = request_three_d_secure
end

Instance Attribute Details

#mandate_optionsObject

Configuration options for setting up an eMandate for cards issued in India.



74
75
76
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 74

def mandate_options
  @mandate_options
end

#networkObject

Selected network to process the payment on. Depends on the available networks of the card.



76
77
78
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 76

def network
  @network
end

#request_three_d_secureObject

An advanced option 3D Secure. We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



81
82
83
# File 'lib/stripe/params/v2/billing/collection_setting_update_params.rb', line 81

def request_three_d_secure
  @request_three_d_secure
end