Class: Stripe::V2::Billing::CollectionSettingVersion
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::CollectionSettingVersion
- Defined in:
- lib/stripe/resources/v2/billing/collection_setting_version.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.collection_setting_version"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
readonly
Either automatic, or send_invoice.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#email_delivery ⇒ Object
readonly
Email delivery settings.
-
#id ⇒ Object
readonly
The ID of the CollectionSettingVersion object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_configuration ⇒ Object
readonly
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
readonly
Payment Method specific configuration stored on the object.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_method ⇒ Object (readonly)
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.
233 234 235 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 233 def collection_method @collection_method end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
235 236 237 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 235 def created @created end |
#email_delivery ⇒ Object (readonly)
Email delivery settings.
237 238 239 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 237 def email_delivery @email_delivery end |
#id ⇒ Object (readonly)
The ID of the CollectionSettingVersion object.
239 240 241 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 239 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
247 248 249 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 247 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
241 242 243 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 241 def object @object end |
#payment_method_configuration ⇒ Object (readonly)
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
243 244 245 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 243 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object (readonly)
Payment Method specific configuration stored on the object.
245 246 247 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 245 def @payment_method_options end |
Class Method Details
.field_remappings ⇒ Object
256 257 258 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 256 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
249 250 251 252 253 254 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 249 def self.inner_class_types @inner_class_types = { email_delivery: EmailDelivery, payment_method_options: PaymentMethodOptions, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 9 def self.object_name "v2.billing.collection_setting_version" end |