Class: Stripe::V2::Billing::CollectionSettingVersion
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::CollectionSettingVersion
- Defined in:
- lib/stripe/resources/v2/billing/collection_setting_version.rb
Defined Under Namespace
Classes: EmailDelivery, PaymentMethodOptions
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.collection_setting_version"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
readonly
Either automatic, or send_invoice.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#email_delivery ⇒ Object
readonly
Email delivery settings.
-
#id ⇒ Object
readonly
The ID of the CollectionSettingVersion object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_configuration ⇒ Object
readonly
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
-
#payment_method_options ⇒ Object
readonly
Payment Method specific configuration stored on the object.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#collection_method ⇒ Object (readonly)
Either automatic, or send_invoice. When charging automatically, Stripe will attempt to pay this bill at the end of the period using the payment method attached to the payer profile. When sending an invoice, Stripe will email your payer profile an invoice with payment instructions. Defaults to automatic.
118 119 120 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 118 def collection_method @collection_method end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
120 121 122 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 120 def created @created end |
#email_delivery ⇒ Object (readonly)
Email delivery settings.
122 123 124 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 122 def email_delivery @email_delivery end |
#id ⇒ Object (readonly)
The ID of the CollectionSettingVersion object.
124 125 126 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 124 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
132 133 134 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 132 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
126 127 128 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 126 def object @object end |
#payment_method_configuration ⇒ Object (readonly)
The ID of the PaymentMethodConfiguration object, which controls which payment methods are displayed to your customers.
128 129 130 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 128 def payment_method_configuration @payment_method_configuration end |
#payment_method_options ⇒ Object (readonly)
Payment Method specific configuration stored on the object.
130 131 132 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 130 def @payment_method_options end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 9 def self.object_name "v2.billing.collection_setting_version" end |