Class: Stripe::V2::Billing::CollectionSettingVersion::EmailDelivery::PaymentDue

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting_version.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#enabledObject (readonly)

If true an email for the invoice would be generated and sent out.



16
17
18
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 16

def enabled
  @enabled
end

If true the payment link to hosted invocie page would be included in email and PDF of the invoice.



18
19
20
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 18

def include_payment_link
  @include_payment_link
end