Class: Stripe::V2::Billing::CollectionSettingVersion::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting_version.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, Konbini, SepaDebit, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

This sub-hash contains details about the Canadian pre-authorized debit payment method options.



221
222
223
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 221

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

This sub-hash contains details about the Bancontact payment method.



223
224
225
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 223

def bancontact
  @bancontact
end

#cardObject (readonly)

This sub-hash contains details about the Card payment method options.



225
226
227
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 225

def card
  @card
end

#customer_balanceObject (readonly)

This sub-hash contains details about the Bank transfer payment method options.



227
228
229
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 227

def customer_balance
  @customer_balance
end

#konbiniObject (readonly)

This sub-hash contains details about the Konbini payment method options.



229
230
231
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 229

def konbini
  @konbini
end

#sepa_debitObject (readonly)

This sub-hash contains details about the SEPA Direct Debit payment method options.



231
232
233
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 231

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject (readonly)

This sub-hash contains details about the ACH direct debit payment method options.



233
234
235
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 233

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



247
248
249
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 247

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



235
236
237
238
239
240
241
242
243
244
245
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 235

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    card: Card,
    customer_balance: CustomerBalance,
    konbini: Konbini,
    sepa_debit: SepaDebit,
    us_bank_account: UsBankAccount,
  }
end