Class: Stripe::V2::Billing::CollectionSettingVersion::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/collection_setting_version.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, Konbini, SepaDebit, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

This sub-hash contains details about the Canadian pre-authorized debit payment method options.



100
101
102
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 100

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

This sub-hash contains details about the Bancontact payment method.



102
103
104
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 102

def bancontact
  @bancontact
end

#cardObject (readonly)

This sub-hash contains details about the Card payment method options.



104
105
106
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 104

def card
  @card
end

#customer_balanceObject (readonly)

This sub-hash contains details about the Bank transfer payment method options.



106
107
108
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 106

def customer_balance
  @customer_balance
end

#konbiniObject (readonly)

This sub-hash contains details about the Konbini payment method options.



108
109
110
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 108

def konbini
  @konbini
end

#sepa_debitObject (readonly)

This sub-hash contains details about the SEPA Direct Debit payment method options.



110
111
112
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 110

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject (readonly)

This sub-hash contains details about the ACH direct debit payment method options.



112
113
114
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 112

def 
  @us_bank_account
end