Class: Stripe::V2::Billing::CollectionSettingVersion::PaymentMethodOptions::CustomerBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::CollectionSettingVersion::PaymentMethodOptions::CustomerBalance
- Defined in:
- lib/stripe/resources/v2/billing/collection_setting_version.rb
Defined Under Namespace
Classes: BankTransfer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_transfer ⇒ Object
readonly
Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.
-
#funding_type ⇒ Object
readonly
The funding method type to be used when there are not enough funds in the customer balance.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_transfer ⇒ Object (readonly)
Configuration for the bank transfer funding type, if the ‘funding_type` is set to `bank_transfer`.
145 146 147 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 145 def bank_transfer @bank_transfer end |
#funding_type ⇒ Object (readonly)
The funding method type to be used when there are not enough funds in the customer balance. Currently the only supported value is ‘bank_transfer`.
147 148 149 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 147 def funding_type @funding_type end |
Class Method Details
.field_remappings ⇒ Object
153 154 155 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 153 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
149 150 151 |
# File 'lib/stripe/resources/v2/billing/collection_setting_version.rb', line 149 def self.inner_class_types @inner_class_types = { bank_transfer: BankTransfer } end |