Class: Stripe::V2::Billing::ContractCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: BillingSettings, ContractLine, LicenseQuantityAction, OneTimeFee, PricingLine, PricingOverride
Instance Attribute Summary collapse
-
#billing_settings ⇒ Object
The billing settings for the contract.
-
#contract_lines ⇒ Object
A list of contract lines to create with the contract.
-
#contract_number ⇒ Object
A unique user-provided contract number e.g.
-
#currency ⇒ Object
Currency of the contract.
-
#include ⇒ Object
Additional fields to include in the response.
-
#license_quantity_actions ⇒ Object
A list of license quantity actions to create with the contract.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#one_time_fees ⇒ Object
A list of one-time fees to create with the contract.
-
#pricing_lines ⇒ Object
A list of pricing lines to create with the contract.
-
#pricing_overrides ⇒ Object
A list of pricing overrides to create with the contract.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_settings: nil, contract_lines: nil, contract_number: nil, currency: nil, include: nil, license_quantity_actions: nil, metadata: nil, one_time_fees: nil, pricing_lines: nil, pricing_overrides: nil) ⇒ ContractCreateParams
constructor
A new instance of ContractCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_settings: nil, contract_lines: nil, contract_number: nil, currency: nil, include: nil, license_quantity_actions: nil, metadata: nil, one_time_fees: nil, pricing_lines: nil, pricing_overrides: nil) ⇒ ContractCreateParams
Returns a new instance of ContractCreateParams.
771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 771 def initialize( billing_settings: nil, contract_lines: nil, contract_number: nil, currency: nil, include: nil, license_quantity_actions: nil, metadata: nil, one_time_fees: nil, pricing_lines: nil, pricing_overrides: nil ) @billing_settings = billing_settings @contract_lines = contract_lines @contract_number = contract_number @currency = currency @include = include @license_quantity_actions = license_quantity_actions @metadata = @one_time_fees = one_time_fees @pricing_lines = pricing_lines @pricing_overrides = pricing_overrides end |
Instance Attribute Details
#billing_settings ⇒ Object
The billing settings for the contract.
751 752 753 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 751 def billing_settings @billing_settings end |
#contract_lines ⇒ Object
A list of contract lines to create with the contract.
753 754 755 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 753 def contract_lines @contract_lines end |
#contract_number ⇒ Object
A unique user-provided contract number e.g. C-2026-0001.
755 756 757 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 755 def contract_number @contract_number end |
#currency ⇒ Object
Currency of the contract.
757 758 759 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 757 def currency @currency end |
#include ⇒ Object
Additional fields to include in the response.
759 760 761 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 759 def include @include end |
#license_quantity_actions ⇒ Object
A list of license quantity actions to create with the contract.
761 762 763 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 761 def license_quantity_actions @license_quantity_actions end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
763 764 765 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 763 def @metadata end |
#one_time_fees ⇒ Object
A list of one-time fees to create with the contract. Each fee is billed as individual invoice items per its bill_schedule.
765 766 767 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 765 def one_time_fees @one_time_fees end |
#pricing_lines ⇒ Object
A list of pricing lines to create with the contract.
767 768 769 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 767 def pricing_lines @pricing_lines end |
#pricing_overrides ⇒ Object
A list of pricing overrides to create with the contract.
769 770 771 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 769 def pricing_overrides @pricing_overrides end |
Class Method Details
.field_encodings ⇒ Object
795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 795 def self.field_encodings @field_encodings = { one_time_fees: { kind: :array, element: { kind: :object, fields: { bill_schedule: { kind: :array, element: { kind: :object, fields: { value: :int64_string } }, }, }, }, }, pricing_overrides: { kind: :array, element: { kind: :object, fields: { overwrite_price: { kind: :object, fields: { tiers: { kind: :array, element: { kind: :object, fields: { up_to_decimal: :decimal_string } }, }, }, }, }, }, }, } end |