Class: Stripe::V2::Billing::ContractCreateParams::BillingCycleAnchor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::BillingCycleAnchor
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: Config
Instance Attribute Summary collapse
-
#config ⇒ Object
Configuration for determining the billing cycle anchor by calendar fields.
-
#timestamp ⇒ Object
A specific timestamp to use as the billing cycle anchor.
-
#type ⇒ Object
The type of billing cycle anchor.
Instance Method Summary collapse
-
#initialize(config: nil, timestamp: nil, type: nil) ⇒ BillingCycleAnchor
constructor
A new instance of BillingCycleAnchor.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(config: nil, timestamp: nil, type: nil) ⇒ BillingCycleAnchor
Returns a new instance of BillingCycleAnchor.
42 43 44 45 46 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 42 def initialize(config: nil, timestamp: nil, type: nil) @config = config @timestamp = @type = type end |
Instance Attribute Details
#config ⇒ Object
Configuration for determining the billing cycle anchor by calendar fields.
36 37 38 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 36 def config @config end |
#timestamp ⇒ Object
A specific timestamp to use as the billing cycle anchor.
38 39 40 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 38 def @timestamp end |
#type ⇒ Object
The type of billing cycle anchor.
40 41 42 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 40 def type @type end |