Class: Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Replace::CreditGrant::ApplicabilityConfig::Scope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::ContractLine::Override::ServiceAction::Replace::CreditGrant::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
The billable items to apply the credit grant to.
-
#price_type ⇒ Object
The price type that credit grants can apply to.
Instance Method Summary collapse
-
#initialize(billable_items: nil, price_type: nil) ⇒ Scope
constructor
A new instance of Scope.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billable_items: nil, price_type: nil) ⇒ Scope
Returns a new instance of Scope.
241 242 243 244 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 241 def initialize(billable_items: nil, price_type: nil) @billable_items = billable_items @price_type = price_type end |
Instance Attribute Details
#billable_items ⇒ Object
The billable items to apply the credit grant to.
237 238 239 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 237 def billable_items @billable_items end |
#price_type ⇒ Object
The price type that credit grants can apply to.
239 240 241 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 239 def price_type @price_type end |