Class: Stripe::V2::Billing::ContractCreateParams::PricingLine
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ContractCreateParams::PricingLine
- Defined in:
- lib/stripe/params/v2/billing/contract_create_params.rb
Defined Under Namespace
Classes: EndsAt, Pricing, StartsAt
Instance Attribute Summary collapse
-
#ends_at ⇒ Object
When the pricing line ends.
-
#lookup_key ⇒ Object
A user-provided lookup key to reference this pricing line.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#pricing ⇒ Object
The pricing configuration for the pricing line.
-
#starts_at ⇒ Object
When the pricing line starts.
Instance Method Summary collapse
-
#initialize(ends_at: nil, lookup_key: nil, metadata: nil, pricing: nil, starts_at: nil) ⇒ PricingLine
constructor
A new instance of PricingLine.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ends_at: nil, lookup_key: nil, metadata: nil, pricing: nil, starts_at: nil) ⇒ PricingLine
Returns a new instance of PricingLine.
561 562 563 564 565 566 567 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 561 def initialize(ends_at: nil, lookup_key: nil, metadata: nil, pricing: nil, starts_at: nil) @ends_at = ends_at @lookup_key = lookup_key @metadata = @pricing = pricing @starts_at = starts_at end |
Instance Attribute Details
#ends_at ⇒ Object
When the pricing line ends.
551 552 553 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 551 def ends_at @ends_at end |
#lookup_key ⇒ Object
A user-provided lookup key to reference this pricing line.
553 554 555 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 553 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
555 556 557 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 555 def @metadata end |
#pricing ⇒ Object
The pricing configuration for the pricing line.
557 558 559 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 557 def pricing @pricing end |
#starts_at ⇒ Object
When the pricing line starts.
559 560 561 |
# File 'lib/stripe/params/v2/billing/contract_create_params.rb', line 559 def starts_at @starts_at end |