Class: Stripe::V2::Billing::ContractPricingLineQuantityChange
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::ContractPricingLineQuantityChange
- Defined in:
- lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb
Overview
A quantity change object for a pricing line, returned by ListContractPricingLineQuantityChanges.
Defined Under Namespace
Classes: Pricing
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.contract_pricing_line_quantity_change"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The timestamp when this quantity change object was created.
-
#effective_at ⇒ Object
readonly
The timestamp when this quantity change takes effect.
-
#id ⇒ Object
readonly
The id of the quantity change object.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#object ⇒ Object
readonly
String representing the object's type.
-
#pricing ⇒ Object
readonly
The pricing configuration for the associated pricing line.
-
#pricing_line ⇒ Object
readonly
The id of the pricing line associated with this quantity change.
-
#quantity ⇒ Object
readonly
The quantity at the effective time.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The timestamp when this quantity change object was created.
29 30 31 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 29 def created @created end |
#effective_at ⇒ Object (readonly)
The timestamp when this quantity change takes effect.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 31 def effective_at @effective_at end |
#id ⇒ Object (readonly)
The id of the quantity change object.
33 34 35 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 33 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
35 36 37 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 35 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
37 38 39 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 37 def object @object end |
#pricing ⇒ Object (readonly)
The pricing configuration for the associated pricing line.
39 40 41 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 39 def pricing @pricing end |
#pricing_line ⇒ Object (readonly)
The id of the pricing line associated with this quantity change.
41 42 43 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 41 def pricing_line @pricing_line end |
#quantity ⇒ Object (readonly)
The quantity at the effective time.
43 44 45 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 43 def quantity @quantity end |
Class Method Details
.field_encodings ⇒ Object
53 54 55 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 53 def self.field_encodings @field_encodings = { quantity: :decimal_string } end |
.field_remappings ⇒ Object
49 50 51 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 49 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
45 46 47 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 45 def self.inner_class_types @inner_class_types = { pricing: Pricing } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/contract_pricing_line_quantity_change.rb', line 10 def self.object_name "v2.billing.contract_pricing_line_quantity_change" end |