Class: Stripe::V2::Billing::CustomPricingUnitCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/custom_pricing_unit_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(display_name: nil, lookup_key: nil, metadata: nil) ⇒ CustomPricingUnitCreateParams

Returns a new instance of CustomPricingUnitCreateParams.



18
19
20
21
22
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_create_params.rb', line 18

def initialize(display_name: nil, lookup_key: nil, metadata: nil)
  @display_name = display_name
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#display_nameObject

Description that customers will see in the invoice line item. Maximum length of 10 characters.



10
11
12
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_create_params.rb', line 10

def display_name
  @display_name
end

#lookup_keyObject

An internal key you can use to search for a particular custom pricing unit item. Must be unique among items. Maximum length of 200 characters.



14
15
16
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_create_params.rb', line 14

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



16
17
18
# File 'lib/stripe/params/v2/billing/custom_pricing_unit_create_params.rb', line 16

def 
  @metadata
end