Class: Stripe::V2::Billing::Intent

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/intent.rb

Defined Under Namespace

Classes: AmountDetails, CadenceData, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_detailsObject (readonly)

Breakdown of the amount for this Billing Intent.



315
316
317
# File 'lib/stripe/resources/v2/billing/intent.rb', line 315

def amount_details
  @amount_details
end

#cadenceObject (readonly)

ID of an existing Cadence to use.



331
332
333
# File 'lib/stripe/resources/v2/billing/intent.rb', line 331

def cadence
  @cadence
end

#cadence_dataObject (readonly)

Data for creating a new Cadence.



333
334
335
# File 'lib/stripe/resources/v2/billing/intent.rb', line 333

def cadence_data
  @cadence_data
end

#createdObject (readonly)

Time at which the object was created.



317
318
319
# File 'lib/stripe/resources/v2/billing/intent.rb', line 317

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



319
320
321
# File 'lib/stripe/resources/v2/billing/intent.rb', line 319

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



321
322
323
# File 'lib/stripe/resources/v2/billing/intent.rb', line 321

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



329
330
331
# File 'lib/stripe/resources/v2/billing/intent.rb', line 329

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



323
324
325
# File 'lib/stripe/resources/v2/billing/intent.rb', line 323

def object
  @object
end

#statusObject (readonly)

Current status of the Billing Intent.



325
326
327
# File 'lib/stripe/resources/v2/billing/intent.rb', line 325

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for status transitions of the Billing Intent.



327
328
329
# File 'lib/stripe/resources/v2/billing/intent.rb', line 327

def status_transitions
  @status_transitions
end

Class Method Details

.field_remappingsObject



343
344
345
# File 'lib/stripe/resources/v2/billing/intent.rb', line 343

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



335
336
337
338
339
340
341
# File 'lib/stripe/resources/v2/billing/intent.rb', line 335

def self.inner_class_types
  @inner_class_types = {
    amount_details: AmountDetails,
    status_transitions: StatusTransitions,
    cadence_data: CadenceData,
  }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/intent.rb', line 9

def self.object_name
  "v2.billing.intent"
end