Class: Stripe::V2::Billing::Intent

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/intent.rb

Defined Under Namespace

Classes: AmountDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_detailsObject (readonly)

Breakdown of the amount for this Billing Intent.



39
40
41
# File 'lib/stripe/resources/v2/billing/intent.rb', line 39

def amount_details
  @amount_details
end

#cadenceObject (readonly)

ID of an existing Cadence to use.



55
56
57
# File 'lib/stripe/resources/v2/billing/intent.rb', line 55

def cadence
  @cadence
end

#createdObject (readonly)

Time at which the object was created.



41
42
43
# File 'lib/stripe/resources/v2/billing/intent.rb', line 41

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



43
44
45
# File 'lib/stripe/resources/v2/billing/intent.rb', line 43

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



45
46
47
# File 'lib/stripe/resources/v2/billing/intent.rb', line 45

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



53
54
55
# File 'lib/stripe/resources/v2/billing/intent.rb', line 53

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



47
48
49
# File 'lib/stripe/resources/v2/billing/intent.rb', line 47

def object
  @object
end

#statusObject (readonly)

Current status of the Billing Intent.



49
50
51
# File 'lib/stripe/resources/v2/billing/intent.rb', line 49

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for status transitions of the Billing Intent.



51
52
53
# File 'lib/stripe/resources/v2/billing/intent.rb', line 51

def status_transitions
  @status_transitions
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/intent.rb', line 9

def self.object_name
  "v2.billing.intent"
end