Class: Stripe::V2::Billing::Intent

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/intent.rb

Defined Under Namespace

Classes: AmountDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_detailsObject (readonly)

Breakdown of the amount for this Billing Intent.



55
56
57
# File 'lib/stripe/resources/v2/billing/intent.rb', line 55

def amount_details
  @amount_details
end

#cadenceObject (readonly)

ID of an existing Cadence to use.



71
72
73
# File 'lib/stripe/resources/v2/billing/intent.rb', line 71

def cadence
  @cadence
end

#createdObject (readonly)

Time at which the object was created.



57
58
59
# File 'lib/stripe/resources/v2/billing/intent.rb', line 57

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



59
60
61
# File 'lib/stripe/resources/v2/billing/intent.rb', line 59

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



61
62
63
# File 'lib/stripe/resources/v2/billing/intent.rb', line 61

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



69
70
71
# File 'lib/stripe/resources/v2/billing/intent.rb', line 69

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



63
64
65
# File 'lib/stripe/resources/v2/billing/intent.rb', line 63

def object
  @object
end

#statusObject (readonly)

Current status of the Billing Intent.



65
66
67
# File 'lib/stripe/resources/v2/billing/intent.rb', line 65

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for status transitions of the Billing Intent.



67
68
69
# File 'lib/stripe/resources/v2/billing/intent.rb', line 67

def status_transitions
  @status_transitions
end

Class Method Details

.field_remappingsObject



80
81
82
# File 'lib/stripe/resources/v2/billing/intent.rb', line 80

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



73
74
75
76
77
78
# File 'lib/stripe/resources/v2/billing/intent.rb', line 73

def self.inner_class_types
  @inner_class_types = {
    amount_details: AmountDetails,
    status_transitions: StatusTransitions,
  }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/intent.rb', line 9

def self.object_name
  "v2.billing.intent"
end