Class: Stripe::V2::Billing::IntentAction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::IntentAction
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Overview
A Billing Intent Action represents a specific operation within a Billing Intent, such as subscribing to a Pricing Plan, modifying a subscription’s quantity, or deactivating service. Each action has a specific type and associated details that define what change will be made when the Intent is committed.
Defined Under Namespace
Classes: Apply, Deactivate, Modify, Remove, Subscribe
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.intent_action"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#apply ⇒ Object
readonly
Details for an apply action.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivate ⇒ Object
readonly
Details for a deactivate action.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#modify ⇒ Object
readonly
Details for a modify action.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#remove ⇒ Object
readonly
Details for a remove action.
-
#subscribe ⇒ Object
readonly
Details for a subscribe action.
-
#type ⇒ Object
readonly
Type of the Billing Intent Action.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#apply ⇒ Object (readonly)
Details for an apply action.
671 672 673 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 671 def apply @apply end |
#created ⇒ Object (readonly)
Time at which the object was created.
661 662 663 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 661 def created @created end |
#deactivate ⇒ Object (readonly)
Details for a deactivate action.
673 674 675 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 673 def deactivate @deactivate end |
#id ⇒ Object (readonly)
Unique identifier for the object.
663 664 665 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 663 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
669 670 671 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 669 def livemode @livemode end |
#modify ⇒ Object (readonly)
Details for a modify action.
675 676 677 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 675 def modify @modify end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
665 666 667 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 665 def object @object end |
#remove ⇒ Object (readonly)
Details for a remove action.
677 678 679 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 677 def remove @remove end |
#subscribe ⇒ Object (readonly)
Details for a subscribe action.
679 680 681 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 679 def subscribe @subscribe end |
#type ⇒ Object (readonly)
Type of the Billing Intent Action.
667 668 669 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 667 def type @type end |
Class Method Details
.field_encodings ⇒ Object
695 696 697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 695 def self.field_encodings @field_encodings = { apply: { kind: :object, fields: { invoice_discount_rule: { kind: :object, fields: { percent_off: { kind: :object, fields: { percent_off: :decimal_string } } }, }, }, }, } end |
.field_remappings ⇒ Object
691 692 693 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 691 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
681 682 683 684 685 686 687 688 689 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 681 def self.inner_class_types @inner_class_types = { apply: Apply, deactivate: Deactivate, modify: Modify, remove: Remove, subscribe: Subscribe, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 12 def self.object_name "v2.billing.intent_action" end |