Class: Stripe::V2::Billing::IntentAction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::IntentAction
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Overview
A Billing Intent Action represents a specific operation within a Billing Intent, such as subscribing to a Pricing Plan, modifying a subscription’s quantity, or deactivating service. Each action has a specific type and associated details that define what change will be made when the Intent is committed.
Defined Under Namespace
Classes: Apply, Deactivate, Modify, Remove, Subscribe
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.intent_action"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#apply ⇒ Object
readonly
Details for an apply action.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivate ⇒ Object
readonly
Details for a deactivate action.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#modify ⇒ Object
readonly
Details for a modify action.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#remove ⇒ Object
readonly
Details for a remove action.
-
#subscribe ⇒ Object
readonly
Details for a subscribe action.
-
#type ⇒ Object
readonly
Type of the Billing Intent Action.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#apply ⇒ Object (readonly)
Details for an apply action.
590 591 592 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 590 def apply @apply end |
#created ⇒ Object (readonly)
Time at which the object was created.
580 581 582 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 580 def created @created end |
#deactivate ⇒ Object (readonly)
Details for a deactivate action.
592 593 594 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 592 def deactivate @deactivate end |
#id ⇒ Object (readonly)
Unique identifier for the object.
582 583 584 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 582 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
588 589 590 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 588 def livemode @livemode end |
#modify ⇒ Object (readonly)
Details for a modify action.
594 595 596 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 594 def modify @modify end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
584 585 586 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 584 def object @object end |
#remove ⇒ Object (readonly)
Details for a remove action.
596 597 598 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 596 def remove @remove end |
#subscribe ⇒ Object (readonly)
Details for a subscribe action.
598 599 600 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 598 def subscribe @subscribe end |
#type ⇒ Object (readonly)
Type of the Billing Intent Action.
586 587 588 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 586 def type @type end |
Class Method Details
.field_remappings ⇒ Object
610 611 612 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 610 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
600 601 602 603 604 605 606 607 608 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 600 def self.inner_class_types @inner_class_types = { apply: Apply, deactivate: Deactivate, modify: Modify, remove: Remove, subscribe: Subscribe, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 12 def self.object_name "v2.billing.intent_action" end |