Class: Stripe::V2::Billing::IntentAction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::IntentAction
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: Apply, Deactivate, Modify, Remove, Subscribe
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.intent_action"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#apply ⇒ Object
readonly
Details for an apply action.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivate ⇒ Object
readonly
Details for a deactivate action.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#modify ⇒ Object
readonly
Details for a modify action.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#remove ⇒ Object
readonly
Details for a remove action.
-
#subscribe ⇒ Object
readonly
Details for a subscribe action.
-
#type ⇒ Object
readonly
Type of the Billing Intent Action.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#apply ⇒ Object (readonly)
Details for an apply action.
475 476 477 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 475 def apply @apply end |
#created ⇒ Object (readonly)
Time at which the object was created.
465 466 467 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 465 def created @created end |
#deactivate ⇒ Object (readonly)
Details for a deactivate action.
477 478 479 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 477 def deactivate @deactivate end |
#id ⇒ Object (readonly)
Unique identifier for the object.
467 468 469 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 467 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
473 474 475 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 473 def livemode @livemode end |
#modify ⇒ Object (readonly)
Details for a modify action.
479 480 481 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 479 def modify @modify end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
469 470 471 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 469 def object @object end |
#remove ⇒ Object (readonly)
Details for a remove action.
481 482 483 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 481 def remove @remove end |
#subscribe ⇒ Object (readonly)
Details for a subscribe action.
483 484 485 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 483 def subscribe @subscribe end |
#type ⇒ Object (readonly)
Type of the Billing Intent Action.
471 472 473 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 471 def type @type end |
Class Method Details
.field_remappings ⇒ Object
495 496 497 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 495 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
485 486 487 488 489 490 491 492 493 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 485 def self.inner_class_types @inner_class_types = { apply: Apply, deactivate: Deactivate, modify: Modify, remove: Remove, subscribe: Subscribe, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 9 def self.object_name "v2.billing.intent_action" end |