Class: Stripe::V2::Billing::IntentAction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::IntentAction
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: Apply, Deactivate, Modify, Remove, Subscribe
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.intent_action"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#apply ⇒ Object
readonly
Details for an apply action.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivate ⇒ Object
readonly
Details for a deactivate action.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#modify ⇒ Object
readonly
Details for a modify action.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#remove ⇒ Object
readonly
Details for a remove action.
-
#subscribe ⇒ Object
readonly
Details for a subscribe action.
-
#type ⇒ Object
readonly
Type of the Billing Intent Action.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#apply ⇒ Object (readonly)
Details for an apply action.
457 458 459 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 457 def apply @apply end |
#created ⇒ Object (readonly)
Time at which the object was created.
447 448 449 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 447 def created @created end |
#deactivate ⇒ Object (readonly)
Details for a deactivate action.
459 460 461 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 459 def deactivate @deactivate end |
#id ⇒ Object (readonly)
Unique identifier for the object.
449 450 451 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 449 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
455 456 457 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 455 def livemode @livemode end |
#modify ⇒ Object (readonly)
Details for a modify action.
461 462 463 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 461 def modify @modify end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
451 452 453 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 451 def object @object end |
#remove ⇒ Object (readonly)
Details for a remove action.
463 464 465 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 463 def remove @remove end |
#subscribe ⇒ Object (readonly)
Details for a subscribe action.
465 466 467 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 465 def subscribe @subscribe end |
#type ⇒ Object (readonly)
Type of the Billing Intent Action.
453 454 455 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 453 def type @type end |
Class Method Details
.field_remappings ⇒ Object
477 478 479 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 477 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
467 468 469 470 471 472 473 474 475 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 467 def self.inner_class_types @inner_class_types = { apply: Apply, deactivate: Deactivate, modify: Modify, remove: Remove, subscribe: Subscribe, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 9 def self.object_name "v2.billing.intent_action" end |