Class: Stripe::V2::Billing::IntentAction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::IntentAction
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: Apply, Deactivate, Modify, Remove, Subscribe
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.intent_action"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#apply ⇒ Object
readonly
Details for an apply action.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#deactivate ⇒ Object
readonly
Details for a deactivate action.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#modify ⇒ Object
readonly
Details for a modify action.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#remove ⇒ Object
readonly
Details for a remove action.
-
#subscribe ⇒ Object
readonly
Details for a subscribe action.
-
#type ⇒ Object
readonly
Type of the Billing Intent Action.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#apply ⇒ Object (readonly)
Details for an apply action.
369 370 371 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 369 def apply @apply end |
#created ⇒ Object (readonly)
Time at which the object was created.
359 360 361 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 359 def created @created end |
#deactivate ⇒ Object (readonly)
Details for a deactivate action.
371 372 373 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 371 def deactivate @deactivate end |
#id ⇒ Object (readonly)
Unique identifier for the object.
361 362 363 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 361 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
367 368 369 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 367 def livemode @livemode end |
#modify ⇒ Object (readonly)
Details for a modify action.
373 374 375 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 373 def modify @modify end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
363 364 365 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 363 def object @object end |
#remove ⇒ Object (readonly)
Details for a remove action.
375 376 377 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 375 def remove @remove end |
#subscribe ⇒ Object (readonly)
Details for a subscribe action.
377 378 379 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 377 def subscribe @subscribe end |
#type ⇒ Object (readonly)
Type of the Billing Intent Action.
365 366 367 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 365 def type @type end |
Class Method Details
.field_remappings ⇒ Object
389 390 391 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 389 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
379 380 381 382 383 384 385 386 387 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 379 def self.inner_class_types @inner_class_types = { apply: Apply, deactivate: Deactivate, modify: Modify, remove: Remove, subscribe: Subscribe, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 9 def self.object_name "v2.billing.intent_action" end |