Class: Stripe::V2::Billing::IntentAction

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Defined Under Namespace

Classes: Apply, Deactivate, Modify, Remove, Subscribe

Constant Summary collapse

OBJECT_NAME =
"v2.billing.intent_action"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applyObject (readonly)

Details for an apply action.



188
189
190
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 188

def apply
  @apply
end

#createdObject (readonly)

Time at which the object was created.



178
179
180
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 178

def created
  @created
end

#deactivateObject (readonly)

Details for a deactivate action.



190
191
192
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 190

def deactivate
  @deactivate
end

#idObject (readonly)

Unique identifier for the object.



180
181
182
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 180

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



186
187
188
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 186

def livemode
  @livemode
end

#modifyObject (readonly)

Details for a modify action.



192
193
194
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 192

def modify
  @modify
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



182
183
184
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 182

def object
  @object
end

#removeObject (readonly)

Details for a remove action.



194
195
196
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 194

def remove
  @remove
end

#subscribeObject (readonly)

Details for a subscribe action.



196
197
198
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 196

def subscribe
  @subscribe
end

#typeObject (readonly)

Type of the Billing Intent Action.



184
185
186
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 184

def type
  @type
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 9

def self.object_name
  "v2.billing.intent_action"
end