Class: Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: PercentOff
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
readonly
The entity that the discount rule applies to, for example, the Billing Cadence.
-
#invoice_discount_rule ⇒ Object
readonly
The ID of the created discount rule.
-
#percent_off ⇒ Object
readonly
Configuration for percentage off discount.
-
#type ⇒ Object
readonly
Type of the discount rule.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applies_to ⇒ Object (readonly)
The entity that the discount rule applies to, for example, the Billing Cadence.
42 43 44 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 42 def applies_to @applies_to end |
#invoice_discount_rule ⇒ Object (readonly)
The ID of the created discount rule. This is only present once the Billing Intent is committed and the discount rule is created.
44 45 46 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 44 def invoice_discount_rule @invoice_discount_rule end |
#percent_off ⇒ Object (readonly)
Configuration for percentage off discount.
48 49 50 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 48 def percent_off @percent_off end |
#type ⇒ Object (readonly)
Type of the discount rule.
46 47 48 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 46 def type @type end |
Class Method Details
.field_remappings ⇒ Object
54 55 56 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 54 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
50 51 52 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 50 def self.inner_class_types @inner_class_types = { percent_off: PercentOff } end |