Class: Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Apply::InvoiceDiscountRule
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: PercentOff
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
readonly
The entity that the discount rule applies to, for example, the Billing Cadence.
-
#invoice_discount_rule ⇒ Object
readonly
The ID of the created discount rule.
-
#percent_off ⇒ Object
readonly
Configuration for percentage off discount.
-
#type ⇒ Object
readonly
Type of the discount rule.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applies_to ⇒ Object (readonly)
The entity that the discount rule applies to, for example, the Billing Cadence.
26 27 28 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 26 def applies_to @applies_to end |
#invoice_discount_rule ⇒ Object (readonly)
The ID of the created discount rule. This is only present once the Billing Intent is committed and the discount rule is created.
28 29 30 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 28 def invoice_discount_rule @invoice_discount_rule end |
#percent_off ⇒ Object (readonly)
Configuration for percentage off discount.
32 33 34 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 32 def percent_off @percent_off end |
#type ⇒ Object (readonly)
Type of the discount rule.
30 31 32 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 30 def type @type end |