Class: Stripe::V2::Billing::IntentAction::Deactivate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Deactivate
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: CancellationDetails, EffectiveAt, PricingPlanSubscriptionDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cancellation_details ⇒ Object
readonly
Details about why the cancellation was requested by the user.
-
#collect_at ⇒ Object
readonly
Allows users to override the collect at behavior.
-
#effective_at ⇒ Object
readonly
When the deactivate action will take effect.
-
#pricing_plan_subscription_details ⇒ Object
readonly
Details for deactivating a Pricing Plan Subscription.
-
#type ⇒ Object
readonly
Type of the action details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cancellation_details ⇒ Object (readonly)
Details about why the cancellation was requested by the user.
156 157 158 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 156 def cancellation_details @cancellation_details end |
#collect_at ⇒ Object (readonly)
Allows users to override the collect at behavior.
158 159 160 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 158 def collect_at @collect_at end |
#effective_at ⇒ Object (readonly)
When the deactivate action will take effect. If not specified, the default behavior is on_reserve.
160 161 162 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 160 def effective_at @effective_at end |
#pricing_plan_subscription_details ⇒ Object (readonly)
Details for deactivating a Pricing Plan Subscription.
164 165 166 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 164 def pricing_plan_subscription_details @pricing_plan_subscription_details end |
#type ⇒ Object (readonly)
Type of the action details.
162 163 164 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 162 def type @type end |
Class Method Details
.field_remappings ⇒ Object
174 175 176 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 174 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
166 167 168 169 170 171 172 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 166 def self.inner_class_types @inner_class_types = { cancellation_details: CancellationDetails, effective_at: EffectiveAt, pricing_plan_subscription_details: PricingPlanSubscriptionDetails, } end |