Class: Stripe::V2::Billing::IntentAction::Deactivate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Deactivate
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: CancellationDetails, EffectiveAt, PricingPlanSubscriptionDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cancellation_details ⇒ Object
readonly
Details about why the cancellation was requested by the user.
-
#collect_at ⇒ Object
readonly
Allows users to override the collect at behavior.
-
#effective_at ⇒ Object
readonly
When the deactivate action will take effect.
-
#pricing_plan_subscription_details ⇒ Object
readonly
Details for deactivating a Pricing Plan Subscription.
-
#type ⇒ Object
readonly
Type of the action details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cancellation_details ⇒ Object (readonly)
Details about why the cancellation was requested by the user.
252 253 254 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 252 def cancellation_details @cancellation_details end |
#collect_at ⇒ Object (readonly)
Allows users to override the collect at behavior.
254 255 256 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 254 def collect_at @collect_at end |
#effective_at ⇒ Object (readonly)
When the deactivate action will take effect. If not specified, the default behavior is on_reserve.
256 257 258 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 256 def effective_at @effective_at end |
#pricing_plan_subscription_details ⇒ Object (readonly)
Details for deactivating a Pricing Plan Subscription.
260 261 262 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 260 def pricing_plan_subscription_details @pricing_plan_subscription_details end |
#type ⇒ Object (readonly)
Type of the action details.
258 259 260 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 258 def type @type end |
Class Method Details
.field_remappings ⇒ Object
270 271 272 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 270 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
262 263 264 265 266 267 268 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 262 def self.inner_class_types @inner_class_types = { cancellation_details: CancellationDetails, effective_at: EffectiveAt, pricing_plan_subscription_details: PricingPlanSubscriptionDetails, } end |