Class: Stripe::V2::Billing::IntentAction::Deactivate::CancellationDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Deactivate::CancellationDetails
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#comment ⇒ Object
readonly
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
-
#feedback ⇒ Object
readonly
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#comment ⇒ Object (readonly)
Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.
217 218 219 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 217 def comment @comment end |
#feedback ⇒ Object (readonly)
The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.
219 220 221 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 219 def feedback @feedback end |
Class Method Details
.field_remappings ⇒ Object
225 226 227 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 225 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
221 222 223 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 221 def self.inner_class_types @inner_class_types = {} end |