Class: Stripe::V2::Billing::IntentAction::Modify::EffectiveAt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Modify::EffectiveAt
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
readonly
The timestamp at which the modify action will take effect.
-
#type ⇒ Object
readonly
When the modify action will take effect.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#timestamp ⇒ Object (readonly)
The timestamp at which the modify action will take effect. Only present if type is timestamp.
151 152 153 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 151 def @timestamp end |
#type ⇒ Object (readonly)
When the modify action will take effect.
153 154 155 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 153 def type @type end |
Class Method Details
.field_remappings ⇒ Object
159 160 161 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 159 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
155 156 157 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 155 def self.inner_class_types @inner_class_types = {} end |