Class: Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: ComponentConfiguration
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
readonly
New configurations for the components of the Pricing Plan.
-
#new_pricing_plan ⇒ Object
readonly
ID of the new Pricing Plan.
-
#new_pricing_plan_version ⇒ Object
readonly
Version of the Pricing Plan to use.
-
#pricing_plan_subscription ⇒ Object
readonly
ID of the Pricing Plan Subscription to modify.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#component_configurations ⇒ Object (readonly)
New configurations for the components of the Pricing Plan.
182 183 184 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 182 def component_configurations @component_configurations end |
#new_pricing_plan ⇒ Object (readonly)
ID of the new Pricing Plan.
184 185 186 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 184 def new_pricing_plan @new_pricing_plan end |
#new_pricing_plan_version ⇒ Object (readonly)
Version of the Pricing Plan to use.
186 187 188 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 186 def new_pricing_plan_version @new_pricing_plan_version end |
#pricing_plan_subscription ⇒ Object (readonly)
ID of the Pricing Plan Subscription to modify.
188 189 190 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 188 def pricing_plan_subscription @pricing_plan_subscription end |
Class Method Details
.field_remappings ⇒ Object
194 195 196 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 194 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
190 191 192 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 190 def self.inner_class_types @inner_class_types = { component_configurations: ComponentConfiguration } end |