Class: Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: ComponentConfiguration
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
readonly
New configurations for the components of the Pricing Plan.
-
#new_pricing_plan ⇒ Object
readonly
ID of the new Pricing Plan.
-
#new_pricing_plan_version ⇒ Object
readonly
Version of the Pricing Plan to use.
-
#pricing_plan_subscription ⇒ Object
readonly
ID of the Pricing Plan Subscription to modify.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#component_configurations ⇒ Object (readonly)
New configurations for the components of the Pricing Plan.
90 91 92 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 90 def component_configurations @component_configurations end |
#new_pricing_plan ⇒ Object (readonly)
ID of the new Pricing Plan.
92 93 94 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 92 def new_pricing_plan @new_pricing_plan end |
#new_pricing_plan_version ⇒ Object (readonly)
Version of the Pricing Plan to use.
94 95 96 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 94 def new_pricing_plan_version @new_pricing_plan_version end |
#pricing_plan_subscription ⇒ Object (readonly)
ID of the Pricing Plan Subscription to modify.
96 97 98 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 96 def pricing_plan_subscription @pricing_plan_subscription end |