Class: Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Defined Under Namespace

Classes: LicenseFee, RecurringCreditGrant

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#license_feeObject (readonly)

Overrides the behavior for license fee components when the action takes effect during the service period.



387
388
389
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 387

def license_fee
  @license_fee
end

#recurring_credit_grantObject (readonly)

Overrides the behavior for recurring credit grant components when the action takes effect during the service period.



389
390
391
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 389

def recurring_credit_grant
  @recurring_credit_grant
end

#typeObject (readonly)

The type of behavior to override.



385
386
387
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 385

def type
  @type
end

Class Method Details

.field_remappingsObject



398
399
400
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 398

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



391
392
393
394
395
396
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 391

def self.inner_class_types
  @inner_class_types = {
    license_fee: LicenseFee,
    recurring_credit_grant: RecurringCreditGrant,
  }
end