Class: Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#credit_proration_behavior ⇒ Object
readonly
The proration behavior for the partial servicing period.
-
#debit_proration_behavior ⇒ Object
readonly
The proration behavior for the partial servicing period.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#credit_proration_behavior ⇒ Object (readonly)
The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.
316 317 318 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 316 def credit_proration_behavior @credit_proration_behavior end |
#debit_proration_behavior ⇒ Object (readonly)
The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.
318 319 320 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 318 def debit_proration_behavior @debit_proration_behavior end |
Class Method Details
.field_remappings ⇒ Object
324 325 326 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 324 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
320 321 322 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 320 def self.inner_class_types @inner_class_types = {} end |