Class: Stripe::V2::Billing::IntentAction::Remove
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Remove
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice_discount_rule ⇒ Object
readonly
The ID of the discount rule to remove for future invoices.
-
#type ⇒ Object
readonly
Type of the remove action.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice_discount_rule ⇒ Object (readonly)
The ID of the discount rule to remove for future invoices.
300 301 302 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 300 def invoice_discount_rule @invoice_discount_rule end |
#type ⇒ Object (readonly)
Type of the remove action.
298 299 300 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 298 def type @type end |
Class Method Details
.field_remappings ⇒ Object
306 307 308 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 306 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
302 303 304 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 302 def self.inner_class_types @inner_class_types = {} end |