Class: Stripe::V2::Billing::IntentAction::Remove
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Remove
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice_discount_rule ⇒ Object
readonly
The ID of the discount rule to remove for future invoices.
-
#type ⇒ Object
readonly
Type of the remove action.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice_discount_rule ⇒ Object (readonly)
The ID of the discount rule to remove for future invoices.
224 225 226 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 224 def invoice_discount_rule @invoice_discount_rule end |
#type ⇒ Object (readonly)
Type of the remove action.
222 223 224 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 222 def type @type end |
Class Method Details
.field_remappings ⇒ Object
230 231 232 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 230 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
226 227 228 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 226 def self.inner_class_types @inner_class_types = {} end |