Class: Stripe::V2::Billing::IntentAction::Remove
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Remove
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#invoice_discount_rule ⇒ Object
readonly
The ID of the discount rule to remove for future invoices.
-
#type ⇒ Object
readonly
Type of the remove action.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#invoice_discount_rule ⇒ Object (readonly)
The ID of the discount rule to remove for future invoices.
112 113 114 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 112 def invoice_discount_rule @invoice_discount_rule end |
#type ⇒ Object (readonly)
Type of the remove action.
110 111 112 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 110 def type @type end |