Class: Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Defined Under Namespace

Classes: ComponentConfiguration, Overrides

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#component_configurationsObject (readonly)

Configurations for the components of the Pricing Plan.



499
500
501
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 499

def component_configurations
  @component_configurations
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



501
502
503
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 501

def 
  @metadata
end

#overridesObject (readonly)

Configurations for overriding behaviors related to the subscription.



503
504
505
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 503

def overrides
  @overrides
end

#pricing_planObject (readonly)

ID of the Pricing Plan to subscribe to.



505
506
507
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 505

def pricing_plan
  @pricing_plan
end

#pricing_plan_subscriptionObject (readonly)

ID of the created Pricing Plan Subscription. This is only present once the Billing Intent is committed and the Pricing Plan Subscription is created.



507
508
509
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 507

def pricing_plan_subscription
  @pricing_plan_subscription
end

#pricing_plan_versionObject (readonly)

Version of the Pricing Plan to use.



509
510
511
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 509

def pricing_plan_version
  @pricing_plan_version
end

Class Method Details

.field_remappingsObject



518
519
520
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 518

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



511
512
513
514
515
516
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 511

def self.inner_class_types
  @inner_class_types = {
    component_configurations: ComponentConfiguration,
    overrides: Overrides,
  }
end