Class: Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: ComponentConfiguration
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
readonly
Configurations for the components of the Pricing Plan.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#pricing_plan ⇒ Object
readonly
ID of the Pricing Plan to subscribe to.
-
#pricing_plan_subscription ⇒ Object
readonly
ID of the created Pricing Plan Subscription.
-
#pricing_plan_version ⇒ Object
readonly
Version of the Pricing Plan to use.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#component_configurations ⇒ Object (readonly)
Configurations for the components of the Pricing Plan.
282 283 284 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 282 def component_configurations @component_configurations end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
284 285 286 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 284 def @metadata end |
#pricing_plan ⇒ Object (readonly)
ID of the Pricing Plan to subscribe to.
286 287 288 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 286 def pricing_plan @pricing_plan end |
#pricing_plan_subscription ⇒ Object (readonly)
ID of the created Pricing Plan Subscription. This is only present once the Billing Intent is committed and the Pricing Plan Subscription is created.
288 289 290 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 288 def pricing_plan_subscription @pricing_plan_subscription end |
#pricing_plan_version ⇒ Object (readonly)
Version of the Pricing Plan to use.
290 291 292 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 290 def pricing_plan_version @pricing_plan_version end |
Class Method Details
.field_remappings ⇒ Object
296 297 298 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 296 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
292 293 294 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 292 def self.inner_class_types @inner_class_types = { component_configurations: ComponentConfiguration } end |