Class: Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: ComponentConfiguration
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
readonly
Configurations for the components of the Pricing Plan.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#pricing_plan ⇒ Object
readonly
ID of the Pricing Plan to subscribe to.
-
#pricing_plan_subscription ⇒ Object
readonly
ID of the created Pricing Plan Subscription.
-
#pricing_plan_version ⇒ Object
readonly
Version of the Pricing Plan to use.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#component_configurations ⇒ Object (readonly)
Configurations for the components of the Pricing Plan.
138 139 140 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 138 def component_configurations @component_configurations end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
140 141 142 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 140 def @metadata end |
#pricing_plan ⇒ Object (readonly)
ID of the Pricing Plan to subscribe to.
142 143 144 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 142 def pricing_plan @pricing_plan end |
#pricing_plan_subscription ⇒ Object (readonly)
ID of the created Pricing Plan Subscription. This is only present once the Billing Intent is committed and the Pricing Plan Subscription is created.
144 145 146 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 144 def pricing_plan_subscription @pricing_plan_subscription end |
#pricing_plan_version ⇒ Object (readonly)
Version of the Pricing Plan to use.
146 147 148 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 146 def pricing_plan_version @pricing_plan_version end |