Class: Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::IntentAction::Subscribe::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior
- Defined in:
- lib/stripe/resources/v2/billing/intent_action.rb
Defined Under Namespace
Classes: LicenseFee, RecurringCreditGrant
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#license_fee ⇒ Object
readonly
Overrides the behavior for license fee components when the action takes effect during the service period.
-
#recurring_credit_grant ⇒ Object
readonly
Overrides the behavior for recurring credit grant components when the action takes effect during the service period.
-
#type ⇒ Object
readonly
The type of behavior to override.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#license_fee ⇒ Object (readonly)
Overrides the behavior for license fee components when the action takes effect during the service period.
551 552 553 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 551 def license_fee @license_fee end |
#recurring_credit_grant ⇒ Object (readonly)
Overrides the behavior for recurring credit grant components when the action takes effect during the service period.
553 554 555 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 553 def recurring_credit_grant @recurring_credit_grant end |
#type ⇒ Object (readonly)
The type of behavior to override.
555 556 557 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 555 def type @type end |
Class Method Details
.field_remappings ⇒ Object
564 565 566 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 564 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
557 558 559 560 561 562 |
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 557 def self.inner_class_types @inner_class_types = { license_fee: LicenseFee, recurring_credit_grant: RecurringCreditGrant, } end |