Class: Stripe::V2::Billing::IntentAction::Subscribe::V1SubscriptionDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/intent_action.rb

Defined Under Namespace

Classes: Item

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#descriptionObject (readonly)

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



409
410
411
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 409

def description
  @description
end

#itemsObject (readonly)

A list of up to 20 subscription items, each with an attached price.



411
412
413
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 411

def items
  @items
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



413
414
415
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 413

def 
  @metadata
end

Class Method Details

.field_remappingsObject



419
420
421
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 419

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



415
416
417
# File 'lib/stripe/resources/v2/billing/intent_action.rb', line 415

def self.inner_class_types
  @inner_class_types = { items: Item }
end