Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Apply
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: EffectiveAt, InvoiceDiscountRule, SpendModifierRule
Instance Attribute Summary collapse
-
#effective_at ⇒ Object
When the apply action will take effect.
-
#invoice_discount_rule ⇒ Object
Details for applying a discount rule to future invoices.
-
#spend_modifier_rule ⇒ Object
Details for applying a spend modifier rule.
-
#type ⇒ Object
Type of the apply action details.
Instance Method Summary collapse
-
#initialize(effective_at: nil, type: nil, invoice_discount_rule: nil, spend_modifier_rule: nil) ⇒ Apply
constructor
A new instance of Apply.
Methods inherited from RequestParams
Constructor Details
#initialize(effective_at: nil, type: nil, invoice_discount_rule: nil, spend_modifier_rule: nil) ⇒ Apply
Returns a new instance of Apply.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 115 def initialize( effective_at: nil, type: nil, invoice_discount_rule: nil, spend_modifier_rule: nil ) @effective_at = effective_at @type = type @invoice_discount_rule = invoice_discount_rule @spend_modifier_rule = spend_modifier_rule end |
Instance Attribute Details
#effective_at ⇒ Object
When the apply action will take effect. Defaults to on_reserve if not specified.
107 108 109 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 107 def effective_at @effective_at end |
#invoice_discount_rule ⇒ Object
Details for applying a discount rule to future invoices.
111 112 113 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 111 def invoice_discount_rule @invoice_discount_rule end |
#spend_modifier_rule ⇒ Object
Details for applying a spend modifier rule. Only present if type is spend_modifier_rule.
113 114 115 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 113 def spend_modifier_rule @spend_modifier_rule end |
#type ⇒ Object
Type of the apply action details.
109 110 111 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 109 def type @type end |