Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Apply
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: InvoiceDiscountRule
Instance Attribute Summary collapse
-
#invoice_discount_rule ⇒ Object
Details for applying a discount rule to future invoices.
-
#type ⇒ Object
Type of the apply action details.
Instance Method Summary collapse
-
#initialize(type: nil, invoice_discount_rule: nil) ⇒ Apply
constructor
A new instance of Apply.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, invoice_discount_rule: nil) ⇒ Apply
Returns a new instance of Apply.
48 49 50 51 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 48 def initialize(type: nil, invoice_discount_rule: nil) @type = type @invoice_discount_rule = invoice_discount_rule end |
Instance Attribute Details
#invoice_discount_rule ⇒ Object
Details for applying a discount rule to future invoices.
46 47 48 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 46 def invoice_discount_rule @invoice_discount_rule end |
#type ⇒ Object
Type of the apply action details.
44 45 46 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 44 def type @type end |