Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: PercentOff
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
The entity that the discount rule applies to, for example, the cadence.
-
#percent_off ⇒ Object
Configuration for percentage off discount.
-
#type ⇒ Object
Type of the discount rule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, type: nil, percent_off: nil) ⇒ InvoiceDiscountRule
constructor
A new instance of InvoiceDiscountRule.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, type: nil, percent_off: nil) ⇒ InvoiceDiscountRule
Returns a new instance of InvoiceDiscountRule.
46 47 48 49 50 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 46 def initialize(applies_to: nil, type: nil, percent_off: nil) @applies_to = applies_to @type = type @percent_off = percent_off end |
Instance Attribute Details
#applies_to ⇒ Object
The entity that the discount rule applies to, for example, the cadence.
40 41 42 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 40 def applies_to @applies_to end |
#percent_off ⇒ Object
Configuration for percentage off discount.
44 45 46 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 44 def percent_off @percent_off end |
#type ⇒ Object
Type of the discount rule.
42 43 44 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 42 def type @type end |