Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: PercentOff
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
The entity that the discount rule applies to, for example, the cadence.
-
#percent_off ⇒ Object
Configuration for percentage off discount.
-
#type ⇒ Object
Type of the discount rule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, type: nil, percent_off: nil) ⇒ InvoiceDiscountRule
constructor
A new instance of InvoiceDiscountRule.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, type: nil, percent_off: nil) ⇒ InvoiceDiscountRule
Returns a new instance of InvoiceDiscountRule.
37 38 39 40 41 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 37 def initialize(applies_to: nil, type: nil, percent_off: nil) @applies_to = applies_to @type = type @percent_off = percent_off end |
Instance Attribute Details
#applies_to ⇒ Object
The entity that the discount rule applies to, for example, the cadence.
31 32 33 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 31 def applies_to @applies_to end |
#percent_off ⇒ Object
Configuration for percentage off discount.
35 36 37 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 35 def percent_off @percent_off end |
#type ⇒ Object
Type of the discount rule.
33 34 35 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 33 def type @type end |