Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply::InvoiceDiscountRule::PercentOff

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: MaximumApplications

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(maximum_applications: nil, percent_off: nil) ⇒ PercentOff

Returns a new instance of PercentOff.



25
26
27
28
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 25

def initialize(maximum_applications: nil, percent_off: nil)
  @maximum_applications = maximum_applications
  @percent_off = percent_off
end

Instance Attribute Details

#maximum_applicationsObject

The maximum number of times this discount can be applied for this cadence.



21
22
23
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 21

def maximum_applications
  @maximum_applications
end

#percent_offObject

Percent that will be taken off of the amount. For example, percent_off of 50.0 will make $100 amount $50 instead.



23
24
25
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 23

def percent_off
  @percent_off
end