Class: Stripe::V2::Billing::IntentCreateParams::Action::Apply::SpendModifierRule::MaxBillingPeriodSpend
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Apply::SpendModifierRule::MaxBillingPeriodSpend
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Amount, CustomPricingUnitOverageRate
Instance Attribute Summary collapse
-
#amount ⇒ Object
The maximum amount allowed for the billing period.
-
#custom_pricing_unit_overage_rate ⇒ Object
The configration for the overage rate for the custom pricing unit.
Instance Method Summary collapse
-
#initialize(amount: nil, custom_pricing_unit_overage_rate: nil) ⇒ MaxBillingPeriodSpend
constructor
A new instance of MaxBillingPeriodSpend.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, custom_pricing_unit_overage_rate: nil) ⇒ MaxBillingPeriodSpend
Returns a new instance of MaxBillingPeriodSpend.
88 89 90 91 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 88 def initialize(amount: nil, custom_pricing_unit_overage_rate: nil) @amount = amount @custom_pricing_unit_overage_rate = custom_pricing_unit_overage_rate end |
Instance Attribute Details
#amount ⇒ Object
The maximum amount allowed for the billing period.
84 85 86 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 84 def amount @amount end |
#custom_pricing_unit_overage_rate ⇒ Object
The configration for the overage rate for the custom pricing unit.
86 87 88 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 86 def custom_pricing_unit_overage_rate @custom_pricing_unit_overage_rate end |