Class: Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



61
62
63
64
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 61

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



57
58
59
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 57

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



59
60
61
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 59

def feedback
  @feedback
end