Class: Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::CancellationDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(comment: nil, feedback: nil) ⇒ CancellationDetails

Returns a new instance of CancellationDetails.



135
136
137
138
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 135

def initialize(comment: nil, feedback: nil)
  @comment = comment
  @feedback = feedback
end

Instance Attribute Details

#commentObject

Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.



131
132
133
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 131

def comment
  @comment
end

#feedbackObject

The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user.



133
134
135
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 133

def feedback
  @feedback
end