Class: Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Deactivate::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the deactivate action will take effect.
-
#type ⇒ Object
When the deactivate action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
147 148 149 150 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 147 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the deactivate action will take effect. Only present if type is timestamp.
143 144 145 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 143 def @timestamp end |
#type ⇒ Object
When the deactivate action will take effect.
145 146 147 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 145 def type @type end |