Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: ComponentConfiguration, Overrides

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails

Returns a new instance of PricingPlanSubscriptionDetails.



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 287

def initialize(
  component_configurations: nil,
  new_pricing_plan: nil,
  new_pricing_plan_version: nil,
  overrides: nil,
  pricing_plan_subscription: nil
)
  @component_configurations = component_configurations
  @new_pricing_plan = new_pricing_plan
  @new_pricing_plan_version = new_pricing_plan_version
  @overrides = overrides
  @pricing_plan_subscription = pricing_plan_subscription
end

Instance Attribute Details

#component_configurationsObject

New configurations for the components of the pricing plan.



277
278
279
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 277

def component_configurations
  @component_configurations
end

#new_pricing_planObject

The ID of the new Pricing Plan, if changing plans.



279
280
281
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 279

def new_pricing_plan
  @new_pricing_plan
end

#new_pricing_plan_versionObject

The ID of the new Pricing Plan Version to use.



281
282
283
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 281

def new_pricing_plan_version
  @new_pricing_plan_version
end

#overridesObject

Configurations for overriding behaviors related to the subscription.



283
284
285
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 283

def overrides
  @overrides
end

#pricing_plan_subscriptionObject

The ID of the Pricing Plan Subscription to modify.



285
286
287
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 285

def pricing_plan_subscription
  @pricing_plan_subscription
end