Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: ComponentConfiguration, Overrides
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
New configurations for the components of the pricing plan.
-
#new_pricing_plan ⇒ Object
The ID of the new Pricing Plan, if changing plans.
-
#new_pricing_plan_version ⇒ Object
The ID of the new Pricing Plan Version to use.
-
#overrides ⇒ Object
Allows users to override the partial period behavior.
-
#pricing_plan_subscription ⇒ Object
The ID of the Pricing Plan Subscription to modify.
Instance Method Summary collapse
-
#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails
constructor
A new instance of PricingPlanSubscriptionDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails
Returns a new instance of PricingPlanSubscriptionDetails.
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 213 def initialize( component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil ) @component_configurations = component_configurations @new_pricing_plan = new_pricing_plan @new_pricing_plan_version = new_pricing_plan_version @overrides = overrides @pricing_plan_subscription = pricing_plan_subscription end |
Instance Attribute Details
#component_configurations ⇒ Object
New configurations for the components of the pricing plan.
203 204 205 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 203 def component_configurations @component_configurations end |
#new_pricing_plan ⇒ Object
The ID of the new Pricing Plan, if changing plans.
205 206 207 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 205 def new_pricing_plan @new_pricing_plan end |
#new_pricing_plan_version ⇒ Object
The ID of the new Pricing Plan Version to use.
207 208 209 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 207 def new_pricing_plan_version @new_pricing_plan_version end |
#overrides ⇒ Object
Allows users to override the partial period behavior.
209 210 211 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 209 def overrides @overrides end |
#pricing_plan_subscription ⇒ Object
The ID of the Pricing Plan Subscription to modify.
211 212 213 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 211 def pricing_plan_subscription @pricing_plan_subscription end |