Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: ComponentConfiguration, Overrides

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, overrides: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails

Returns a new instance of PricingPlanSubscriptionDetails.



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 197

def initialize(
  component_configurations: nil,
  new_pricing_plan: nil,
  new_pricing_plan_version: nil,
  overrides: nil,
  pricing_plan_subscription: nil
)
  @component_configurations = component_configurations
  @new_pricing_plan = new_pricing_plan
  @new_pricing_plan_version = new_pricing_plan_version
  @overrides = overrides
  @pricing_plan_subscription = pricing_plan_subscription
end

Instance Attribute Details

#component_configurationsObject

New configurations for the components of the pricing plan.



187
188
189
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 187

def component_configurations
  @component_configurations
end

#new_pricing_planObject

The ID of the new Pricing Plan, if changing plans.



189
190
191
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 189

def new_pricing_plan
  @new_pricing_plan
end

#new_pricing_plan_versionObject

The ID of the new Pricing Plan Version to use.



191
192
193
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 191

def new_pricing_plan_version
  @new_pricing_plan_version
end

#overridesObject

Allows users to override the partial period behavior.



193
194
195
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 193

def overrides
  @overrides
end

#pricing_plan_subscriptionObject

The ID of the Pricing Plan Subscription to modify.



195
196
197
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 195

def pricing_plan_subscription
  @pricing_plan_subscription
end