Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: ComponentConfiguration
Instance Attribute Summary collapse
-
#component_configurations ⇒ Object
New configurations for the components of the pricing plan.
-
#new_pricing_plan ⇒ Object
The ID of the new Pricing Plan, if changing plans.
-
#new_pricing_plan_version ⇒ Object
The ID of the new Pricing Plan Version to use.
-
#pricing_plan_subscription ⇒ Object
The ID of the Pricing Plan Subscription to modify.
Instance Method Summary collapse
-
#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails
constructor
A new instance of PricingPlanSubscriptionDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, pricing_plan_subscription: nil) ⇒ PricingPlanSubscriptionDetails
Returns a new instance of PricingPlanSubscriptionDetails.
152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 152 def initialize( component_configurations: nil, new_pricing_plan: nil, new_pricing_plan_version: nil, pricing_plan_subscription: nil ) @component_configurations = component_configurations @new_pricing_plan = new_pricing_plan @new_pricing_plan_version = new_pricing_plan_version @pricing_plan_subscription = pricing_plan_subscription end |
Instance Attribute Details
#component_configurations ⇒ Object
New configurations for the components of the pricing plan.
144 145 146 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 144 def component_configurations @component_configurations end |
#new_pricing_plan ⇒ Object
The ID of the new Pricing Plan, if changing plans.
146 147 148 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 146 def new_pricing_plan @new_pricing_plan end |
#new_pricing_plan_version ⇒ Object
The ID of the new Pricing Plan Version to use.
148 149 150 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 148 def new_pricing_plan_version @new_pricing_plan_version end |
#pricing_plan_subscription ⇒ Object
The ID of the Pricing Plan Subscription to modify.
150 151 152 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 150 def pricing_plan_subscription @pricing_plan_subscription end |