Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: LicenseFee, RecurringCreditGrant
Instance Attribute Summary collapse
-
#license_fee ⇒ Object
Overrides the behavior for license fee components when the action takes effect during the service period.
-
#recurring_credit_grant ⇒ Object
Overrides the behavior for recurring credit grant components when the action takes effect during the service period.
-
#type ⇒ Object
The type of behavior to override.
Instance Method Summary collapse
-
#initialize(license_fee: nil, recurring_credit_grant: nil, type: nil) ⇒ PartialPeriodBehavior
constructor
A new instance of PartialPeriodBehavior.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(license_fee: nil, recurring_credit_grant: nil, type: nil) ⇒ PartialPeriodBehavior
Returns a new instance of PartialPeriodBehavior.
319 320 321 322 323 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 319 def initialize(license_fee: nil, recurring_credit_grant: nil, type: nil) @license_fee = license_fee @recurring_credit_grant = recurring_credit_grant @type = type end |
Instance Attribute Details
#license_fee ⇒ Object
Overrides the behavior for license fee components when the action takes effect during the service period.
313 314 315 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 313 def license_fee @license_fee end |
#recurring_credit_grant ⇒ Object
Overrides the behavior for recurring credit grant components when the action takes effect during the service period.
315 316 317 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 315 def recurring_credit_grant @recurring_credit_grant end |
#type ⇒ Object
The type of behavior to override.
317 318 319 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 317 def type @type end |