Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: LicenseFee, RecurringCreditGrant

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(type: nil, license_fee: nil, recurring_credit_grant: nil) ⇒ PartialPeriodBehavior

Returns a new instance of PartialPeriodBehavior.



316
317
318
319
320
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 316

def initialize(type: nil, license_fee: nil, recurring_credit_grant: nil)
  @type = type
  @license_fee = license_fee
  @recurring_credit_grant = recurring_credit_grant
end

Instance Attribute Details

#license_feeObject

Overrides the behavior for license fee components when the action takes effect during the service period.



312
313
314
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 312

def license_fee
  @license_fee
end

#recurring_credit_grantObject

Overrides the behavior for recurring credit grant components when the action takes effect during the service period.



314
315
316
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 314

def recurring_credit_grant
  @recurring_credit_grant
end

#typeObject

The type of behavior to override.



310
311
312
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 310

def type
  @type
end