Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#credit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period.
-
#debit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period.
Instance Method Summary collapse
-
#initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) ⇒ LicenseFee
constructor
A new instance of LicenseFee.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) ⇒ LicenseFee
Returns a new instance of LicenseFee.
295 296 297 298 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 295 def initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) @credit_proration_behavior = credit_proration_behavior @debit_proration_behavior = debit_proration_behavior end |
Instance Attribute Details
#credit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.
291 292 293 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 291 def credit_proration_behavior @credit_proration_behavior end |
#debit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user modifies the subscription. If not specified, defaults to prorated.
293 294 295 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 293 def debit_proration_behavior @debit_proration_behavior end |