Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) ⇒ LicenseFee

Returns a new instance of LicenseFee.



254
255
256
257
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 254

def initialize(credit_proration_behavior: nil, debit_proration_behavior: nil)
  @credit_proration_behavior = credit_proration_behavior
  @debit_proration_behavior = debit_proration_behavior
end

Instance Attribute Details

#credit_proration_behaviorObject

The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user is upgrading.



250
251
252
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 250

def credit_proration_behavior
  @credit_proration_behavior
end

#debit_proration_behaviorObject

The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user is downgrading.



252
253
254
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 252

def debit_proration_behavior
  @debit_proration_behavior
end