Class: Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Modify::PricingPlanSubscriptionDetails::Overrides::PartialPeriodBehavior::LicenseFee
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#credit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period.
-
#debit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period.
Instance Method Summary collapse
-
#initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) ⇒ LicenseFee
constructor
A new instance of LicenseFee.
Methods inherited from RequestParams
Constructor Details
#initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) ⇒ LicenseFee
Returns a new instance of LicenseFee.
164 165 166 167 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 164 def initialize(credit_proration_behavior: nil, debit_proration_behavior: nil) @credit_proration_behavior = credit_proration_behavior @debit_proration_behavior = debit_proration_behavior end |
Instance Attribute Details
#credit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user is upgrading.
160 161 162 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 160 def credit_proration_behavior @credit_proration_behavior end |
#debit_proration_behavior ⇒ Object
The proration behavior for the partial servicing period. Defines how we prorate the license fee when the user is downgrading.
162 163 164 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 162 def debit_proration_behavior @debit_proration_behavior end |