Class: Stripe::V2::Billing::IntentCreateParams::Action::Remove
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Remove
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: EffectiveAt
Instance Attribute Summary collapse
-
#effective_at ⇒ Object
When the remove action will take effect.
-
#invoice_discount_rule ⇒ Object
The ID of the discount rule to remove for future invoices.
-
#spend_modifier_rule ⇒ Object
The ID of the spend modifier rule to remove.
-
#type ⇒ Object
Type of the remove action.
Instance Method Summary collapse
-
#initialize(effective_at: nil, type: nil, invoice_discount_rule: nil, spend_modifier_rule: nil) ⇒ Remove
constructor
A new instance of Remove.
Methods inherited from RequestParams
Constructor Details
#initialize(effective_at: nil, type: nil, invoice_discount_rule: nil, spend_modifier_rule: nil) ⇒ Remove
Returns a new instance of Remove.
341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 341 def initialize( effective_at: nil, type: nil, invoice_discount_rule: nil, spend_modifier_rule: nil ) @effective_at = effective_at @type = type @invoice_discount_rule = invoice_discount_rule @spend_modifier_rule = spend_modifier_rule end |
Instance Attribute Details
#effective_at ⇒ Object
When the remove action will take effect. Defaults to on_reserve if not specified.
333 334 335 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 333 def effective_at @effective_at end |
#invoice_discount_rule ⇒ Object
The ID of the discount rule to remove for future invoices.
337 338 339 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 337 def invoice_discount_rule @invoice_discount_rule end |
#spend_modifier_rule ⇒ Object
The ID of the spend modifier rule to remove.
339 340 341 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 339 def spend_modifier_rule @spend_modifier_rule end |
#type ⇒ Object
Type of the remove action.
335 336 337 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 335 def type @type end |