Class: Stripe::V2::Billing::IntentCreateParams::Action::Remove
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Remove
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#invoice_discount_rule ⇒ Object
The ID of the discount rule to remove for future invoices.
-
#type ⇒ Object
Type of the remove action.
Instance Method Summary collapse
-
#initialize(type: nil, invoice_discount_rule: nil) ⇒ Remove
constructor
A new instance of Remove.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil, invoice_discount_rule: nil) ⇒ Remove
Returns a new instance of Remove.
239 240 241 242 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 239 def initialize(type: nil, invoice_discount_rule: nil) @type = type @invoice_discount_rule = invoice_discount_rule end |
Instance Attribute Details
#invoice_discount_rule ⇒ Object
The ID of the discount rule to remove for future invoices.
237 238 239 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 237 def invoice_discount_rule @invoice_discount_rule end |
#type ⇒ Object
Type of the remove action.
235 236 237 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 235 def type @type end |