Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the subscribe action will take effect.
-
#type ⇒ Object
When the subscribe action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
414 415 416 417 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 414 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the subscribe action will take effect. Only present if type is timestamp.
410 411 412 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 410 def @timestamp end |
#type ⇒ Object
When the subscribe action will take effect.
412 413 414 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 412 def type @type end |