Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the subscribe action will take effect.
-
#type ⇒ Object
When the subscribe action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
252 253 254 255 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 252 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the subscribe action will take effect. Only present if type is timestamp.
248 249 250 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 248 def @timestamp end |
#type ⇒ Object
When the subscribe action will take effect.
250 251 252 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 250 def type @type end |