Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::EffectiveAt
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
The timestamp at which the subscribe action will take effect.
-
#type ⇒ Object
When the subscribe action will take effect.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
constructor
A new instance of EffectiveAt.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ EffectiveAt
Returns a new instance of EffectiveAt.
214 215 216 217 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 214 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
The timestamp at which the subscribe action will take effect. Only present if type is timestamp.
210 211 212 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 210 def @timestamp end |
#type ⇒ Object
When the subscribe action will take effect.
212 213 214 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 212 def type @type end |