Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails
constructor
A new instance of V1SubscriptionDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails
Returns a new instance of V1SubscriptionDetails.
524 525 526 527 528 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 524 def initialize(description: nil, items: nil, metadata: nil) @description = description @items = items @metadata = end |
Instance Attribute Details
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
518 519 520 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 518 def description @description end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
520 521 522 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 520 def items @items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
522 523 524 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 522 def @metadata end |