Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails
constructor
A new instance of V1SubscriptionDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails
Returns a new instance of V1SubscriptionDetails.
366 367 368 369 370 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 366 def initialize(description: nil, items: nil, metadata: nil) @description = description @items = items @metadata = end |
Instance Attribute Details
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
360 361 362 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 360 def description @description end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
362 363 364 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 362 def items @items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
364 365 366 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 364 def @metadata end |