Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails

Returns a new instance of V1SubscriptionDetails.



350
351
352
353
354
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 350

def initialize(description: nil, items: nil, metadata: nil)
  @description = description
  @items = items
  @metadata = 
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



344
345
346
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 344

def description
  @description
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



346
347
348
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 346

def items
  @items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



348
349
350
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 348

def 
  @metadata
end