Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, items: nil, metadata: nil) ⇒ V1SubscriptionDetails

Returns a new instance of V1SubscriptionDetails.



280
281
282
283
284
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 280

def initialize(description: nil, items: nil, metadata: nil)
  @description = description
  @items = items
  @metadata = 
end

Instance Attribute Details

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



274
275
276
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 274

def description
  @description
end

#itemsObject

A list of up to 20 subscription items, each with an attached price.



276
277
278
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 276

def items
  @items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



278
279
280
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 278

def 
  @metadata
end