Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails::Item
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
Instance Method Summary collapse
-
#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item
Returns a new instance of Item.
513 514 515 516 517 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 513 def initialize(metadata: nil, price: nil, quantity: nil) @metadata = @price = price @quantity = quantity end |
Instance Attribute Details
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
507 508 509 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 507 def @metadata end |
#price ⇒ Object
The ID of the price object.
509 510 511 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 509 def price @price end |
#quantity ⇒ Object
Quantity for this item. If not provided, defaults to 1.
511 512 513 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 511 def quantity @quantity end |