Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item

Returns a new instance of Item.



445
446
447
448
449
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 445

def initialize(metadata: nil, price: nil, quantity: nil)
  @metadata = 
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



439
440
441
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 439

def 
  @metadata
end

#priceObject

The ID of the price object.



441
442
443
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 441

def price
  @price
end

#quantityObject

Quantity for this item. If not provided, will default to 1.



443
444
445
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 443

def quantity
  @quantity
end