Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item

Returns a new instance of Item.



336
337
338
339
340
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 336

def initialize(metadata: nil, price: nil, quantity: nil)
  @metadata = 
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



330
331
332
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 330

def 
  @metadata
end

#priceObject

The ID of the price object.



332
333
334
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 332

def price
  @price
end

#quantityObject

Quantity for this item. If not provided, will default to 1.



334
335
336
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 334

def quantity
  @quantity
end