Class: Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::Action::Subscribe::V1SubscriptionDetails::Item
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
Instance Method Summary collapse
-
#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(metadata: nil, price: nil, quantity: nil) ⇒ Item
Returns a new instance of Item.
266 267 268 269 270 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 266 def initialize(metadata: nil, price: nil, quantity: nil) @metadata = @price = price @quantity = quantity end |
Instance Attribute Details
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
260 261 262 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 260 def @metadata end |
#price ⇒ Object
The ID of the price object.
262 263 264 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 262 def price @price end |
#quantity ⇒ Object
Quantity for this item. If not provided, will default to 1.
264 265 266 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 264 def quantity @quantity end |