Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Day

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: Time

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(time: nil) ⇒ Day

Returns a new instance of Day.



453
454
455
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 453

def initialize(time: nil)
  @time = time
end

Instance Attribute Details

#timeObject

The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.



451
452
453
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 451

def time
  @time
end