Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Day
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Day
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(time: nil) ⇒ Day
constructor
A new instance of Day.
Methods inherited from RequestParams
Constructor Details
#initialize(time: nil) ⇒ Day
Returns a new instance of Day.
453 454 455 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 453 def initialize(time: nil) @time = time end |
Instance Attribute Details
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
451 452 453 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 451 def time @time end |