Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Month
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Month
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
The month to anchor the billing on for a type=“month” billing cycle from 1-12.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Month
constructor
A new instance of Month.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Month
Returns a new instance of Month.
492 493 494 495 496 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 492 def initialize(day_of_month: nil, month_of_year: nil, time: nil) @day_of_month = day_of_month @month_of_year = month_of_year @time = time end |
Instance Attribute Details
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month. If not provided, this will default to the day the cadence was created.
481 482 483 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 481 def day_of_month @day_of_month end |
#month_of_year ⇒ Object
The month to anchor the billing on for a type=“month” billing cycle from 1-12. If not provided, this will default to the month the cadence was created. This setting can only be used for monthly billing cycles with ‘interval_count` of 2, 3, 4 or 6. All occurrences will be calculated from month provided.
486 487 488 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 486 def month_of_year @month_of_year end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
490 491 492 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 490 def time @time end |