Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Week
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Week
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_week ⇒ Object
The day of the week to bill the type=week billing cycle on.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_week: nil, time: nil) ⇒ Week
constructor
A new instance of Week.
Methods inherited from RequestParams
Constructor Details
#initialize(day_of_week: nil, time: nil) ⇒ Week
Returns a new instance of Week.
621 622 623 624 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 621 def initialize(day_of_week: nil, time: nil) @day_of_week = day_of_week @time = time end |
Instance Attribute Details
#day_of_week ⇒ Object
The day of the week to bill the type=week billing cycle on. Numbered from 1-7 for Monday to Sunday respectively, based on the ISO-8601 week day numbering. If not provided, this will default to the day the cadence was created.
615 616 617 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 615 def day_of_week @day_of_week end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
619 620 621 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 619 def time @time end |