Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Year
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Year
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Time
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31.
-
#month_of_year ⇒ Object
The month to bill on from 1-12.
-
#time ⇒ Object
The time at which the billing cycle ends.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Year
constructor
A new instance of Year.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Year
Returns a new instance of Year.
738 739 740 741 742 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 738 def initialize(day_of_month: nil, month_of_year: nil, time: nil) @day_of_month = day_of_month @month_of_year = month_of_year @time = time end |
Instance Attribute Details
#day_of_month ⇒ Object
The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month. If not provided, this will default to the day the cadence was created.
729 730 731 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 729 def day_of_month @day_of_month end |
#month_of_year ⇒ Object
The month to bill on from 1-12. If not provided, this will default to the month the cadence was created.
732 733 734 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 732 def month_of_year @month_of_year end |
#time ⇒ Object
The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.
736 737 738 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 736 def time @time end |