Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::BillingCycle::Year

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: Time

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(day_of_month: nil, month_of_year: nil, time: nil) ⇒ Year

Returns a new instance of Year.



659
660
661
662
663
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 659

def initialize(day_of_month: nil, month_of_year: nil, time: nil)
  @day_of_month = day_of_month
  @month_of_year = month_of_year
  @time = time
end

Instance Attribute Details

#day_of_monthObject

The day to anchor the billing on for a type=“month” billing cycle from 1-31. If this number is greater than the number of days in the month being billed, this will anchor to the last day of the month. If not provided, this will default to the day the cadence was created.



650
651
652
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 650

def day_of_month
  @day_of_month
end

#month_of_yearObject

The month to bill on from 1-12. If not provided, this will default to the month the cadence was created.



653
654
655
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 653

def month_of_year
  @month_of_year
end

#timeObject

The time at which the billing cycle ends. This field is optional, and if not provided, it will default to the time at which the cadence was created in UTC timezone.



657
658
659
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 657

def time
  @time
end