Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: BillingProfileData
Instance Attribute Summary collapse
-
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill will be paid.
-
#billing_profile_data ⇒ Object
Data for creating a new profile.
Instance Method Summary collapse
-
#initialize(billing_profile: nil, billing_profile_data: nil) ⇒ Payer
constructor
A new instance of Payer.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_profile: nil, billing_profile_data: nil) ⇒ Payer
Returns a new instance of Payer.
623 624 625 626 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 623 def initialize(billing_profile: nil, billing_profile_data: nil) @billing_profile = billing_profile @billing_profile_data = billing_profile_data end |
Instance Attribute Details
#billing_profile ⇒ Object
The ID of the Billing Profile object which determines how a bill will be paid.
619 620 621 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 619 def billing_profile @billing_profile end |
#billing_profile_data ⇒ Object
Data for creating a new profile.
621 622 623 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 621 def billing_profile_data @billing_profile_data end |