Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer to associate with the profile.
-
#default_payment_method ⇒ Object
The default payment method to use when billing this profile.
Instance Method Summary collapse
-
#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData
constructor
A new instance of BillingProfileData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData
Returns a new instance of BillingProfileData.
788 789 790 791 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 788 def initialize(customer: nil, default_payment_method: nil) @customer = customer @default_payment_method = default_payment_method end |
Instance Attribute Details
#customer ⇒ Object
The customer to associate with the profile.
782 783 784 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 782 def customer @customer end |
#default_payment_method ⇒ Object
The default payment method to use when billing this profile. If left blank, the ‘PaymentMethod` from the `PaymentIntent` provided on commit is used to create the profile.
786 787 788 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 786 def default_payment_method @default_payment_method end |