Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer to associate with the profile.
-
#default_payment_method ⇒ Object
The default payment method to use when billing this profile.
Instance Method Summary collapse
-
#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData
constructor
A new instance of BillingProfileData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData
Returns a new instance of BillingProfileData.
785 786 787 788 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 785 def initialize(customer: nil, default_payment_method: nil) @customer = customer @default_payment_method = default_payment_method end |
Instance Attribute Details
#customer ⇒ Object
The customer to associate with the profile.
779 780 781 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 779 def customer @customer end |
#default_payment_method ⇒ Object
The default payment method to use when billing this profile. If left blank, the ‘PaymentMethod` from the `PaymentIntent` provided on commit will be used to create the profile.
783 784 785 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 783 def default_payment_method @default_payment_method end |