Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData

Returns a new instance of BillingProfileData.



706
707
708
709
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 706

def initialize(customer: nil, default_payment_method: nil)
  @customer = customer
  @default_payment_method = default_payment_method
end

Instance Attribute Details

#customerObject

The customer to associate with the profile.



700
701
702
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 700

def customer
  @customer
end

#default_payment_methodObject

The default payment method to use when billing this profile. If left blank, the ‘PaymentMethod` from the `PaymentIntent` provided on commit will be used to create the profile.



704
705
706
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 704

def default_payment_method
  @default_payment_method
end