Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData

Returns a new instance of BillingProfileData.



613
614
615
616
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 613

def initialize(customer: nil, default_payment_method: nil)
  @customer = customer
  @default_payment_method = default_payment_method
end

Instance Attribute Details

#customerObject

The customer to associate with the profile.



607
608
609
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 607

def customer
  @customer
end

#default_payment_methodObject

The default payment method to use when billing this profile. If left blank, the ‘PaymentMethod` from the `PaymentIntent` provided on commit will be used to create the profile.



611
612
613
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 611

def default_payment_method
  @default_payment_method
end