Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Payer::BillingProfileData
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer to associate with the profile.
-
#default_payment_method ⇒ Object
The default payment method to use when billing this profile.
Instance Method Summary collapse
-
#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData
constructor
A new instance of BillingProfileData.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, default_payment_method: nil) ⇒ BillingProfileData
Returns a new instance of BillingProfileData.
613 614 615 616 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 613 def initialize(customer: nil, default_payment_method: nil) @customer = customer @default_payment_method = default_payment_method end |
Instance Attribute Details
#customer ⇒ Object
The customer to associate with the profile.
607 608 609 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 607 def customer @customer end |
#default_payment_method ⇒ Object
The default payment method to use when billing this profile. If left blank, the ‘PaymentMethod` from the `PaymentIntent` provided on commit will be used to create the profile.
611 612 613 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 611 def default_payment_method @default_payment_method end |