Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Defined Under Namespace

Classes: Bill, Collection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bill: nil, collection: nil) ⇒ Settings

Returns a new instance of Settings.



664
665
666
667
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 664

def initialize(bill: nil, collection: nil)
  @bill = bill
  @collection = collection
end

Instance Attribute Details

#billObject

Settings that configure bill generation, which includes calculating totals, tax, and presenting invoices. If no setting is provided here, the settings from the customer referenced on the payer will be used. If no customer settings are present, the merchant default settings will be used.



658
659
660
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 658

def bill
  @bill
end

#collectionObject

Settings that configure and manage the behavior of collecting payments. If no setting is provided here, the settings from the customer referenced from the payer will be used if they exist. If no customer settings are present, the merchant default settings will be used.



662
663
664
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 662

def collection
  @collection
end