Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Defined Under Namespace
Classes: Bill, Collection
Instance Attribute Summary collapse
-
#bill ⇒ Object
Settings that configure bill generation, which includes calculating totals, tax, and presenting invoices.
-
#collection ⇒ Object
Settings that configure and manage the behavior of collecting payments.
Instance Method Summary collapse
-
#initialize(bill: nil, collection: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bill: nil, collection: nil) ⇒ Settings
Returns a new instance of Settings.
757 758 759 760 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 757 def initialize(bill: nil, collection: nil) @bill = bill @collection = collection end |
Instance Attribute Details
#bill ⇒ Object
Settings that configure bill generation, which includes calculating totals, tax, and presenting invoices. If no setting is provided here, the settings from the customer referenced on the payer will be used. If no customer settings are present, the merchant default settings will be used.
751 752 753 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 751 def bill @bill end |
#collection ⇒ Object
Settings that configure and manage the behavior of collecting payments. If no setting is provided here, the settings from the customer referenced from the payer will be used if they exist. If no customer settings are present, the merchant default settings will be used.
755 756 757 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 755 def collection @collection end |