Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Bill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Bill

Returns a new instance of Bill.



730
731
732
733
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 730

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



725
726
727
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 725

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



728
729
730
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 728

def version
  @version
end