Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Bill

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Bill

Returns a new instance of Bill.



637
638
639
640
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 637

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



632
633
634
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 632

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



635
636
637
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 635

def version
  @version
end