Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Bill
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Bill
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of the Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Bill
constructor
A new instance of Bill.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, version: nil) ⇒ Bill
Returns a new instance of Bill.
637 638 639 640 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 637 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
632 633 634 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 632 def id @id end |
#version ⇒ Object
An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.
635 636 637 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 635 def version @version end |