Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



825
826
827
828
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 825

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



820
821
822
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 820

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



823
824
825
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 823

def version
  @version
end