Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Collection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Collection
- Defined in:
- lib/stripe/params/v2/billing/intent_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the referenced settings object.
-
#version ⇒ Object
An optional field to specify the version of the Settings to use.
Instance Method Summary collapse
-
#initialize(id: nil, version: nil) ⇒ Collection
constructor
A new instance of Collection.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, version: nil) ⇒ Collection
Returns a new instance of Collection.
743 744 745 746 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 743 def initialize(id: nil, version: nil) @id = id @version = version end |
Instance Attribute Details
#id ⇒ Object
The ID of the referenced settings object.
738 739 740 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 738 def id @id end |
#version ⇒ Object
An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.
741 742 743 |
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 741 def version @version end |