Class: Stripe::V2::Billing::IntentCreateParams::CadenceData::Settings::Collection

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/intent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(id: nil, version: nil) ⇒ Collection

Returns a new instance of Collection.



650
651
652
653
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 650

def initialize(id: nil, version: nil)
  @id = id
  @version = version
end

Instance Attribute Details

#idObject

The ID of the referenced settings object.



645
646
647
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 645

def id
  @id
end

#versionObject

An optional field to specify the version of the Settings to use. If not provided, this will always default to the live version any time the settings are used.



648
649
650
# File 'lib/stripe/params/v2/billing/intent_create_params.rb', line 648

def version
  @version
end