Class: Stripe::V2::Billing::LicenseFee
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::LicenseFee
- Defined in:
- lib/stripe/resources/v2/billing/license_fee.rb
Defined Under Namespace
Classes: Tier, TransformQuantity
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.license_fee"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active ⇒ Object
readonly
Whether this License Fee is active.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#display_name ⇒ Object
readonly
A customer-facing name for the license fee.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#latest_version ⇒ Object
readonly
The ID of the license fee’s most recently created version.
-
#licensed_item ⇒ Object
readonly
A Licensed Item represents a billable item whose pricing is based on license fees.
-
#live_version ⇒ Object
readonly
The ID of the License Fee Version that will be used by all subscriptions when no specific version is specified.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
An internal key you can use to search for a particular License Fee.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#service_interval ⇒ Object
readonly
The interval for assessing service.
-
#service_interval_count ⇒ Object
readonly
The length of the interval for assessing service.
-
#tax_behavior ⇒ Object
readonly
The Stripe Tax tax behavior - whether the license fee is inclusive or exclusive of tax.
-
#tiering_mode ⇒ Object
readonly
Defines whether the tiering price should be graduated or volume-based.
-
#tiers ⇒ Object
readonly
Each element represents a pricing tier.
-
#transform_quantity ⇒ Object
readonly
Apply a transformation to the reported usage or set quantity before computing the amount billed.
-
#unit_amount ⇒ Object
readonly
The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active ⇒ Object (readonly)
Whether this License Fee is active. Inactive License Fees cannot be used in new activations or be modified.
49 50 51 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 49 def active @active end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
51 52 53 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 51 def created @created end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
53 54 55 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 53 def currency @currency end |
#display_name ⇒ Object (readonly)
A customer-facing name for the license fee. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.
57 58 59 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 57 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
59 60 61 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 59 def id @id end |
#latest_version ⇒ Object (readonly)
The ID of the license fee’s most recently created version.
61 62 63 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 61 def latest_version @latest_version end |
#licensed_item ⇒ Object (readonly)
A Licensed Item represents a billable item whose pricing is based on license fees. You can use license fees to specify the pricing and create subscriptions to these items.
64 65 66 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 64 def licensed_item @licensed_item end |
#live_version ⇒ Object (readonly)
The ID of the License Fee Version that will be used by all subscriptions when no specific version is specified.
66 67 68 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 66 def live_version @live_version end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
92 93 94 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 92 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
An internal key you can use to search for a particular License Fee. Maximum length of 200 characters.
68 69 70 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 68 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
70 71 72 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 70 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
72 73 74 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 72 def object @object end |
#service_interval ⇒ Object (readonly)
The interval for assessing service.
74 75 76 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 74 def service_interval @service_interval end |
#service_interval_count ⇒ Object (readonly)
The length of the interval for assessing service. For example, set this to 3 and ‘service_interval` to `“month”` in order to specify quarterly service.
77 78 79 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 77 def service_interval_count @service_interval_count end |
#tax_behavior ⇒ Object (readonly)
The Stripe Tax tax behavior - whether the license fee is inclusive or exclusive of tax.
79 80 81 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 79 def tax_behavior @tax_behavior end |
#tiering_mode ⇒ Object (readonly)
Defines whether the tiering price should be graduated or volume-based. In volume-based tiering, the maximum quantity within a period determines the per-unit price. In graduated tiering, the pricing changes as the quantity grows into new tiers. Can only be set if ‘tiers` is set.
83 84 85 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 83 def tiering_mode @tiering_mode end |
#tiers ⇒ Object (readonly)
Each element represents a pricing tier. Cannot be set if ‘unit_amount` is provided.
85 86 87 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 85 def tiers @tiers end |
#transform_quantity ⇒ Object (readonly)
Apply a transformation to the reported usage or set quantity before computing the amount billed.
87 88 89 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 87 def transform_quantity @transform_quantity end |
#unit_amount ⇒ Object (readonly)
The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places. Cannot be set if ‘tiers` is provided.
90 91 92 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 90 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
98 99 100 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 98 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
94 95 96 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 94 def self.inner_class_types @inner_class_types = { tiers: Tier, transform_quantity: TransformQuantity } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 9 def self.object_name "v2.billing.license_fee" end |