Class: Stripe::V2::Billing::LicenseFee

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/license_fee.rb

Defined Under Namespace

Classes: Tier, TransformQuantity

Constant Summary collapse

OBJECT_NAME =
"v2.billing.license_fee"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether this License Fee is active. Inactive License Fees cannot be used in new activations or be modified.



49
50
51
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 49

def active
  @active
end

#createdObject (readonly)

Timestamp of when the object was created.



51
52
53
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 51

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



53
54
55
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 53

def currency
  @currency
end

#display_nameObject (readonly)

A customer-facing name for the license fee. This name is used in Stripe-hosted products like the Customer Portal and Checkout. It does not show up on Invoices. Maximum length of 250 characters.



57
58
59
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 57

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



59
60
61
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 59

def id
  @id
end

#latest_versionObject (readonly)

The ID of the license fee’s most recently created version.



61
62
63
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 61

def latest_version
  @latest_version
end

#licensed_itemObject (readonly)

The Licensed Item that this License Fee binds to.



63
64
65
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 63

def licensed_item
  @licensed_item
end

#live_versionObject (readonly)

The ID of the License Fee Version that will be used by all subscriptions when no specific version is specified.



65
66
67
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 65

def live_version
  @live_version
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



91
92
93
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 91

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular License Fee. Maximum length of 200 characters.



67
68
69
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 67

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



69
70
71
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 69

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



71
72
73
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 71

def object
  @object
end

#service_intervalObject (readonly)

The interval for assessing service.



73
74
75
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 73

def service_interval
  @service_interval
end

#service_interval_countObject (readonly)

The length of the interval for assessing service. For example, set this to 3 and ‘service_interval` to `“month”` in order to specify quarterly service.



76
77
78
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 76

def service_interval_count
  @service_interval_count
end

#tax_behaviorObject (readonly)

The Stripe Tax tax behavior - whether the license fee is inclusive or exclusive of tax.



78
79
80
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 78

def tax_behavior
  @tax_behavior
end

#tiering_modeObject (readonly)

Defines whether the tiering price should be graduated or volume-based. In volume-based tiering, the maximum quantity within a period determines the per-unit price. In graduated tiering, the pricing changes as the quantity grows into new tiers. Can only be set if ‘tiers` is set.



82
83
84
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 82

def tiering_mode
  @tiering_mode
end

#tiersObject (readonly)

Each element represents a pricing tier. Cannot be set if ‘unit_amount` is provided.



84
85
86
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 84

def tiers
  @tiers
end

#transform_quantityObject (readonly)

Apply a transformation to the reported usage or set quantity before computing the amount billed.



86
87
88
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 86

def transform_quantity
  @transform_quantity
end

#unit_amountObject (readonly)

The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places. Cannot be set if ‘tiers` is provided.



89
90
91
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 89

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



97
98
99
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 97

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



93
94
95
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 93

def self.inner_class_types
  @inner_class_types = { tiers: Tier, transform_quantity: TransformQuantity }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/license_fee.rb', line 9

def self.object_name
  "v2.billing.license_fee"
end