Class: Stripe::V2::Billing::LicenseFeeSubscription
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::LicenseFeeSubscription
- Defined in:
- lib/stripe/resources/v2/billing/license_fee_subscription.rb
Overview
A License Fee Subscription represents a customer’s subscription to a License Fee at a specified quantity. It tracks the number of units (such as seats or licenses) the customer has subscribed to and bills them according to the service interval defined in the License Fee and the Billing Cadence.
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.license_fee_subscription"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
readonly
The ID of the Billing Cadence.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#license_fee ⇒ Object
readonly
The ID of the License Fee.
-
#license_fee_version ⇒ Object
readonly
The ID of the License Fee Version.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#quantity ⇒ Object
readonly
Quantity of the License Fee subscribed to.
-
#test_clock ⇒ Object
readonly
The ID of the Test Clock, if any.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence ⇒ Object (readonly)
The ID of the Billing Cadence.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 17 def billing_cadence @billing_cadence end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
19 20 21 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 19 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 21 def id @id end |
#license_fee ⇒ Object (readonly)
The ID of the License Fee.
23 24 25 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 23 def license_fee @license_fee end |
#license_fee_version ⇒ Object (readonly)
The ID of the License Fee Version.
25 26 27 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 25 def license_fee_version @license_fee_version end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
35 36 37 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 35 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
27 28 29 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 27 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
29 30 31 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 29 def object @object end |
#quantity ⇒ Object (readonly)
Quantity of the License Fee subscribed to.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 31 def quantity @quantity end |
#test_clock ⇒ Object (readonly)
The ID of the Test Clock, if any.
33 34 35 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 33 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
41 42 43 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 41 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
37 38 39 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 37 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 12 def self.object_name "v2.billing.license_fee_subscription" end |