Class: Stripe::V2::Billing::LicenseFeeSubscription
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::LicenseFeeSubscription
- Defined in:
- lib/stripe/resources/v2/billing/license_fee_subscription.rb
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.license_fee_subscription"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
readonly
The ID of the Billing Cadence.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#license_fee ⇒ Object
readonly
The ID of the License Fee.
-
#license_fee_version ⇒ Object
readonly
The ID of the License Fee Version.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#quantity ⇒ Object
readonly
Quantity of the License Fee subscribed to.
-
#test_clock ⇒ Object
readonly
The ID of the Test Clock, if any.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence ⇒ Object (readonly)
The ID of the Billing Cadence.
14 15 16 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 14 def billing_cadence @billing_cadence end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
16 17 18 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 16 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
18 19 20 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 18 def id @id end |
#license_fee ⇒ Object (readonly)
The ID of the License Fee.
20 21 22 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 20 def license_fee @license_fee end |
#license_fee_version ⇒ Object (readonly)
The ID of the License Fee Version.
22 23 24 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 22 def license_fee_version @license_fee_version end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
32 33 34 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 32 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
24 25 26 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 24 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
26 27 28 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 26 def object @object end |
#quantity ⇒ Object (readonly)
Quantity of the License Fee subscribed to.
28 29 30 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 28 def quantity @quantity end |
#test_clock ⇒ Object (readonly)
The ID of the Test Clock, if any.
30 31 32 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 30 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
38 39 40 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 38 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
34 35 36 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 34 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 9 def self.object_name "v2.billing.license_fee_subscription" end |