Class: Stripe::V2::Billing::LicenseFeeSubscription

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/license_fee_subscription.rb

Constant Summary collapse

OBJECT_NAME =
"v2.billing.license_fee_subscription"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cadenceObject (readonly)

The ID of the Billing Cadence.



14
15
16
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 14

def billing_cadence
  @billing_cadence
end

#createdObject (readonly)

Timestamp of when the object was created.



16
17
18
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 16

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



18
19
20
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 18

def id
  @id
end

#license_feeObject (readonly)

The ID of the License Fee.



20
21
22
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 20

def license_fee
  @license_fee
end

#license_fee_versionObject (readonly)

The ID of the License Fee Version.



22
23
24
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 22

def license_fee_version
  @license_fee_version
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



32
33
34
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 32

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



24
25
26
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 24

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



26
27
28
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 26

def object
  @object
end

#quantityObject (readonly)

Quantity of the License Fee subscribed to.



28
29
30
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 28

def quantity
  @quantity
end

#test_clockObject (readonly)

The ID of the Test Clock, if any.



30
31
32
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 30

def test_clock
  @test_clock
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/license_fee_subscription.rb', line 9

def self.object_name
  "v2.billing.license_fee_subscription"
end