Class: Stripe::V2::Billing::LicenseFeeVersion

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/license_fee_version.rb

Defined Under Namespace

Classes: Tier, TransformQuantity

Constant Summary collapse

OBJECT_NAME =
"v2.billing.license_fee_version"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



49
50
51
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 49

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



51
52
53
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 51

def id
  @id
end

#license_fee_idObject (readonly)

The ID of the parent License Fee.



53
54
55
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 53

def license_fee_id
  @license_fee_id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



68
69
70
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 68

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



55
56
57
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 55

def object
  @object
end

#tiering_modeObject (readonly)

Defines whether the tiering price should be graduated or volume-based. In volume-based tiering, the maximum quantity within a period determines the per-unit price. In graduated tiering, the pricing changes as the quantity grows into new tiers. Can only be set if ‘tiers` is set.



59
60
61
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 59

def tiering_mode
  @tiering_mode
end

#tiersObject (readonly)

Each element represents a pricing tier. Cannot be set if ‘unit_amount` is provided.



61
62
63
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 61

def tiers
  @tiers
end

#transform_quantityObject (readonly)

Apply a transformation to the reported usage or set quantity before computing the amount billed.



63
64
65
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 63

def transform_quantity
  @transform_quantity
end

#unit_amountObject (readonly)

The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places. Cannot be set if ‘tiers` is provided.



66
67
68
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 66

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



74
75
76
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 74

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



70
71
72
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 70

def self.inner_class_types
  @inner_class_types = { tiers: Tier, transform_quantity: TransformQuantity }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 9

def self.object_name
  "v2.billing.license_fee_version"
end