Class: Stripe::V2::Billing::LicenseFeeVersion
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::LicenseFeeVersion
- Defined in:
- lib/stripe/resources/v2/billing/license_fee_version.rb
Defined Under Namespace
Classes: Tier, TransformQuantity
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.license_fee_version"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#license_fee_id ⇒ Object
readonly
The ID of the parent License Fee.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#tiering_mode ⇒ Object
readonly
Defines whether the tiering price should be graduated or volume-based.
-
#tiers ⇒ Object
readonly
Each element represents a pricing tier.
-
#transform_quantity ⇒ Object
readonly
Apply a transformation to the reported usage or set quantity before computing the amount billed.
-
#unit_amount ⇒ Object
readonly
The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Timestamp of when the object was created.
33 34 35 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 33 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
35 36 37 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 35 def id @id end |
#license_fee_id ⇒ Object (readonly)
The ID of the parent License Fee.
37 38 39 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 37 def license_fee_id @license_fee_id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
52 53 54 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 52 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
39 40 41 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 39 def object @object end |
#tiering_mode ⇒ Object (readonly)
Defines whether the tiering price should be graduated or volume-based. In volume-based tiering, the maximum quantity within a period determines the per-unit price. In graduated tiering, the pricing changes as the quantity grows into new tiers. Can only be set if ‘tiers` is set.
43 44 45 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 43 def tiering_mode @tiering_mode end |
#tiers ⇒ Object (readonly)
Each element represents a pricing tier. Cannot be set if ‘unit_amount` is provided.
45 46 47 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 45 def tiers @tiers end |
#transform_quantity ⇒ Object (readonly)
Apply a transformation to the reported usage or set quantity before computing the amount billed.
47 48 49 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 47 def transform_quantity @transform_quantity end |
#unit_amount ⇒ Object (readonly)
The per-unit amount to be charged, represented as a decimal string in minor currency units with at most 12 decimal places. Cannot be set if ‘tiers` is provided.
50 51 52 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 50 def unit_amount @unit_amount end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/license_fee_version.rb', line 9 def self.object_name "v2.billing.license_fee_version" end |