Class: Stripe::V2::Billing::LicensedItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/licensed_item.rb

Overview

A Licensed Item represents a billable item whose pricing is based on license fees. You can use license fees to specify the pricing and create subscriptions to these items.

Defined Under Namespace

Classes: TaxDetails

Constant Summary collapse

OBJECT_NAME =
"v2.billing.licensed_item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



20
21
22
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 20

def created
  @created
end

#display_nameObject (readonly)

Description that customers will see in the invoice line item. Maximum length of 250 characters.



23
24
25
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 23

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



25
26
27
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 25

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



40
41
42
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 40

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular billable item. Maximum length of 200 characters.



28
29
30
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 28

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



30
31
32
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 30

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



32
33
34
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 32

def object
  @object
end

#tax_detailsObject (readonly)

Stripe Tax details.



34
35
36
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 34

def tax_details
  @tax_details
end

#unit_labelObject (readonly)

The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “seat” for Checkout to display “(price) per seat”, or “environment” to display “(price) per environment”. Maximum length of 100 characters.



38
39
40
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 38

def unit_label
  @unit_label
end

Class Method Details

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/billing/licensed_item.rb', line 11

def self.object_name
  "v2.billing.licensed_item"
end