Class: Stripe::V2::Billing::MeterEventAdjustment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::MeterEventAdjustment
- Defined in:
- lib/stripe/resources/v2/billing/meter_event_adjustment.rb
Overview
A Meter Event Adjustment is used to cancel or modify previously recorded meter events. Meter Event Adjustments allow you to correct billing data by canceling individual events or event ranges, with tracking of adjustment status and creation time.
Defined Under Namespace
Classes: Cancel
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.meter_event_adjustment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cancel ⇒ Object
readonly
Specifies which event to cancel.
-
#created ⇒ Object
readonly
The time the adjustment was created.
-
#event_name ⇒ Object
readonly
The name of the meter event.
-
#id ⇒ Object
readonly
The unique id of this meter event adjustment.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Open Enum.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cancel ⇒ Object (readonly)
Specifies which event to cancel.
27 28 29 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 27 def cancel @cancel end |
#created ⇒ Object (readonly)
The time the adjustment was created.
29 30 31 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 29 def created @created end |
#event_name ⇒ Object (readonly)
The name of the meter event. Corresponds with the ‘event_name` field on a meter.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 31 def event_name @event_name end |
#id ⇒ Object (readonly)
The unique id of this meter event adjustment.
33 34 35 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 33 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
35 36 37 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 35 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
37 38 39 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 37 def object @object end |
#status ⇒ Object (readonly)
Open Enum. The meter event adjustment’s status.
39 40 41 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 39 def status @status end |
#type ⇒ Object (readonly)
Open Enum. Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet.
41 42 43 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 41 def type @type end |
Class Method Details
.field_remappings ⇒ Object
47 48 49 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 47 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
43 44 45 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 43 def self.inner_class_types @inner_class_types = { cancel: Cancel } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 10 def self.object_name "v2.billing.meter_event_adjustment" end |