Class: Stripe::V2::Billing::MeterEventAdjustment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::MeterEventAdjustment
- Defined in:
- lib/stripe/resources/v2/billing/meter_event_adjustment.rb
Defined Under Namespace
Classes: Cancel
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.meter_event_adjustment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cancel ⇒ Object
readonly
Specifies which event to cancel.
-
#created ⇒ Object
readonly
The time the adjustment was created.
-
#event_name ⇒ Object
readonly
The name of the meter event.
-
#id ⇒ Object
readonly
The unique id of this meter event adjustment.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Open Enum.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cancel ⇒ Object (readonly)
Specifies which event to cancel.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 17 def cancel @cancel end |
#created ⇒ Object (readonly)
The time the adjustment was created.
19 20 21 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 19 def created @created end |
#event_name ⇒ Object (readonly)
The name of the meter event. Corresponds with the ‘event_name` field on a meter.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 21 def event_name @event_name end |
#id ⇒ Object (readonly)
The unique id of this meter event adjustment.
23 24 25 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 23 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
25 26 27 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 25 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
27 28 29 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 27 def object @object end |
#status ⇒ Object (readonly)
Open Enum. The meter event adjustment’s status.
29 30 31 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 29 def status @status end |
#type ⇒ Object (readonly)
Open Enum. Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 31 def type @type end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/meter_event_adjustment.rb', line 9 def self.object_name "v2.billing.meter_event_adjustment" end |