Class: Stripe::V2::Billing::MeteredItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/metered_item.rb

Overview

A Metered Item represents a billable item whose pricing is based on usage, measured by a meter. You can use rate cards to specify the pricing and create subscriptions to these items.

Defined Under Namespace

Classes: MeterSegmentCondition, TaxDetails

Constant Summary collapse

OBJECT_NAME =
"v2.billing.metered_item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



43
44
45
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 43

def created
  @created
end

#display_nameObject (readonly)

Description that customers will see in the invoice line item. Maximum length of 250 characters.



46
47
48
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 46

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



48
49
50
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 48

def id
  @id
end

#invoice_presentation_dimensionsObject (readonly)

Optional array of Meter dimensions to group event dimension keys for invoice line items.



50
51
52
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 50

def invoice_presentation_dimensions
  @invoice_presentation_dimensions
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



70
71
72
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 70

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular billable item. Maximum length of 200 characters.



53
54
55
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 53

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



55
56
57
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 55

def 
  @metadata
end

#meterObject (readonly)

ID of the Meter that measures usage for this Metered Item.



57
58
59
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 57

def meter
  @meter
end

#meter_segment_conditionsObject (readonly)

Optional array of Meter segments to filter event dimension keys for billing.



59
60
61
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 59

def meter_segment_conditions
  @meter_segment_conditions
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



61
62
63
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 61

def object
  @object
end

#tax_detailsObject (readonly)

Stripe Tax details.



63
64
65
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 63

def tax_details
  @tax_details
end

#unit_labelObject (readonly)

The unit to use when displaying prices for this billable item in places like Checkout. For example, set this field to “CPU-hour” for Checkout to display “(price) per CPU-hour”, or “1 million events” to display “(price) per 1 million events”. Maximum length of 100 characters.



68
69
70
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 68

def unit_label
  @unit_label
end

Class Method Details

.field_remappingsObject



79
80
81
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 79

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



72
73
74
75
76
77
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 72

def self.inner_class_types
  @inner_class_types = {
    meter_segment_conditions: MeterSegmentCondition,
    tax_details: TaxDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/billing/metered_item.rb', line 11

def self.object_name
  "v2.billing.metered_item"
end