Class: Stripe::V2::Billing::PricingPlan
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::PricingPlan
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan.rb
Overview
A Pricing Plan represents a bundled collection of billing components that define how customers are charged. Each plan can include multiple components such as Rate Cards for usage-based pricing, License Fees for recurring charges, and Service Actions for recurring credit grants. After creating a Pricing Plan, you can subscribe customers to it by creating a Pricing Plan Subscription.
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.pricing_plan"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active ⇒ Object
readonly
Whether the PricingPlan is active.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
The currency of the PricingPlan.
-
#description ⇒ Object
readonly
A description for pricing plan subscription.
-
#display_name ⇒ Object
readonly
Display name of the PricingPlan.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#live_version ⇒ Object
readonly
The ID of the live version of the PricingPlan.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
An internal key you can use to search for a particular PricingPlan.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#tax_behavior ⇒ Object
readonly
The Stripe Tax tax behavior - whether the PricingPlan is inclusive or exclusive of tax.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active ⇒ Object (readonly)
Whether the PricingPlan is active.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 17 def active @active end |
#created ⇒ Object (readonly)
Time at which the object was created.
19 20 21 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 19 def created @created end |
#currency ⇒ Object (readonly)
The currency of the PricingPlan.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 21 def currency @currency end |
#description ⇒ Object (readonly)
A description for pricing plan subscription. Maximum length of 500 characters.
24 25 26 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 24 def description @description end |
#display_name ⇒ Object (readonly)
Display name of the PricingPlan.
26 27 28 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 26 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
28 29 30 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 28 def id @id end |
#live_version ⇒ Object (readonly)
The ID of the live version of the PricingPlan.
30 31 32 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 30 def live_version @live_version end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
40 41 42 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 40 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
An internal key you can use to search for a particular PricingPlan. Maximum length of 200 characters.
32 33 34 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 32 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
34 35 36 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 34 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
36 37 38 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 36 def object @object end |
#tax_behavior ⇒ Object (readonly)
The Stripe Tax tax behavior - whether the PricingPlan is inclusive or exclusive of tax.
38 39 40 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 38 def tax_behavior @tax_behavior end |
Class Method Details
.field_remappings ⇒ Object
46 47 48 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 46 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
42 43 44 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 42 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 12 def self.object_name "v2.billing.pricing_plan" end |