Class: Stripe::V2::Billing::PricingPlan

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/pricing_plan.rb

Constant Summary collapse

OBJECT_NAME =
"v2.billing.pricing_plan"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether the PricingPlan is active.



14
15
16
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 14

def active
  @active
end

#createdObject (readonly)

Time at which the object was created.



16
17
18
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 16

def created
  @created
end

#currencyObject (readonly)

The currency of the PricingPlan.



18
19
20
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 18

def currency
  @currency
end

#descriptionObject (readonly)

A description for pricing plan subscription. Maximum length of 500 characters.



21
22
23
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 21

def description
  @description
end

#display_nameObject (readonly)

Display name of the PricingPlan.



23
24
25
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 23

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



25
26
27
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 25

def id
  @id
end

#latest_versionObject (readonly)

The ID of the latest version of the PricingPlan.



27
28
29
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 27

def latest_version
  @latest_version
end

#live_versionObject (readonly)

The ID of the live version of the PricingPlan.



29
30
31
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 29

def live_version
  @live_version
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



39
40
41
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 39

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular PricingPlan. Maximum length of 200 characters.



31
32
33
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 31

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



33
34
35
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 33

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



35
36
37
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 35

def object
  @object
end

#tax_behaviorObject (readonly)

The Stripe Tax tax behavior - whether the PricingPlan is inclusive or exclusive of tax.



37
38
39
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 37

def tax_behavior
  @tax_behavior
end

Class Method Details

.field_remappingsObject



45
46
47
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 45

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



41
42
43
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 41

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/pricing_plan.rb', line 9

def self.object_name
  "v2.billing.pricing_plan"
end