Class: Stripe::V2::Billing::PricingPlanComponent

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/pricing_plan_component.rb

Overview

A Pricing Plan Component represents an individual billing element within a Pricing Plan. Components can be Rate Cards for usage-based charges, License Fees for recurring fixed charges, or Service Actions for recurring credit grants. Each component is associated with a specific version of the Pricing Plan and defines one aspect of how customers are billed.

Defined Under Namespace

Classes: LicenseFee, RateCard, ServiceAction

Constant Summary collapse

OBJECT_NAME =
"v2.billing.pricing_plan_component"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created.



59
60
61
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 59

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



61
62
63
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 61

def id
  @id
end

#license_feeObject (readonly)

Details if this component is a License Fee.



77
78
79
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 77

def license_fee
  @license_fee
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



75
76
77
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 75

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular PricingPlanComponent.



63
64
65
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 63

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



65
66
67
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 65

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



67
68
69
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 67

def object
  @object
end

#pricing_planObject (readonly)

The ID of the Pricing Plan this component belongs to.



69
70
71
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 69

def pricing_plan
  @pricing_plan
end

#pricing_plan_versionObject (readonly)

The ID of the Pricing Plan Version this component belongs to.



71
72
73
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 71

def pricing_plan_version
  @pricing_plan_version
end

#rate_cardObject (readonly)

Details if this component is a Rate Card.



79
80
81
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 79

def rate_card
  @rate_card
end

#service_actionObject (readonly)

Details if this component is a Service Action.



81
82
83
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 81

def service_action
  @service_action
end

#typeObject (readonly)

The type of the PricingPlanComponent.



73
74
75
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 73

def type
  @type
end

Class Method Details

.field_remappingsObject



91
92
93
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 91

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



83
84
85
86
87
88
89
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 83

def self.inner_class_types
  @inner_class_types = {
    license_fee: LicenseFee,
    rate_card: RateCard,
    service_action: ServiceAction,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 12

def self.object_name
  "v2.billing.pricing_plan_component"
end