Class: Stripe::V2::Billing::PricingPlanComponent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::PricingPlanComponent
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_component.rb
Defined Under Namespace
Classes: LicenseFee, RateCard, ServiceAction
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.pricing_plan_component"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#license_fee ⇒ Object
readonly
Details if this component is a License Fee.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
An internal key you can use to search for a particular PricingPlanComponent.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pricing_plan ⇒ Object
readonly
The ID of the Pricing Plan this component belongs to.
-
#pricing_plan_version ⇒ Object
readonly
The ID of the Pricing Plan Version this component belongs to.
-
#rate_card ⇒ Object
readonly
Details if this component is a Rate Card.
-
#service_action ⇒ Object
readonly
Details if this component is a Service Action.
-
#type ⇒ Object
readonly
The type of the PricingPlanComponent.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created.
32 33 34 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 32 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
34 35 36 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 34 def id @id end |
#license_fee ⇒ Object (readonly)
Details if this component is a License Fee.
50 51 52 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 50 def license_fee @license_fee end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
48 49 50 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 48 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
An internal key you can use to search for a particular PricingPlanComponent.
36 37 38 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 36 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
38 39 40 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 38 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
40 41 42 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 40 def object @object end |
#pricing_plan ⇒ Object (readonly)
The ID of the Pricing Plan this component belongs to.
42 43 44 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 42 def pricing_plan @pricing_plan end |
#pricing_plan_version ⇒ Object (readonly)
The ID of the Pricing Plan Version this component belongs to.
44 45 46 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 44 def pricing_plan_version @pricing_plan_version end |
#rate_card ⇒ Object (readonly)
Details if this component is a Rate Card.
52 53 54 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 52 def rate_card @rate_card end |
#service_action ⇒ Object (readonly)
Details if this component is a Service Action.
54 55 56 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 54 def service_action @service_action end |
#type ⇒ Object (readonly)
The type of the PricingPlanComponent.
46 47 48 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 46 def type @type end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_component.rb', line 9 def self.object_name "v2.billing.pricing_plan_component" end |