Class: Stripe::V2::Billing::PricingPlanService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::PricingPlanService::UpdateParams
- Defined in:
- lib/stripe/services/v2/billing/pricing_plan_service.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the PricingPlan is active.
-
#description ⇒ Object
Description of pricing plan subscription.
-
#display_name ⇒ Object
Display name of the PricingPlan.
-
#live_version ⇒ Object
The ID of the live version of the PricingPlan.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular PricingPlan.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, description: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, description: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 79 def initialize( active: nil, description: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil ) @active = active @description = description @display_name = display_name @live_version = live_version @lookup_key = lookup_key @metadata = end |
Instance Attribute Details
#active ⇒ Object
Whether the PricingPlan is active.
67 68 69 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 67 def active @active end |
#description ⇒ Object
Description of pricing plan subscription.
69 70 71 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 69 def description @description end |
#display_name ⇒ Object
Display name of the PricingPlan. Maximum 250 characters.
71 72 73 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 71 def display_name @display_name end |
#live_version ⇒ Object
The ID of the live version of the PricingPlan.
73 74 75 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 73 def live_version @live_version end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular PricingPlan. Maximum length of 200 characters.
75 76 77 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 75 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
77 78 79 |
# File 'lib/stripe/services/v2/billing/pricing_plan_service.rb', line 77 def @metadata end |