Class: Stripe::V2::Billing::PricingPlanSubscription

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/pricing_plan_subscription.rb

Overview

A Pricing Plan Subscription represents a customer’s active subscription to a Pricing Plan. It tracks both the servicing status (whether the customer is receiving service) and collection status (whether payments are current). Subscriptions are created through Billing Intents and bill according to the associated Billing Cadence.

Defined Under Namespace

Classes: CancellationDetails, CollectionStatusTransitions, ServicingStatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.pricing_plan_subscription"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cadenceObject (readonly)

The ID of the Billing Cadence this subscription is billed on.



75
76
77
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 75

def billing_cadence
  @billing_cadence
end

#cancellation_detailsObject (readonly)

Details about why the subscription was canceled, if applicable. Includes system-generated reason.



77
78
79
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 77

def cancellation_details
  @cancellation_details
end

#collection_statusObject (readonly)

Current collection status of this subscription.



79
80
81
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 79

def collection_status
  @collection_status
end

#collection_status_transitionsObject (readonly)

Timestamps for collection status transitions.



81
82
83
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 81

def collection_status_transitions
  @collection_status_transitions
end

#createdObject (readonly)

Time at which the object was created.



83
84
85
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 83

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



85
86
87
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 85

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



101
102
103
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 101

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



87
88
89
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 87

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



89
90
91
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 89

def object
  @object
end

#pricing_planObject (readonly)

The ID of the Pricing Plan for this subscription.



91
92
93
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 91

def pricing_plan
  @pricing_plan
end

#pricing_plan_versionObject (readonly)

The ID of the Pricing Plan Version for this subscription.



93
94
95
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 93

def pricing_plan_version
  @pricing_plan_version
end

#servicing_statusObject (readonly)

Current servicing status of this subscription.



95
96
97
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 95

def servicing_status
  @servicing_status
end

#servicing_status_transitionsObject (readonly)

Timestamps for servicing status transitions.



97
98
99
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 97

def servicing_status_transitions
  @servicing_status_transitions
end

#test_clockObject (readonly)

The ID of the Test Clock of the associated Billing Cadence, if any.



99
100
101
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 99

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



111
112
113
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 111

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



103
104
105
106
107
108
109
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 103

def self.inner_class_types
  @inner_class_types = {
    cancellation_details: CancellationDetails,
    collection_status_transitions: CollectionStatusTransitions,
    servicing_status_transitions: ServicingStatusTransitions,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 12

def self.object_name
  "v2.billing.pricing_plan_subscription"
end