Class: Stripe::V2::Billing::PricingPlanSubscription

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/pricing_plan_subscription.rb

Defined Under Namespace

Classes: CancellationDetails, CollectionStatusTransitions, ServicingStatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.billing.pricing_plan_subscription"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_cadenceObject (readonly)

The ID of the Billing Cadence this subscription is billed on.



72
73
74
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 72

def billing_cadence
  @billing_cadence
end

#cancellation_detailsObject (readonly)

Details about why the subscription was canceled, if applicable. Includes system-generated reason.



74
75
76
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 74

def cancellation_details
  @cancellation_details
end

#collection_statusObject (readonly)

Current collection status of this subscription.



76
77
78
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 76

def collection_status
  @collection_status
end

#collection_status_transitionsObject (readonly)

Timestamps for collection status transitions.



78
79
80
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 78

def collection_status_transitions
  @collection_status_transitions
end

#createdObject (readonly)

Time at which the object was created.



80
81
82
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 80

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



82
83
84
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 82

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



98
99
100
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 98

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



84
85
86
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 84

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



86
87
88
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 86

def object
  @object
end

#pricing_planObject (readonly)

The ID of the Pricing Plan for this subscription.



88
89
90
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 88

def pricing_plan
  @pricing_plan
end

#pricing_plan_versionObject (readonly)

The ID of the Pricing Plan Version for this subscription.



90
91
92
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 90

def pricing_plan_version
  @pricing_plan_version
end

#servicing_statusObject (readonly)

Current servicing status of this subscription.



92
93
94
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 92

def servicing_status
  @servicing_status
end

#servicing_status_transitionsObject (readonly)

Timestamps for servicing status transitions.



94
95
96
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 94

def servicing_status_transitions
  @servicing_status_transitions
end

#test_clockObject (readonly)

The ID of the Test Clock of the associated Billing Cadence, if any.



96
97
98
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 96

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



108
109
110
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 108

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



100
101
102
103
104
105
106
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 100

def self.inner_class_types
  @inner_class_types = {
    cancellation_details: CancellationDetails,
    collection_status_transitions: CollectionStatusTransitions,
    servicing_status_transitions: ServicingStatusTransitions,
  }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 9

def self.object_name
  "v2.billing.pricing_plan_subscription"
end