Class: Stripe::V2::Billing::PricingPlanSubscription
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::PricingPlanSubscription
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Defined Under Namespace
Classes: CollectionStatusTransitions, ServicingStatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.pricing_plan_subscription"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
readonly
The ID of the Billing Cadence this subscription is billed on.
-
#collection_status ⇒ Object
readonly
Current collection status of this subscription.
-
#collection_status_transitions ⇒ Object
readonly
Timestamps for collection status transitions.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pricing_plan ⇒ Object
readonly
The ID of the Pricing Plan for this subscription.
-
#pricing_plan_version ⇒ Object
readonly
The ID of the Pricing Plan Version for this subscription.
-
#servicing_status ⇒ Object
readonly
Current servicing status of this subscription.
-
#servicing_status_transitions ⇒ Object
readonly
Timestamps for servicing status transitions.
-
#test_clock ⇒ Object
readonly
The ID of the Test Clock of the associated Billing Cadence, if any.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence ⇒ Object (readonly)
The ID of the Billing Cadence this subscription is billed on.
55 56 57 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 55 def billing_cadence @billing_cadence end |
#collection_status ⇒ Object (readonly)
Current collection status of this subscription.
57 58 59 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 57 def collection_status @collection_status end |
#collection_status_transitions ⇒ Object (readonly)
Timestamps for collection status transitions.
59 60 61 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 59 def collection_status_transitions @collection_status_transitions end |
#created ⇒ Object (readonly)
Time at which the object was created.
61 62 63 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 61 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
63 64 65 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 63 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
79 80 81 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 79 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
65 66 67 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 65 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
67 68 69 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 67 def object @object end |
#pricing_plan ⇒ Object (readonly)
The ID of the Pricing Plan for this subscription.
69 70 71 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 69 def pricing_plan @pricing_plan end |
#pricing_plan_version ⇒ Object (readonly)
The ID of the Pricing Plan Version for this subscription.
71 72 73 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 71 def pricing_plan_version @pricing_plan_version end |
#servicing_status ⇒ Object (readonly)
Current servicing status of this subscription.
73 74 75 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 73 def servicing_status @servicing_status end |
#servicing_status_transitions ⇒ Object (readonly)
Timestamps for servicing status transitions.
75 76 77 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 75 def servicing_status_transitions @servicing_status_transitions end |
#test_clock ⇒ Object (readonly)
The ID of the Test Clock of the associated Billing Cadence, if any.
77 78 79 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 77 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
88 89 90 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 88 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
81 82 83 84 85 86 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 81 def self.inner_class_types @inner_class_types = { collection_status_transitions: CollectionStatusTransitions, servicing_status_transitions: ServicingStatusTransitions, } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 9 def self.object_name "v2.billing.pricing_plan_subscription" end |