Class: Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantDetails::ApplicabilityConfig::Scope
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::PricingPlanSubscription::PricingPlanComponentDetail::RecurringCreditGrantDetails::CreditGrantDetails::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/resources/v2/billing/pricing_plan_subscription.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
readonly
The billable items to apply the credit grant to.
-
#price_type ⇒ Object
readonly
The price type that credit grants can apply to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billable_items ⇒ Object (readonly)
The billable items to apply the credit grant to.
282 283 284 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 282 def billable_items @billable_items end |
#price_type ⇒ Object (readonly)
The price type that credit grants can apply to. Stripe supports the metered price type, which applies to metered prices and rate cards. Cannot be used in combination with billable_items.
284 285 286 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 284 def price_type @price_type end |
Class Method Details
.field_remappings ⇒ Object
290 291 292 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 290 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
286 287 288 |
# File 'lib/stripe/resources/v2/billing/pricing_plan_subscription.rb', line 286 def self.inner_class_types @inner_class_types = {} end |