Class: Stripe::V2::Billing::PricingPlanUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::PricingPlanUpdateParams
- Defined in:
- lib/stripe/params/v2/billing/pricing_plan_update_params.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the PricingPlan is active.
-
#description ⇒ Object
Description of pricing plan subscription.
-
#display_name ⇒ Object
Display name of the PricingPlan.
-
#live_version ⇒ Object
The ID of the live version of the PricingPlan.
-
#lookup_key ⇒ Object
An internal key you can use to search for a particular PricingPlan.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, description: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ PricingPlanUpdateParams
constructor
A new instance of PricingPlanUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(active: nil, description: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil) ⇒ PricingPlanUpdateParams
Returns a new instance of PricingPlanUpdateParams.
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 21 def initialize( active: nil, description: nil, display_name: nil, live_version: nil, lookup_key: nil, metadata: nil ) @active = active @description = description @display_name = display_name @live_version = live_version @lookup_key = lookup_key @metadata = end |
Instance Attribute Details
#active ⇒ Object
Whether the PricingPlan is active.
9 10 11 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 9 def active @active end |
#description ⇒ Object
Description of pricing plan subscription.
11 12 13 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 11 def description @description end |
#display_name ⇒ Object
Display name of the PricingPlan. Maximum 250 characters.
13 14 15 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 13 def display_name @display_name end |
#live_version ⇒ Object
The ID of the live version of the PricingPlan.
15 16 17 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 15 def live_version @live_version end |
#lookup_key ⇒ Object
An internal key you can use to search for a particular PricingPlan. Maximum length of 200 characters.
17 18 19 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 17 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
19 20 21 |
# File 'lib/stripe/params/v2/billing/pricing_plan_update_params.rb', line 19 def @metadata end |