Class: Stripe::V2::Billing::PricingPlanVersion

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/pricing_plan_version.rb

Constant Summary collapse

OBJECT_NAME =
"v2.billing.pricing_plan_version"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created.



14
15
16
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 14

def created
  @created
end

#end_dateObject (readonly)

The timestamp when this version became inactive. Null if it’s the latest version.



16
17
18
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 16

def end_date
  @end_date
end

#idObject (readonly)

Unique identifier for the object.



18
19
20
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 18

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



26
27
28
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 26

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



20
21
22
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 20

def object
  @object
end

#pricing_planObject (readonly)

The ID of the PricingPlan this version belongs to.



22
23
24
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 22

def pricing_plan
  @pricing_plan
end

#start_dateObject (readonly)

The timestamp when this version became active.



24
25
26
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 24

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



32
33
34
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 32

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



28
29
30
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 28

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/pricing_plan_version.rb', line 9

def self.object_name
  "v2.billing.pricing_plan_version"
end