Class: Stripe::V2::Billing::PricingPlans::ComponentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb

Defined Under Namespace

Classes: LicenseFee, RateCard, ServiceAction

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(lookup_key: nil, metadata: nil, type: nil, license_fee: nil, rate_card: nil, service_action: nil) ⇒ ComponentCreateParams

Returns a new instance of ComponentCreateParams.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 54

def initialize(
  lookup_key: nil,
  metadata: nil,
  type: nil,
  license_fee: nil,
  rate_card: nil,
  service_action: nil
)
  @lookup_key = lookup_key
  @metadata = 
  @type = type
  @license_fee = license_fee
  @rate_card = rate_card
  @service_action = service_action
end

Instance Attribute Details

#license_feeObject

Details if this component is a License Fee.



48
49
50
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 48

def license_fee
  @license_fee
end

#lookup_keyObject

An identifier that can be used to find this component.



42
43
44
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 42

def lookup_key
  @lookup_key
end

#metadataObject

Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



44
45
46
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 44

def 
  @metadata
end

#rate_cardObject

Details if this component is a Rate Card.



50
51
52
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 50

def rate_card
  @rate_card
end

#service_actionObject

Details if this component is a Service Action.



52
53
54
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 52

def service_action
  @service_action
end

#typeObject

The type of the PricingPlanComponent.



46
47
48
# File 'lib/stripe/params/v2/billing/pricing_plans/component_create_params.rb', line 46

def type
  @type
end