Class: Stripe::V2::Billing::PricingPlans::ComponentListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::PricingPlans::ComponentListParams
- Defined in:
- lib/stripe/params/v2/billing/pricing_plans/component_list_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Filter by lookup keys.
-
#pricing_plan_version ⇒ Object
The ID of the Pricing Plan Version to list components for.
Instance Method Summary collapse
-
#initialize(limit: nil, lookup_keys: nil, pricing_plan_version: nil) ⇒ ComponentListParams
constructor
A new instance of ComponentListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil, lookup_keys: nil, pricing_plan_version: nil) ⇒ ComponentListParams
Returns a new instance of ComponentListParams.
18 19 20 21 22 |
# File 'lib/stripe/params/v2/billing/pricing_plans/component_list_params.rb', line 18 def initialize(limit: nil, lookup_keys: nil, pricing_plan_version: nil) @limit = limit @lookup_keys = lookup_keys @pricing_plan_version = pricing_plan_version end |
Instance Attribute Details
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 20.
10 11 12 |
# File 'lib/stripe/params/v2/billing/pricing_plans/component_list_params.rb', line 10 def limit @limit end |
#lookup_keys ⇒ Object
Filter by lookup keys. Mutually exclusive with ‘pricing_plan_version`. You can specify up to 10 lookup keys.
13 14 15 |
# File 'lib/stripe/params/v2/billing/pricing_plans/component_list_params.rb', line 13 def lookup_keys @lookup_keys end |
#pricing_plan_version ⇒ Object
The ID of the Pricing Plan Version to list components for. Will use the latest version if not provided. Mutually exclusive with ‘lookup_keys`.
16 17 18 |
# File 'lib/stripe/params/v2/billing/pricing_plans/component_list_params.rb', line 16 def pricing_plan_version @pricing_plan_version end |