Class: Stripe::V2::Billing::PricingPlans::ComponentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::PricingPlans::ComponentService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/pricing_plans/component_service.rb
Defined Under Namespace
Classes: LicenseFee, RateCard, ServiceAction
Instance Attribute Summary collapse
-
#license_fee ⇒ Object
Details if this component is a License Fee.
-
#lookup_key ⇒ Object
An identifier that can be used to find this component.
-
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#rate_card ⇒ Object
Details if this component is a Rate Card.
-
#service_action ⇒ Object
Details if this component is a Service Action.
-
#type ⇒ Object
The type of the PricingPlanComponent.
Instance Method Summary collapse
-
#initialize(lookup_key: nil, metadata: nil, type: nil, license_fee: nil, rate_card: nil, service_action: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(lookup_key: nil, metadata: nil, type: nil, license_fee: nil, rate_card: nil, service_action: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 72 def initialize( lookup_key: nil, metadata: nil, type: nil, license_fee: nil, rate_card: nil, service_action: nil ) @lookup_key = lookup_key @metadata = @type = type @license_fee = license_fee @rate_card = rate_card @service_action = service_action end |
Instance Attribute Details
#license_fee ⇒ Object
Details if this component is a License Fee.
66 67 68 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 66 def license_fee @license_fee end |
#lookup_key ⇒ Object
An identifier that can be used to find this component.
60 61 62 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 60 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
62 63 64 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 62 def @metadata end |
#rate_card ⇒ Object
Details if this component is a Rate Card.
68 69 70 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 68 def rate_card @rate_card end |
#service_action ⇒ Object
Details if this component is a Service Action.
70 71 72 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 70 def service_action @service_action end |
#type ⇒ Object
The type of the PricingPlanComponent.
64 65 66 |
# File 'lib/stripe/services/v2/billing/pricing_plans/component_service.rb', line 64 def type @type end |