Class: Stripe::V2::Billing::PricingPlans::ComponentUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/pricing_plans/component_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(lookup_key: nil, metadata: nil) ⇒ ComponentUpdateParams

Returns a new instance of ComponentUpdateParams.



14
15
16
17
# File 'lib/stripe/params/v2/billing/pricing_plans/component_update_params.rb', line 14

def initialize(lookup_key: nil, metadata: nil)
  @lookup_key = lookup_key
  @metadata = 
end

Instance Attribute Details

#lookup_keyObject

An identifier that can be used to find this component. Maximum length of 200 characters.



10
11
12
# File 'lib/stripe/params/v2/billing/pricing_plans/component_update_params.rb', line 10

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object.



12
13
14
# File 'lib/stripe/params/v2/billing/pricing_plans/component_update_params.rb', line 12

def 
  @metadata
end