Class: Stripe::V2::Billing::Profile
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::Profile
- Defined in:
- lib/stripe/resources/v2/billing/profile.rb
Overview
A Billing Profile is a representation of how a bill is paid, separating payment behavior from customer identity.
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.profile"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#customer ⇒ Object
readonly
The ID of the customer object.
-
#default_payment_method ⇒ Object
readonly
The ID of the payment method object.
-
#display_name ⇒ Object
readonly
A customer-facing name for the billing profile.
-
#id ⇒ Object
readonly
The ID of the billing profile object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
An internal key you can use to search for a particular billing profile.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The current status of the billing profile.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Timestamp of when the object was created.
15 16 17 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 15 def created @created end |
#customer ⇒ Object (readonly)
The ID of the customer object.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 17 def customer @customer end |
#default_payment_method ⇒ Object (readonly)
The ID of the payment method object.
19 20 21 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 19 def default_payment_method @default_payment_method end |
#display_name ⇒ Object (readonly)
A customer-facing name for the billing profile. Maximum length of 250 characters.
22 23 24 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 22 def display_name @display_name end |
#id ⇒ Object (readonly)
The ID of the billing profile object.
24 25 26 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 24 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
26 27 28 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 26 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
An internal key you can use to search for a particular billing profile. Maximum length of 200 characters.
29 30 31 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 29 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
31 32 33 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 31 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
33 34 35 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 33 def object @object end |
#status ⇒ Object (readonly)
The current status of the billing profile.
35 36 37 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 35 def status @status end |
Class Method Details
.field_remappings ⇒ Object
41 42 43 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 41 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
37 38 39 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 37 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/billing/profile.rb', line 10 def self.object_name "v2.billing.profile" end |