Class: Stripe::V2::Billing::Profile

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/profile.rb

Constant Summary collapse

OBJECT_NAME =
"v2.billing.profile"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



14
15
16
# File 'lib/stripe/resources/v2/billing/profile.rb', line 14

def created
  @created
end

#customerObject (readonly)

The ID of the customer object.



16
17
18
# File 'lib/stripe/resources/v2/billing/profile.rb', line 16

def customer
  @customer
end

#default_payment_methodObject (readonly)

The ID of the payment method object.



18
19
20
# File 'lib/stripe/resources/v2/billing/profile.rb', line 18

def default_payment_method
  @default_payment_method
end

#display_nameObject (readonly)

A customer-facing name for the billing profile. Maximum length of 250 characters.



21
22
23
# File 'lib/stripe/resources/v2/billing/profile.rb', line 21

def display_name
  @display_name
end

#idObject (readonly)

The ID of the billing profile object.



23
24
25
# File 'lib/stripe/resources/v2/billing/profile.rb', line 23

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



34
35
36
# File 'lib/stripe/resources/v2/billing/profile.rb', line 34

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for a particular billing profile. Maximum length of 200 characters.



26
27
28
# File 'lib/stripe/resources/v2/billing/profile.rb', line 26

def lookup_key
  @lookup_key
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



28
29
30
# File 'lib/stripe/resources/v2/billing/profile.rb', line 28

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



30
31
32
# File 'lib/stripe/resources/v2/billing/profile.rb', line 30

def object
  @object
end

#statusObject (readonly)

The current status of the billing profile.



32
33
34
# File 'lib/stripe/resources/v2/billing/profile.rb', line 32

def status
  @status
end

Class Method Details

.field_remappingsObject



40
41
42
# File 'lib/stripe/resources/v2/billing/profile.rb', line 40

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



36
37
38
# File 'lib/stripe/resources/v2/billing/profile.rb', line 36

def self.inner_class_types
  @inner_class_types = {}
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/profile.rb', line 9

def self.object_name
  "v2.billing.profile"
end