Class: Stripe::V2::Billing::ProfileService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ProfileService::ListParams
- Defined in:
- lib/stripe/services/v2/billing/profile_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
Filter billing profiles by a customer.
-
#default_payment_method ⇒ Object
Filter billing profiles by a default payment method.
-
#limit ⇒ Object
Optionally set the maximum number of results per page.
-
#lookup_keys ⇒ Object
Filter billing profiles by lookup keys.
-
#status ⇒ Object
Filter billing profiles by status.
Instance Method Summary collapse
-
#initialize(customer: nil, default_payment_method: nil, limit: nil, lookup_keys: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, default_payment_method: nil, limit: nil, lookup_keys: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 25 def initialize( customer: nil, default_payment_method: nil, limit: nil, lookup_keys: nil, status: nil ) @customer = customer @default_payment_method = default_payment_method @limit = limit @lookup_keys = lookup_keys @status = status end |
Instance Attribute Details
#customer ⇒ Object
Filter billing profiles by a customer. Mutually exclusive with ‘lookup_keys` and `default_payment_method`.
11 12 13 |
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 11 def customer @customer end |
#default_payment_method ⇒ Object
Filter billing profiles by a default payment method. Mutually exclusive with ‘customer` and `lookup_keys`.
14 15 16 |
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 14 def default_payment_method @default_payment_method end |
#limit ⇒ Object
Optionally set the maximum number of results per page. Defaults to 10.
16 17 18 |
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 16 def limit @limit end |
#lookup_keys ⇒ Object
Filter billing profiles by lookup keys. Mutually exclusive with ‘customer` and `default_payment_method`. You can specify up to 10 lookup_keys.
20 21 22 |
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 20 def lookup_keys @lookup_keys end |
#status ⇒ Object
Filter billing profiles by status. Can be combined with all other filters. If not provided, all billing profiles will be returned.
23 24 25 |
# File 'lib/stripe/services/v2/billing/profile_service.rb', line 23 def status @status end |