Class: Stripe::V2::Billing::RateCardCustomPricingUnitOverageRate
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::RateCardCustomPricingUnitOverageRate
- Defined in:
- lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb
Overview
A rate card custom pricing unit overage rate defines the conversion rate from a custom pricing unit to fiat currency when credits are exhausted. This enables automatic overage charges at a configurable per-unit rate.
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.rate_card_custom_pricing_unit_overage_rate"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#custom_pricing_unit ⇒ Object
readonly
The ID of the custom pricing unit this overage rate applies to.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#one_time_item ⇒ Object
readonly
A one-time item represents a product that can be charged as a one-time line item, used for overage charges when custom pricing unit credits are exhausted.
-
#rate_card ⇒ Object
readonly
The ID of the Rate Card this overage rate belongs to.
-
#rate_card_version ⇒ Object
readonly
The ID of the Rate Card Version this overage rate was created on.
-
#unit_amount ⇒ Object
readonly
The per-unit amount to charge for overages, represented as a decimal string in minor currency units with at most 12 decimal places.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Timestamp of when the object was created.
17 18 19 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 17 def created @created end |
#custom_pricing_unit ⇒ Object (readonly)
The ID of the custom pricing unit this overage rate applies to.
19 20 21 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 19 def custom_pricing_unit @custom_pricing_unit end |
#id ⇒ Object (readonly)
Unique identifier for the object.
21 22 23 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 21 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
36 37 38 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 36 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
23 24 25 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 23 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
25 26 27 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 25 def object @object end |
#one_time_item ⇒ Object (readonly)
A one-time item represents a product that can be charged as a one-time line item, used for overage charges when custom pricing unit credits are exhausted.
28 29 30 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 28 def one_time_item @one_time_item end |
#rate_card ⇒ Object (readonly)
The ID of the Rate Card this overage rate belongs to.
30 31 32 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 30 def rate_card @rate_card end |
#rate_card_version ⇒ Object (readonly)
The ID of the Rate Card Version this overage rate was created on.
32 33 34 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 32 def rate_card_version @rate_card_version end |
#unit_amount ⇒ Object (readonly)
The per-unit amount to charge for overages, represented as a decimal string in minor currency units with at most 12 decimal places.
34 35 36 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 34 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
42 43 44 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 42 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
38 39 40 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 38 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/rate_card_custom_pricing_unit_overage_rate.rb', line 12 def self.object_name "v2.billing.rate_card_custom_pricing_unit_overage_rate" end |