Class: Stripe::V2::Billing::RateCardRate::Tier
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::RateCardRate::Tier
- Defined in:
- lib/stripe/resources/v2/billing/rate_card_rate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#flat_amount ⇒ Object
readonly
Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.
-
#unit_amount ⇒ Object
readonly
Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.
-
#up_to_decimal ⇒ Object
readonly
Up to and including this quantity will be contained in the tier.
-
#up_to_inf ⇒ Object
readonly
No upper bound to this tier.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#flat_amount ⇒ Object (readonly)
Price for the entire tier, represented as a decimal string in minor currency units with at most 12 decimal places.
22 23 24 |
# File 'lib/stripe/resources/v2/billing/rate_card_rate.rb', line 22 def flat_amount @flat_amount end |
#unit_amount ⇒ Object (readonly)
Per-unit price for units included in this tier, represented as a decimal string in minor currency units with at most 12 decimal places.
25 26 27 |
# File 'lib/stripe/resources/v2/billing/rate_card_rate.rb', line 25 def unit_amount @unit_amount end |
#up_to_decimal ⇒ Object (readonly)
Up to and including this quantity will be contained in the tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.
28 29 30 |
# File 'lib/stripe/resources/v2/billing/rate_card_rate.rb', line 28 def up_to_decimal @up_to_decimal end |
#up_to_inf ⇒ Object (readonly)
No upper bound to this tier. Only one of ‘up_to_decimal` and `up_to_inf` may be set.
30 31 32 |
# File 'lib/stripe/resources/v2/billing/rate_card_rate.rb', line 30 def up_to_inf @up_to_inf end |