Class: Stripe::V2::Billing::RateCardSubscription
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Billing::RateCardSubscription
- Defined in:
- lib/stripe/resources/v2/billing/rate_card_subscription.rb
Overview
A Rate Card Subscription represents a customer’s subscription to a Rate Card’s usage-based pricing. It tracks the servicing status (whether usage is being measured) and collection status (whether payments are current). Subscriptions bill according to the service interval defined in the Rate Card and are collected on the associated Billing Cadence.
Defined Under Namespace
Classes: CollectionStatusTransitions, ServicingStatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.billing.rate_card_subscription"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
readonly
The ID of the Billing Cadence.
-
#collection_status ⇒ Object
readonly
The payment status of a Rate Card Subscription.
-
#collection_status_transitions ⇒ Object
readonly
The collection status transitions of the Rate Card Subscription.
-
#created ⇒ Object
readonly
Timestamp of when the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#rate_card ⇒ Object
readonly
The ID of the Rate Card.
-
#rate_card_version ⇒ Object
readonly
The ID of the Rate Card Version.
-
#servicing_status ⇒ Object
readonly
The servicing status of a Rate Card Subscription.
-
#servicing_status_transitions ⇒ Object
readonly
The servicing status transitions of the Rate Card Subscription.
-
#test_clock ⇒ Object
readonly
The ID of the Test Clock, if any.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_cadence ⇒ Object (readonly)
The ID of the Billing Cadence.
58 59 60 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 58 def billing_cadence @billing_cadence end |
#collection_status ⇒ Object (readonly)
The payment status of a Rate Card Subscription.
60 61 62 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 60 def collection_status @collection_status end |
#collection_status_transitions ⇒ Object (readonly)
The collection status transitions of the Rate Card Subscription.
62 63 64 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 62 def collection_status_transitions @collection_status_transitions end |
#created ⇒ Object (readonly)
Timestamp of when the object was created.
64 65 66 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 64 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
66 67 68 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 66 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
82 83 84 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 82 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
68 69 70 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 68 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
70 71 72 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 70 def object @object end |
#rate_card ⇒ Object (readonly)
The ID of the Rate Card.
72 73 74 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 72 def rate_card @rate_card end |
#rate_card_version ⇒ Object (readonly)
The ID of the Rate Card Version.
74 75 76 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 74 def rate_card_version @rate_card_version end |
#servicing_status ⇒ Object (readonly)
The servicing status of a Rate Card Subscription.
76 77 78 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 76 def servicing_status @servicing_status end |
#servicing_status_transitions ⇒ Object (readonly)
The servicing status transitions of the Rate Card Subscription.
78 79 80 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 78 def servicing_status_transitions @servicing_status_transitions end |
#test_clock ⇒ Object (readonly)
The ID of the Test Clock, if any.
80 81 82 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 80 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
91 92 93 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 91 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
84 85 86 87 88 89 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 84 def self.inner_class_types @inner_class_types = { collection_status_transitions: CollectionStatusTransitions, servicing_status_transitions: ServicingStatusTransitions, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/billing/rate_card_subscription.rb', line 12 def self.object_name "v2.billing.rate_card_subscription" end |