Class: Stripe::V2::Billing::RateCardSubscriptionListParams::Payer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(customer: nil, type: nil) ⇒ Payer

Returns a new instance of Payer.



14
15
16
17
# File 'lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb', line 14

def initialize(customer: nil, type: nil)
  @customer = customer
  @type = type
end

Instance Attribute Details

#customerObject

The ID of the Customer object. If provided, only the Rate Card Subscriptions that are subscribed on the Billing Cadences with the specified payer will be returned.



10
11
12
# File 'lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb', line 10

def customer
  @customer
end

#typeObject

A string identifying the type of the payer. Currently the only supported value is ‘customer`.



12
13
14
# File 'lib/stripe/params/v2/billing/rate_card_subscription_list_params.rb', line 12

def type
  @type
end