Class: Stripe::V2::Billing::ServiceAction

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/billing/service_action.rb

Defined Under Namespace

Classes: CreditGrant, CreditGrantPerTenant

Constant Summary collapse

OBJECT_NAME =
"v2.billing.service_action"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Timestamp of when the object was created.



95
96
97
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 95

def created
  @created
end

#credit_grantObject (readonly)

Details for the credit grant. Provided only if ‘type` is “credit_grant”.



111
112
113
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 111

def credit_grant
  @credit_grant
end

#credit_grant_per_tenantObject (readonly)

Details for the credit grant per tenant. Provided only if ‘type` is “credit_grant_per_tenant”.



113
114
115
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 113

def credit_grant_per_tenant
  @credit_grant_per_tenant
end

#idObject (readonly)

Unique identifier for the object.



97
98
99
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 97

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



109
110
111
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 109

def livemode
  @livemode
end

#lookup_keyObject (readonly)

An internal key you can use to search for this service action.



99
100
101
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 99

def lookup_key
  @lookup_key
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



101
102
103
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 101

def object
  @object
end

#service_intervalObject (readonly)

The interval for assessing service.



103
104
105
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 103

def service_interval
  @service_interval
end

#service_interval_countObject (readonly)

The length of the interval for assessing service.



105
106
107
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 105

def service_interval_count
  @service_interval_count
end

#typeObject (readonly)

The type of the service action.



107
108
109
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 107

def type
  @type
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 9

def self.object_name
  "v2.billing.service_action"
end