Class: Stripe::V2::Billing::ServiceAction::CreditGrant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::ServiceAction::CreditGrant
- Defined in:
- lib/stripe/resources/v2/billing/service_action.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the credit grant.
-
#applicability_config ⇒ Object
readonly
Defines the scope where the credit grant is applicable.
-
#category ⇒ Object
readonly
The category of the credit grant.
-
#expiry_config ⇒ Object
readonly
The expiry configuration for the credit grant.
-
#name ⇒ Object
readonly
A descriptive name shown in dashboard.
-
#priority ⇒ Object
readonly
The desired priority for applying this credit grant.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the credit grant.
98 99 100 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 98 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Defines the scope where the credit grant is applicable.
100 101 102 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 100 def applicability_config @applicability_config end |
#category ⇒ Object (readonly)
The category of the credit grant.
102 103 104 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 102 def category @category end |
#expiry_config ⇒ Object (readonly)
The expiry configuration for the credit grant.
104 105 106 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 104 def expiry_config @expiry_config end |
#name ⇒ Object (readonly)
A descriptive name shown in dashboard.
106 107 108 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 106 def name @name end |
#priority ⇒ Object (readonly)
The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.
108 109 110 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 108 def priority @priority end |
Class Method Details
.field_encodings ⇒ Object
122 123 124 125 126 127 128 129 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 122 def self.field_encodings @field_encodings = { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } }, }, } end |
.field_remappings ⇒ Object
118 119 120 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 118 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
110 111 112 113 114 115 116 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 110 def self.inner_class_types @inner_class_types = { amount: Amount, applicability_config: ApplicabilityConfig, expiry_config: ExpiryConfig, } end |