Class: Stripe::V2::Billing::ServiceAction::CreditGrant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::ServiceAction::CreditGrant
- Defined in:
- lib/stripe/resources/v2/billing/service_action.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the credit grant.
-
#applicability_config ⇒ Object
readonly
Defines the scope where the credit grant is applicable.
-
#expiry_config ⇒ Object
readonly
The expiry configuration for the credit grant.
-
#name ⇒ Object
readonly
A descriptive name shown in dashboard.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the credit grant.
85 86 87 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 85 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Defines the scope where the credit grant is applicable.
87 88 89 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 87 def applicability_config @applicability_config end |
#expiry_config ⇒ Object (readonly)
The expiry configuration for the credit grant.
89 90 91 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 89 def expiry_config @expiry_config end |
#name ⇒ Object (readonly)
A descriptive name shown in dashboard.
91 92 93 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 91 def name @name end |
Class Method Details
.field_remappings ⇒ Object
101 102 103 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 101 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
93 94 95 96 97 98 99 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 93 def self.inner_class_types @inner_class_types = { amount: Amount, applicability_config: ApplicabilityConfig, expiry_config: ExpiryConfig, } end |