Class: Stripe::V2::Billing::ServiceAction::CreditGrant::ApplicabilityConfig::Scope
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::ServiceAction::CreditGrant::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/resources/v2/billing/service_action.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
readonly
The billable items to apply the credit grant to.
-
#price_type ⇒ Object
readonly
The price type that credit grants can apply to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billable_items ⇒ Object (readonly)
The billable items to apply the credit grant to.
61 62 63 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 61 def billable_items @billable_items end |
#price_type ⇒ Object (readonly)
The price type that credit grants can apply to. Stripe supports the metered price type, which applies to metered prices and rate cards. Cannot be used in combination with billable_items.
63 64 65 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 63 def price_type @price_type end |
Class Method Details
.field_remappings ⇒ Object
69 70 71 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 69 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
65 66 67 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 65 def self.inner_class_types @inner_class_types = {} end |