Class: Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/billing/service_action.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the credit grant.



217
218
219
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 217

def amount
  @amount
end

#applicability_configObject (readonly)

Defines the scope where the credit grant is applicable.



219
220
221
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 219

def applicability_config
  @applicability_config
end

#categoryObject (readonly)

The category of the credit grant.



221
222
223
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 221

def category
  @category
end

#expiry_configObject (readonly)

The expiry configuration for the credit grant.



223
224
225
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 223

def expiry_config
  @expiry_config
end

#nameObject (readonly)

Customer-facing name for the credit grant.



225
226
227
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 225

def name
  @name
end

#priorityObject (readonly)

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



227
228
229
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 227

def priority
  @priority
end

Class Method Details

.field_remappingsObject



237
238
239
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 237

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



229
230
231
232
233
234
235
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 229

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    applicability_config: ApplicabilityConfig,
    expiry_config: ExpiryConfig,
  }
end