Class: Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Billing::ServiceAction::CreditGrantPerTenant
- Defined in:
- lib/stripe/resources/v2/billing/service_action.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the credit grant.
-
#applicability_config ⇒ Object
readonly
Defines the scope where the credit grant is applicable.
-
#expiry_config ⇒ Object
readonly
The expiry configuration for the credit grant.
-
#name ⇒ Object
readonly
Customer-facing name for the credit grant.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the credit grant.
86 87 88 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 86 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Defines the scope where the credit grant is applicable.
88 89 90 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 88 def applicability_config @applicability_config end |
#expiry_config ⇒ Object (readonly)
The expiry configuration for the credit grant.
90 91 92 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 90 def expiry_config @expiry_config end |
#name ⇒ Object (readonly)
Customer-facing name for the credit grant.
92 93 94 |
# File 'lib/stripe/resources/v2/billing/service_action.rb', line 92 def name @name end |