Class: Stripe::V2::Billing::ServiceActionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Defined Under Namespace
Classes: CreditGrant, CreditGrantPerTenant
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
Details for the credit grant.
-
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant.
-
#lookup_key ⇒ Object
An internal key you can use to search for this service action.
-
#service_interval ⇒ Object
The interval for assessing service.
-
#service_interval_count ⇒ Object
The length of the interval for assessing service.
-
#type ⇒ Object
The type of the service action.
Instance Method Summary collapse
-
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ ServiceActionCreateParams
constructor
A new instance of ServiceActionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ ServiceActionCreateParams
Returns a new instance of ServiceActionCreateParams.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 260 def initialize( lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil ) @lookup_key = lookup_key @service_interval = service_interval @service_interval_count = service_interval_count @type = type @credit_grant = credit_grant @credit_grant_per_tenant = credit_grant_per_tenant end |
Instance Attribute Details
#credit_grant ⇒ Object
Details for the credit grant. Required if ‘type` is `credit_grant`.
256 257 258 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 256 def credit_grant @credit_grant end |
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant. Required if ‘type` is `credit_grant_per_tenant`.
258 259 260 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 258 def credit_grant_per_tenant @credit_grant_per_tenant end |
#lookup_key ⇒ Object
An internal key you can use to search for this service action. Maximum length of 200 characters.
248 249 250 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 248 def lookup_key @lookup_key end |
#service_interval ⇒ Object
The interval for assessing service.
250 251 252 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 250 def service_interval @service_interval end |
#service_interval_count ⇒ Object
The length of the interval for assessing service.
252 253 254 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 252 def service_interval_count @service_interval_count end |
#type ⇒ Object
The type of the service action.
254 255 256 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 254 def type @type end |