Class: Stripe::V2::Billing::ServiceActionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Defined Under Namespace
Classes: CreditGrant, CreditGrantPerTenant
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
Details for the credit grant.
-
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant.
-
#lookup_key ⇒ Object
An internal key you can use to search for this service action.
-
#service_interval ⇒ Object
The interval for assessing service.
-
#service_interval_count ⇒ Object
The length of the interval for assessing service.
-
#type ⇒ Object
The type of the service action.
Instance Method Summary collapse
-
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ ServiceActionCreateParams
constructor
A new instance of ServiceActionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ ServiceActionCreateParams
Returns a new instance of ServiceActionCreateParams.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 236 def initialize( lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil ) @lookup_key = lookup_key @service_interval = service_interval @service_interval_count = service_interval_count @type = type @credit_grant = credit_grant @credit_grant_per_tenant = credit_grant_per_tenant end |
Instance Attribute Details
#credit_grant ⇒ Object
Details for the credit grant. Required if ‘type` is `credit_grant`.
232 233 234 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 232 def credit_grant @credit_grant end |
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant. Required if ‘type` is `credit_grant_per_tenant`.
234 235 236 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 234 def credit_grant_per_tenant @credit_grant_per_tenant end |
#lookup_key ⇒ Object
An internal key you can use to search for this service action. Maximum length of 200 characters.
224 225 226 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 224 def lookup_key @lookup_key end |
#service_interval ⇒ Object
The interval for assessing service.
226 227 228 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 226 def service_interval @service_interval end |
#service_interval_count ⇒ Object
The length of the interval for assessing service.
228 229 230 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 228 def service_interval_count @service_interval_count end |
#type ⇒ Object
The type of the service action.
230 231 232 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 230 def type @type end |