Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/service_action_create_params.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil) ⇒ CreditGrant

Returns a new instance of CreditGrant.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 88

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  expiry_config: nil,
  name: nil,
  priority: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @expiry_config = expiry_config
  @name = name
  @priority = priority
end

Instance Attribute Details

#amountObject

The amount of the credit grant.



76
77
78
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 76

def amount
  @amount
end

#applicability_configObject

Defines the scope where the credit grant is applicable.



78
79
80
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 78

def applicability_config
  @applicability_config
end

#categoryObject

The category of the credit grant.



80
81
82
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 80

def category
  @category
end

#expiry_configObject

The expiry configuration for the credit grant.



82
83
84
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 82

def expiry_config
  @expiry_config
end

#nameObject

A descriptive name shown in dashboard.



84
85
86
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 84

def name
  @name
end

#priorityObject

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



86
87
88
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 86

def priority
  @priority
end