Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/service_action_create_params.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, name: nil, priority: nil) ⇒ CreditGrant

Returns a new instance of CreditGrant.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 76

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  expiry_config: nil,
  name: nil,
  priority: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @expiry_config = expiry_config
  @name = name
  @priority = priority
end

Instance Attribute Details

#amountObject

The amount of the credit grant.



64
65
66
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 64

def amount
  @amount
end

#applicability_configObject

Defines the scope where the credit grant is applicable.



66
67
68
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 66

def applicability_config
  @applicability_config
end

#categoryObject

The category of the credit grant.



68
69
70
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 68

def category
  @category
end

#expiry_configObject

The expiry configuration for the credit grant.



70
71
72
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 70

def expiry_config
  @expiry_config
end

#nameObject

A descriptive name shown in dashboard.



72
73
74
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 72

def name
  @name
end

#priorityObject

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



74
75
76
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 74

def priority
  @priority
end