Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant::ApplicabilityConfig::Scope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionCreateParams::CreditGrant::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/params/v2/billing/service_action_create_params.rb
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
The billable items to apply the credit grant to.
-
#price_type ⇒ Object
The price type that credit grants can apply to.
Instance Method Summary collapse
-
#initialize(billable_items: nil, price_type: nil) ⇒ Scope
constructor
A new instance of Scope.
Methods inherited from RequestParams
Constructor Details
#initialize(billable_items: nil, price_type: nil) ⇒ Scope
Returns a new instance of Scope.
54 55 56 57 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 54 def initialize(billable_items: nil, price_type: nil) @billable_items = billable_items @price_type = price_type end |
Instance Attribute Details
#billable_items ⇒ Object
The billable items to apply the credit grant to.
50 51 52 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 50 def billable_items @billable_items end |
#price_type ⇒ Object
The price type that credit grants can apply to. We currently only support the ‘metered` price type. This will apply to metered prices and rate cards. Cannot be used in combination with `billable_items`.
52 53 54 |
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 52 def price_type @price_type end |