Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/service_action_create_params.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig, GrantCondition

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, grant_condition: nil, name: nil, priority: nil) ⇒ CreditGrantPerTenant

Returns a new instance of CreditGrantPerTenant.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 229

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  expiry_config: nil,
  grant_condition: nil,
  name: nil,
  priority: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @expiry_config = expiry_config
  @grant_condition = grant_condition
  @name = name
  @priority = priority
end

Instance Attribute Details

#amountObject

The amount of the credit grant.



215
216
217
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 215

def amount
  @amount
end

#applicability_configObject

Defines the scope where the credit grant is applicable.



217
218
219
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 217

def applicability_config
  @applicability_config
end

#categoryObject

The category of the credit grant.



219
220
221
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 219

def category
  @category
end

#expiry_configObject

The expiry configuration for the credit grant.



221
222
223
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 221

def expiry_config
  @expiry_config
end

#grant_conditionObject

The grant condition for the credit grant.



223
224
225
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 223

def grant_condition
  @grant_condition
end

#nameObject

Customer-facing name for the credit grant.



225
226
227
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 225

def name
  @name
end

#priorityObject

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



227
228
229
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 227

def priority
  @priority
end