Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/service_action_create_params.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, ExpiryConfig, GrantCondition

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, grant_condition: nil, name: nil, priority: nil) ⇒ CreditGrantPerTenant

Returns a new instance of CreditGrantPerTenant.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 205

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  expiry_config: nil,
  grant_condition: nil,
  name: nil,
  priority: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @expiry_config = expiry_config
  @grant_condition = grant_condition
  @name = name
  @priority = priority
end

Instance Attribute Details

#amountObject

The amount of the credit grant.



191
192
193
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 191

def amount
  @amount
end

#applicability_configObject

Defines the scope where the credit grant is applicable.



193
194
195
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 193

def applicability_config
  @applicability_config
end

#categoryObject

The category of the credit grant.



195
196
197
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 195

def category
  @category
end

#expiry_configObject

The expiry configuration for the credit grant.



197
198
199
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 197

def expiry_config
  @expiry_config
end

#grant_conditionObject

The grant condition for the credit grant.



199
200
201
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 199

def grant_condition
  @grant_condition
end

#nameObject

Customer-facing name for the credit grant.



201
202
203
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 201

def name
  @name
end

#priorityObject

The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.



203
204
205
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 203

def priority
  @priority
end