Class: Stripe::V2::Billing::ServiceActionCreateParams::CreditGrantPerTenant::ApplicabilityConfig::Scope

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/billing/service_action_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billable_items: nil, price_type: nil) ⇒ Scope

Returns a new instance of Scope.



156
157
158
159
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 156

def initialize(billable_items: nil, price_type: nil)
  @billable_items = billable_items
  @price_type = price_type
end

Instance Attribute Details

#billable_itemsObject

The billable items to apply the credit grant to.



152
153
154
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 152

def billable_items
  @billable_items
end

#price_typeObject

The price type that credit grants can apply to. Stripe supports the ‘metered` price type, which applies to metered prices and rate cards. Cannot be used in combination with `billable_items`.



154
155
156
# File 'lib/stripe/params/v2/billing/service_action_create_params.rb', line 154

def price_type
  @price_type
end