Class: Stripe::V2::Billing::ServiceActionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: CreditGrant, CreditGrantPerTenant
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
Details for the credit grant.
-
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant.
-
#lookup_key ⇒ Object
An internal key you can use to search for this service action.
-
#service_interval ⇒ Object
The interval for assessing service.
-
#service_interval_count ⇒ Object
The length of the interval for assessing service.
-
#type ⇒ Object
The type of the service action.
Instance Method Summary collapse
-
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 216 def initialize( lookup_key: nil, service_interval: nil, service_interval_count: nil, type: nil, credit_grant: nil, credit_grant_per_tenant: nil ) @lookup_key = lookup_key @service_interval = service_interval @service_interval_count = service_interval_count @type = type @credit_grant = credit_grant @credit_grant_per_tenant = credit_grant_per_tenant end |
Instance Attribute Details
#credit_grant ⇒ Object
Details for the credit grant. Required if ‘type` is `credit_grant`.
212 213 214 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 212 def credit_grant @credit_grant end |
#credit_grant_per_tenant ⇒ Object
Details for the credit grant per tenant. Required if ‘type` is `credit_grant_per_tenant`.
214 215 216 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 214 def credit_grant_per_tenant @credit_grant_per_tenant end |
#lookup_key ⇒ Object
An internal key you can use to search for this service action. Maximum length of 200 characters.
204 205 206 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 204 def lookup_key @lookup_key end |
#service_interval ⇒ Object
The interval for assessing service.
206 207 208 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 206 def service_interval @service_interval end |
#service_interval_count ⇒ Object
The length of the interval for assessing service.
208 209 210 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 208 def service_interval_count @service_interval_count end |
#type ⇒ Object
The type of the service action.
210 211 212 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 210 def type @type end |