Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrant::ApplicabilityConfig::Scope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrant::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
The billable items to apply the credit grant to.
-
#price_type ⇒ Object
The price type that credit grants can apply to.
Instance Method Summary collapse
-
#initialize(billable_items: nil, price_type: nil) ⇒ Scope
constructor
A new instance of Scope.
Methods inherited from RequestParams
Constructor Details
#initialize(billable_items: nil, price_type: nil) ⇒ Scope
Returns a new instance of Scope.
43 44 45 46 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 43 def initialize(billable_items: nil, price_type: nil) @billable_items = billable_items @price_type = price_type end |
Instance Attribute Details
#billable_items ⇒ Object
The billable items to apply the credit grant to.
39 40 41 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 39 def billable_items @billable_items end |
#price_type ⇒ Object
The price type that credit grants can apply to. We currently only support the ‘metered` price type. This will apply to metered prices and rate cards. Cannot be used in combination with `billable_items`.
41 42 43 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 41 def price_type @price_type end |