Class: Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Billing::ServiceActionService::CreateParams::CreditGrantPerTenant
- Defined in:
- lib/stripe/services/v2/billing/service_action_service.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig, ExpiryConfig, GrantCondition
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the credit grant.
-
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
-
#category ⇒ Object
The category of the credit grant.
-
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
-
#grant_condition ⇒ Object
The grant condition for the credit grant.
-
#name ⇒ Object
Customer-facing name for the credit grant.
-
#priority ⇒ Object
The desired priority for applying this credit grant.
Instance Method Summary collapse
-
#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, grant_condition: nil, name: nil, priority: nil) ⇒ CreditGrantPerTenant
constructor
A new instance of CreditGrantPerTenant.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, applicability_config: nil, category: nil, expiry_config: nil, grant_condition: nil, name: nil, priority: nil) ⇒ CreditGrantPerTenant
Returns a new instance of CreditGrantPerTenant.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 206 def initialize( amount: nil, applicability_config: nil, category: nil, expiry_config: nil, grant_condition: nil, name: nil, priority: nil ) @amount = amount @applicability_config = applicability_config @category = category @expiry_config = expiry_config @grant_condition = grant_condition @name = name @priority = priority end |
Instance Attribute Details
#amount ⇒ Object
The amount of the credit grant.
192 193 194 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 192 def amount @amount end |
#applicability_config ⇒ Object
Defines the scope where the credit grant is applicable.
194 195 196 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 194 def applicability_config @applicability_config end |
#category ⇒ Object
The category of the credit grant.
196 197 198 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 196 def category @category end |
#expiry_config ⇒ Object
The expiry configuration for the credit grant.
198 199 200 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 198 def expiry_config @expiry_config end |
#grant_condition ⇒ Object
The grant condition for the credit grant.
200 201 202 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 200 def grant_condition @grant_condition end |
#name ⇒ Object
Customer-facing name for the credit grant.
202 203 204 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 202 def name @name end |
#priority ⇒ Object
The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.
204 205 206 |
# File 'lib/stripe/services/v2/billing/service_action_service.rb', line 204 def priority @priority end |