Class: Stripe::V2::Commerce::ProductCatalogImport::StatusDetails::SucceededWithErrors
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Commerce::ProductCatalogImport::StatusDetails::SucceededWithErrors
- Defined in:
- lib/stripe/resources/v2/commerce/product_catalog_import.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#error_count ⇒ Object
readonly
The total number of records that failed to process.
-
#error_file ⇒ Object
readonly
A file containing details about all errors that occurred.
-
#samples ⇒ Object
readonly
A sample of errors that occurred during processing.
-
#success_count ⇒ Object
readonly
The total number of records processed.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#error_count ⇒ Object (readonly)
The total number of records that failed to process.
154 155 156 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 154 def error_count @error_count end |
#error_file ⇒ Object (readonly)
A file containing details about all errors that occurred.
156 157 158 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 156 def error_file @error_file end |
#samples ⇒ Object (readonly)
A sample of errors that occurred during processing.
158 159 160 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 158 def samples @samples end |
#success_count ⇒ Object (readonly)
The total number of records processed.
160 161 162 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 160 def success_count @success_count end |
Class Method Details
.field_encodings ⇒ Object
170 171 172 173 174 175 176 177 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 170 def self.field_encodings @field_encodings = { error_count: :int64_string, error_file: { kind: :object, fields: { size: :int64_string } }, samples: { kind: :array, element: { kind: :object, fields: { row: :int64_string } } }, success_count: :int64_string, } end |
.field_remappings ⇒ Object
166 167 168 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 166 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
162 163 164 |
# File 'lib/stripe/resources/v2/commerce/product_catalog_import.rb', line 162 def self.inner_class_types @inner_class_types = { error_file: ErrorFile, samples: Sample } end |