Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

An Account v2 object represents a company, individual, or other entity that your Stripe integration interacts with. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API is broadly available to Connect platforms, and to other users in preview. The Accounts v2 API also supports the Global Payouts preview feature.

Defined Under Namespace

Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

The configurations that have been applied to this account.



3611
3612
3613
# File 'lib/stripe/resources/v2/core/account.rb', line 3611

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

Indicates whether the account has been closed.



3613
3614
3615
# File 'lib/stripe/resources/v2/core/account.rb', line 3613

def closed
  @closed
end

#configurationObject (readonly)

An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.



3615
3616
3617
# File 'lib/stripe/resources/v2/core/account.rb', line 3615

def configuration
  @configuration
end

#contact_emailObject (readonly)

The primary contact email address for the Account.



3617
3618
3619
# File 'lib/stripe/resources/v2/core/account.rb', line 3617

def contact_email
  @contact_email
end

#contact_phoneObject (readonly)

The default contact phone for the Account.



3619
3620
3621
# File 'lib/stripe/resources/v2/core/account.rb', line 3619

def contact_phone
  @contact_phone
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3621
3622
3623
# File 'lib/stripe/resources/v2/core/account.rb', line 3621

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3623
3624
3625
# File 'lib/stripe/resources/v2/core/account.rb', line 3623

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values for settings shared across Account configurations.



3625
3626
3627
# File 'lib/stripe/resources/v2/core/account.rb', line 3625

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3627
3628
3629
# File 'lib/stripe/resources/v2/core/account.rb', line 3627

def display_name
  @display_name
end

#future_requirementsObject (readonly)

Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.



3629
3630
3631
# File 'lib/stripe/resources/v2/core/account.rb', line 3629

def future_requirements
  @future_requirements
end

#idObject (readonly)

Unique identifier for the Account.



3631
3632
3633
# File 'lib/stripe/resources/v2/core/account.rb', line 3631

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



3633
3634
3635
# File 'lib/stripe/resources/v2/core/account.rb', line 3633

def identity
  @identity
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



3635
3636
3637
# File 'lib/stripe/resources/v2/core/account.rb', line 3635

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3637
3638
3639
# File 'lib/stripe/resources/v2/core/account.rb', line 3637

def 
  @metadata
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



3639
3640
3641
# File 'lib/stripe/resources/v2/core/account.rb', line 3639

def object
  @object
end

#requirementsObject (readonly)

Information about the active requirements for the Account, including what information needs to be collected, and by when.



3641
3642
3643
# File 'lib/stripe/resources/v2/core/account.rb', line 3641

def requirements
  @requirements
end

Class Method Details

.field_encodingsObject



3657
3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
3669
3670
3671
# File 'lib/stripe/resources/v2/core/account.rb', line 3657

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end

.field_remappingsObject



3653
3654
3655
# File 'lib/stripe/resources/v2/core/account.rb', line 3653

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3643
3644
3645
3646
3647
3648
3649
3650
3651
# File 'lib/stripe/resources/v2/core/account.rb', line 3643

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    future_requirements: FutureRequirements,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/account.rb', line 11

def self.object_name
  "v2.core.account"
end