Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

An Account v2 object represents a company, individual, or other entity that your Stripe integration interacts with. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API is broadly available to Connect platforms, and to other users in preview. The Accounts v2 API also supports the Global Payouts preview feature.

Defined Under Namespace

Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

The configurations that have been applied to this account.



4490
4491
4492
# File 'lib/stripe/resources/v2/core/account.rb', line 4490

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

Indicates whether the account has been closed.



4492
4493
4494
# File 'lib/stripe/resources/v2/core/account.rb', line 4492

def closed
  @closed
end

#configurationObject (readonly)

An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.



4494
4495
4496
# File 'lib/stripe/resources/v2/core/account.rb', line 4494

def configuration
  @configuration
end

#contact_emailObject (readonly)

The primary contact email address for the Account.



4496
4497
4498
# File 'lib/stripe/resources/v2/core/account.rb', line 4496

def contact_email
  @contact_email
end

#contact_phoneObject (readonly)

The default contact phone for the Account.



4498
4499
4500
# File 'lib/stripe/resources/v2/core/account.rb', line 4498

def contact_phone
  @contact_phone
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4500
4501
4502
# File 'lib/stripe/resources/v2/core/account.rb', line 4500

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4502
4503
4504
# File 'lib/stripe/resources/v2/core/account.rb', line 4502

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values for settings shared across Account configurations.



4504
4505
4506
# File 'lib/stripe/resources/v2/core/account.rb', line 4504

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4506
4507
4508
# File 'lib/stripe/resources/v2/core/account.rb', line 4506

def display_name
  @display_name
end

#future_requirementsObject (readonly)

Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.



4508
4509
4510
# File 'lib/stripe/resources/v2/core/account.rb', line 4508

def future_requirements
  @future_requirements
end

#idObject (readonly)

Unique identifier for the Account.



4510
4511
4512
# File 'lib/stripe/resources/v2/core/account.rb', line 4510

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



4512
4513
4514
# File 'lib/stripe/resources/v2/core/account.rb', line 4512

def identity
  @identity
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



4514
4515
4516
# File 'lib/stripe/resources/v2/core/account.rb', line 4514

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4516
4517
4518
# File 'lib/stripe/resources/v2/core/account.rb', line 4516

def 
  @metadata
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



4518
4519
4520
# File 'lib/stripe/resources/v2/core/account.rb', line 4518

def object
  @object
end

#requirementsObject (readonly)

Information about the active requirements for the Account, including what information needs to be collected, and by when.



4520
4521
4522
# File 'lib/stripe/resources/v2/core/account.rb', line 4520

def requirements
  @requirements
end

Class Method Details

.field_encodingsObject



4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
# File 'lib/stripe/resources/v2/core/account.rb', line 4536

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end

.field_remappingsObject



4532
4533
4534
# File 'lib/stripe/resources/v2/core/account.rb', line 4532

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4522
4523
4524
4525
4526
4527
4528
4529
4530
# File 'lib/stripe/resources/v2/core/account.rb', line 4522

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    future_requirements: FutureRequirements,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/account.rb', line 11

def self.object_name
  "v2.core.account"
end