Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

An Account v2 object represents a company, individual, or other entity that your Stripe integration interacts with. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API is broadly available to Connect platforms, and to other users in preview. The Accounts v2 API also supports the Global Payouts preview feature.

Defined Under Namespace

Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

The configurations that have been applied to this account.



6197
6198
6199
# File 'lib/stripe/resources/v2/core/account.rb', line 6197

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

Indicates whether the account has been closed.



6199
6200
6201
# File 'lib/stripe/resources/v2/core/account.rb', line 6199

def closed
  @closed
end

#configurationObject (readonly)

An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.



6201
6202
6203
# File 'lib/stripe/resources/v2/core/account.rb', line 6201

def configuration
  @configuration
end

#contact_emailObject (readonly)

The primary contact email address for the Account.



6203
6204
6205
# File 'lib/stripe/resources/v2/core/account.rb', line 6203

def contact_email
  @contact_email
end

#contact_phoneObject (readonly)

The default contact phone for the Account.



6205
6206
6207
# File 'lib/stripe/resources/v2/core/account.rb', line 6205

def contact_phone
  @contact_phone
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



6207
6208
6209
# File 'lib/stripe/resources/v2/core/account.rb', line 6207

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



6209
6210
6211
# File 'lib/stripe/resources/v2/core/account.rb', line 6209

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values for settings shared across Account configurations.



6211
6212
6213
# File 'lib/stripe/resources/v2/core/account.rb', line 6211

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



6213
6214
6215
# File 'lib/stripe/resources/v2/core/account.rb', line 6213

def display_name
  @display_name
end

#future_requirementsObject (readonly)

Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.



6215
6216
6217
# File 'lib/stripe/resources/v2/core/account.rb', line 6215

def future_requirements
  @future_requirements
end

#idObject (readonly)

Unique identifier for the Account.



6217
6218
6219
# File 'lib/stripe/resources/v2/core/account.rb', line 6217

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



6219
6220
6221
# File 'lib/stripe/resources/v2/core/account.rb', line 6219

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



6221
6222
6223
# File 'lib/stripe/resources/v2/core/account.rb', line 6221

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



6223
6224
6225
# File 'lib/stripe/resources/v2/core/account.rb', line 6223

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



6225
6226
6227
# File 'lib/stripe/resources/v2/core/account.rb', line 6225

def object
  @object
end

#requirementsObject (readonly)

Information about the active requirements for the Account, including what information needs to be collected, and by when.



6227
6228
6229
# File 'lib/stripe/resources/v2/core/account.rb', line 6227

def requirements
  @requirements
end

Class Method Details

.field_encodingsObject



6243
6244
6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
# File 'lib/stripe/resources/v2/core/account.rb', line 6243

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end

.field_remappingsObject



6239
6240
6241
# File 'lib/stripe/resources/v2/core/account.rb', line 6239

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



6229
6230
6231
6232
6233
6234
6235
6236
6237
# File 'lib/stripe/resources/v2/core/account.rb', line 6229

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    future_requirements: FutureRequirements,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/account.rb', line 11

def self.object_name
  "v2.core.account"
end