Class: Stripe::V2::Core::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Account
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Overview
An Account v2 object represents a company, individual, or other entity that your Stripe integration interacts with. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API is broadly available to Connect platforms, and to other users in preview. The Accounts v2 API also supports the Global Payouts preview feature.
Defined Under Namespace
Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied_configurations ⇒ Object
readonly
The configurations that have been applied to this account.
-
#closed ⇒ Object
readonly
Indicates whether the account has been closed.
-
#configuration ⇒ Object
readonly
An Account represents a company, individual, or other entity that a user interacts with.
-
#contact_email ⇒ Object
readonly
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
readonly
The default contact phone for the Account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#dashboard ⇒ Object
readonly
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
readonly
Default values for settings shared across Account configurations.
-
#display_name ⇒ Object
readonly
A descriptive name for the Account.
-
#future_requirements ⇒ Object
readonly
Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.
-
#id ⇒ Object
readonly
Unique identifier for the Account.
-
#identity ⇒ Object
readonly
Information about the company, individual, and business represented by the Account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requirements ⇒ Object
readonly
Information about the active requirements for the Account, including what information needs to be collected, and by when.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied_configurations ⇒ Object (readonly)
The configurations that have been applied to this account.
3549 3550 3551 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3549 def applied_configurations @applied_configurations end |
#closed ⇒ Object (readonly)
Indicates whether the account has been closed.
3551 3552 3553 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3551 def closed @closed end |
#configuration ⇒ Object (readonly)
An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.
3553 3554 3555 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3553 def configuration @configuration end |
#contact_email ⇒ Object (readonly)
The primary contact email address for the Account.
3555 3556 3557 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3555 def contact_email @contact_email end |
#contact_phone ⇒ Object (readonly)
The default contact phone for the Account.
3557 3558 3559 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3557 def contact_phone @contact_phone end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
3559 3560 3561 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3559 def created @created end |
#dashboard ⇒ Object (readonly)
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
3561 3562 3563 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3561 def dashboard @dashboard end |
#defaults ⇒ Object (readonly)
Default values for settings shared across Account configurations.
3563 3564 3565 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3563 def defaults @defaults end |
#display_name ⇒ Object (readonly)
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
3565 3566 3567 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3565 def display_name @display_name end |
#future_requirements ⇒ Object (readonly)
Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.
3567 3568 3569 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3567 def future_requirements @future_requirements end |
#id ⇒ Object (readonly)
Unique identifier for the Account.
3569 3570 3571 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3569 def id @id end |
#identity ⇒ Object (readonly)
Information about the company, individual, and business represented by the Account.
3571 3572 3573 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3571 def identity @identity end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
3573 3574 3575 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3573 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3575 3576 3577 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3575 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
3577 3578 3579 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3577 def object @object end |
#requirements ⇒ Object (readonly)
Information about the active requirements for the Account, including what information needs to be collected, and by when.
3579 3580 3581 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3579 def requirements @requirements end |
Class Method Details
.field_encodings ⇒ Object
3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3595 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |
.field_remappings ⇒ Object
3591 3592 3593 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3591 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3581 3582 3583 3584 3585 3586 3587 3588 3589 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3581 def self.inner_class_types @inner_class_types = { configuration: Configuration, defaults: Defaults, future_requirements: FutureRequirements, identity: Identity, requirements: Requirements, } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11 def self.object_name "v2.core.account" end |