Class: Stripe::V2::Core::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Account
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Overview
An Account v2 object represents a company, individual, or other entity that your Stripe integration interacts with. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API is broadly available to Connect platforms, and to other users in preview. The Accounts v2 API also supports the Global Payouts preview feature.
Defined Under Namespace
Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied_configurations ⇒ Object
readonly
The configurations that have been applied to this account.
-
#closed ⇒ Object
readonly
Indicates whether the account has been closed.
-
#configuration ⇒ Object
readonly
An Account represents a company, individual, or other entity that a user interacts with.
-
#contact_email ⇒ Object
readonly
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
readonly
The default contact phone for the Account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#dashboard ⇒ Object
readonly
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
readonly
Default values for settings shared across Account configurations.
-
#display_name ⇒ Object
readonly
A descriptive name for the Account.
-
#future_requirements ⇒ Object
readonly
Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.
-
#id ⇒ Object
readonly
Unique identifier for the Account.
-
#identity ⇒ Object
readonly
Information about the company, individual, and business represented by the Account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requirements ⇒ Object
readonly
Information about the active requirements for the Account, including what information needs to be collected, and by when.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied_configurations ⇒ Object (readonly)
The configurations that have been applied to this account.
6055 6056 6057 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6055 def applied_configurations @applied_configurations end |
#closed ⇒ Object (readonly)
Indicates whether the account has been closed.
6057 6058 6059 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6057 def closed @closed end |
#configuration ⇒ Object (readonly)
An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.
6059 6060 6061 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6059 def configuration @configuration end |
#contact_email ⇒ Object (readonly)
The primary contact email address for the Account.
6061 6062 6063 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6061 def contact_email @contact_email end |
#contact_phone ⇒ Object (readonly)
The default contact phone for the Account.
6063 6064 6065 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6063 def contact_phone @contact_phone end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
6065 6066 6067 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6065 def created @created end |
#dashboard ⇒ Object (readonly)
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
6067 6068 6069 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6067 def dashboard @dashboard end |
#defaults ⇒ Object (readonly)
Default values for settings shared across Account configurations.
6069 6070 6071 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6069 def defaults @defaults end |
#display_name ⇒ Object (readonly)
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
6071 6072 6073 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6071 def display_name @display_name end |
#future_requirements ⇒ Object (readonly)
Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.
6073 6074 6075 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6073 def future_requirements @future_requirements end |
#id ⇒ Object (readonly)
Unique identifier for the Account.
6075 6076 6077 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6075 def id @id end |
#identity ⇒ Object (readonly)
Information about the company, individual, and business represented by the Account.
6077 6078 6079 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6077 def identity @identity end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
6079 6080 6081 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6079 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
6081 6082 6083 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6081 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
6083 6084 6085 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6083 def object @object end |
#requirements ⇒ Object (readonly)
Information about the active requirements for the Account, including what information needs to be collected, and by when.
6085 6086 6087 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6085 def requirements @requirements end |
Class Method Details
.field_encodings ⇒ Object
6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 6115 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6101 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |
.field_remappings ⇒ Object
6097 6098 6099 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6097 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
6087 6088 6089 6090 6091 6092 6093 6094 6095 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6087 def self.inner_class_types @inner_class_types = { configuration: Configuration, defaults: Defaults, future_requirements: FutureRequirements, identity: Identity, requirements: Requirements, } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11 def self.object_name "v2.core.account" end |