Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

An Account v2 object represents a company, individual, or other entity that interacts with a platform on Stripe. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API supports both the Global Payouts preview feature and the Connect-Billing integration preview feature. However, a particular Account can only access one of them. The Connect-Billing integration preview feature allows an Account v2 to pay subscription fees to a platform. An Account v1 required a separate Customer object to pay subscription fees.

Defined Under Namespace

Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

The configurations that have been applied to this account.



4116
4117
4118
# File 'lib/stripe/resources/v2/core/account.rb', line 4116

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

Indicates whether the account has been closed.



4118
4119
4120
# File 'lib/stripe/resources/v2/core/account.rb', line 4118

def closed
  @closed
end

#configurationObject (readonly)

An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.



4120
4121
4122
# File 'lib/stripe/resources/v2/core/account.rb', line 4120

def configuration
  @configuration
end

#contact_emailObject (readonly)

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4122
4123
4124
# File 'lib/stripe/resources/v2/core/account.rb', line 4122

def contact_email
  @contact_email
end

#contact_phoneObject (readonly)

The default contact phone for the Account.



4124
4125
4126
# File 'lib/stripe/resources/v2/core/account.rb', line 4124

def contact_phone
  @contact_phone
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4126
4127
4128
# File 'lib/stripe/resources/v2/core/account.rb', line 4126

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4128
4129
4130
# File 'lib/stripe/resources/v2/core/account.rb', line 4128

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values for settings shared across Account configurations.



4130
4131
4132
# File 'lib/stripe/resources/v2/core/account.rb', line 4130

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4132
4133
4134
# File 'lib/stripe/resources/v2/core/account.rb', line 4132

def display_name
  @display_name
end

#future_requirementsObject (readonly)

Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.



4134
4135
4136
# File 'lib/stripe/resources/v2/core/account.rb', line 4134

def future_requirements
  @future_requirements
end

#idObject (readonly)

Unique identifier for the Account.



4136
4137
4138
# File 'lib/stripe/resources/v2/core/account.rb', line 4136

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



4138
4139
4140
# File 'lib/stripe/resources/v2/core/account.rb', line 4138

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



4140
4141
4142
# File 'lib/stripe/resources/v2/core/account.rb', line 4140

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4142
4143
4144
# File 'lib/stripe/resources/v2/core/account.rb', line 4142

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



4144
4145
4146
# File 'lib/stripe/resources/v2/core/account.rb', line 4144

def object
  @object
end

#requirementsObject (readonly)

Information about the active requirements for the Account, including what information needs to be collected, and by when.



4146
4147
4148
# File 'lib/stripe/resources/v2/core/account.rb', line 4146

def requirements
  @requirements
end

Class Method Details

.field_encodingsObject



4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
4176
# File 'lib/stripe/resources/v2/core/account.rb', line 4162

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end

.field_remappingsObject



4158
4159
4160
# File 'lib/stripe/resources/v2/core/account.rb', line 4158

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4148
4149
4150
4151
4152
4153
4154
4155
4156
# File 'lib/stripe/resources/v2/core/account.rb', line 4148

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    future_requirements: FutureRequirements,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/v2/core/account.rb', line 12

def self.object_name
  "v2.core.account"
end