Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

An Account v2 object represents a company, individual, or other entity that interacts with a platform on Stripe. It contains both identifying information and properties that control its behavior and functionality. An Account can have one or more configurations that enable sets of related features, such as allowing it to act as a merchant or customer. The Accounts v2 API supports both the Global Payouts preview feature and the Connect-Billing integration preview feature. However, a particular Account can only access one of them. The Connect-Billing integration preview feature allows an Account v2 to pay subscription fees to a platform. An Account v1 required a separate Customer object to pay subscription fees.

Defined Under Namespace

Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

The configurations that have been applied to this account.



5957
5958
5959
# File 'lib/stripe/resources/v2/core/account.rb', line 5957

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

Indicates whether the account has been closed.



5959
5960
5961
# File 'lib/stripe/resources/v2/core/account.rb', line 5959

def closed
  @closed
end

#configurationObject (readonly)

An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.



5961
5962
5963
# File 'lib/stripe/resources/v2/core/account.rb', line 5961

def configuration
  @configuration
end

#contact_emailObject (readonly)

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



5963
5964
5965
# File 'lib/stripe/resources/v2/core/account.rb', line 5963

def contact_email
  @contact_email
end

#contact_phoneObject (readonly)

The default contact phone for the Account.



5965
5966
5967
# File 'lib/stripe/resources/v2/core/account.rb', line 5965

def contact_phone
  @contact_phone
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



5967
5968
5969
# File 'lib/stripe/resources/v2/core/account.rb', line 5967

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



5969
5970
5971
# File 'lib/stripe/resources/v2/core/account.rb', line 5969

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values for settings shared across Account configurations.



5971
5972
5973
# File 'lib/stripe/resources/v2/core/account.rb', line 5971

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



5973
5974
5975
# File 'lib/stripe/resources/v2/core/account.rb', line 5973

def display_name
  @display_name
end

#future_requirementsObject (readonly)

Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.



5975
5976
5977
# File 'lib/stripe/resources/v2/core/account.rb', line 5975

def future_requirements
  @future_requirements
end

#idObject (readonly)

Unique identifier for the Account.



5977
5978
5979
# File 'lib/stripe/resources/v2/core/account.rb', line 5977

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



5979
5980
5981
# File 'lib/stripe/resources/v2/core/account.rb', line 5979

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



5987
5988
5989
# File 'lib/stripe/resources/v2/core/account.rb', line 5987

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5981
5982
5983
# File 'lib/stripe/resources/v2/core/account.rb', line 5981

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



5983
5984
5985
# File 'lib/stripe/resources/v2/core/account.rb', line 5983

def object
  @object
end

#requirementsObject (readonly)

Information about the active requirements for the Account, including what information needs to be collected, and by when.



5985
5986
5987
# File 'lib/stripe/resources/v2/core/account.rb', line 5985

def requirements
  @requirements
end

Class Method Details

.field_remappingsObject



5999
6000
6001
# File 'lib/stripe/resources/v2/core/account.rb', line 5999

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5989
5990
5991
5992
5993
5994
5995
5996
5997
# File 'lib/stripe/resources/v2/core/account.rb', line 5989

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    future_requirements: FutureRequirements,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/v2/core/account.rb', line 12

def self.object_name
  "v2.core.account"
end