Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.

Defined Under Namespace

Classes: Configuration, Defaults, FutureRequirements, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

The configurations that have been applied to this account.



4089
4090
4091
# File 'lib/stripe/resources/v2/core/account.rb', line 4089

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

Indicates whether the account has been closed.



4091
4092
4093
# File 'lib/stripe/resources/v2/core/account.rb', line 4091

def closed
  @closed
end

#configurationObject (readonly)

An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.



4093
4094
4095
# File 'lib/stripe/resources/v2/core/account.rb', line 4093

def configuration
  @configuration
end

#contact_emailObject (readonly)

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4095
4096
4097
# File 'lib/stripe/resources/v2/core/account.rb', line 4095

def contact_email
  @contact_email
end

#contact_phoneObject (readonly)

The default contact phone for the Account.



4097
4098
4099
# File 'lib/stripe/resources/v2/core/account.rb', line 4097

def contact_phone
  @contact_phone
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4099
4100
4101
# File 'lib/stripe/resources/v2/core/account.rb', line 4099

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4101
4102
4103
# File 'lib/stripe/resources/v2/core/account.rb', line 4101

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values for settings shared across Account configurations.



4103
4104
4105
# File 'lib/stripe/resources/v2/core/account.rb', line 4103

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4105
4106
4107
# File 'lib/stripe/resources/v2/core/account.rb', line 4105

def display_name
  @display_name
end

#future_requirementsObject (readonly)

Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.



4107
4108
4109
# File 'lib/stripe/resources/v2/core/account.rb', line 4107

def future_requirements
  @future_requirements
end

#idObject (readonly)

Unique identifier for the Account.



4109
4110
4111
# File 'lib/stripe/resources/v2/core/account.rb', line 4109

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



4111
4112
4113
# File 'lib/stripe/resources/v2/core/account.rb', line 4111

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



4119
4120
4121
# File 'lib/stripe/resources/v2/core/account.rb', line 4119

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4113
4114
4115
# File 'lib/stripe/resources/v2/core/account.rb', line 4113

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



4115
4116
4117
# File 'lib/stripe/resources/v2/core/account.rb', line 4115

def object
  @object
end

#requirementsObject (readonly)

Information about the active requirements for the Account, including what information needs to be collected, and by when.



4117
4118
4119
# File 'lib/stripe/resources/v2/core/account.rb', line 4117

def requirements
  @requirements
end

Class Method Details

.field_remappingsObject



4131
4132
4133
# File 'lib/stripe/resources/v2/core/account.rb', line 4131

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4121
4122
4123
4124
4125
4126
4127
4128
4129
# File 'lib/stripe/resources/v2/core/account.rb', line 4121

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    future_requirements: FutureRequirements,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account.rb', line 10

def self.object_name
  "v2.core.account"
end