Class: Stripe::V2::Core::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Account
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Overview
A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.
Defined Under Namespace
Classes: Configuration, Defaults, Identity, Requirements
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied_configurations ⇒ Object
readonly
Filter only accounts that have all of the configurations specified.
-
#closed ⇒ Object
readonly
A value indicating if the Account has been closed.
-
#configuration ⇒ Object
readonly
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
readonly
The default contact email address for the Account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#dashboard ⇒ Object
readonly
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
readonly
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
readonly
A descriptive name for the Account.
-
#id ⇒ Object
readonly
Unique identifier for the Account.
-
#identity ⇒ Object
readonly
Information about the company, individual, and business represented by the Account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requirements ⇒ Object
readonly
Information about the requirements for the Account, including what information needs to be collected, and by when.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied_configurations ⇒ Object (readonly)
Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.
4924 4925 4926 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4924 def applied_configurations @applied_configurations end |
#closed ⇒ Object (readonly)
A value indicating if the Account has been closed.
4926 4927 4928 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4926 def closed @closed end |
#configuration ⇒ Object (readonly)
An Account Configuration which allows the Account to take on a key persona across Stripe products.
4928 4929 4930 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4928 def configuration @configuration end |
#contact_email ⇒ Object (readonly)
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
4930 4931 4932 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4930 def contact_email @contact_email end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
4932 4933 4934 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4932 def created @created end |
#dashboard ⇒ Object (readonly)
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
4934 4935 4936 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4934 def dashboard @dashboard end |
#defaults ⇒ Object (readonly)
Default values to be used on Account Configurations.
4936 4937 4938 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4936 def defaults @defaults end |
#display_name ⇒ Object (readonly)
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
4938 4939 4940 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4938 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the Account.
4940 4941 4942 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4940 def id @id end |
#identity ⇒ Object (readonly)
Information about the company, individual, and business represented by the Account.
4942 4943 4944 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4942 def identity @identity end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
4950 4951 4952 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4950 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4944 4945 4946 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4944 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
4946 4947 4948 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4946 def object @object end |
#requirements ⇒ Object (readonly)
Information about the requirements for the Account, including what information needs to be collected, and by when.
4948 4949 4950 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4948 def requirements @requirements end |
Class Method Details
.field_remappings ⇒ Object
4961 4962 4963 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4961 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4952 4953 4954 4955 4956 4957 4958 4959 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4952 def self.inner_class_types @inner_class_types = { configuration: Configuration, defaults: Defaults, identity: Identity, requirements: Requirements, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10 def self.object_name "v2.core.account" end |