Class: Stripe::V2::Core::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Account
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Overview
A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.
Defined Under Namespace
Classes: Configuration, Defaults, Identity, Requirements
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied_configurations ⇒ Object
readonly
Filter only accounts that have all of the configurations specified.
-
#closed ⇒ Object
readonly
A value indicating if the Account has been closed.
-
#configuration ⇒ Object
readonly
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
readonly
The default contact email address for the Account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#dashboard ⇒ Object
readonly
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
readonly
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
readonly
A descriptive name for the Account.
-
#id ⇒ Object
readonly
Unique identifier for the Account.
-
#identity ⇒ Object
readonly
Information about the company, individual, and business represented by the Account.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requirements ⇒ Object
readonly
Information about the requirements for the Account, including what information needs to be collected, and by when.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied_configurations ⇒ Object (readonly)
Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.
4768 4769 4770 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4768 def applied_configurations @applied_configurations end |
#closed ⇒ Object (readonly)
A value indicating if the Account has been closed.
4770 4771 4772 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4770 def closed @closed end |
#configuration ⇒ Object (readonly)
An Account Configuration which allows the Account to take on a key persona across Stripe products.
4772 4773 4774 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4772 def configuration @configuration end |
#contact_email ⇒ Object (readonly)
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
4774 4775 4776 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4774 def contact_email @contact_email end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
4776 4777 4778 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4776 def created @created end |
#dashboard ⇒ Object (readonly)
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
4778 4779 4780 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4778 def dashboard @dashboard end |
#defaults ⇒ Object (readonly)
Default values to be used on Account Configurations.
4780 4781 4782 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4780 def defaults @defaults end |
#display_name ⇒ Object (readonly)
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
4782 4783 4784 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4782 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the Account.
4784 4785 4786 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4784 def id @id end |
#identity ⇒ Object (readonly)
Information about the company, individual, and business represented by the Account.
4786 4787 4788 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4786 def identity @identity end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
4794 4795 4796 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4794 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4788 4789 4790 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4788 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
4790 4791 4792 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4790 def object @object end |
#requirements ⇒ Object (readonly)
Information about the requirements for the Account, including what information needs to be collected, and by when.
4792 4793 4794 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4792 def requirements @requirements end |
Class Method Details
.field_remappings ⇒ Object
4805 4806 4807 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4805 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4796 4797 4798 4799 4800 4801 4802 4803 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4796 def self.inner_class_types @inner_class_types = { configuration: Configuration, defaults: Defaults, identity: Identity, requirements: Requirements, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10 def self.object_name "v2.core.account" end |