Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.

Defined Under Namespace

Classes: Configuration, Defaults, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.



4566
4567
4568
# File 'lib/stripe/resources/v2/core/account.rb', line 4566

def applied_configurations
  @applied_configurations
end

#closedObject (readonly)

A value indicating if the Account has been closed.



4568
4569
4570
# File 'lib/stripe/resources/v2/core/account.rb', line 4568

def closed
  @closed
end

#configurationObject (readonly)

An Account Configuration which allows the Account to take on a key persona across Stripe products.



4570
4571
4572
# File 'lib/stripe/resources/v2/core/account.rb', line 4570

def configuration
  @configuration
end

#contact_emailObject (readonly)

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4572
4573
4574
# File 'lib/stripe/resources/v2/core/account.rb', line 4572

def contact_email
  @contact_email
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4574
4575
4576
# File 'lib/stripe/resources/v2/core/account.rb', line 4574

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4576
4577
4578
# File 'lib/stripe/resources/v2/core/account.rb', line 4576

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values to be used on Account Configurations.



4578
4579
4580
# File 'lib/stripe/resources/v2/core/account.rb', line 4578

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4580
4581
4582
# File 'lib/stripe/resources/v2/core/account.rb', line 4580

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the Account.



4582
4583
4584
# File 'lib/stripe/resources/v2/core/account.rb', line 4582

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



4584
4585
4586
# File 'lib/stripe/resources/v2/core/account.rb', line 4584

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



4592
4593
4594
# File 'lib/stripe/resources/v2/core/account.rb', line 4592

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4586
4587
4588
# File 'lib/stripe/resources/v2/core/account.rb', line 4586

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



4588
4589
4590
# File 'lib/stripe/resources/v2/core/account.rb', line 4588

def object
  @object
end

#requirementsObject (readonly)

Information about the requirements for the Account, including what information needs to be collected, and by when.



4590
4591
4592
# File 'lib/stripe/resources/v2/core/account.rb', line 4590

def requirements
  @requirements
end

Class Method Details

.field_remappingsObject



4603
4604
4605
# File 'lib/stripe/resources/v2/core/account.rb', line 4603

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4594
4595
4596
4597
4598
4599
4600
4601
# File 'lib/stripe/resources/v2/core/account.rb', line 4594

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account.rb', line 10

def self.object_name
  "v2.core.account"
end