Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.

Defined Under Namespace

Classes: Configuration, Defaults, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.



3844
3845
3846
# File 'lib/stripe/resources/v2/core/account.rb', line 3844

def applied_configurations
  @applied_configurations
end

#configurationObject (readonly)

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3846
3847
3848
# File 'lib/stripe/resources/v2/core/account.rb', line 3846

def configuration
  @configuration
end

#contact_emailObject (readonly)

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3848
3849
3850
# File 'lib/stripe/resources/v2/core/account.rb', line 3848

def contact_email
  @contact_email
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3850
3851
3852
# File 'lib/stripe/resources/v2/core/account.rb', line 3850

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3852
3853
3854
# File 'lib/stripe/resources/v2/core/account.rb', line 3852

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values to be used on Account Configurations.



3854
3855
3856
# File 'lib/stripe/resources/v2/core/account.rb', line 3854

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3856
3857
3858
# File 'lib/stripe/resources/v2/core/account.rb', line 3856

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the Account.



3858
3859
3860
# File 'lib/stripe/resources/v2/core/account.rb', line 3858

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



3860
3861
3862
# File 'lib/stripe/resources/v2/core/account.rb', line 3860

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



3868
3869
3870
# File 'lib/stripe/resources/v2/core/account.rb', line 3868

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3862
3863
3864
# File 'lib/stripe/resources/v2/core/account.rb', line 3862

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



3864
3865
3866
# File 'lib/stripe/resources/v2/core/account.rb', line 3864

def object
  @object
end

#requirementsObject (readonly)

Information about the requirements for the Account, including what information needs to be collected, and by when.



3866
3867
3868
# File 'lib/stripe/resources/v2/core/account.rb', line 3866

def requirements
  @requirements
end

Class Method Details

.field_remappingsObject



3879
3880
3881
# File 'lib/stripe/resources/v2/core/account.rb', line 3879

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3870
3871
3872
3873
3874
3875
3876
3877
# File 'lib/stripe/resources/v2/core/account.rb', line 3870

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account.rb', line 10

def self.object_name
  "v2.core.account"
end