Class: Stripe::V2::Core::Account

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Overview

A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.

Defined Under Namespace

Classes: Configuration, Defaults, Identity, Requirements

Constant Summary collapse

OBJECT_NAME =
"v2.core.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#applied_configurationsObject (readonly)

Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.



3797
3798
3799
# File 'lib/stripe/resources/v2/core/account.rb', line 3797

def applied_configurations
  @applied_configurations
end

#configurationObject (readonly)

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3799
3800
3801
# File 'lib/stripe/resources/v2/core/account.rb', line 3799

def configuration
  @configuration
end

#contact_emailObject (readonly)

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3801
3802
3803
# File 'lib/stripe/resources/v2/core/account.rb', line 3801

def contact_email
  @contact_email
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3803
3804
3805
# File 'lib/stripe/resources/v2/core/account.rb', line 3803

def created
  @created
end

#dashboardObject (readonly)

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3805
3806
3807
# File 'lib/stripe/resources/v2/core/account.rb', line 3805

def dashboard
  @dashboard
end

#defaultsObject (readonly)

Default values to be used on Account Configurations.



3807
3808
3809
# File 'lib/stripe/resources/v2/core/account.rb', line 3807

def defaults
  @defaults
end

#display_nameObject (readonly)

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3809
3810
3811
# File 'lib/stripe/resources/v2/core/account.rb', line 3809

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the Account.



3811
3812
3813
# File 'lib/stripe/resources/v2/core/account.rb', line 3811

def id
  @id
end

#identityObject (readonly)

Information about the company, individual, and business represented by the Account.



3813
3814
3815
# File 'lib/stripe/resources/v2/core/account.rb', line 3813

def identity
  @identity
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



3821
3822
3823
# File 'lib/stripe/resources/v2/core/account.rb', line 3821

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3815
3816
3817
# File 'lib/stripe/resources/v2/core/account.rb', line 3815

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



3817
3818
3819
# File 'lib/stripe/resources/v2/core/account.rb', line 3817

def object
  @object
end

#requirementsObject (readonly)

Information about the requirements for the Account, including what information needs to be collected, and by when.



3819
3820
3821
# File 'lib/stripe/resources/v2/core/account.rb', line 3819

def requirements
  @requirements
end

Class Method Details

.field_remappingsObject



3832
3833
3834
# File 'lib/stripe/resources/v2/core/account.rb', line 3832

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3823
3824
3825
3826
3827
3828
3829
3830
# File 'lib/stripe/resources/v2/core/account.rb', line 3823

def self.inner_class_types
  @inner_class_types = {
    configuration: Configuration,
    defaults: Defaults,
    identity: Identity,
    requirements: Requirements,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account.rb', line 10

def self.object_name
  "v2.core.account"
end