Class: Stripe::V2::Core::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Account
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Overview
A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.
Defined Under Namespace
Classes: Configuration, Defaults, Identity, Requirements
Constant Summary collapse
- OBJECT_NAME =
"v2.core.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied_configurations ⇒ Object
readonly
Filter only accounts that have all of the configurations specified.
-
#configuration ⇒ Object
readonly
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
readonly
The default contact email address for the Account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#dashboard ⇒ Object
readonly
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
readonly
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
readonly
A descriptive name for the Account.
-
#id ⇒ Object
readonly
Unique identifier for the Account.
-
#identity ⇒ Object
readonly
Information about the company, individual, and business represented by the Account.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requirements ⇒ Object
readonly
Information about the requirements for the Account, including what information needs to be collected, and by when.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied_configurations ⇒ Object (readonly)
Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.
1689 1690 1691 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1689 def applied_configurations @applied_configurations end |
#configuration ⇒ Object (readonly)
An Account Configuration which allows the Account to take on a key persona across Stripe products.
1691 1692 1693 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1691 def configuration @configuration end |
#contact_email ⇒ Object (readonly)
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
1693 1694 1695 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1693 def contact_email @contact_email end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1695 1696 1697 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1695 def created @created end |
#dashboard ⇒ Object (readonly)
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
1697 1698 1699 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1697 def dashboard @dashboard end |
#defaults ⇒ Object (readonly)
Default values to be used on Account Configurations.
1699 1700 1701 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1699 def defaults @defaults end |
#display_name ⇒ Object (readonly)
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1701 1702 1703 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1701 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the Account.
1703 1704 1705 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1703 def id @id end |
#identity ⇒ Object (readonly)
Information about the company, individual, and business represented by the Account.
1705 1706 1707 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1705 def identity @identity end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1707 1708 1709 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1707 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
1709 1710 1711 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1709 def object @object end |
#requirements ⇒ Object (readonly)
Information about the requirements for the Account, including what information needs to be collected, and by when.
1711 1712 1713 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1711 def requirements @requirements end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/account.rb', line 10 def self.object_name "v2.core.account" end |