Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_creatorObject (readonly)

The CardCreator Configuration allows the Account to create and issue cards to users.



3520
3521
3522
# File 'lib/stripe/resources/v2/core/account.rb', line 3520

def card_creator
  @card_creator
end

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).



3522
3523
3524
# File 'lib/stripe/resources/v2/core/account.rb', line 3522

def customer
  @customer
end

#merchantObject (readonly)

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



3524
3525
3526
# File 'lib/stripe/resources/v2/core/account.rb', line 3524

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



3526
3527
3528
# File 'lib/stripe/resources/v2/core/account.rb', line 3526

def recipient
  @recipient
end

#storerObject (readonly)

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



3528
3529
3530
# File 'lib/stripe/resources/v2/core/account.rb', line 3528

def storer
  @storer
end

Class Method Details

.field_remappingsObject



3540
3541
3542
# File 'lib/stripe/resources/v2/core/account.rb', line 3540

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3530
3531
3532
3533
3534
3535
3536
3537
3538
# File 'lib/stripe/resources/v2/core/account.rb', line 3530

def self.inner_class_types
  @inner_class_types = {
    card_creator: CardCreator,
    customer: Customer,
    merchant: Merchant,
    recipient: Recipient,
    storer: Storer,
  }
end