Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_creatorObject (readonly)

The CardCreator Configuration allows the Account to create and issue cards to users.



3490
3491
3492
# File 'lib/stripe/resources/v2/core/account.rb', line 3490

def card_creator
  @card_creator
end

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows.



3492
3493
3494
# File 'lib/stripe/resources/v2/core/account.rb', line 3492

def customer
  @customer
end

#merchantObject (readonly)

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



3494
3495
3496
# File 'lib/stripe/resources/v2/core/account.rb', line 3494

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



3496
3497
3498
# File 'lib/stripe/resources/v2/core/account.rb', line 3496

def recipient
  @recipient
end

#storerObject (readonly)

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



3498
3499
3500
# File 'lib/stripe/resources/v2/core/account.rb', line 3498

def storer
  @storer
end

Class Method Details

.field_remappingsObject



3510
3511
3512
# File 'lib/stripe/resources/v2/core/account.rb', line 3510

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3500
3501
3502
3503
3504
3505
3506
3507
3508
# File 'lib/stripe/resources/v2/core/account.rb', line 3500

def self.inner_class_types
  @inner_class_types = {
    card_creator: CardCreator,
    customer: Customer,
    merchant: Merchant,
    recipient: Recipient,
    storer: Storer,
  }
end