Class: Stripe::V2::Core::Account::Configuration
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, Recipient, Storer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
readonly
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
readonly
The Customer Configuration allows the Account to be used in inbound payment flows.
-
#merchant ⇒ Object
readonly
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
readonly
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
readonly
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_creator ⇒ Object (readonly)
The CardCreator Configuration allows the Account to create and issue cards to users.
3202 3203 3204 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3202 def card_creator @card_creator end |
#customer ⇒ Object (readonly)
The Customer Configuration allows the Account to be used in inbound payment flows.
3204 3205 3206 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3204 def customer @customer end |
#merchant ⇒ Object (readonly)
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
3206 3207 3208 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3206 def merchant @merchant end |
#recipient ⇒ Object (readonly)
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
3208 3209 3210 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3208 def recipient @recipient end |
#storer ⇒ Object (readonly)
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
3210 3211 3212 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3210 def storer @storer end |
Class Method Details
.field_remappings ⇒ Object
3222 3223 3224 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3222 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3212 3213 3214 3215 3216 3217 3218 3219 3220 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3212 def self.inner_class_types @inner_class_types = { card_creator: CardCreator, customer: Customer, merchant: Merchant, recipient: Recipient, storer: Storer, } end |