Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_creatorObject (readonly)

The CardCreator Configuration allows the Account to create and issue cards to users.



3114
3115
3116
# File 'lib/stripe/resources/v2/core/account.rb', line 3114

def card_creator
  @card_creator
end

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows.



3116
3117
3118
# File 'lib/stripe/resources/v2/core/account.rb', line 3116

def customer
  @customer
end

#merchantObject (readonly)

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



3118
3119
3120
# File 'lib/stripe/resources/v2/core/account.rb', line 3118

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



3120
3121
3122
# File 'lib/stripe/resources/v2/core/account.rb', line 3120

def recipient
  @recipient
end

#storerObject (readonly)

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



3122
3123
3124
# File 'lib/stripe/resources/v2/core/account.rb', line 3122

def storer
  @storer
end

Class Method Details

.field_remappingsObject



3134
3135
3136
# File 'lib/stripe/resources/v2/core/account.rb', line 3134

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3124
3125
3126
3127
3128
3129
3130
3131
3132
# File 'lib/stripe/resources/v2/core/account.rb', line 3124

def self.inner_class_types
  @inner_class_types = {
    card_creator: CardCreator,
    customer: Customer,
    merchant: Merchant,
    recipient: Recipient,
    storer: Storer,
  }
end