Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_creatorObject (readonly)

The CardCreator Configuration allows the Account to create and issue cards to users.



3229
3230
3231
# File 'lib/stripe/resources/v2/core/account.rb', line 3229

def card_creator
  @card_creator
end

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows.



3231
3232
3233
# File 'lib/stripe/resources/v2/core/account.rb', line 3231

def customer
  @customer
end

#merchantObject (readonly)

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



3233
3234
3235
# File 'lib/stripe/resources/v2/core/account.rb', line 3233

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds.



3235
3236
3237
# File 'lib/stripe/resources/v2/core/account.rb', line 3235

def recipient
  @recipient
end

#storerObject (readonly)

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



3237
3238
3239
# File 'lib/stripe/resources/v2/core/account.rb', line 3237

def storer
  @storer
end

Class Method Details

.field_remappingsObject



3249
3250
3251
# File 'lib/stripe/resources/v2/core/account.rb', line 3249

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3239
3240
3241
3242
3243
3244
3245
3246
3247
# File 'lib/stripe/resources/v2/core/account.rb', line 3239

def self.inner_class_types
  @inner_class_types = {
    card_creator: CardCreator,
    customer: Customer,
    merchant: Merchant,
    recipient: Recipient,
    storer: Storer,
  }
end