Class: Stripe::V2::Core::Account::Configuration
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, Recipient, Storer
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
readonly
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
readonly
The Customer Configuration allows the Account to be used in inbound payment flows.
-
#merchant ⇒ Object
readonly
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
readonly
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
readonly
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_creator ⇒ Object (readonly)
The CardCreator Configuration allows the Account to create and issue cards to users.
2848 2849 2850 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2848 def card_creator @card_creator end |
#customer ⇒ Object (readonly)
The Customer Configuration allows the Account to be used in inbound payment flows.
2850 2851 2852 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2850 def customer @customer end |
#merchant ⇒ Object (readonly)
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.
2852 2853 2854 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2852 def merchant @merchant end |
#recipient ⇒ Object (readonly)
The Recipient Configuration allows the Account to receive funds.
2854 2855 2856 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2854 def recipient @recipient end |
#storer ⇒ Object (readonly)
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
2856 2857 2858 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2856 def storer @storer end |
Class Method Details
.field_remappings ⇒ Object
2868 2869 2870 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2868 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2858 2859 2860 2861 2862 2863 2864 2865 2866 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2858 def self.inner_class_types @inner_class_types = { card_creator: CardCreator, customer: Customer, merchant: Merchant, recipient: Recipient, storer: Storer, } end |