Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient, Storer

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows.



2540
2541
2542
# File 'lib/stripe/resources/v2/core/account.rb', line 2540

def customer
  @customer
end

#merchantObject (readonly)

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



2542
2543
2544
# File 'lib/stripe/resources/v2/core/account.rb', line 2542

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds.



2544
2545
2546
# File 'lib/stripe/resources/v2/core/account.rb', line 2544

def recipient
  @recipient
end

#storerObject (readonly)

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



2546
2547
2548
# File 'lib/stripe/resources/v2/core/account.rb', line 2546

def storer
  @storer
end

Class Method Details

.field_remappingsObject



2557
2558
2559
# File 'lib/stripe/resources/v2/core/account.rb', line 2557

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2548
2549
2550
2551
2552
2553
2554
2555
# File 'lib/stripe/resources/v2/core/account.rb', line 2548

def self.inner_class_types
  @inner_class_types = {
    customer: Customer,
    merchant: Merchant,
    recipient: Recipient,
    storer: Storer,
  }
end