Class: Stripe::V2::Core::Account::Configuration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customerObject (readonly)

The Customer Configuration allows the Account to be used in inbound payment flows.



1083
1084
1085
# File 'lib/stripe/resources/v2/core/account.rb', line 1083

def customer
  @customer
end

#merchantObject (readonly)

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1085
1086
1087
# File 'lib/stripe/resources/v2/core/account.rb', line 1085

def merchant
  @merchant
end

#recipientObject (readonly)

The Recipient Configuration allows the Account to receive funds.



1087
1088
1089
# File 'lib/stripe/resources/v2/core/account.rb', line 1087

def recipient
  @recipient
end