Class: Stripe::V2::Core::Account::Configuration::Customer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the customer configuration is active. You can deactivate or reactivate the customer configuration by updating this property. Deactivating the configuration by setting this value to false will unrequest all capabilities within the configuration. It will not delete any of the configuration's other properties.



2794
2795
2796
# File 'lib/stripe/resources/v2/core/account.rb', line 2794

def applied
  @applied
end

#automatic_indirect_taxObject (readonly)

Settings for automatic indirect tax calculation on the customer's invoices, subscriptions, Checkout Sessions, and Payment Links. Available when automatic tax calculation is available for the customer account's location.



2796
2797
2798
# File 'lib/stripe/resources/v2/core/account.rb', line 2796

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject (readonly)

Default Billing settings for the customer account, used in Invoices and Subscriptions.



2798
2799
2800
# File 'lib/stripe/resources/v2/core/account.rb', line 2798

def billing
  @billing
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Customer Configuration.



2800
2801
2802
# File 'lib/stripe/resources/v2/core/account.rb', line 2800

def capabilities
  @capabilities
end

#shippingObject (readonly)

The customer's shipping information. Appears on invoices emailed to this customer.



2802
2803
2804
# File 'lib/stripe/resources/v2/core/account.rb', line 2802

def shipping
  @shipping
end

#test_clockObject (readonly)

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



2804
2805
2806
# File 'lib/stripe/resources/v2/core/account.rb', line 2804

def test_clock
  @test_clock
end

Class Method Details

.field_encodingsObject



2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
# File 'lib/stripe/resources/v2/core/account.rb', line 2819

def self.field_encodings
  @field_encodings = {
    capabilities: {
      kind: :object,
      fields: {
        automatic_indirect_tax: {
          kind: :object,
          fields: {
            protections: {
              kind: :object,
              fields: {
                psp_migration: {
                  kind: :object,
                  fields: { expires_at: :int64_string, requested_at: :int64_string },
                },
              },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



2815
2816
2817
# File 'lib/stripe/resources/v2/core/account.rb', line 2815

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2806
2807
2808
2809
2810
2811
2812
2813
# File 'lib/stripe/resources/v2/core/account.rb', line 2806

def self.inner_class_types
  @inner_class_types = {
    automatic_indirect_tax: AutomaticIndirectTax,
    billing: Billing,
    capabilities: Capabilities,
    shipping: Shipping,
  }
end