Class: Stripe::V2::Core::Account::Configuration::Customer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the customer configuration is active. You can deactivate or reactivate the customer configuration by updating this property. Deactivating the configuration by setting this value to false will unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.



755
756
757
# File 'lib/stripe/resources/v2/core/account.rb', line 755

def applied
  @applied
end

#automatic_indirect_taxObject (readonly)

Settings for automatic indirect tax calculation on the customer’s invoices, subscriptions, Checkout Sessions, and Payment Links. Available when automatic tax calculation is available for the customer account’s location.



757
758
759
# File 'lib/stripe/resources/v2/core/account.rb', line 757

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject (readonly)

Default Billing settings for the customer account, used in Invoices and Subscriptions.



759
760
761
# File 'lib/stripe/resources/v2/core/account.rb', line 759

def billing
  @billing
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Customer Configuration.



761
762
763
# File 'lib/stripe/resources/v2/core/account.rb', line 761

def capabilities
  @capabilities
end

#shippingObject (readonly)

The customer’s shipping information. Appears on invoices emailed to this customer.



763
764
765
# File 'lib/stripe/resources/v2/core/account.rb', line 763

def shipping
  @shipping
end

#test_clockObject (readonly)

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



765
766
767
# File 'lib/stripe/resources/v2/core/account.rb', line 765

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



776
777
778
# File 'lib/stripe/resources/v2/core/account.rb', line 776

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



767
768
769
770
771
772
773
774
# File 'lib/stripe/resources/v2/core/account.rb', line 767

def self.inner_class_types
  @inner_class_types = {
    automatic_indirect_tax: AutomaticIndirectTax,
    billing: Billing,
    capabilities: Capabilities,
    shipping: Shipping,
  }
end