Class: Stripe::V2::Core::Account::Configuration::Customer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the customer configuration is active.
-
#automatic_indirect_tax ⇒ Object
readonly
Settings for automatic indirect tax calculation on the customer’s invoices, subscriptions, Checkout Sessions, and Payment Links.
-
#billing ⇒ Object
readonly
Default Billing settings for the customer account, used in Invoices and Subscriptions.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Customer Configuration.
-
#shipping ⇒ Object
readonly
The customer’s shipping information.
-
#test_clock ⇒ Object
readonly
ID of the test clock to attach to the customer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the customer configuration is active. You can deactivate or reactivate the customer configuration by updating this property. Deactivating the configuration by setting this value to false will unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.
194 195 196 |
# File 'lib/stripe/resources/v2/core/account.rb', line 194 def applied @applied end |
#automatic_indirect_tax ⇒ Object (readonly)
Settings for automatic indirect tax calculation on the customer’s invoices, subscriptions, Checkout Sessions, and Payment Links. Available when automatic tax calculation is available for the customer account’s location.
196 197 198 |
# File 'lib/stripe/resources/v2/core/account.rb', line 196 def automatic_indirect_tax @automatic_indirect_tax end |
#billing ⇒ Object (readonly)
Default Billing settings for the customer account, used in Invoices and Subscriptions.
198 199 200 |
# File 'lib/stripe/resources/v2/core/account.rb', line 198 def billing @billing end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Customer Configuration.
200 201 202 |
# File 'lib/stripe/resources/v2/core/account.rb', line 200 def capabilities @capabilities end |
#shipping ⇒ Object (readonly)
The customer’s shipping information. Appears on invoices emailed to this customer.
202 203 204 |
# File 'lib/stripe/resources/v2/core/account.rb', line 202 def shipping @shipping end |
#test_clock ⇒ Object (readonly)
ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
204 205 206 |
# File 'lib/stripe/resources/v2/core/account.rb', line 204 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
215 216 217 |
# File 'lib/stripe/resources/v2/core/account.rb', line 215 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
206 207 208 209 210 211 212 213 |
# File 'lib/stripe/resources/v2/core/account.rb', line 206 def self.inner_class_types @inner_class_types = { automatic_indirect_tax: AutomaticIndirectTax, billing: Billing, capabilities: Capabilities, shipping: Shipping, } end |