Class: Stripe::V2::Core::Account::Configuration::Customer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the customer configuration is active. You can deactivate or reactivate the customer configuration by updating this property. Deactivating the configuration by setting this value to false will unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.



724
725
726
# File 'lib/stripe/resources/v2/core/account.rb', line 724

def applied
  @applied
end

#automatic_indirect_taxObject (readonly)

Settings for automatic indirect tax calculation on the customer’s invoices, subscriptions, Checkout Sessions, and Payment Links. Available when automatic tax calculation is available for the customer account’s location.



726
727
728
# File 'lib/stripe/resources/v2/core/account.rb', line 726

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject (readonly)

Default Billing settings for the customer account, used in Invoices and Subscriptions.



728
729
730
# File 'lib/stripe/resources/v2/core/account.rb', line 728

def billing
  @billing
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Customer Configuration.



730
731
732
# File 'lib/stripe/resources/v2/core/account.rb', line 730

def capabilities
  @capabilities
end

#shippingObject (readonly)

The customer’s shipping information. Appears on invoices emailed to this customer.



732
733
734
# File 'lib/stripe/resources/v2/core/account.rb', line 732

def shipping
  @shipping
end

#test_clockObject (readonly)

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



734
735
736
# File 'lib/stripe/resources/v2/core/account.rb', line 734

def test_clock
  @test_clock
end

Class Method Details

.field_remappingsObject



745
746
747
# File 'lib/stripe/resources/v2/core/account.rb', line 745

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



736
737
738
739
740
741
742
743
# File 'lib/stripe/resources/v2/core/account.rb', line 736

def self.inner_class_types
  @inner_class_types = {
    automatic_indirect_tax: AutomaticIndirectTax,
    billing: Billing,
    capabilities: Capabilities,
    shipping: Shipping,
  }
end