Class: Stripe::V2::Core::Account::Configuration::Customer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the customer configuration is active.
-
#automatic_indirect_tax ⇒ Object
readonly
Settings for automatic indirect tax calculation on the customer’s invoices, subscriptions, Checkout Sessions, and Payment Links.
-
#billing ⇒ Object
readonly
Default Billing settings for the customer account, used in Invoices and Subscriptions.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Customer Configuration.
-
#shipping ⇒ Object
readonly
The customer’s shipping information.
-
#test_clock ⇒ Object
readonly
ID of the test clock to attach to the customer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the customer configuration is active. You can deactivate or reactivate the customer configuration by updating this property. Deactivating the configuration by setting this value to false will unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.
725 726 727 |
# File 'lib/stripe/resources/v2/core/account.rb', line 725 def applied @applied end |
#automatic_indirect_tax ⇒ Object (readonly)
Settings for automatic indirect tax calculation on the customer’s invoices, subscriptions, Checkout Sessions, and Payment Links. Available when automatic tax calculation is available for the customer account’s location.
727 728 729 |
# File 'lib/stripe/resources/v2/core/account.rb', line 727 def automatic_indirect_tax @automatic_indirect_tax end |
#billing ⇒ Object (readonly)
Default Billing settings for the customer account, used in Invoices and Subscriptions.
729 730 731 |
# File 'lib/stripe/resources/v2/core/account.rb', line 729 def billing @billing end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Customer Configuration.
731 732 733 |
# File 'lib/stripe/resources/v2/core/account.rb', line 731 def capabilities @capabilities end |
#shipping ⇒ Object (readonly)
The customer’s shipping information. Appears on invoices emailed to this customer.
733 734 735 |
# File 'lib/stripe/resources/v2/core/account.rb', line 733 def shipping @shipping end |
#test_clock ⇒ Object (readonly)
ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
735 736 737 |
# File 'lib/stripe/resources/v2/core/account.rb', line 735 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
746 747 748 |
# File 'lib/stripe/resources/v2/core/account.rb', line 746 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
737 738 739 740 741 742 743 744 |
# File 'lib/stripe/resources/v2/core/account.rb', line 737 def self.inner_class_types @inner_class_types = { automatic_indirect_tax: AutomaticIndirectTax, billing: Billing, capabilities: Capabilities, shipping: Shipping, } end |