Class: Stripe::V2::Core::Account::Configuration::Customer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#automatic_indirect_tax ⇒ Object
readonly
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links.
-
#billing ⇒ Object
readonly
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Customer Configuration.
-
#shipping ⇒ Object
readonly
The customer’s shipping information.
-
#test_clock ⇒ Object
readonly
ID of the test clock to attach to the customer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
195 196 197 |
# File 'lib/stripe/resources/v2/core/account.rb', line 195 def applied @applied end |
#automatic_indirect_tax ⇒ Object (readonly)
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.
197 198 199 |
# File 'lib/stripe/resources/v2/core/account.rb', line 197 def automatic_indirect_tax @automatic_indirect_tax end |
#billing ⇒ Object (readonly)
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
199 200 201 |
# File 'lib/stripe/resources/v2/core/account.rb', line 199 def billing @billing end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Customer Configuration.
201 202 203 |
# File 'lib/stripe/resources/v2/core/account.rb', line 201 def capabilities @capabilities end |
#shipping ⇒ Object (readonly)
The customer’s shipping information. Appears on invoices emailed to this customer.
203 204 205 |
# File 'lib/stripe/resources/v2/core/account.rb', line 203 def shipping @shipping end |
#test_clock ⇒ Object (readonly)
ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
205 206 207 |
# File 'lib/stripe/resources/v2/core/account.rb', line 205 def test_clock @test_clock end |
Class Method Details
.field_remappings ⇒ Object
216 217 218 |
# File 'lib/stripe/resources/v2/core/account.rb', line 216 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
207 208 209 210 211 212 213 214 |
# File 'lib/stripe/resources/v2/core/account.rb', line 207 def self.inner_class_types @inner_class_types = { automatic_indirect_tax: AutomaticIndirectTax, billing: Billing, capabilities: Capabilities, shipping: Shipping, } end |