Class: Stripe::V2::Core::Account::Configuration::Customer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#automatic_indirect_taxObject (readonly)

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



107
108
109
# File 'lib/stripe/resources/v2/core/account.rb', line 107

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject (readonly)

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



109
110
111
# File 'lib/stripe/resources/v2/core/account.rb', line 109

def billing
  @billing
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Customer Configuration.



111
112
113
# File 'lib/stripe/resources/v2/core/account.rb', line 111

def capabilities
  @capabilities
end

#shippingObject (readonly)

The customer’s shipping information. Appears on invoices emailed to this customer.



113
114
115
# File 'lib/stripe/resources/v2/core/account.rb', line 113

def shipping
  @shipping
end

#test_clockObject (readonly)

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



115
116
117
# File 'lib/stripe/resources/v2/core/account.rb', line 115

def test_clock
  @test_clock
end