Class: Stripe::V2::Core::Account::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Location
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#exempt ⇒ Object
readonly
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
readonly
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location ⇒ Object
readonly
The [identified](docs.stripe.com/tax/customer-locations#address-hierarchy-other) tax location of the customer.
-
#location_source ⇒ Object
readonly
The data source used to identify the customer’s tax location.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#exempt ⇒ Object (readonly)
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.
352 353 354 |
# File 'lib/stripe/resources/v2/core/account.rb', line 352 def exempt @exempt end |
#ip_address ⇒ Object (readonly)
A recent IP address of the customer used for tax reporting and tax location inference.
354 355 356 |
# File 'lib/stripe/resources/v2/core/account.rb', line 354 def ip_address @ip_address end |
#location ⇒ Object (readonly)
The [identified](docs.stripe.com/tax/customer-locations#address-hierarchy-other) tax location of the customer. Will only be rendered if the ‘automatic_indirect_tax` feature is requested and `active`.
356 357 358 |
# File 'lib/stripe/resources/v2/core/account.rb', line 356 def location @location end |
#location_source ⇒ Object (readonly)
The data source used to identify the customer’s tax location. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.
358 359 360 |
# File 'lib/stripe/resources/v2/core/account.rb', line 358 def location_source @location_source end |
Class Method Details
.field_remappings ⇒ Object
364 365 366 |
# File 'lib/stripe/resources/v2/core/account.rb', line 364 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
360 361 362 |
# File 'lib/stripe/resources/v2/core/account.rb', line 360 def self.inner_class_types @inner_class_types = { location: Location } end |