Class: Stripe::V2::Core::Account::Configuration::Customer::AutomaticIndirectTax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Location

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#exemptObject (readonly)

Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.



24
25
26
# File 'lib/stripe/resources/v2/core/account.rb', line 24

def exempt
  @exempt
end

#ip_addressObject (readonly)

A recent IP address of the customer used for tax reporting and tax location inference.



26
27
28
# File 'lib/stripe/resources/v2/core/account.rb', line 26

def ip_address
  @ip_address
end

#locationObject (readonly)

The customer’s identified tax location - uses ‘location_source`. Will only be rendered if the `automatic_indirect_tax` feature is requested and `active`.



28
29
30
# File 'lib/stripe/resources/v2/core/account.rb', line 28

def location
  @location
end

#location_sourceObject (readonly)

The data source used to identify the customer’s tax location - defaults to ‘identity_address’. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.



30
31
32
# File 'lib/stripe/resources/v2/core/account.rb', line 30

def location_source
  @location_source
end