Class: Stripe::V2::Core::Account::Configuration::Customer::Billing
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Customer::Billing
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Invoice
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#default_payment_method ⇒ Object
readonly
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
-
#invoice ⇒ Object
readonly
Default settings used on invoices for this customer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#default_payment_method ⇒ Object (readonly)
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
60 61 62 |
# File 'lib/stripe/resources/v2/core/account.rb', line 60 def default_payment_method @default_payment_method end |
#invoice ⇒ Object (readonly)
Default settings used on invoices for this customer.
62 63 64 |
# File 'lib/stripe/resources/v2/core/account.rb', line 62 def invoice @invoice end |