Class: Stripe::V2::Core::Account::Configuration::Customer::Billing::Invoice

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CustomField, Rendering

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#custom_fieldsObject (readonly)

The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.



49
50
51
# File 'lib/stripe/resources/v2/core/account.rb', line 49

def custom_fields
  @custom_fields
end

Default footer to be displayed on invoices for this customer.



51
52
53
# File 'lib/stripe/resources/v2/core/account.rb', line 51

def footer
  @footer
end

#next_sequenceObject (readonly)

The sequence to be used on the customer’s next invoice. Defaults to 1.



53
54
55
# File 'lib/stripe/resources/v2/core/account.rb', line 53

def next_sequence
  @next_sequence
end

#prefixObject (readonly)

The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.



55
56
57
# File 'lib/stripe/resources/v2/core/account.rb', line 55

def prefix
  @prefix
end

#renderingObject (readonly)

Default options for invoice PDF rendering for this customer.



57
58
59
# File 'lib/stripe/resources/v2/core/account.rb', line 57

def rendering
  @rendering
end