Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, SmartDisputes, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the merchant configuration is active. You can deactivate or reactivate the merchant configuration by updating this property. Deactivating the configuration by setting this value to false doesn’t delete the configuration’s properties.



1962
1963
1964
# File 'lib/stripe/resources/v2/core/account.rb', line 1962

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings for Bacs Direct Debit payments.



1964
1965
1966
# File 'lib/stripe/resources/v2/core/account.rb', line 1964

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



1966
1967
1968
# File 'lib/stripe/resources/v2/core/account.rb', line 1966

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



1968
1969
1970
# File 'lib/stripe/resources/v2/core/account.rb', line 1968

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



1970
1971
1972
# File 'lib/stripe/resources/v2/core/account.rb', line 1970

def card_payments
  @card_payments
end

#konbini_paymentsObject (readonly)

Settings specific to Konbini payments on the account.



1972
1973
1974
# File 'lib/stripe/resources/v2/core/account.rb', line 1972

def konbini_payments
  @konbini_payments
end

#mccObject (readonly)

The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.



1974
1975
1976
# File 'lib/stripe/resources/v2/core/account.rb', line 1974

def mcc
  @mcc
end

#script_statement_descriptorObject (readonly)

Settings for the default text that appears on statements for language variations.



1976
1977
1978
# File 'lib/stripe/resources/v2/core/account.rb', line 1976

def script_statement_descriptor
  @script_statement_descriptor
end

#sepa_debit_paymentsObject (readonly)

Settings for SEPA Direct Debit payments.



1978
1979
1980
# File 'lib/stripe/resources/v2/core/account.rb', line 1978

def sepa_debit_payments
  @sepa_debit_payments
end

#smart_disputesObject (readonly)

Settings for Smart Disputes automatic response feature.



1980
1981
1982
# File 'lib/stripe/resources/v2/core/account.rb', line 1980

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject (readonly)

Statement descriptor.



1982
1983
1984
# File 'lib/stripe/resources/v2/core/account.rb', line 1982

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



1984
1985
1986
# File 'lib/stripe/resources/v2/core/account.rb', line 1984

def support
  @support
end

Class Method Details

.field_remappingsObject



2001
2002
2003
# File 'lib/stripe/resources/v2/core/account.rb', line 2001

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
# File 'lib/stripe/resources/v2/core/account.rb', line 1986

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    konbini_payments: KonbiniPayments,
    script_statement_descriptor: ScriptStatementDescriptor,
    sepa_debit_payments: SepaDebitPayments,
    smart_disputes: SmartDisputes,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end