Class: Stripe::V2::Core::Account::Configuration::Merchant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, SmartDisputes, StatementDescriptor, Support
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the merchant configuration is active.
-
#bacs_debit_payments ⇒ Object
readonly
Settings for Bacs Direct Debit payments.
-
#branding ⇒ Object
readonly
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Merchant Configuration.
-
#card_payments ⇒ Object
readonly
Card payments settings.
-
#konbini_payments ⇒ Object
readonly
Settings specific to Konbini payments on the account.
-
#mcc ⇒ Object
readonly
The Merchant Category Code (MCC) for the merchant.
-
#script_statement_descriptor ⇒ Object
readonly
Settings for the default text that appears on statements for language variations.
-
#sepa_debit_payments ⇒ Object
readonly
Settings for SEPA Direct Debit payments.
-
#smart_disputes ⇒ Object
readonly
Settings for Smart Disputes automatic response feature.
-
#statement_descriptor ⇒ Object
readonly
Statement descriptor.
-
#support ⇒ Object
readonly
Publicly available contact information for sending support issues to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the merchant configuration is active. You can deactivate or reactivate the merchant configuration by updating this property. Deactivating the configuration by setting this value to false doesn’t delete the configuration’s properties.
1930 1931 1932 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1930 def applied @applied end |
#bacs_debit_payments ⇒ Object (readonly)
Settings for Bacs Direct Debit payments.
1932 1933 1934 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1932 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object (readonly)
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
1934 1935 1936 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1934 def branding @branding end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Merchant Configuration.
1936 1937 1938 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1936 def capabilities @capabilities end |
#card_payments ⇒ Object (readonly)
Card payments settings.
1938 1939 1940 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1938 def card_payments @card_payments end |
#konbini_payments ⇒ Object (readonly)
Settings specific to Konbini payments on the account.
1940 1941 1942 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1940 def konbini_payments @konbini_payments end |
#mcc ⇒ Object (readonly)
The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
1942 1943 1944 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1942 def mcc @mcc end |
#script_statement_descriptor ⇒ Object (readonly)
Settings for the default text that appears on statements for language variations.
1944 1945 1946 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1944 def script_statement_descriptor @script_statement_descriptor end |
#sepa_debit_payments ⇒ Object (readonly)
Settings for SEPA Direct Debit payments.
1946 1947 1948 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1946 def sepa_debit_payments @sepa_debit_payments end |
#smart_disputes ⇒ Object (readonly)
Settings for Smart Disputes automatic response feature.
1948 1949 1950 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1948 def smart_disputes @smart_disputes end |
#statement_descriptor ⇒ Object (readonly)
Statement descriptor.
1950 1951 1952 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1950 def statement_descriptor @statement_descriptor end |
#support ⇒ Object (readonly)
Publicly available contact information for sending support issues to.
1952 1953 1954 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1952 def support @support end |
Class Method Details
.field_remappings ⇒ Object
1969 1970 1971 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1969 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1954 def self.inner_class_types @inner_class_types = { bacs_debit_payments: BacsDebitPayments, branding: Branding, capabilities: Capabilities, card_payments: CardPayments, konbini_payments: KonbiniPayments, script_statement_descriptor: ScriptStatementDescriptor, sepa_debit_payments: SepaDebitPayments, smart_disputes: SmartDisputes, statement_descriptor: StatementDescriptor, support: Support, } end |