Class: Stripe::V2::Core::Account::Configuration::Merchant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, SmartDisputes, StatementDescriptor, Support
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the merchant configuration is active.
-
#bacs_debit_payments ⇒ Object
readonly
Settings for Bacs Direct Debit payments.
-
#branding ⇒ Object
readonly
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Merchant Configuration.
-
#card_payments ⇒ Object
readonly
Card payments settings.
-
#konbini_payments ⇒ Object
readonly
Settings specific to Konbini payments on the account.
-
#mcc ⇒ Object
readonly
The Merchant Category Code (MCC) for the merchant.
-
#script_statement_descriptor ⇒ Object
readonly
Settings for the default text that appears on statements for language variations.
-
#sepa_debit_payments ⇒ Object
readonly
Settings for SEPA Direct Debit payments.
-
#smart_disputes ⇒ Object
readonly
Settings for Smart Disputes automatic response feature.
-
#statement_descriptor ⇒ Object
readonly
Statement descriptor.
-
#support ⇒ Object
readonly
Publicly available contact information for sending support issues to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the merchant configuration is active. You can deactivate or reactivate the merchant configuration by updating this property. Deactivating the configuration by setting this value to false doesn’t delete the configuration’s properties.
2491 2492 2493 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2491 def applied @applied end |
#bacs_debit_payments ⇒ Object (readonly)
Settings for Bacs Direct Debit payments.
2493 2494 2495 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2493 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object (readonly)
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
2495 2496 2497 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2495 def branding @branding end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Merchant Configuration.
2497 2498 2499 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2497 def capabilities @capabilities end |
#card_payments ⇒ Object (readonly)
Card payments settings.
2499 2500 2501 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2499 def card_payments @card_payments end |
#konbini_payments ⇒ Object (readonly)
Settings specific to Konbini payments on the account.
2501 2502 2503 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2501 def konbini_payments @konbini_payments end |
#mcc ⇒ Object (readonly)
The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
2503 2504 2505 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2503 def mcc @mcc end |
#script_statement_descriptor ⇒ Object (readonly)
Settings for the default text that appears on statements for language variations.
2505 2506 2507 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2505 def script_statement_descriptor @script_statement_descriptor end |
#sepa_debit_payments ⇒ Object (readonly)
Settings for SEPA Direct Debit payments.
2507 2508 2509 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2507 def sepa_debit_payments @sepa_debit_payments end |
#smart_disputes ⇒ Object (readonly)
Settings for Smart Disputes automatic response feature.
2509 2510 2511 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2509 def smart_disputes @smart_disputes end |
#statement_descriptor ⇒ Object (readonly)
Statement descriptor.
2511 2512 2513 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2511 def statement_descriptor @statement_descriptor end |
#support ⇒ Object (readonly)
Publicly available contact information for sending support issues to.
2513 2514 2515 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2513 def support @support end |
Class Method Details
.field_remappings ⇒ Object
2530 2531 2532 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2530 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2515 def self.inner_class_types @inner_class_types = { bacs_debit_payments: BacsDebitPayments, branding: Branding, capabilities: Capabilities, card_payments: CardPayments, konbini_payments: KonbiniPayments, script_statement_descriptor: ScriptStatementDescriptor, sepa_debit_payments: SepaDebitPayments, smart_disputes: SmartDisputes, statement_descriptor: StatementDescriptor, support: Support, } end |