Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, SmartDisputes, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the merchant configuration is active. You can deactivate or reactivate the merchant configuration by updating this property. Deactivating the configuration by setting this value to false doesn’t delete the configuration’s properties.



2237
2238
2239
# File 'lib/stripe/resources/v2/core/account.rb', line 2237

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings for Bacs Direct Debit payments.



2239
2240
2241
# File 'lib/stripe/resources/v2/core/account.rb', line 2239

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



2241
2242
2243
# File 'lib/stripe/resources/v2/core/account.rb', line 2241

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



2243
2244
2245
# File 'lib/stripe/resources/v2/core/account.rb', line 2243

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



2245
2246
2247
# File 'lib/stripe/resources/v2/core/account.rb', line 2245

def card_payments
  @card_payments
end

#konbini_paymentsObject (readonly)

Settings specific to Konbini payments on the account.



2247
2248
2249
# File 'lib/stripe/resources/v2/core/account.rb', line 2247

def konbini_payments
  @konbini_payments
end

#mccObject (readonly)

The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.



2249
2250
2251
# File 'lib/stripe/resources/v2/core/account.rb', line 2249

def mcc
  @mcc
end

#script_statement_descriptorObject (readonly)

Settings for the default text that appears on statements for language variations.



2251
2252
2253
# File 'lib/stripe/resources/v2/core/account.rb', line 2251

def script_statement_descriptor
  @script_statement_descriptor
end

#sepa_debit_paymentsObject (readonly)

Settings for SEPA Direct Debit payments.



2253
2254
2255
# File 'lib/stripe/resources/v2/core/account.rb', line 2253

def sepa_debit_payments
  @sepa_debit_payments
end

#smart_disputesObject (readonly)

Settings for Smart Disputes automatic response feature.



2255
2256
2257
# File 'lib/stripe/resources/v2/core/account.rb', line 2255

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject (readonly)

Statement descriptor.



2257
2258
2259
# File 'lib/stripe/resources/v2/core/account.rb', line 2257

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



2259
2260
2261
# File 'lib/stripe/resources/v2/core/account.rb', line 2259

def support
  @support
end

Class Method Details

.field_remappingsObject



2276
2277
2278
# File 'lib/stripe/resources/v2/core/account.rb', line 2276

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
# File 'lib/stripe/resources/v2/core/account.rb', line 2261

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    konbini_payments: KonbiniPayments,
    script_statement_descriptor: ScriptStatementDescriptor,
    sepa_debit_payments: SepaDebitPayments,
    smart_disputes: SmartDisputes,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end