Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, SmartDisputes, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the merchant configuration is active. You can deactivate or reactivate the merchant configuration by updating this property. Deactivating the configuration by setting this value to false doesn’t delete the configuration’s properties.



2461
2462
2463
# File 'lib/stripe/resources/v2/core/account.rb', line 2461

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings for Bacs Direct Debit payments.



2463
2464
2465
# File 'lib/stripe/resources/v2/core/account.rb', line 2463

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



2465
2466
2467
# File 'lib/stripe/resources/v2/core/account.rb', line 2465

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



2467
2468
2469
# File 'lib/stripe/resources/v2/core/account.rb', line 2467

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



2469
2470
2471
# File 'lib/stripe/resources/v2/core/account.rb', line 2469

def card_payments
  @card_payments
end

#konbini_paymentsObject (readonly)

Settings specific to Konbini payments on the account.



2471
2472
2473
# File 'lib/stripe/resources/v2/core/account.rb', line 2471

def konbini_payments
  @konbini_payments
end

#mccObject (readonly)

The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.



2473
2474
2475
# File 'lib/stripe/resources/v2/core/account.rb', line 2473

def mcc
  @mcc
end

#script_statement_descriptorObject (readonly)

Settings for the default text that appears on statements for language variations.



2475
2476
2477
# File 'lib/stripe/resources/v2/core/account.rb', line 2475

def script_statement_descriptor
  @script_statement_descriptor
end

#sepa_debit_paymentsObject (readonly)

Settings for SEPA Direct Debit payments.



2477
2478
2479
# File 'lib/stripe/resources/v2/core/account.rb', line 2477

def sepa_debit_payments
  @sepa_debit_payments
end

#smart_disputesObject (readonly)

Settings for Smart Disputes automatic response feature.



2479
2480
2481
# File 'lib/stripe/resources/v2/core/account.rb', line 2479

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject (readonly)

Statement descriptor.



2481
2482
2483
# File 'lib/stripe/resources/v2/core/account.rb', line 2481

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



2483
2484
2485
# File 'lib/stripe/resources/v2/core/account.rb', line 2483

def support
  @support
end

Class Method Details

.field_remappingsObject



2500
2501
2502
# File 'lib/stripe/resources/v2/core/account.rb', line 2500

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
# File 'lib/stripe/resources/v2/core/account.rb', line 2485

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    konbini_payments: KonbiniPayments,
    script_statement_descriptor: ScriptStatementDescriptor,
    sepa_debit_payments: SepaDebitPayments,
    smart_disputes: SmartDisputes,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end