Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the merchant configuration is active. You can deactivate or reactivate the merchant configuration by updating this property. Deactivating the configuration by setting this value to false doesn’t delete the configuration’s properties.



2208
2209
2210
# File 'lib/stripe/resources/v2/core/account.rb', line 2208

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings for Bacs Direct Debit payments.



2210
2211
2212
# File 'lib/stripe/resources/v2/core/account.rb', line 2210

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



2212
2213
2214
# File 'lib/stripe/resources/v2/core/account.rb', line 2212

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



2214
2215
2216
# File 'lib/stripe/resources/v2/core/account.rb', line 2214

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



2216
2217
2218
# File 'lib/stripe/resources/v2/core/account.rb', line 2216

def card_payments
  @card_payments
end

#konbini_paymentsObject (readonly)

Settings specific to Konbini payments on the account.



2218
2219
2220
# File 'lib/stripe/resources/v2/core/account.rb', line 2218

def konbini_payments
  @konbini_payments
end

#mccObject (readonly)

The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.



2220
2221
2222
# File 'lib/stripe/resources/v2/core/account.rb', line 2220

def mcc
  @mcc
end

#script_statement_descriptorObject (readonly)

Settings for the default text that appears on statements for language variations.



2222
2223
2224
# File 'lib/stripe/resources/v2/core/account.rb', line 2222

def script_statement_descriptor
  @script_statement_descriptor
end

#sepa_debit_paymentsObject (readonly)

Settings for SEPA Direct Debit payments.



2224
2225
2226
# File 'lib/stripe/resources/v2/core/account.rb', line 2224

def sepa_debit_payments
  @sepa_debit_payments
end

#statement_descriptorObject (readonly)

Statement descriptor.



2226
2227
2228
# File 'lib/stripe/resources/v2/core/account.rb', line 2226

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



2228
2229
2230
# File 'lib/stripe/resources/v2/core/account.rb', line 2228

def support
  @support
end

Class Method Details

.field_remappingsObject



2244
2245
2246
# File 'lib/stripe/resources/v2/core/account.rb', line 2244

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
# File 'lib/stripe/resources/v2/core/account.rb', line 2230

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    konbini_payments: KonbiniPayments,
    script_statement_descriptor: ScriptStatementDescriptor,
    sepa_debit_payments: SepaDebitPayments,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end