Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SepaDebitPayments, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



2314
2315
2316
# File 'lib/stripe/resources/v2/core/account.rb', line 2314

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings used for Bacs debit payments.



2316
2317
2318
# File 'lib/stripe/resources/v2/core/account.rb', line 2316

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



2318
2319
2320
# File 'lib/stripe/resources/v2/core/account.rb', line 2318

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



2320
2321
2322
# File 'lib/stripe/resources/v2/core/account.rb', line 2320

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



2322
2323
2324
# File 'lib/stripe/resources/v2/core/account.rb', line 2322

def card_payments
  @card_payments
end

#konbini_paymentsObject (readonly)

Settings specific to Konbini payments on the account.



2324
2325
2326
# File 'lib/stripe/resources/v2/core/account.rb', line 2324

def konbini_payments
  @konbini_payments
end

#mccObject (readonly)

The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.



2326
2327
2328
# File 'lib/stripe/resources/v2/core/account.rb', line 2326

def mcc
  @mcc
end

#script_statement_descriptorObject (readonly)

Settings for the default text that appears on statements for language variations.



2328
2329
2330
# File 'lib/stripe/resources/v2/core/account.rb', line 2328

def script_statement_descriptor
  @script_statement_descriptor
end

#sepa_debit_paymentsObject (readonly)

Settings used for SEPA debit payments.



2330
2331
2332
# File 'lib/stripe/resources/v2/core/account.rb', line 2330

def sepa_debit_payments
  @sepa_debit_payments
end

#statement_descriptorObject (readonly)

Statement descriptor.



2332
2333
2334
# File 'lib/stripe/resources/v2/core/account.rb', line 2332

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



2334
2335
2336
# File 'lib/stripe/resources/v2/core/account.rb', line 2334

def support
  @support
end

Class Method Details

.field_remappingsObject



2350
2351
2352
# File 'lib/stripe/resources/v2/core/account.rb', line 2350

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
# File 'lib/stripe/resources/v2/core/account.rb', line 2336

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    konbini_payments: KonbiniPayments,
    script_statement_descriptor: ScriptStatementDescriptor,
    sepa_debit_payments: SepaDebitPayments,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end