Class: Stripe::V2::Core::Account::Configuration::Merchant
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, SepaDebitPayments, StatementDescriptor, Support
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
readonly
Settings used for Bacs debit payments.
-
#branding ⇒ Object
readonly
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Merchant Configuration.
-
#card_payments ⇒ Object
readonly
Card payments settings.
-
#mcc ⇒ Object
readonly
The merchant category code for the merchant.
-
#sepa_debit_payments ⇒ Object
readonly
Settings used for SEPA debit payments.
-
#statement_descriptor ⇒ Object
readonly
Statement descriptor.
-
#support ⇒ Object
readonly
Publicly available contact information for sending support issues to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
2227 2228 2229 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2227 def applied @applied end |
#bacs_debit_payments ⇒ Object (readonly)
Settings used for Bacs debit payments.
2229 2230 2231 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2229 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object (readonly)
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
2231 2232 2233 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2231 def branding @branding end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Merchant Configuration.
2233 2234 2235 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2233 def capabilities @capabilities end |
#card_payments ⇒ Object (readonly)
Card payments settings.
2235 2236 2237 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2235 def card_payments @card_payments end |
#mcc ⇒ Object (readonly)
The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.
2237 2238 2239 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2237 def mcc @mcc end |
#sepa_debit_payments ⇒ Object (readonly)
Settings used for SEPA debit payments.
2239 2240 2241 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2239 def sepa_debit_payments @sepa_debit_payments end |
#statement_descriptor ⇒ Object (readonly)
Statement descriptor.
2241 2242 2243 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2241 def statement_descriptor @statement_descriptor end |
#support ⇒ Object (readonly)
Publicly available contact information for sending support issues to.
2243 2244 2245 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2243 def support @support end |
Class Method Details
.field_remappings ⇒ Object
2257 2258 2259 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2257 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2245 def self.inner_class_types @inner_class_types = { bacs_debit_payments: BacsDebitPayments, branding: Branding, capabilities: Capabilities, card_payments: CardPayments, sepa_debit_payments: SepaDebitPayments, statement_descriptor: StatementDescriptor, support: Support, } end |