Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, SepaDebitPayments, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



2181
2182
2183
# File 'lib/stripe/resources/v2/core/account.rb', line 2181

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings used for Bacs debit payments.



2183
2184
2185
# File 'lib/stripe/resources/v2/core/account.rb', line 2183

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



2185
2186
2187
# File 'lib/stripe/resources/v2/core/account.rb', line 2185

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



2187
2188
2189
# File 'lib/stripe/resources/v2/core/account.rb', line 2187

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



2189
2190
2191
# File 'lib/stripe/resources/v2/core/account.rb', line 2189

def card_payments
  @card_payments
end

#mccObject (readonly)

The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.



2191
2192
2193
# File 'lib/stripe/resources/v2/core/account.rb', line 2191

def mcc
  @mcc
end

#sepa_debit_paymentsObject (readonly)

Settings used for SEPA debit payments.



2193
2194
2195
# File 'lib/stripe/resources/v2/core/account.rb', line 2193

def sepa_debit_payments
  @sepa_debit_payments
end

#statement_descriptorObject (readonly)

Statement descriptor.



2195
2196
2197
# File 'lib/stripe/resources/v2/core/account.rb', line 2195

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



2197
2198
2199
# File 'lib/stripe/resources/v2/core/account.rb', line 2197

def support
  @support
end

Class Method Details

.field_remappingsObject



2211
2212
2213
# File 'lib/stripe/resources/v2/core/account.rb', line 2211

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
# File 'lib/stripe/resources/v2/core/account.rb', line 2199

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    sepa_debit_payments: SepaDebitPayments,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end