Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, SepaDebitPayments, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



1907
1908
1909
# File 'lib/stripe/resources/v2/core/account.rb', line 1907

def applied
  @applied
end

#bacs_debit_paymentsObject (readonly)

Settings used for Bacs debit payments.



1909
1910
1911
# File 'lib/stripe/resources/v2/core/account.rb', line 1909

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



1911
1912
1913
# File 'lib/stripe/resources/v2/core/account.rb', line 1911

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



1913
1914
1915
# File 'lib/stripe/resources/v2/core/account.rb', line 1913

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



1915
1916
1917
# File 'lib/stripe/resources/v2/core/account.rb', line 1915

def card_payments
  @card_payments
end

#mccObject (readonly)

The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.



1917
1918
1919
# File 'lib/stripe/resources/v2/core/account.rb', line 1917

def mcc
  @mcc
end

#sepa_debit_paymentsObject (readonly)

Settings used for SEPA debit payments.



1919
1920
1921
# File 'lib/stripe/resources/v2/core/account.rb', line 1919

def sepa_debit_payments
  @sepa_debit_payments
end

#statement_descriptorObject (readonly)

Statement descriptor.



1921
1922
1923
# File 'lib/stripe/resources/v2/core/account.rb', line 1921

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



1923
1924
1925
# File 'lib/stripe/resources/v2/core/account.rb', line 1923

def support
  @support
end

Class Method Details

.field_remappingsObject



1937
1938
1939
# File 'lib/stripe/resources/v2/core/account.rb', line 1937

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
# File 'lib/stripe/resources/v2/core/account.rb', line 1925

def self.inner_class_types
  @inner_class_types = {
    bacs_debit_payments: BacsDebitPayments,
    branding: Branding,
    capabilities: Capabilities,
    card_payments: CardPayments,
    sepa_debit_payments: SepaDebitPayments,
    statement_descriptor: StatementDescriptor,
    support: Support,
  }
end