Class: Stripe::V2::Core::Account::Configuration::Merchant

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, SepaDebitPayments, StatementDescriptor, Support

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bacs_debit_paymentsObject (readonly)

Settings used for Bacs debit payments.



937
938
939
# File 'lib/stripe/resources/v2/core/account.rb', line 937

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject (readonly)

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



939
940
941
# File 'lib/stripe/resources/v2/core/account.rb', line 939

def branding
  @branding
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Merchant Configuration.



941
942
943
# File 'lib/stripe/resources/v2/core/account.rb', line 941

def capabilities
  @capabilities
end

#card_paymentsObject (readonly)

Card payments settings.



943
944
945
# File 'lib/stripe/resources/v2/core/account.rb', line 943

def card_payments
  @card_payments
end

#mccObject (readonly)

The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.



945
946
947
# File 'lib/stripe/resources/v2/core/account.rb', line 945

def mcc
  @mcc
end

#sepa_debit_paymentsObject (readonly)

Settings used for SEPA debit payments.



947
948
949
# File 'lib/stripe/resources/v2/core/account.rb', line 947

def sepa_debit_payments
  @sepa_debit_payments
end

#statement_descriptorObject (readonly)

Statement descriptor.



949
950
951
# File 'lib/stripe/resources/v2/core/account.rb', line 949

def statement_descriptor
  @statement_descriptor
end

#supportObject (readonly)

Publicly available contact information for sending support issues to.



951
952
953
# File 'lib/stripe/resources/v2/core/account.rb', line 951

def support
  @support
end