Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SunbitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_debit_payments ⇒ Object
readonly
Allow the merchant to process ACH debit payments.
-
#acss_debit_payments ⇒ Object
readonly
Allow the merchant to process ACSS debit payments.
-
#affirm_payments ⇒ Object
readonly
Allow the merchant to process Affirm payments.
-
#afterpay_clearpay_payments ⇒ Object
readonly
Allow the merchant to process Afterpay/Clearpay payments.
-
#alma_payments ⇒ Object
readonly
Allow the merchant to process Alma payments.
-
#amazon_pay_payments ⇒ Object
readonly
Allow the merchant to process Amazon Pay payments.
-
#au_becs_debit_payments ⇒ Object
readonly
Allow the merchant to process Australian BECS Direct Debit payments.
-
#bacs_debit_payments ⇒ Object
readonly
Allow the merchant to process BACS Direct Debit payments.
-
#bancontact_payments ⇒ Object
readonly
Allow the merchant to process Bancontact payments.
-
#blik_payments ⇒ Object
readonly
Allow the merchant to process BLIK payments.
-
#boleto_payments ⇒ Object
readonly
Allow the merchant to process Boleto payments.
-
#card_payments ⇒ Object
readonly
Allow the merchant to collect card payments.
-
#cartes_bancaires_payments ⇒ Object
readonly
Allow the merchant to process Cartes Bancaires payments.
-
#cashapp_payments ⇒ Object
readonly
Allow the merchant to process Cash App payments.
-
#eps_payments ⇒ Object
readonly
Allow the merchant to process EPS payments.
-
#fpx_payments ⇒ Object
readonly
Allow the merchant to process FPX payments.
-
#gb_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process UK bank transfer payments.
-
#grabpay_payments ⇒ Object
readonly
Allow the merchant to process GrabPay payments.
-
#ideal_payments ⇒ Object
readonly
Allow the merchant to process iDEAL payments.
-
#jcb_payments ⇒ Object
readonly
Allow the merchant to process JCB card payments.
-
#jp_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process Japanese bank transfer payments.
-
#kakao_pay_payments ⇒ Object
readonly
Allow the merchant to process Kakao Pay payments.
-
#klarna_payments ⇒ Object
readonly
Allow the merchant to process Klarna payments.
-
#konbini_payments ⇒ Object
readonly
Allow the merchant to process Konbini convenience store payments.
-
#kr_card_payments ⇒ Object
readonly
Allow the merchant to process Korean card payments.
-
#link_payments ⇒ Object
readonly
Allow the merchant to process Link payments.
-
#mobilepay_payments ⇒ Object
readonly
Allow the merchant to process MobilePay payments.
-
#multibanco_payments ⇒ Object
readonly
Allow the merchant to process Multibanco payments.
-
#mx_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process Mexican bank transfer payments.
-
#naver_pay_payments ⇒ Object
readonly
Allow the merchant to process Naver Pay payments.
-
#oxxo_payments ⇒ Object
readonly
Allow the merchant to process OXXO payments.
-
#p24_payments ⇒ Object
readonly
Allow the merchant to process Przelewy24 (P24) payments.
-
#pay_by_bank_payments ⇒ Object
readonly
Allow the merchant to process Pay by Bank payments.
-
#payco_payments ⇒ Object
readonly
Allow the merchant to process PAYCO payments.
-
#paynow_payments ⇒ Object
readonly
Allow the merchant to process PayNow payments.
-
#promptpay_payments ⇒ Object
readonly
Allow the merchant to process PromptPay payments.
-
#revolut_pay_payments ⇒ Object
readonly
Allow the merchant to process Revolut Pay payments.
-
#samsung_pay_payments ⇒ Object
readonly
Allow the merchant to process Samsung Pay payments.
-
#sepa_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process SEPA bank transfer payments.
-
#sepa_debit_payments ⇒ Object
readonly
Allow the merchant to process SEPA Direct Debit payments.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
-
#sunbit_payments ⇒ Object
readonly
Allow the merchant to process Sunbit payments.
-
#swish_payments ⇒ Object
readonly
Allow the merchant to process Swish payments.
-
#twint_payments ⇒ Object
readonly
Allow the merchant to process TWINT payments.
-
#us_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process US bank transfer payments.
-
#zip_payments ⇒ Object
readonly
Allow the merchant to process Zip payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_debit_payments ⇒ Object (readonly)
Allow the merchant to process ACH debit payments.
1602 1603 1604 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1602 def ach_debit_payments @ach_debit_payments end |
#acss_debit_payments ⇒ Object (readonly)
Allow the merchant to process ACSS debit payments.
1604 1605 1606 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1604 def acss_debit_payments @acss_debit_payments end |
#affirm_payments ⇒ Object (readonly)
Allow the merchant to process Affirm payments.
1606 1607 1608 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1606 def affirm_payments @affirm_payments end |
#afterpay_clearpay_payments ⇒ Object (readonly)
Allow the merchant to process Afterpay/Clearpay payments.
1608 1609 1610 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1608 def afterpay_clearpay_payments @afterpay_clearpay_payments end |
#alma_payments ⇒ Object (readonly)
Allow the merchant to process Alma payments.
1610 1611 1612 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1610 def alma_payments @alma_payments end |
#amazon_pay_payments ⇒ Object (readonly)
Allow the merchant to process Amazon Pay payments.
1612 1613 1614 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1612 def amazon_pay_payments @amazon_pay_payments end |
#au_becs_debit_payments ⇒ Object (readonly)
Allow the merchant to process Australian BECS Direct Debit payments.
1614 1615 1616 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1614 def au_becs_debit_payments @au_becs_debit_payments end |
#bacs_debit_payments ⇒ Object (readonly)
Allow the merchant to process BACS Direct Debit payments.
1616 1617 1618 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1616 def bacs_debit_payments @bacs_debit_payments end |
#bancontact_payments ⇒ Object (readonly)
Allow the merchant to process Bancontact payments.
1618 1619 1620 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1618 def bancontact_payments @bancontact_payments end |
#blik_payments ⇒ Object (readonly)
Allow the merchant to process BLIK payments.
1620 1621 1622 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1620 def blik_payments @blik_payments end |
#boleto_payments ⇒ Object (readonly)
Allow the merchant to process Boleto payments.
1622 1623 1624 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1622 def boleto_payments @boleto_payments end |
#card_payments ⇒ Object (readonly)
Allow the merchant to collect card payments.
1624 1625 1626 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1624 def card_payments @card_payments end |
#cartes_bancaires_payments ⇒ Object (readonly)
Allow the merchant to process Cartes Bancaires payments.
1626 1627 1628 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1626 def cartes_bancaires_payments @cartes_bancaires_payments end |
#cashapp_payments ⇒ Object (readonly)
Allow the merchant to process Cash App payments.
1628 1629 1630 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1628 def cashapp_payments @cashapp_payments end |
#eps_payments ⇒ Object (readonly)
Allow the merchant to process EPS payments.
1630 1631 1632 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1630 def eps_payments @eps_payments end |
#fpx_payments ⇒ Object (readonly)
Allow the merchant to process FPX payments.
1632 1633 1634 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1632 def fpx_payments @fpx_payments end |
#gb_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process UK bank transfer payments.
1634 1635 1636 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1634 def gb_bank_transfer_payments @gb_bank_transfer_payments end |
#grabpay_payments ⇒ Object (readonly)
Allow the merchant to process GrabPay payments.
1636 1637 1638 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1636 def grabpay_payments @grabpay_payments end |
#ideal_payments ⇒ Object (readonly)
Allow the merchant to process iDEAL payments.
1638 1639 1640 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1638 def ideal_payments @ideal_payments end |
#jcb_payments ⇒ Object (readonly)
Allow the merchant to process JCB card payments.
1640 1641 1642 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1640 def jcb_payments @jcb_payments end |
#jp_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process Japanese bank transfer payments.
1642 1643 1644 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1642 def jp_bank_transfer_payments @jp_bank_transfer_payments end |
#kakao_pay_payments ⇒ Object (readonly)
Allow the merchant to process Kakao Pay payments.
1644 1645 1646 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1644 def kakao_pay_payments @kakao_pay_payments end |
#klarna_payments ⇒ Object (readonly)
Allow the merchant to process Klarna payments.
1646 1647 1648 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1646 def klarna_payments @klarna_payments end |
#konbini_payments ⇒ Object (readonly)
Allow the merchant to process Konbini convenience store payments.
1648 1649 1650 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1648 def konbini_payments @konbini_payments end |
#kr_card_payments ⇒ Object (readonly)
Allow the merchant to process Korean card payments.
1650 1651 1652 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1650 def kr_card_payments @kr_card_payments end |
#link_payments ⇒ Object (readonly)
Allow the merchant to process Link payments.
1652 1653 1654 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1652 def link_payments @link_payments end |
#mobilepay_payments ⇒ Object (readonly)
Allow the merchant to process MobilePay payments.
1654 1655 1656 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1654 def mobilepay_payments @mobilepay_payments end |
#multibanco_payments ⇒ Object (readonly)
Allow the merchant to process Multibanco payments.
1656 1657 1658 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1656 def multibanco_payments @multibanco_payments end |
#mx_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process Mexican bank transfer payments.
1658 1659 1660 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1658 def mx_bank_transfer_payments @mx_bank_transfer_payments end |
#naver_pay_payments ⇒ Object (readonly)
Allow the merchant to process Naver Pay payments.
1660 1661 1662 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1660 def naver_pay_payments @naver_pay_payments end |
#oxxo_payments ⇒ Object (readonly)
Allow the merchant to process OXXO payments.
1662 1663 1664 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1662 def oxxo_payments @oxxo_payments end |
#p24_payments ⇒ Object (readonly)
Allow the merchant to process Przelewy24 (P24) payments.
1664 1665 1666 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1664 def p24_payments @p24_payments end |
#pay_by_bank_payments ⇒ Object (readonly)
Allow the merchant to process Pay by Bank payments.
1666 1667 1668 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1666 def pay_by_bank_payments @pay_by_bank_payments end |
#payco_payments ⇒ Object (readonly)
Allow the merchant to process PAYCO payments.
1668 1669 1670 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1668 def payco_payments @payco_payments end |
#paynow_payments ⇒ Object (readonly)
Allow the merchant to process PayNow payments.
1670 1671 1672 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1670 def paynow_payments @paynow_payments end |
#promptpay_payments ⇒ Object (readonly)
Allow the merchant to process PromptPay payments.
1672 1673 1674 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1672 def promptpay_payments @promptpay_payments end |
#revolut_pay_payments ⇒ Object (readonly)
Allow the merchant to process Revolut Pay payments.
1674 1675 1676 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1674 def revolut_pay_payments @revolut_pay_payments end |
#samsung_pay_payments ⇒ Object (readonly)
Allow the merchant to process Samsung Pay payments.
1676 1677 1678 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1676 def samsung_pay_payments @samsung_pay_payments end |
#sepa_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process SEPA bank transfer payments.
1678 1679 1680 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1678 def sepa_bank_transfer_payments @sepa_bank_transfer_payments end |
#sepa_debit_payments ⇒ Object (readonly)
Allow the merchant to process SEPA Direct Debit payments.
1680 1681 1682 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1680 def sepa_debit_payments @sepa_debit_payments end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
1682 1683 1684 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1682 def stripe_balance @stripe_balance end |
#sunbit_payments ⇒ Object (readonly)
Allow the merchant to process Sunbit payments.
1684 1685 1686 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1684 def sunbit_payments @sunbit_payments end |
#swish_payments ⇒ Object (readonly)
Allow the merchant to process Swish payments.
1686 1687 1688 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1686 def swish_payments @swish_payments end |
#twint_payments ⇒ Object (readonly)
Allow the merchant to process TWINT payments.
1688 1689 1690 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1688 def twint_payments @twint_payments end |
#us_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process US bank transfer payments.
1690 1691 1692 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1690 def us_bank_transfer_payments @us_bank_transfer_payments end |
#zip_payments ⇒ Object (readonly)
Allow the merchant to process Zip payments.
1692 1693 1694 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1692 def zip_payments @zip_payments end |
Class Method Details
.field_remappings ⇒ Object
1745 1746 1747 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1745 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1694 def self.inner_class_types @inner_class_types = { ach_debit_payments: AchDebitPayments, acss_debit_payments: AcssDebitPayments, affirm_payments: AffirmPayments, afterpay_clearpay_payments: AfterpayClearpayPayments, alma_payments: AlmaPayments, amazon_pay_payments: AmazonPayPayments, au_becs_debit_payments: AuBecsDebitPayments, bacs_debit_payments: BacsDebitPayments, bancontact_payments: BancontactPayments, blik_payments: BlikPayments, boleto_payments: BoletoPayments, card_payments: CardPayments, cartes_bancaires_payments: CartesBancairesPayments, cashapp_payments: CashappPayments, eps_payments: EpsPayments, fpx_payments: FpxPayments, gb_bank_transfer_payments: GbBankTransferPayments, grabpay_payments: GrabpayPayments, ideal_payments: IdealPayments, jcb_payments: JcbPayments, jp_bank_transfer_payments: JpBankTransferPayments, kakao_pay_payments: KakaoPayPayments, klarna_payments: KlarnaPayments, konbini_payments: KonbiniPayments, kr_card_payments: KrCardPayments, link_payments: LinkPayments, mobilepay_payments: MobilepayPayments, multibanco_payments: MultibancoPayments, mx_bank_transfer_payments: MxBankTransferPayments, naver_pay_payments: NaverPayPayments, oxxo_payments: OxxoPayments, p24_payments: P24Payments, pay_by_bank_payments: PayByBankPayments, payco_payments: PaycoPayments, paynow_payments: PaynowPayments, promptpay_payments: PromptpayPayments, revolut_pay_payments: RevolutPayPayments, samsung_pay_payments: SamsungPayPayments, sepa_bank_transfer_payments: SepaBankTransferPayments, sepa_debit_payments: SepaDebitPayments, stripe_balance: StripeBalance, sunbit_payments: SunbitPayments, swish_payments: SwishPayments, twint_payments: TwintPayments, us_bank_transfer_payments: UsBankTransferPayments, zip_payments: ZipPayments, } end |