Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_debit_paymentsObject (readonly)

Allow the merchant to process ACH debit payments.



2134
2135
2136
# File 'lib/stripe/resources/v2/core/account.rb', line 2134

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject (readonly)

Allow the merchant to process ACSS debit payments.



2136
2137
2138
# File 'lib/stripe/resources/v2/core/account.rb', line 2136

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject (readonly)

Allow the merchant to process Affirm payments.



2138
2139
2140
# File 'lib/stripe/resources/v2/core/account.rb', line 2138

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject (readonly)

Allow the merchant to process Afterpay/Clearpay payments.



2140
2141
2142
# File 'lib/stripe/resources/v2/core/account.rb', line 2140

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject (readonly)

Allow the merchant to process Alma payments.



2142
2143
2144
# File 'lib/stripe/resources/v2/core/account.rb', line 2142

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject (readonly)

Allow the merchant to process Amazon Pay payments.



2144
2145
2146
# File 'lib/stripe/resources/v2/core/account.rb', line 2144

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject (readonly)

Allow the merchant to process Australian BECS Direct Debit payments.



2146
2147
2148
# File 'lib/stripe/resources/v2/core/account.rb', line 2146

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject (readonly)

Allow the merchant to process BACS Direct Debit payments.



2148
2149
2150
# File 'lib/stripe/resources/v2/core/account.rb', line 2148

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject (readonly)

Allow the merchant to process Bancontact payments.



2150
2151
2152
# File 'lib/stripe/resources/v2/core/account.rb', line 2150

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject (readonly)

Allow the merchant to process BLIK payments.



2152
2153
2154
# File 'lib/stripe/resources/v2/core/account.rb', line 2152

def blik_payments
  @blik_payments
end

#boleto_paymentsObject (readonly)

Allow the merchant to process Boleto payments.



2154
2155
2156
# File 'lib/stripe/resources/v2/core/account.rb', line 2154

def boleto_payments
  @boleto_payments
end

#card_paymentsObject (readonly)

Allow the merchant to collect card payments.



2156
2157
2158
# File 'lib/stripe/resources/v2/core/account.rb', line 2156

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject (readonly)

Allow the merchant to process Cartes Bancaires payments.



2158
2159
2160
# File 'lib/stripe/resources/v2/core/account.rb', line 2158

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject (readonly)

Allow the merchant to process Cash App payments.



2160
2161
2162
# File 'lib/stripe/resources/v2/core/account.rb', line 2160

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject (readonly)

Allow the merchant to process EPS payments.



2162
2163
2164
# File 'lib/stripe/resources/v2/core/account.rb', line 2162

def eps_payments
  @eps_payments
end

#fpx_paymentsObject (readonly)

Allow the merchant to process FPX payments.



2164
2165
2166
# File 'lib/stripe/resources/v2/core/account.rb', line 2164

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject (readonly)

Allow the merchant to process UK bank transfer payments.



2166
2167
2168
# File 'lib/stripe/resources/v2/core/account.rb', line 2166

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject (readonly)

Allow the merchant to process GrabPay payments.



2168
2169
2170
# File 'lib/stripe/resources/v2/core/account.rb', line 2168

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject (readonly)

Allow the merchant to process iDEAL payments.



2170
2171
2172
# File 'lib/stripe/resources/v2/core/account.rb', line 2170

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject (readonly)

Allow the merchant to process JCB card payments.



2172
2173
2174
# File 'lib/stripe/resources/v2/core/account.rb', line 2172

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Japanese bank transfer payments.



2174
2175
2176
# File 'lib/stripe/resources/v2/core/account.rb', line 2174

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject (readonly)

Allow the merchant to process Kakao Pay payments.



2176
2177
2178
# File 'lib/stripe/resources/v2/core/account.rb', line 2176

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject (readonly)

Allow the merchant to process Klarna payments.



2178
2179
2180
# File 'lib/stripe/resources/v2/core/account.rb', line 2178

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject (readonly)

Allow the merchant to process Konbini convenience store payments.



2180
2181
2182
# File 'lib/stripe/resources/v2/core/account.rb', line 2180

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject (readonly)

Allow the merchant to process Korean card payments.



2182
2183
2184
# File 'lib/stripe/resources/v2/core/account.rb', line 2182

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



2184
2185
2186
# File 'lib/stripe/resources/v2/core/account.rb', line 2184

def link_payments
  @link_payments
end

#mobilepay_paymentsObject (readonly)

Allow the merchant to process MobilePay payments.



2186
2187
2188
# File 'lib/stripe/resources/v2/core/account.rb', line 2186

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject (readonly)

Allow the merchant to process Multibanco payments.



2188
2189
2190
# File 'lib/stripe/resources/v2/core/account.rb', line 2188

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Mexican bank transfer payments.



2190
2191
2192
# File 'lib/stripe/resources/v2/core/account.rb', line 2190

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



2192
2193
2194
# File 'lib/stripe/resources/v2/core/account.rb', line 2192

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject (readonly)

Allow the merchant to process OXXO payments.



2194
2195
2196
# File 'lib/stripe/resources/v2/core/account.rb', line 2194

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject (readonly)

Allow the merchant to process Przelewy24 (P24) payments.



2196
2197
2198
# File 'lib/stripe/resources/v2/core/account.rb', line 2196

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject (readonly)

Allow the merchant to process Pay by Bank payments.



2198
2199
2200
# File 'lib/stripe/resources/v2/core/account.rb', line 2198

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject (readonly)

Allow the merchant to process PAYCO payments.



2200
2201
2202
# File 'lib/stripe/resources/v2/core/account.rb', line 2200

def payco_payments
  @payco_payments
end

#paynow_paymentsObject (readonly)

Allow the merchant to process PayNow payments.



2202
2203
2204
# File 'lib/stripe/resources/v2/core/account.rb', line 2202

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject (readonly)

Allow the merchant to process PromptPay payments.



2204
2205
2206
# File 'lib/stripe/resources/v2/core/account.rb', line 2204

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject (readonly)

Allow the merchant to process Revolut Pay payments.



2206
2207
2208
# File 'lib/stripe/resources/v2/core/account.rb', line 2206

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject (readonly)

Allow the merchant to process Samsung Pay payments.



2208
2209
2210
# File 'lib/stripe/resources/v2/core/account.rb', line 2208

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject (readonly)

Allow the merchant to process SEPA bank transfer payments.



2210
2211
2212
# File 'lib/stripe/resources/v2/core/account.rb', line 2210

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject (readonly)

Allow the merchant to process SEPA Direct Debit payments.



2212
2213
2214
# File 'lib/stripe/resources/v2/core/account.rb', line 2212

def sepa_debit_payments
  @sepa_debit_payments
end

#stripe_balanceObject (readonly)

Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).



2214
2215
2216
# File 'lib/stripe/resources/v2/core/account.rb', line 2214

def stripe_balance
  @stripe_balance
end

#swish_paymentsObject (readonly)

Allow the merchant to process Swish payments.



2216
2217
2218
# File 'lib/stripe/resources/v2/core/account.rb', line 2216

def swish_payments
  @swish_payments
end

#twint_paymentsObject (readonly)

Allow the merchant to process TWINT payments.



2218
2219
2220
# File 'lib/stripe/resources/v2/core/account.rb', line 2218

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject (readonly)

Allow the merchant to process US bank transfer payments.



2220
2221
2222
# File 'lib/stripe/resources/v2/core/account.rb', line 2220

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject (readonly)

Allow the merchant to process Zip payments.



2222
2223
2224
# File 'lib/stripe/resources/v2/core/account.rb', line 2222

def zip_payments
  @zip_payments
end

Class Method Details

.field_remappingsObject



2274
2275
2276
# File 'lib/stripe/resources/v2/core/account.rb', line 2274

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
# File 'lib/stripe/resources/v2/core/account.rb', line 2224

def self.inner_class_types
  @inner_class_types = {
    ach_debit_payments: AchDebitPayments,
    acss_debit_payments: AcssDebitPayments,
    affirm_payments: AffirmPayments,
    afterpay_clearpay_payments: AfterpayClearpayPayments,
    alma_payments: AlmaPayments,
    amazon_pay_payments: AmazonPayPayments,
    au_becs_debit_payments: AuBecsDebitPayments,
    bacs_debit_payments: BacsDebitPayments,
    bancontact_payments: BancontactPayments,
    blik_payments: BlikPayments,
    boleto_payments: BoletoPayments,
    card_payments: CardPayments,
    cartes_bancaires_payments: CartesBancairesPayments,
    cashapp_payments: CashappPayments,
    eps_payments: EpsPayments,
    fpx_payments: FpxPayments,
    gb_bank_transfer_payments: GbBankTransferPayments,
    grabpay_payments: GrabpayPayments,
    ideal_payments: IdealPayments,
    jcb_payments: JcbPayments,
    jp_bank_transfer_payments: JpBankTransferPayments,
    kakao_pay_payments: KakaoPayPayments,
    klarna_payments: KlarnaPayments,
    konbini_payments: KonbiniPayments,
    kr_card_payments: KrCardPayments,
    link_payments: LinkPayments,
    mobilepay_payments: MobilepayPayments,
    multibanco_payments: MultibancoPayments,
    mx_bank_transfer_payments: MxBankTransferPayments,
    naver_pay_payments: NaverPayPayments,
    oxxo_payments: OxxoPayments,
    p24_payments: P24Payments,
    pay_by_bank_payments: PayByBankPayments,
    payco_payments: PaycoPayments,
    paynow_payments: PaynowPayments,
    promptpay_payments: PromptpayPayments,
    revolut_pay_payments: RevolutPayPayments,
    samsung_pay_payments: SamsungPayPayments,
    sepa_bank_transfer_payments: SepaBankTransferPayments,
    sepa_debit_payments: SepaDebitPayments,
    stripe_balance: StripeBalance,
    swish_payments: SwishPayments,
    twint_payments: TwintPayments,
    us_bank_transfer_payments: UsBankTransferPayments,
    zip_payments: ZipPayments,
  }
end