Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_debit_payments ⇒ Object
readonly
Allow the merchant to process ACH debit payments.
-
#acss_debit_payments ⇒ Object
readonly
Allow the merchant to process ACSS debit payments.
-
#affirm_payments ⇒ Object
readonly
Allow the merchant to process Affirm payments.
-
#afterpay_clearpay_payments ⇒ Object
readonly
Allow the merchant to process Afterpay/Clearpay payments.
-
#alma_payments ⇒ Object
readonly
Allow the merchant to process Alma payments.
-
#amazon_pay_payments ⇒ Object
readonly
Allow the merchant to process Amazon Pay payments.
-
#au_becs_debit_payments ⇒ Object
readonly
Allow the merchant to process Australian BECS Direct Debit payments.
-
#bacs_debit_payments ⇒ Object
readonly
Allow the merchant to process BACS Direct Debit payments.
-
#bancontact_payments ⇒ Object
readonly
Allow the merchant to process Bancontact payments.
-
#blik_payments ⇒ Object
readonly
Allow the merchant to process BLIK payments.
-
#boleto_payments ⇒ Object
readonly
Allow the merchant to process Boleto payments.
-
#card_payments ⇒ Object
readonly
Allow the merchant to collect card payments.
-
#cartes_bancaires_payments ⇒ Object
readonly
Allow the merchant to process Cartes Bancaires payments.
-
#cashapp_payments ⇒ Object
readonly
Allow the merchant to process Cash App payments.
-
#eps_payments ⇒ Object
readonly
Allow the merchant to process EPS payments.
-
#fpx_payments ⇒ Object
readonly
Allow the merchant to process FPX payments.
-
#gb_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process UK bank transfer payments.
-
#grabpay_payments ⇒ Object
readonly
Allow the merchant to process GrabPay payments.
-
#ideal_payments ⇒ Object
readonly
Allow the merchant to process iDEAL payments.
-
#jcb_payments ⇒ Object
readonly
Allow the merchant to process JCB card payments.
-
#jp_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process Japanese bank transfer payments.
-
#kakao_pay_payments ⇒ Object
readonly
Allow the merchant to process Kakao Pay payments.
-
#klarna_payments ⇒ Object
readonly
Allow the merchant to process Klarna payments.
-
#konbini_payments ⇒ Object
readonly
Allow the merchant to process Konbini convenience store payments.
-
#kr_card_payments ⇒ Object
readonly
Allow the merchant to process Korean card payments.
-
#link_payments ⇒ Object
readonly
Allow the merchant to process Link payments.
-
#mobilepay_payments ⇒ Object
readonly
Allow the merchant to process MobilePay payments.
-
#multibanco_payments ⇒ Object
readonly
Allow the merchant to process Multibanco payments.
-
#mx_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process Mexican bank transfer payments.
-
#naver_pay_payments ⇒ Object
readonly
Allow the merchant to process Naver Pay payments.
-
#oxxo_payments ⇒ Object
readonly
Allow the merchant to process OXXO payments.
-
#p24_payments ⇒ Object
readonly
Allow the merchant to process Przelewy24 (P24) payments.
-
#pay_by_bank_payments ⇒ Object
readonly
Allow the merchant to process Pay by Bank payments.
-
#payco_payments ⇒ Object
readonly
Allow the merchant to process PAYCO payments.
-
#paynow_payments ⇒ Object
readonly
Allow the merchant to process PayNow payments.
-
#promptpay_payments ⇒ Object
readonly
Allow the merchant to process PromptPay payments.
-
#revolut_pay_payments ⇒ Object
readonly
Allow the merchant to process Revolut Pay payments.
-
#samsung_pay_payments ⇒ Object
readonly
Allow the merchant to process Samsung Pay payments.
-
#sepa_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process SEPA bank transfer payments.
-
#sepa_debit_payments ⇒ Object
readonly
Allow the merchant to process SEPA Direct Debit payments.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
-
#swish_payments ⇒ Object
readonly
Allow the merchant to process Swish payments.
-
#twint_payments ⇒ Object
readonly
Allow the merchant to process TWINT payments.
-
#us_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process US bank transfer payments.
-
#zip_payments ⇒ Object
readonly
Allow the merchant to process Zip payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_debit_payments ⇒ Object (readonly)
Allow the merchant to process ACH debit payments.
1984 1985 1986 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1984 def ach_debit_payments @ach_debit_payments end |
#acss_debit_payments ⇒ Object (readonly)
Allow the merchant to process ACSS debit payments.
1986 1987 1988 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1986 def acss_debit_payments @acss_debit_payments end |
#affirm_payments ⇒ Object (readonly)
Allow the merchant to process Affirm payments.
1988 1989 1990 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1988 def affirm_payments @affirm_payments end |
#afterpay_clearpay_payments ⇒ Object (readonly)
Allow the merchant to process Afterpay/Clearpay payments.
1990 1991 1992 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1990 def afterpay_clearpay_payments @afterpay_clearpay_payments end |
#alma_payments ⇒ Object (readonly)
Allow the merchant to process Alma payments.
1992 1993 1994 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1992 def alma_payments @alma_payments end |
#amazon_pay_payments ⇒ Object (readonly)
Allow the merchant to process Amazon Pay payments.
1994 1995 1996 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1994 def amazon_pay_payments @amazon_pay_payments end |
#au_becs_debit_payments ⇒ Object (readonly)
Allow the merchant to process Australian BECS Direct Debit payments.
1996 1997 1998 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1996 def au_becs_debit_payments @au_becs_debit_payments end |
#bacs_debit_payments ⇒ Object (readonly)
Allow the merchant to process BACS Direct Debit payments.
1998 1999 2000 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1998 def bacs_debit_payments @bacs_debit_payments end |
#bancontact_payments ⇒ Object (readonly)
Allow the merchant to process Bancontact payments.
2000 2001 2002 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2000 def bancontact_payments @bancontact_payments end |
#blik_payments ⇒ Object (readonly)
Allow the merchant to process BLIK payments.
2002 2003 2004 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2002 def blik_payments @blik_payments end |
#boleto_payments ⇒ Object (readonly)
Allow the merchant to process Boleto payments.
2004 2005 2006 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2004 def boleto_payments @boleto_payments end |
#card_payments ⇒ Object (readonly)
Allow the merchant to collect card payments.
2006 2007 2008 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2006 def card_payments @card_payments end |
#cartes_bancaires_payments ⇒ Object (readonly)
Allow the merchant to process Cartes Bancaires payments.
2008 2009 2010 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2008 def cartes_bancaires_payments @cartes_bancaires_payments end |
#cashapp_payments ⇒ Object (readonly)
Allow the merchant to process Cash App payments.
2010 2011 2012 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2010 def cashapp_payments @cashapp_payments end |
#eps_payments ⇒ Object (readonly)
Allow the merchant to process EPS payments.
2012 2013 2014 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2012 def eps_payments @eps_payments end |
#fpx_payments ⇒ Object (readonly)
Allow the merchant to process FPX payments.
2014 2015 2016 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2014 def fpx_payments @fpx_payments end |
#gb_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process UK bank transfer payments.
2016 2017 2018 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2016 def gb_bank_transfer_payments @gb_bank_transfer_payments end |
#grabpay_payments ⇒ Object (readonly)
Allow the merchant to process GrabPay payments.
2018 2019 2020 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2018 def grabpay_payments @grabpay_payments end |
#ideal_payments ⇒ Object (readonly)
Allow the merchant to process iDEAL payments.
2020 2021 2022 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2020 def ideal_payments @ideal_payments end |
#jcb_payments ⇒ Object (readonly)
Allow the merchant to process JCB card payments.
2022 2023 2024 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2022 def jcb_payments @jcb_payments end |
#jp_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process Japanese bank transfer payments.
2024 2025 2026 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2024 def jp_bank_transfer_payments @jp_bank_transfer_payments end |
#kakao_pay_payments ⇒ Object (readonly)
Allow the merchant to process Kakao Pay payments.
2026 2027 2028 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2026 def kakao_pay_payments @kakao_pay_payments end |
#klarna_payments ⇒ Object (readonly)
Allow the merchant to process Klarna payments.
2028 2029 2030 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2028 def klarna_payments @klarna_payments end |
#konbini_payments ⇒ Object (readonly)
Allow the merchant to process Konbini convenience store payments.
2030 2031 2032 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2030 def konbini_payments @konbini_payments end |
#kr_card_payments ⇒ Object (readonly)
Allow the merchant to process Korean card payments.
2032 2033 2034 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2032 def kr_card_payments @kr_card_payments end |
#link_payments ⇒ Object (readonly)
Allow the merchant to process Link payments.
2034 2035 2036 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2034 def link_payments @link_payments end |
#mobilepay_payments ⇒ Object (readonly)
Allow the merchant to process MobilePay payments.
2036 2037 2038 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2036 def mobilepay_payments @mobilepay_payments end |
#multibanco_payments ⇒ Object (readonly)
Allow the merchant to process Multibanco payments.
2038 2039 2040 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2038 def multibanco_payments @multibanco_payments end |
#mx_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process Mexican bank transfer payments.
2040 2041 2042 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2040 def mx_bank_transfer_payments @mx_bank_transfer_payments end |
#naver_pay_payments ⇒ Object (readonly)
Allow the merchant to process Naver Pay payments.
2042 2043 2044 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2042 def naver_pay_payments @naver_pay_payments end |
#oxxo_payments ⇒ Object (readonly)
Allow the merchant to process OXXO payments.
2044 2045 2046 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2044 def oxxo_payments @oxxo_payments end |
#p24_payments ⇒ Object (readonly)
Allow the merchant to process Przelewy24 (P24) payments.
2046 2047 2048 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2046 def p24_payments @p24_payments end |
#pay_by_bank_payments ⇒ Object (readonly)
Allow the merchant to process Pay by Bank payments.
2048 2049 2050 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2048 def pay_by_bank_payments @pay_by_bank_payments end |
#payco_payments ⇒ Object (readonly)
Allow the merchant to process PAYCO payments.
2050 2051 2052 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2050 def payco_payments @payco_payments end |
#paynow_payments ⇒ Object (readonly)
Allow the merchant to process PayNow payments.
2052 2053 2054 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2052 def paynow_payments @paynow_payments end |
#promptpay_payments ⇒ Object (readonly)
Allow the merchant to process PromptPay payments.
2054 2055 2056 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2054 def promptpay_payments @promptpay_payments end |
#revolut_pay_payments ⇒ Object (readonly)
Allow the merchant to process Revolut Pay payments.
2056 2057 2058 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2056 def revolut_pay_payments @revolut_pay_payments end |
#samsung_pay_payments ⇒ Object (readonly)
Allow the merchant to process Samsung Pay payments.
2058 2059 2060 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2058 def samsung_pay_payments @samsung_pay_payments end |
#sepa_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process SEPA bank transfer payments.
2060 2061 2062 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2060 def sepa_bank_transfer_payments @sepa_bank_transfer_payments end |
#sepa_debit_payments ⇒ Object (readonly)
Allow the merchant to process SEPA Direct Debit payments.
2062 2063 2064 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2062 def sepa_debit_payments @sepa_debit_payments end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
2064 2065 2066 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2064 def stripe_balance @stripe_balance end |
#swish_payments ⇒ Object (readonly)
Allow the merchant to process Swish payments.
2066 2067 2068 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2066 def swish_payments @swish_payments end |
#twint_payments ⇒ Object (readonly)
Allow the merchant to process TWINT payments.
2068 2069 2070 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2068 def twint_payments @twint_payments end |
#us_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process US bank transfer payments.
2070 2071 2072 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2070 def us_bank_transfer_payments @us_bank_transfer_payments end |
#zip_payments ⇒ Object (readonly)
Allow the merchant to process Zip payments.
2072 2073 2074 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2072 def zip_payments @zip_payments end |
Class Method Details
.field_remappings ⇒ Object
2124 2125 2126 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2124 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2074 def self.inner_class_types @inner_class_types = { ach_debit_payments: AchDebitPayments, acss_debit_payments: AcssDebitPayments, affirm_payments: AffirmPayments, afterpay_clearpay_payments: AfterpayClearpayPayments, alma_payments: AlmaPayments, amazon_pay_payments: AmazonPayPayments, au_becs_debit_payments: AuBecsDebitPayments, bacs_debit_payments: BacsDebitPayments, bancontact_payments: BancontactPayments, blik_payments: BlikPayments, boleto_payments: BoletoPayments, card_payments: CardPayments, cartes_bancaires_payments: CartesBancairesPayments, cashapp_payments: CashappPayments, eps_payments: EpsPayments, fpx_payments: FpxPayments, gb_bank_transfer_payments: GbBankTransferPayments, grabpay_payments: GrabpayPayments, ideal_payments: IdealPayments, jcb_payments: JcbPayments, jp_bank_transfer_payments: JpBankTransferPayments, kakao_pay_payments: KakaoPayPayments, klarna_payments: KlarnaPayments, konbini_payments: KonbiniPayments, kr_card_payments: KrCardPayments, link_payments: LinkPayments, mobilepay_payments: MobilepayPayments, multibanco_payments: MultibancoPayments, mx_bank_transfer_payments: MxBankTransferPayments, naver_pay_payments: NaverPayPayments, oxxo_payments: OxxoPayments, p24_payments: P24Payments, pay_by_bank_payments: PayByBankPayments, payco_payments: PaycoPayments, paynow_payments: PaynowPayments, promptpay_payments: PromptpayPayments, revolut_pay_payments: RevolutPayPayments, samsung_pay_payments: SamsungPayPayments, sepa_bank_transfer_payments: SepaBankTransferPayments, sepa_debit_payments: SepaDebitPayments, stripe_balance: StripeBalance, swish_payments: SwishPayments, twint_payments: TwintPayments, us_bank_transfer_payments: UsBankTransferPayments, zip_payments: ZipPayments, } end |