Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_debit_paymentsObject (readonly)

Allow the merchant to process ACH debit payments.



1938
1939
1940
# File 'lib/stripe/resources/v2/core/account.rb', line 1938

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject (readonly)

Allow the merchant to process ACSS debit payments.



1940
1941
1942
# File 'lib/stripe/resources/v2/core/account.rb', line 1940

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject (readonly)

Allow the merchant to process Affirm payments.



1942
1943
1944
# File 'lib/stripe/resources/v2/core/account.rb', line 1942

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject (readonly)

Allow the merchant to process Afterpay/Clearpay payments.



1944
1945
1946
# File 'lib/stripe/resources/v2/core/account.rb', line 1944

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject (readonly)

Allow the merchant to process Alma payments.



1946
1947
1948
# File 'lib/stripe/resources/v2/core/account.rb', line 1946

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject (readonly)

Allow the merchant to process Amazon Pay payments.



1948
1949
1950
# File 'lib/stripe/resources/v2/core/account.rb', line 1948

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject (readonly)

Allow the merchant to process Australian BECS Direct Debit payments.



1950
1951
1952
# File 'lib/stripe/resources/v2/core/account.rb', line 1950

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject (readonly)

Allow the merchant to process BACS Direct Debit payments.



1952
1953
1954
# File 'lib/stripe/resources/v2/core/account.rb', line 1952

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject (readonly)

Allow the merchant to process Bancontact payments.



1954
1955
1956
# File 'lib/stripe/resources/v2/core/account.rb', line 1954

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject (readonly)

Allow the merchant to process BLIK payments.



1956
1957
1958
# File 'lib/stripe/resources/v2/core/account.rb', line 1956

def blik_payments
  @blik_payments
end

#boleto_paymentsObject (readonly)

Allow the merchant to process Boleto payments.



1958
1959
1960
# File 'lib/stripe/resources/v2/core/account.rb', line 1958

def boleto_payments
  @boleto_payments
end

#card_paymentsObject (readonly)

Allow the merchant to collect card payments.



1960
1961
1962
# File 'lib/stripe/resources/v2/core/account.rb', line 1960

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject (readonly)

Allow the merchant to process Cartes Bancaires payments.



1962
1963
1964
# File 'lib/stripe/resources/v2/core/account.rb', line 1962

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject (readonly)

Allow the merchant to process Cash App payments.



1964
1965
1966
# File 'lib/stripe/resources/v2/core/account.rb', line 1964

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject (readonly)

Allow the merchant to process EPS payments.



1966
1967
1968
# File 'lib/stripe/resources/v2/core/account.rb', line 1966

def eps_payments
  @eps_payments
end

#fpx_paymentsObject (readonly)

Allow the merchant to process FPX payments.



1968
1969
1970
# File 'lib/stripe/resources/v2/core/account.rb', line 1968

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject (readonly)

Allow the merchant to process UK bank transfer payments.



1970
1971
1972
# File 'lib/stripe/resources/v2/core/account.rb', line 1970

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject (readonly)

Allow the merchant to process GrabPay payments.



1972
1973
1974
# File 'lib/stripe/resources/v2/core/account.rb', line 1972

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject (readonly)

Allow the merchant to process iDEAL payments.



1974
1975
1976
# File 'lib/stripe/resources/v2/core/account.rb', line 1974

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject (readonly)

Allow the merchant to process JCB card payments.



1976
1977
1978
# File 'lib/stripe/resources/v2/core/account.rb', line 1976

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Japanese bank transfer payments.



1978
1979
1980
# File 'lib/stripe/resources/v2/core/account.rb', line 1978

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject (readonly)

Allow the merchant to process Kakao Pay payments.



1980
1981
1982
# File 'lib/stripe/resources/v2/core/account.rb', line 1980

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject (readonly)

Allow the merchant to process Klarna payments.



1982
1983
1984
# File 'lib/stripe/resources/v2/core/account.rb', line 1982

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject (readonly)

Allow the merchant to process Konbini convenience store payments.



1984
1985
1986
# File 'lib/stripe/resources/v2/core/account.rb', line 1984

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject (readonly)

Allow the merchant to process Korean card payments.



1986
1987
1988
# File 'lib/stripe/resources/v2/core/account.rb', line 1986

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



1988
1989
1990
# File 'lib/stripe/resources/v2/core/account.rb', line 1988

def link_payments
  @link_payments
end

#mobilepay_paymentsObject (readonly)

Allow the merchant to process MobilePay payments.



1990
1991
1992
# File 'lib/stripe/resources/v2/core/account.rb', line 1990

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject (readonly)

Allow the merchant to process Multibanco payments.



1992
1993
1994
# File 'lib/stripe/resources/v2/core/account.rb', line 1992

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Mexican bank transfer payments.



1994
1995
1996
# File 'lib/stripe/resources/v2/core/account.rb', line 1994

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



1996
1997
1998
# File 'lib/stripe/resources/v2/core/account.rb', line 1996

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject (readonly)

Allow the merchant to process OXXO payments.



1998
1999
2000
# File 'lib/stripe/resources/v2/core/account.rb', line 1998

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject (readonly)

Allow the merchant to process Przelewy24 (P24) payments.



2000
2001
2002
# File 'lib/stripe/resources/v2/core/account.rb', line 2000

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject (readonly)

Allow the merchant to process Pay by Bank payments.



2002
2003
2004
# File 'lib/stripe/resources/v2/core/account.rb', line 2002

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject (readonly)

Allow the merchant to process PAYCO payments.



2004
2005
2006
# File 'lib/stripe/resources/v2/core/account.rb', line 2004

def payco_payments
  @payco_payments
end

#paynow_paymentsObject (readonly)

Allow the merchant to process PayNow payments.



2006
2007
2008
# File 'lib/stripe/resources/v2/core/account.rb', line 2006

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject (readonly)

Allow the merchant to process PromptPay payments.



2008
2009
2010
# File 'lib/stripe/resources/v2/core/account.rb', line 2008

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject (readonly)

Allow the merchant to process Revolut Pay payments.



2010
2011
2012
# File 'lib/stripe/resources/v2/core/account.rb', line 2010

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject (readonly)

Allow the merchant to process Samsung Pay payments.



2012
2013
2014
# File 'lib/stripe/resources/v2/core/account.rb', line 2012

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject (readonly)

Allow the merchant to process SEPA bank transfer payments.



2014
2015
2016
# File 'lib/stripe/resources/v2/core/account.rb', line 2014

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject (readonly)

Allow the merchant to process SEPA Direct Debit payments.



2016
2017
2018
# File 'lib/stripe/resources/v2/core/account.rb', line 2016

def sepa_debit_payments
  @sepa_debit_payments
end

#stripe_balanceObject (readonly)

Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).



2018
2019
2020
# File 'lib/stripe/resources/v2/core/account.rb', line 2018

def stripe_balance
  @stripe_balance
end

#swish_paymentsObject (readonly)

Allow the merchant to process Swish payments.



2020
2021
2022
# File 'lib/stripe/resources/v2/core/account.rb', line 2020

def swish_payments
  @swish_payments
end

#twint_paymentsObject (readonly)

Allow the merchant to process TWINT payments.



2022
2023
2024
# File 'lib/stripe/resources/v2/core/account.rb', line 2022

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject (readonly)

Allow the merchant to process US bank transfer payments.



2024
2025
2026
# File 'lib/stripe/resources/v2/core/account.rb', line 2024

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject (readonly)

Allow the merchant to process Zip payments.



2026
2027
2028
# File 'lib/stripe/resources/v2/core/account.rb', line 2026

def zip_payments
  @zip_payments
end

Class Method Details

.field_remappingsObject



2078
2079
2080
# File 'lib/stripe/resources/v2/core/account.rb', line 2078

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
# File 'lib/stripe/resources/v2/core/account.rb', line 2028

def self.inner_class_types
  @inner_class_types = {
    ach_debit_payments: AchDebitPayments,
    acss_debit_payments: AcssDebitPayments,
    affirm_payments: AffirmPayments,
    afterpay_clearpay_payments: AfterpayClearpayPayments,
    alma_payments: AlmaPayments,
    amazon_pay_payments: AmazonPayPayments,
    au_becs_debit_payments: AuBecsDebitPayments,
    bacs_debit_payments: BacsDebitPayments,
    bancontact_payments: BancontactPayments,
    blik_payments: BlikPayments,
    boleto_payments: BoletoPayments,
    card_payments: CardPayments,
    cartes_bancaires_payments: CartesBancairesPayments,
    cashapp_payments: CashappPayments,
    eps_payments: EpsPayments,
    fpx_payments: FpxPayments,
    gb_bank_transfer_payments: GbBankTransferPayments,
    grabpay_payments: GrabpayPayments,
    ideal_payments: IdealPayments,
    jcb_payments: JcbPayments,
    jp_bank_transfer_payments: JpBankTransferPayments,
    kakao_pay_payments: KakaoPayPayments,
    klarna_payments: KlarnaPayments,
    konbini_payments: KonbiniPayments,
    kr_card_payments: KrCardPayments,
    link_payments: LinkPayments,
    mobilepay_payments: MobilepayPayments,
    multibanco_payments: MultibancoPayments,
    mx_bank_transfer_payments: MxBankTransferPayments,
    naver_pay_payments: NaverPayPayments,
    oxxo_payments: OxxoPayments,
    p24_payments: P24Payments,
    pay_by_bank_payments: PayByBankPayments,
    payco_payments: PaycoPayments,
    paynow_payments: PaynowPayments,
    promptpay_payments: PromptpayPayments,
    revolut_pay_payments: RevolutPayPayments,
    samsung_pay_payments: SamsungPayPayments,
    sepa_bank_transfer_payments: SepaBankTransferPayments,
    sepa_debit_payments: SepaDebitPayments,
    stripe_balance: StripeBalance,
    swish_payments: SwishPayments,
    twint_payments: TwintPayments,
    us_bank_transfer_payments: UsBankTransferPayments,
    zip_payments: ZipPayments,
  }
end