Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_debit_paymentsObject (readonly)

Allow the merchant to process ACH debit payments.



819
820
821
# File 'lib/stripe/resources/v2/core/account.rb', line 819

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject (readonly)

Allow the merchant to process ACSS debit payments.



821
822
823
# File 'lib/stripe/resources/v2/core/account.rb', line 821

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject (readonly)

Allow the merchant to process Affirm payments.



823
824
825
# File 'lib/stripe/resources/v2/core/account.rb', line 823

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject (readonly)

Allow the merchant to process Afterpay/Clearpay payments.



825
826
827
# File 'lib/stripe/resources/v2/core/account.rb', line 825

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject (readonly)

Allow the merchant to process Alma payments.



827
828
829
# File 'lib/stripe/resources/v2/core/account.rb', line 827

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject (readonly)

Allow the merchant to process Amazon Pay payments.



829
830
831
# File 'lib/stripe/resources/v2/core/account.rb', line 829

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject (readonly)

Allow the merchant to process Australian BECS Direct Debit payments.



831
832
833
# File 'lib/stripe/resources/v2/core/account.rb', line 831

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject (readonly)

Allow the merchant to process BACS Direct Debit payments.



833
834
835
# File 'lib/stripe/resources/v2/core/account.rb', line 833

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject (readonly)

Allow the merchant to process Bancontact payments.



835
836
837
# File 'lib/stripe/resources/v2/core/account.rb', line 835

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject (readonly)

Allow the merchant to process BLIK payments.



837
838
839
# File 'lib/stripe/resources/v2/core/account.rb', line 837

def blik_payments
  @blik_payments
end

#boleto_paymentsObject (readonly)

Allow the merchant to process Boleto payments.



839
840
841
# File 'lib/stripe/resources/v2/core/account.rb', line 839

def boleto_payments
  @boleto_payments
end

#card_paymentsObject (readonly)

Allow the merchant to collect card payments.



841
842
843
# File 'lib/stripe/resources/v2/core/account.rb', line 841

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject (readonly)

Allow the merchant to process Cartes Bancaires payments.



843
844
845
# File 'lib/stripe/resources/v2/core/account.rb', line 843

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject (readonly)

Allow the merchant to process Cash App payments.



845
846
847
# File 'lib/stripe/resources/v2/core/account.rb', line 845

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject (readonly)

Allow the merchant to process EPS payments.



847
848
849
# File 'lib/stripe/resources/v2/core/account.rb', line 847

def eps_payments
  @eps_payments
end

#fpx_paymentsObject (readonly)

Allow the merchant to process FPX payments.



849
850
851
# File 'lib/stripe/resources/v2/core/account.rb', line 849

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject (readonly)

Allow the merchant to process UK bank transfer payments.



851
852
853
# File 'lib/stripe/resources/v2/core/account.rb', line 851

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject (readonly)

Allow the merchant to process GrabPay payments.



853
854
855
# File 'lib/stripe/resources/v2/core/account.rb', line 853

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject (readonly)

Allow the merchant to process iDEAL payments.



855
856
857
# File 'lib/stripe/resources/v2/core/account.rb', line 855

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject (readonly)

Allow the merchant to process JCB card payments.



857
858
859
# File 'lib/stripe/resources/v2/core/account.rb', line 857

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Japanese bank transfer payments.



859
860
861
# File 'lib/stripe/resources/v2/core/account.rb', line 859

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject (readonly)

Allow the merchant to process Kakao Pay payments.



861
862
863
# File 'lib/stripe/resources/v2/core/account.rb', line 861

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject (readonly)

Allow the merchant to process Klarna payments.



863
864
865
# File 'lib/stripe/resources/v2/core/account.rb', line 863

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject (readonly)

Allow the merchant to process Konbini convenience store payments.



865
866
867
# File 'lib/stripe/resources/v2/core/account.rb', line 865

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject (readonly)

Allow the merchant to process Korean card payments.



867
868
869
# File 'lib/stripe/resources/v2/core/account.rb', line 867

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



869
870
871
# File 'lib/stripe/resources/v2/core/account.rb', line 869

def link_payments
  @link_payments
end

#mobilepay_paymentsObject (readonly)

Allow the merchant to process MobilePay payments.



871
872
873
# File 'lib/stripe/resources/v2/core/account.rb', line 871

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject (readonly)

Allow the merchant to process Multibanco payments.



873
874
875
# File 'lib/stripe/resources/v2/core/account.rb', line 873

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Mexican bank transfer payments.



875
876
877
# File 'lib/stripe/resources/v2/core/account.rb', line 875

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



877
878
879
# File 'lib/stripe/resources/v2/core/account.rb', line 877

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject (readonly)

Allow the merchant to process OXXO payments.



879
880
881
# File 'lib/stripe/resources/v2/core/account.rb', line 879

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject (readonly)

Allow the merchant to process Przelewy24 (P24) payments.



881
882
883
# File 'lib/stripe/resources/v2/core/account.rb', line 881

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject (readonly)

Allow the merchant to process Pay by Bank payments.



883
884
885
# File 'lib/stripe/resources/v2/core/account.rb', line 883

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject (readonly)

Allow the merchant to process PAYCO payments.



885
886
887
# File 'lib/stripe/resources/v2/core/account.rb', line 885

def payco_payments
  @payco_payments
end

#paynow_paymentsObject (readonly)

Allow the merchant to process PayNow payments.



887
888
889
# File 'lib/stripe/resources/v2/core/account.rb', line 887

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject (readonly)

Allow the merchant to process PromptPay payments.



889
890
891
# File 'lib/stripe/resources/v2/core/account.rb', line 889

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject (readonly)

Allow the merchant to process Revolut Pay payments.



891
892
893
# File 'lib/stripe/resources/v2/core/account.rb', line 891

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject (readonly)

Allow the merchant to process Samsung Pay payments.



893
894
895
# File 'lib/stripe/resources/v2/core/account.rb', line 893

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject (readonly)

Allow the merchant to process SEPA bank transfer payments.



895
896
897
# File 'lib/stripe/resources/v2/core/account.rb', line 895

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject (readonly)

Allow the merchant to process SEPA Direct Debit payments.



897
898
899
# File 'lib/stripe/resources/v2/core/account.rb', line 897

def sepa_debit_payments
  @sepa_debit_payments
end

#stripe_balanceObject (readonly)

Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).



899
900
901
# File 'lib/stripe/resources/v2/core/account.rb', line 899

def stripe_balance
  @stripe_balance
end

#swish_paymentsObject (readonly)

Allow the merchant to process Swish payments.



901
902
903
# File 'lib/stripe/resources/v2/core/account.rb', line 901

def swish_payments
  @swish_payments
end

#twint_paymentsObject (readonly)

Allow the merchant to process TWINT payments.



903
904
905
# File 'lib/stripe/resources/v2/core/account.rb', line 903

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject (readonly)

Allow the merchant to process US bank transfer payments.



905
906
907
# File 'lib/stripe/resources/v2/core/account.rb', line 905

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject (readonly)

Allow the merchant to process Zip payments.



907
908
909
# File 'lib/stripe/resources/v2/core/account.rb', line 907

def zip_payments
  @zip_payments
end