Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Merchant::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, StripeBalance, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_debit_payments ⇒ Object
readonly
Allow the merchant to process ACH debit payments.
-
#acss_debit_payments ⇒ Object
readonly
Allow the merchant to process ACSS debit payments.
-
#affirm_payments ⇒ Object
readonly
Allow the merchant to process Affirm payments.
-
#afterpay_clearpay_payments ⇒ Object
readonly
Allow the merchant to process Afterpay/Clearpay payments.
-
#alma_payments ⇒ Object
readonly
Allow the merchant to process Alma payments.
-
#amazon_pay_payments ⇒ Object
readonly
Allow the merchant to process Amazon Pay payments.
-
#au_becs_debit_payments ⇒ Object
readonly
Allow the merchant to process Australian BECS Direct Debit payments.
-
#bacs_debit_payments ⇒ Object
readonly
Allow the merchant to process BACS Direct Debit payments.
-
#bancontact_payments ⇒ Object
readonly
Allow the merchant to process Bancontact payments.
-
#blik_payments ⇒ Object
readonly
Allow the merchant to process BLIK payments.
-
#boleto_payments ⇒ Object
readonly
Allow the merchant to process Boleto payments.
-
#card_payments ⇒ Object
readonly
Allow the merchant to collect card payments.
-
#cartes_bancaires_payments ⇒ Object
readonly
Allow the merchant to process Cartes Bancaires payments.
-
#cashapp_payments ⇒ Object
readonly
Allow the merchant to process Cash App payments.
-
#eps_payments ⇒ Object
readonly
Allow the merchant to process EPS payments.
-
#fpx_payments ⇒ Object
readonly
Allow the merchant to process FPX payments.
-
#gb_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process UK bank transfer payments.
-
#grabpay_payments ⇒ Object
readonly
Allow the merchant to process GrabPay payments.
-
#ideal_payments ⇒ Object
readonly
Allow the merchant to process iDEAL payments.
-
#jcb_payments ⇒ Object
readonly
Allow the merchant to process JCB card payments.
-
#jp_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process Japanese bank transfer payments.
-
#kakao_pay_payments ⇒ Object
readonly
Allow the merchant to process Kakao Pay payments.
-
#klarna_payments ⇒ Object
readonly
Allow the merchant to process Klarna payments.
-
#konbini_payments ⇒ Object
readonly
Allow the merchant to process Konbini convenience store payments.
-
#kr_card_payments ⇒ Object
readonly
Allow the merchant to process Korean card payments.
-
#link_payments ⇒ Object
readonly
Allow the merchant to process Link payments.
-
#mobilepay_payments ⇒ Object
readonly
Allow the merchant to process MobilePay payments.
-
#multibanco_payments ⇒ Object
readonly
Allow the merchant to process Multibanco payments.
-
#mx_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process Mexican bank transfer payments.
-
#naver_pay_payments ⇒ Object
readonly
Allow the merchant to process Naver Pay payments.
-
#oxxo_payments ⇒ Object
readonly
Allow the merchant to process OXXO payments.
-
#p24_payments ⇒ Object
readonly
Allow the merchant to process Przelewy24 (P24) payments.
-
#pay_by_bank_payments ⇒ Object
readonly
Allow the merchant to process Pay by Bank payments.
-
#payco_payments ⇒ Object
readonly
Allow the merchant to process PAYCO payments.
-
#paynow_payments ⇒ Object
readonly
Allow the merchant to process PayNow payments.
-
#promptpay_payments ⇒ Object
readonly
Allow the merchant to process PromptPay payments.
-
#revolut_pay_payments ⇒ Object
readonly
Allow the merchant to process Revolut Pay payments.
-
#samsung_pay_payments ⇒ Object
readonly
Allow the merchant to process Samsung Pay payments.
-
#sepa_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process SEPA bank transfer payments.
-
#sepa_debit_payments ⇒ Object
readonly
Allow the merchant to process SEPA Direct Debit payments.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
-
#swish_payments ⇒ Object
readonly
Allow the merchant to process Swish payments.
-
#twint_payments ⇒ Object
readonly
Allow the merchant to process TWINT payments.
-
#us_bank_transfer_payments ⇒ Object
readonly
Allow the merchant to process US bank transfer payments.
-
#zip_payments ⇒ Object
readonly
Allow the merchant to process Zip payments.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_debit_payments ⇒ Object (readonly)
Allow the merchant to process ACH debit payments.
1664 1665 1666 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1664 def ach_debit_payments @ach_debit_payments end |
#acss_debit_payments ⇒ Object (readonly)
Allow the merchant to process ACSS debit payments.
1666 1667 1668 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1666 def acss_debit_payments @acss_debit_payments end |
#affirm_payments ⇒ Object (readonly)
Allow the merchant to process Affirm payments.
1668 1669 1670 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1668 def affirm_payments @affirm_payments end |
#afterpay_clearpay_payments ⇒ Object (readonly)
Allow the merchant to process Afterpay/Clearpay payments.
1670 1671 1672 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1670 def afterpay_clearpay_payments @afterpay_clearpay_payments end |
#alma_payments ⇒ Object (readonly)
Allow the merchant to process Alma payments.
1672 1673 1674 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1672 def alma_payments @alma_payments end |
#amazon_pay_payments ⇒ Object (readonly)
Allow the merchant to process Amazon Pay payments.
1674 1675 1676 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1674 def amazon_pay_payments @amazon_pay_payments end |
#au_becs_debit_payments ⇒ Object (readonly)
Allow the merchant to process Australian BECS Direct Debit payments.
1676 1677 1678 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1676 def au_becs_debit_payments @au_becs_debit_payments end |
#bacs_debit_payments ⇒ Object (readonly)
Allow the merchant to process BACS Direct Debit payments.
1678 1679 1680 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1678 def bacs_debit_payments @bacs_debit_payments end |
#bancontact_payments ⇒ Object (readonly)
Allow the merchant to process Bancontact payments.
1680 1681 1682 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1680 def bancontact_payments @bancontact_payments end |
#blik_payments ⇒ Object (readonly)
Allow the merchant to process BLIK payments.
1682 1683 1684 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1682 def blik_payments @blik_payments end |
#boleto_payments ⇒ Object (readonly)
Allow the merchant to process Boleto payments.
1684 1685 1686 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1684 def boleto_payments @boleto_payments end |
#card_payments ⇒ Object (readonly)
Allow the merchant to collect card payments.
1686 1687 1688 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1686 def card_payments @card_payments end |
#cartes_bancaires_payments ⇒ Object (readonly)
Allow the merchant to process Cartes Bancaires payments.
1688 1689 1690 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1688 def cartes_bancaires_payments @cartes_bancaires_payments end |
#cashapp_payments ⇒ Object (readonly)
Allow the merchant to process Cash App payments.
1690 1691 1692 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1690 def cashapp_payments @cashapp_payments end |
#eps_payments ⇒ Object (readonly)
Allow the merchant to process EPS payments.
1692 1693 1694 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1692 def eps_payments @eps_payments end |
#fpx_payments ⇒ Object (readonly)
Allow the merchant to process FPX payments.
1694 1695 1696 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1694 def fpx_payments @fpx_payments end |
#gb_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process UK bank transfer payments.
1696 1697 1698 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1696 def gb_bank_transfer_payments @gb_bank_transfer_payments end |
#grabpay_payments ⇒ Object (readonly)
Allow the merchant to process GrabPay payments.
1698 1699 1700 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1698 def grabpay_payments @grabpay_payments end |
#ideal_payments ⇒ Object (readonly)
Allow the merchant to process iDEAL payments.
1700 1701 1702 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1700 def ideal_payments @ideal_payments end |
#jcb_payments ⇒ Object (readonly)
Allow the merchant to process JCB card payments.
1702 1703 1704 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1702 def jcb_payments @jcb_payments end |
#jp_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process Japanese bank transfer payments.
1704 1705 1706 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1704 def jp_bank_transfer_payments @jp_bank_transfer_payments end |
#kakao_pay_payments ⇒ Object (readonly)
Allow the merchant to process Kakao Pay payments.
1706 1707 1708 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1706 def kakao_pay_payments @kakao_pay_payments end |
#klarna_payments ⇒ Object (readonly)
Allow the merchant to process Klarna payments.
1708 1709 1710 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1708 def klarna_payments @klarna_payments end |
#konbini_payments ⇒ Object (readonly)
Allow the merchant to process Konbini convenience store payments.
1710 1711 1712 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1710 def konbini_payments @konbini_payments end |
#kr_card_payments ⇒ Object (readonly)
Allow the merchant to process Korean card payments.
1712 1713 1714 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1712 def kr_card_payments @kr_card_payments end |
#link_payments ⇒ Object (readonly)
Allow the merchant to process Link payments.
1714 1715 1716 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1714 def link_payments @link_payments end |
#mobilepay_payments ⇒ Object (readonly)
Allow the merchant to process MobilePay payments.
1716 1717 1718 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1716 def mobilepay_payments @mobilepay_payments end |
#multibanco_payments ⇒ Object (readonly)
Allow the merchant to process Multibanco payments.
1718 1719 1720 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1718 def multibanco_payments @multibanco_payments end |
#mx_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process Mexican bank transfer payments.
1720 1721 1722 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1720 def mx_bank_transfer_payments @mx_bank_transfer_payments end |
#naver_pay_payments ⇒ Object (readonly)
Allow the merchant to process Naver Pay payments.
1722 1723 1724 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1722 def naver_pay_payments @naver_pay_payments end |
#oxxo_payments ⇒ Object (readonly)
Allow the merchant to process OXXO payments.
1724 1725 1726 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1724 def oxxo_payments @oxxo_payments end |
#p24_payments ⇒ Object (readonly)
Allow the merchant to process Przelewy24 (P24) payments.
1726 1727 1728 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1726 def p24_payments @p24_payments end |
#pay_by_bank_payments ⇒ Object (readonly)
Allow the merchant to process Pay by Bank payments.
1728 1729 1730 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1728 def pay_by_bank_payments @pay_by_bank_payments end |
#payco_payments ⇒ Object (readonly)
Allow the merchant to process PAYCO payments.
1730 1731 1732 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1730 def payco_payments @payco_payments end |
#paynow_payments ⇒ Object (readonly)
Allow the merchant to process PayNow payments.
1732 1733 1734 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1732 def paynow_payments @paynow_payments end |
#promptpay_payments ⇒ Object (readonly)
Allow the merchant to process PromptPay payments.
1734 1735 1736 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1734 def promptpay_payments @promptpay_payments end |
#revolut_pay_payments ⇒ Object (readonly)
Allow the merchant to process Revolut Pay payments.
1736 1737 1738 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1736 def revolut_pay_payments @revolut_pay_payments end |
#samsung_pay_payments ⇒ Object (readonly)
Allow the merchant to process Samsung Pay payments.
1738 1739 1740 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1738 def samsung_pay_payments @samsung_pay_payments end |
#sepa_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process SEPA bank transfer payments.
1740 1741 1742 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1740 def sepa_bank_transfer_payments @sepa_bank_transfer_payments end |
#sepa_debit_payments ⇒ Object (readonly)
Allow the merchant to process SEPA Direct Debit payments.
1742 1743 1744 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1742 def sepa_debit_payments @sepa_debit_payments end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
1744 1745 1746 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1744 def stripe_balance @stripe_balance end |
#swish_payments ⇒ Object (readonly)
Allow the merchant to process Swish payments.
1746 1747 1748 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1746 def swish_payments @swish_payments end |
#twint_payments ⇒ Object (readonly)
Allow the merchant to process TWINT payments.
1748 1749 1750 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1748 def twint_payments @twint_payments end |
#us_bank_transfer_payments ⇒ Object (readonly)
Allow the merchant to process US bank transfer payments.
1750 1751 1752 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1750 def us_bank_transfer_payments @us_bank_transfer_payments end |
#zip_payments ⇒ Object (readonly)
Allow the merchant to process Zip payments.
1752 1753 1754 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1752 def zip_payments @zip_payments end |
Class Method Details
.field_remappings ⇒ Object
1804 1805 1806 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1804 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1754 def self.inner_class_types @inner_class_types = { ach_debit_payments: AchDebitPayments, acss_debit_payments: AcssDebitPayments, affirm_payments: AffirmPayments, afterpay_clearpay_payments: AfterpayClearpayPayments, alma_payments: AlmaPayments, amazon_pay_payments: AmazonPayPayments, au_becs_debit_payments: AuBecsDebitPayments, bacs_debit_payments: BacsDebitPayments, bancontact_payments: BancontactPayments, blik_payments: BlikPayments, boleto_payments: BoletoPayments, card_payments: CardPayments, cartes_bancaires_payments: CartesBancairesPayments, cashapp_payments: CashappPayments, eps_payments: EpsPayments, fpx_payments: FpxPayments, gb_bank_transfer_payments: GbBankTransferPayments, grabpay_payments: GrabpayPayments, ideal_payments: IdealPayments, jcb_payments: JcbPayments, jp_bank_transfer_payments: JpBankTransferPayments, kakao_pay_payments: KakaoPayPayments, klarna_payments: KlarnaPayments, konbini_payments: KonbiniPayments, kr_card_payments: KrCardPayments, link_payments: LinkPayments, mobilepay_payments: MobilepayPayments, multibanco_payments: MultibancoPayments, mx_bank_transfer_payments: MxBankTransferPayments, naver_pay_payments: NaverPayPayments, oxxo_payments: OxxoPayments, p24_payments: P24Payments, pay_by_bank_payments: PayByBankPayments, payco_payments: PaycoPayments, paynow_payments: PaynowPayments, promptpay_payments: PromptpayPayments, revolut_pay_payments: RevolutPayPayments, samsung_pay_payments: SamsungPayPayments, sepa_bank_transfer_payments: SepaBankTransferPayments, sepa_debit_payments: SepaDebitPayments, stripe_balance: StripeBalance, swish_payments: SwishPayments, twint_payments: TwintPayments, us_bank_transfer_payments: UsBankTransferPayments, zip_payments: ZipPayments, } end |