Class: Stripe::V2::Core::Account::Configuration::Merchant::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_debit_paymentsObject (readonly)

Allow the merchant to process ACH debit payments.



798
799
800
# File 'lib/stripe/resources/v2/core/account.rb', line 798

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject (readonly)

Allow the merchant to process ACSS debit payments.



800
801
802
# File 'lib/stripe/resources/v2/core/account.rb', line 800

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject (readonly)

Allow the merchant to process Affirm payments.



802
803
804
# File 'lib/stripe/resources/v2/core/account.rb', line 802

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject (readonly)

Allow the merchant to process Afterpay/Clearpay payments.



804
805
806
# File 'lib/stripe/resources/v2/core/account.rb', line 804

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject (readonly)

Allow the merchant to process Alma payments.



806
807
808
# File 'lib/stripe/resources/v2/core/account.rb', line 806

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject (readonly)

Allow the merchant to process Amazon Pay payments.



808
809
810
# File 'lib/stripe/resources/v2/core/account.rb', line 808

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject (readonly)

Allow the merchant to process Australian BECS Direct Debit payments.



810
811
812
# File 'lib/stripe/resources/v2/core/account.rb', line 810

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject (readonly)

Allow the merchant to process BACS Direct Debit payments.



812
813
814
# File 'lib/stripe/resources/v2/core/account.rb', line 812

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject (readonly)

Allow the merchant to process Bancontact payments.



814
815
816
# File 'lib/stripe/resources/v2/core/account.rb', line 814

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject (readonly)

Allow the merchant to process BLIK payments.



816
817
818
# File 'lib/stripe/resources/v2/core/account.rb', line 816

def blik_payments
  @blik_payments
end

#boleto_paymentsObject (readonly)

Allow the merchant to process Boleto payments.



818
819
820
# File 'lib/stripe/resources/v2/core/account.rb', line 818

def boleto_payments
  @boleto_payments
end

#card_paymentsObject (readonly)

Allow the merchant to collect card payments.



820
821
822
# File 'lib/stripe/resources/v2/core/account.rb', line 820

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject (readonly)

Allow the merchant to process Cartes Bancaires payments.



822
823
824
# File 'lib/stripe/resources/v2/core/account.rb', line 822

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject (readonly)

Allow the merchant to process Cash App payments.



824
825
826
# File 'lib/stripe/resources/v2/core/account.rb', line 824

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject (readonly)

Allow the merchant to process EPS payments.



826
827
828
# File 'lib/stripe/resources/v2/core/account.rb', line 826

def eps_payments
  @eps_payments
end

#fpx_paymentsObject (readonly)

Allow the merchant to process FPX payments.



828
829
830
# File 'lib/stripe/resources/v2/core/account.rb', line 828

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject (readonly)

Allow the merchant to process UK bank transfer payments.



830
831
832
# File 'lib/stripe/resources/v2/core/account.rb', line 830

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject (readonly)

Allow the merchant to process GrabPay payments.



832
833
834
# File 'lib/stripe/resources/v2/core/account.rb', line 832

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject (readonly)

Allow the merchant to process iDEAL payments.



834
835
836
# File 'lib/stripe/resources/v2/core/account.rb', line 834

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject (readonly)

Allow the merchant to process JCB card payments.



836
837
838
# File 'lib/stripe/resources/v2/core/account.rb', line 836

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Japanese bank transfer payments.



838
839
840
# File 'lib/stripe/resources/v2/core/account.rb', line 838

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject (readonly)

Allow the merchant to process Kakao Pay payments.



840
841
842
# File 'lib/stripe/resources/v2/core/account.rb', line 840

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject (readonly)

Allow the merchant to process Klarna payments.



842
843
844
# File 'lib/stripe/resources/v2/core/account.rb', line 842

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject (readonly)

Allow the merchant to process Konbini convenience store payments.



844
845
846
# File 'lib/stripe/resources/v2/core/account.rb', line 844

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject (readonly)

Allow the merchant to process Korean card payments.



846
847
848
# File 'lib/stripe/resources/v2/core/account.rb', line 846

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



848
849
850
# File 'lib/stripe/resources/v2/core/account.rb', line 848

def link_payments
  @link_payments
end

#mobilepay_paymentsObject (readonly)

Allow the merchant to process MobilePay payments.



850
851
852
# File 'lib/stripe/resources/v2/core/account.rb', line 850

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject (readonly)

Allow the merchant to process Multibanco payments.



852
853
854
# File 'lib/stripe/resources/v2/core/account.rb', line 852

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject (readonly)

Allow the merchant to process Mexican bank transfer payments.



854
855
856
# File 'lib/stripe/resources/v2/core/account.rb', line 854

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



856
857
858
# File 'lib/stripe/resources/v2/core/account.rb', line 856

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject (readonly)

Allow the merchant to process OXXO payments.



858
859
860
# File 'lib/stripe/resources/v2/core/account.rb', line 858

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject (readonly)

Allow the merchant to process Przelewy24 (P24) payments.



860
861
862
# File 'lib/stripe/resources/v2/core/account.rb', line 860

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject (readonly)

Allow the merchant to process Pay by Bank payments.



862
863
864
# File 'lib/stripe/resources/v2/core/account.rb', line 862

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject (readonly)

Allow the merchant to process PAYCO payments.



864
865
866
# File 'lib/stripe/resources/v2/core/account.rb', line 864

def payco_payments
  @payco_payments
end

#paynow_paymentsObject (readonly)

Allow the merchant to process PayNow payments.



866
867
868
# File 'lib/stripe/resources/v2/core/account.rb', line 866

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject (readonly)

Allow the merchant to process PromptPay payments.



868
869
870
# File 'lib/stripe/resources/v2/core/account.rb', line 868

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject (readonly)

Allow the merchant to process Revolut Pay payments.



870
871
872
# File 'lib/stripe/resources/v2/core/account.rb', line 870

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject (readonly)

Allow the merchant to process Samsung Pay payments.



872
873
874
# File 'lib/stripe/resources/v2/core/account.rb', line 872

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject (readonly)

Allow the merchant to process SEPA bank transfer payments.



874
875
876
# File 'lib/stripe/resources/v2/core/account.rb', line 874

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject (readonly)

Allow the merchant to process SEPA Direct Debit payments.



876
877
878
# File 'lib/stripe/resources/v2/core/account.rb', line 876

def sepa_debit_payments
  @sepa_debit_payments
end

#swish_paymentsObject (readonly)

Allow the merchant to process Swish payments.



878
879
880
# File 'lib/stripe/resources/v2/core/account.rb', line 878

def swish_payments
  @swish_payments
end

#twint_paymentsObject (readonly)

Allow the merchant to process TWINT payments.



880
881
882
# File 'lib/stripe/resources/v2/core/account.rb', line 880

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject (readonly)

Allow the merchant to process US bank transfer payments.



882
883
884
# File 'lib/stripe/resources/v2/core/account.rb', line 882

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject (readonly)

Allow the merchant to process Zip payments.



884
885
886
# File 'lib/stripe/resources/v2/core/account.rb', line 884

def zip_payments
  @zip_payments
end