Class: Stripe::V2::Core::Account::Configuration::Merchant::StatementDescriptor

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#descriptorObject (readonly)

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.



2404
2405
2406
# File 'lib/stripe/resources/v2/core/account.rb', line 2404

def descriptor
  @descriptor
end

#prefixObject (readonly)

Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge. To maximize space for the dynamic part of the descriptor, keep this text short. If you don’t specify this value, statement_descriptor is used as the prefix. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.



2406
2407
2408
# File 'lib/stripe/resources/v2/core/account.rb', line 2406

def prefix
  @prefix
end

Class Method Details

.field_remappingsObject



2412
2413
2414
# File 'lib/stripe/resources/v2/core/account.rb', line 2412

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2408
2409
2410
# File 'lib/stripe/resources/v2/core/account.rb', line 2408

def self.inner_class_types
  @inner_class_types = {}
end