Class: Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, FinancialAccounts, PaperChecks
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Can send funds from a FinancialAccount to a bank account owned by a different entity.
-
#cards ⇒ Object
readonly
Can send funds from a FinancialAccount to a debit card owned by a different entity.
-
#crypto_wallets ⇒ Object
readonly
Can send funds from a FinancialAccount to a crypto wallet owned by a different entity.
-
#financial_accounts ⇒ Object
readonly
Can send funds from a FinancialAccount to a FinancialAccount owned by a different entity.
-
#paper_checks ⇒ Object
readonly
Can send funds from a FinancialAccount to someone else via paper check.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Can send funds from a FinancialAccount to a bank account owned by a different entity.
11256 11257 11258 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11256 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Can send funds from a FinancialAccount to a debit card owned by a different entity.
11258 11259 11260 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11258 def cards @cards end |
#crypto_wallets ⇒ Object (readonly)
Can send funds from a FinancialAccount to a crypto wallet owned by a different entity.
11260 11261 11262 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11260 def crypto_wallets @crypto_wallets end |
#financial_accounts ⇒ Object (readonly)
Can send funds from a FinancialAccount to a FinancialAccount owned by a different entity.
11262 11263 11264 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11262 def financial_accounts @financial_accounts end |
#paper_checks ⇒ Object (readonly)
Can send funds from a FinancialAccount to someone else via paper check.
11264 11265 11266 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11264 def paper_checks @paper_checks end |
Class Method Details
.field_encodings ⇒ Object
11280 11281 11282 11283 11284 11285 11286 11287 11288 11289 11290 11291 11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 11307 11308 11309 11310 11311 11312 11313 11314 11315 11316 11317 11318 11319 11320 11321 11322 11323 11324 11325 11326 11327 11328 11329 11330 11331 11332 11333 11334 11335 11336 11337 11338 11339 11340 11341 11342 11343 11344 11345 11346 11347 11348 11349 11350 11351 11352 11353 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11280 def self.field_encodings @field_encodings = { bank_accounts: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, cards: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, crypto_wallets: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, financial_accounts: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, paper_checks: { kind: :object, fields: { protections: { kind: :object, fields: { psp_migration: { kind: :object, fields: { expires_at: :int64_string, requested_at: :int64_string }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
11276 11277 11278 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11276 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
11266 11267 11268 11269 11270 11271 11272 11273 11274 |
# File 'lib/stripe/resources/v2/core/account.rb', line 11266 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, cards: Cards, crypto_wallets: CryptoWallets, financial_accounts: FinancialAccounts, paper_checks: PaperChecks, } end |