Class: Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundPayments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundPayments
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, FinancialAccounts
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Can send funds from a FinancialAccount to a bank account owned by a different entity.
-
#cards ⇒ Object
readonly
Can send funds from a FinancialAccount to a debit card owned by a different entity.
-
#financial_accounts ⇒ Object
readonly
Can send funds from a FinancialAccount to a FinancialAccount owned by a different entity.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Can send funds from a FinancialAccount to a bank account owned by a different entity.
2481 2482 2483 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2481 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Can send funds from a FinancialAccount to a debit card owned by a different entity.
2483 2484 2485 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2483 def cards @cards end |
#financial_accounts ⇒ Object (readonly)
Can send funds from a FinancialAccount to a FinancialAccount owned by a different entity.
2485 2486 2487 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2485 def financial_accounts @financial_accounts end |
Class Method Details
.field_remappings ⇒ Object
2495 2496 2497 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2495 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2487 2488 2489 2490 2491 2492 2493 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2487 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, cards: Cards, financial_accounts: FinancialAccounts, } end |