Class: Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundTransfers
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::MoneyManager::Capabilities::OutboundTransfers
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, FinancialAccounts
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Can send funds from a FinancialAccount to a bank account belonging to the same user.
-
#financial_accounts ⇒ Object
readonly
Can send funds from a FinancialAccount to another FinancialAccount belonging to the same user.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Can send funds from a FinancialAccount to a bank account belonging to the same user.
2559 2560 2561 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2559 def bank_accounts @bank_accounts end |
#financial_accounts ⇒ Object (readonly)
Can send funds from a FinancialAccount to another FinancialAccount belonging to the same user.
2561 2562 2563 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2561 def financial_accounts @financial_accounts end |
Class Method Details
.field_remappings ⇒ Object
2570 2571 2572 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2570 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2563 2564 2565 2566 2567 2568 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2563 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, financial_accounts: FinancialAccounts, } end |