Class: Stripe::V2::Core::Account::Configuration::Recipient

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the recipient configuration is active. You can deactivate or reactivate the recipient configuration by updating this property. Deactivating the configuration by setting this value to false unrequest all capabilities within the configuration. It will not delete any of the configuration's other properties.



2061
2062
2063
# File 'lib/stripe/resources/v2/core/account.rb', line 2061

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Recipient Configuration.



2063
2064
2065
# File 'lib/stripe/resources/v2/core/account.rb', line 2063

def capabilities
  @capabilities
end

Class Method Details

.field_remappingsObject



2069
2070
2071
# File 'lib/stripe/resources/v2/core/account.rb', line 2069

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2065
2066
2067
# File 'lib/stripe/resources/v2/core/account.rb', line 2065

def self.inner_class_types
  @inner_class_types = { capabilities: Capabilities }
end