Class: Stripe::V2::Core::Account::Configuration::Recipient
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Capabilities, DefaultOutboundDestination
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the recipient configuration is active.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Recipient Configuration.
-
#default_outbound_destination ⇒ Object
readonly
The payout method to be used as a default outbound destination.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the recipient configuration is active. You can deactivate or reactivate the recipient configuration by updating this property. Deactivating the configuration by setting this value to false unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.
2184 2185 2186 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2184 def applied @applied end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Recipient Configuration.
2186 2187 2188 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2186 def capabilities @capabilities end |
#default_outbound_destination ⇒ Object (readonly)
The payout method to be used as a default outbound destination. This will allow the PayoutMethod to be omitted on OutboundPayments made through the dashboard or APIs.
2188 2189 2190 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2188 def default_outbound_destination @default_outbound_destination end |
Class Method Details
.field_remappings ⇒ Object
2197 2198 2199 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2197 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2190 2191 2192 2193 2194 2195 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2190 def self.inner_class_types @inner_class_types = { capabilities: Capabilities, default_outbound_destination: DefaultOutboundDestination, } end |