Class: Stripe::V2::Core::Account::Configuration::Recipient

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, DefaultOutboundDestination

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the recipient configuration is active. You can deactivate or reactivate the recipient configuration by updating this property. Deactivating the configuration by setting this value to false unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.



2152
2153
2154
# File 'lib/stripe/resources/v2/core/account.rb', line 2152

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Recipient Configuration.



2154
2155
2156
# File 'lib/stripe/resources/v2/core/account.rb', line 2154

def capabilities
  @capabilities
end

#default_outbound_destinationObject (readonly)

The payout method to be used as a default outbound destination. This will allow the PayoutMethod to be omitted on OutboundPayments made through the dashboard or APIs.



2156
2157
2158
# File 'lib/stripe/resources/v2/core/account.rb', line 2156

def default_outbound_destination
  @default_outbound_destination
end

Class Method Details

.field_remappingsObject



2165
2166
2167
# File 'lib/stripe/resources/v2/core/account.rb', line 2165

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2158
2159
2160
2161
2162
2163
# File 'lib/stripe/resources/v2/core/account.rb', line 2158

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    default_outbound_destination: DefaultOutboundDestination,
  }
end