Class: Stripe::V2::Core::Account::Configuration::Recipient
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Capabilities, DefaultOutboundDestination
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the recipient configuration is active.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Recipient Configuration.
-
#default_outbound_destination ⇒ Object
readonly
The payout method to be used as a default outbound destination.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the recipient configuration is active. You can deactivate or reactivate the recipient configuration by updating this property. Deactivating the configuration by setting this value to false unrequest all capabilities within the configuration. It will not delete any of the configuration’s other properties.
2521 2522 2523 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2521 def applied @applied end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Recipient Configuration.
2523 2524 2525 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2523 def capabilities @capabilities end |
#default_outbound_destination ⇒ Object (readonly)
The payout method to be used as a default outbound destination. This will allow the PayoutMethod to be omitted on OutboundPayments made through the dashboard or APIs.
2525 2526 2527 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2525 def default_outbound_destination @default_outbound_destination end |
Class Method Details
.field_remappings ⇒ Object
2534 2535 2536 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2534 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2527 2528 2529 2530 2531 2532 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2527 def self.inner_class_types @inner_class_types = { capabilities: Capabilities, default_outbound_destination: DefaultOutboundDestination, } end |