Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
readonly
Enables this Account to receive OutboundPayments to a linked debit card.
-
#crypto_wallets ⇒ Object
readonly
Enables this Account to receive OutboundPayments to a linked crypto wallet.
-
#paper_checks ⇒ Object
readonly
Capabilities that enable OutboundPayments via paper check.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Capabilities that enable OutboundPayments to a bank account linked to this Account.
2799 2800 2801 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2799 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to a linked debit card.
2801 2802 2803 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2801 def cards @cards end |
#crypto_wallets ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to a linked crypto wallet.
2803 2804 2805 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2803 def crypto_wallets @crypto_wallets end |
#paper_checks ⇒ Object (readonly)
Capabilities that enable OutboundPayments via paper check.
2805 2806 2807 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2805 def paper_checks @paper_checks end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
2807 2808 2809 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2807 def stripe_balance @stripe_balance end |
Class Method Details
.field_remappings ⇒ Object
2819 2820 2821 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2819 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2809 2810 2811 2812 2813 2814 2815 2816 2817 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2809 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, cards: Cards, crypto_wallets: CryptoWallets, paper_checks: PaperChecks, stripe_balance: StripeBalance, } end |