Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
readonly
Enables this Account to receive OutboundPayments to a linked debit card.
-
#crypto_wallets ⇒ Object
readonly
Enables this Account to receive OutboundPayments to a linked crypto wallet.
-
#paper_checks ⇒ Object
readonly
Capabilities that enable OutboundPayments via paper check.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Capabilities that enable OutboundPayments to a bank account linked to this Account.
2768 2769 2770 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2768 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to a linked debit card.
2770 2771 2772 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2770 def cards @cards end |
#crypto_wallets ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to a linked crypto wallet.
2772 2773 2774 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2772 def crypto_wallets @crypto_wallets end |
#paper_checks ⇒ Object (readonly)
Capabilities that enable OutboundPayments via paper check.
2774 2775 2776 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2774 def paper_checks @paper_checks end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
2776 2777 2778 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2776 def stripe_balance @stripe_balance end |
Class Method Details
.field_remappings ⇒ Object
2788 2789 2790 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2788 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2778 2779 2780 2781 2782 2783 2784 2785 2786 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2778 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, cards: Cards, crypto_wallets: CryptoWallets, paper_checks: PaperChecks, stripe_balance: StripeBalance, } end |