Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccounts, Cards, StripeBalance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_accountsObject (readonly)

Capabilities that enable OutboundPayments to a bank account linked to this Account.



2150
2151
2152
# File 'lib/stripe/resources/v2/core/account.rb', line 2150

def bank_accounts
  @bank_accounts
end

#cardsObject (readonly)

Enables this Account to receive OutboundPayments to a linked debit card.



2152
2153
2154
# File 'lib/stripe/resources/v2/core/account.rb', line 2152

def cards
  @cards
end

#stripe_balanceObject (readonly)

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



2154
2155
2156
# File 'lib/stripe/resources/v2/core/account.rb', line 2154

def stripe_balance
  @stripe_balance
end

Class Method Details

.field_remappingsObject



2164
2165
2166
# File 'lib/stripe/resources/v2/core/account.rb', line 2164

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2156
2157
2158
2159
2160
2161
2162
# File 'lib/stripe/resources/v2/core/account.rb', line 2156

def self.inner_class_types
  @inner_class_types = {
    bank_accounts: BankAccounts,
    cards: Cards,
    stripe_balance: StripeBalance,
  }
end