Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_accountsObject (readonly)

Capabilities that enable OutboundPayments to a bank account linked to this Account.



2769
2770
2771
# File 'lib/stripe/resources/v2/core/account.rb', line 2769

def bank_accounts
  @bank_accounts
end

#cardsObject (readonly)

Enables this Account to receive OutboundPayments to a linked debit card.



2771
2772
2773
# File 'lib/stripe/resources/v2/core/account.rb', line 2771

def cards
  @cards
end

#crypto_walletsObject (readonly)

Enables this Account to receive OutboundPayments to a linked crypto wallet.



2773
2774
2775
# File 'lib/stripe/resources/v2/core/account.rb', line 2773

def crypto_wallets
  @crypto_wallets
end

#paper_checksObject (readonly)

Capabilities that enable OutboundPayments via paper check.



2775
2776
2777
# File 'lib/stripe/resources/v2/core/account.rb', line 2775

def paper_checks
  @paper_checks
end

#stripe_balanceObject (readonly)

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



2777
2778
2779
# File 'lib/stripe/resources/v2/core/account.rb', line 2777

def stripe_balance
  @stripe_balance
end

Class Method Details

.field_remappingsObject



2789
2790
2791
# File 'lib/stripe/resources/v2/core/account.rb', line 2789

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/stripe/resources/v2/core/account.rb', line 2779

def self.inner_class_types
  @inner_class_types = {
    bank_accounts: BankAccounts,
    cards: Cards,
    crypto_wallets: CryptoWallets,
    paper_checks: PaperChecks,
    stripe_balance: StripeBalance,
  }
end