Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, StripeBalance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
readonly
Enables this Account to receive OutboundPayments to a linked debit card.
-
#crypto_wallets ⇒ Object
readonly
Enables this Account to receive OutboundPayments to a linked crypto wallet.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Capabilities that enable OutboundPayments to a bank account linked to this Account.
2484 2485 2486 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2484 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to a linked debit card.
2486 2487 2488 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2486 def cards @cards end |
#crypto_wallets ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to a linked crypto wallet.
2488 2489 2490 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2488 def crypto_wallets @crypto_wallets end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
2490 2491 2492 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2490 def stripe_balance @stripe_balance end |
Class Method Details
.field_remappings ⇒ Object
2501 2502 2503 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2501 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2492 2493 2494 2495 2496 2497 2498 2499 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2492 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, cards: Cards, crypto_wallets: CryptoWallets, stripe_balance: StripeBalance, } end |