Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_accountsObject (readonly)

Capabilities that enable OutboundPayments to a bank account linked to this Account.



2571
2572
2573
# File 'lib/stripe/resources/v2/core/account.rb', line 2571

def bank_accounts
  @bank_accounts
end

#cardsObject (readonly)

Capability that enable OutboundPayments to a debit card linked to this Account.



2573
2574
2575
# File 'lib/stripe/resources/v2/core/account.rb', line 2573

def cards
  @cards
end

#crypto_walletsObject (readonly)

Capability that enable OutboundPayments to a crypto wallet linked to this Account.



2575
2576
2577
# File 'lib/stripe/resources/v2/core/account.rb', line 2575

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject (readonly)

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



2577
2578
2579
# File 'lib/stripe/resources/v2/core/account.rb', line 2577

def stripe_balance
  @stripe_balance
end

Class Method Details

.field_remappingsObject



2588
2589
2590
# File 'lib/stripe/resources/v2/core/account.rb', line 2588

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2579
2580
2581
2582
2583
2584
2585
2586
# File 'lib/stripe/resources/v2/core/account.rb', line 2579

def self.inner_class_types
  @inner_class_types = {
    bank_accounts: BankAccounts,
    cards: Cards,
    crypto_wallets: CryptoWallets,
    stripe_balance: StripeBalance,
  }
end