Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, StripeBalance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
readonly
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#crypto_wallets ⇒ Object
readonly
Capability that enable OutboundPayments to a crypto wallet linked to this Account.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Capabilities that enable OutboundPayments to a bank account linked to this Account.
2432 2433 2434 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2432 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Capability that enable OutboundPayments to a debit card linked to this Account.
2434 2435 2436 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2434 def cards @cards end |
#crypto_wallets ⇒ Object (readonly)
Capability that enable OutboundPayments to a crypto wallet linked to this Account.
2436 2437 2438 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2436 def crypto_wallets @crypto_wallets end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
2438 2439 2440 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2438 def stripe_balance @stripe_balance end |
Class Method Details
.field_remappings ⇒ Object
2449 2450 2451 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2449 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2440 2441 2442 2443 2444 2445 2446 2447 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2440 def self.inner_class_types @inner_class_types = { bank_accounts: BankAccounts, cards: Cards, crypto_wallets: CryptoWallets, stripe_balance: StripeBalance, } end |