Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccounts, Cards, StripeBalance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
readonly
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
readonly
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#stripe_balance ⇒ Object
readonly
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_accounts ⇒ Object (readonly)
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1068 1069 1070 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1068 def bank_accounts @bank_accounts end |
#cards ⇒ Object (readonly)
Capability that enable OutboundPayments to a debit card linked to this Account.
1070 1071 1072 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1070 def cards @cards end |
#stripe_balance ⇒ Object (readonly)
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1072 1073 1074 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1072 def stripe_balance @stripe_balance end |