Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::BankAccounts
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::BankAccounts
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#instant ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
-
#local ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
-
#wire ⇒ Object
readonly
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#instant ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
2595 2596 2597 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2595 def instant @instant end |
#local ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
2597 2598 2599 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2597 def local @local end |
#wire ⇒ Object (readonly)
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
2599 2600 2601 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2599 def wire @wire end |
Class Method Details
.field_remappings ⇒ Object
2605 2606 2607 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2605 def self.field_remappings @field_remappings = {} end |