Class: Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Recipient::Capabilities::StripeBalance
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Payouts, StripeTransfers
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payouts ⇒ Object
readonly
Allows the account to do payouts using their Stripe Balance (/v1/balance).
-
#stripe_transfers ⇒ Object
readonly
Allows the account to receive /v1/transfers into their Stripe Balance (/v1/balance).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payouts ⇒ Object (readonly)
Allows the account to do payouts using their Stripe Balance (/v1/balance).
1059 1060 1061 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1059 def payouts @payouts end |
#stripe_transfers ⇒ Object (readonly)
Allows the account to receive /v1/transfers into their Stripe Balance (/v1/balance).
1061 1062 1063 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1061 def stripe_transfers @stripe_transfers end |