Class: Stripe::V2::Core::Account::Configuration::Storer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Capabilities
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the storer configuration is active.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Storer Configuration.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the storer configuration is active. You cannot deactivate (or reactivate) the storer configuration by updating this property.
2596 2597 2598 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2596 def applied @applied end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Storer Configuration.
2598 2599 2600 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2598 def capabilities @capabilities end |
Class Method Details
.field_remappings ⇒ Object
2604 2605 2606 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2604 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2600 2601 2602 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2600 def self.inner_class_types @inner_class_types = { capabilities: Capabilities } end |