Class: Stripe::V2::Core::Account::Configuration::Storer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the storer configuration is active. You cannot deactivate (or reactivate) the storer configuration by updating this property.



3454
3455
3456
# File 'lib/stripe/resources/v2/core/account.rb', line 3454

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Storer Configuration.



3456
3457
3458
# File 'lib/stripe/resources/v2/core/account.rb', line 3456

def capabilities
  @capabilities
end

#high_risk_activitiesObject (readonly)

List of high-risk activities the business is involved in.



3458
3459
3460
# File 'lib/stripe/resources/v2/core/account.rb', line 3458

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject (readonly)

Description of the high-risk activities the business offers.



3460
3461
3462
# File 'lib/stripe/resources/v2/core/account.rb', line 3460

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject (readonly)

Description of the money services offered by the business.



3462
3463
3464
# File 'lib/stripe/resources/v2/core/account.rb', line 3462

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject (readonly)

Indicates whether the business operates in any prohibited countries.



3464
3465
3466
# File 'lib/stripe/resources/v2/core/account.rb', line 3464

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject (readonly)

Does the business participate in any regulated activity.



3466
3467
3468
# File 'lib/stripe/resources/v2/core/account.rb', line 3466

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject (readonly)

Primary purpose of the stored funds.



3468
3469
3470
# File 'lib/stripe/resources/v2/core/account.rb', line 3468

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject (readonly)

Description of the purpose of the stored funds.



3470
3471
3472
# File 'lib/stripe/resources/v2/core/account.rb', line 3470

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject (readonly)

Details of the regulated activity if the business participates in one.



3472
3473
3474
# File 'lib/stripe/resources/v2/core/account.rb', line 3472

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject (readonly)

The source of funds for the business, e.g. profits, income, venture capital, etc.



3474
3475
3476
# File 'lib/stripe/resources/v2/core/account.rb', line 3474

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject (readonly)

Description of the source of funds for the business’ account.



3476
3477
3478
# File 'lib/stripe/resources/v2/core/account.rb', line 3476

def source_of_funds_description
  @source_of_funds_description
end

Class Method Details

.field_remappingsObject



3485
3486
3487
# File 'lib/stripe/resources/v2/core/account.rb', line 3485

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3478
3479
3480
3481
3482
3483
# File 'lib/stripe/resources/v2/core/account.rb', line 3478

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    regulated_activity: RegulatedActivity,
  }
end