Class: Stripe::V2::Core::Account::Configuration::Storer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Indicates whether the storer configuration is active. You cannot deactivate (or reactivate) the storer configuration by updating this property.



3390
3391
3392
# File 'lib/stripe/resources/v2/core/account.rb', line 3390

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Storer Configuration.



3392
3393
3394
# File 'lib/stripe/resources/v2/core/account.rb', line 3392

def capabilities
  @capabilities
end

#high_risk_activitiesObject (readonly)

List of high-risk activities the business is involved in.



3394
3395
3396
# File 'lib/stripe/resources/v2/core/account.rb', line 3394

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject (readonly)

Description of the high-risk activities the business offers.



3396
3397
3398
# File 'lib/stripe/resources/v2/core/account.rb', line 3396

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject (readonly)

Description of the money services offered by the business.



3398
3399
3400
# File 'lib/stripe/resources/v2/core/account.rb', line 3398

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject (readonly)

Indicates whether the business operates in any prohibited countries.



3400
3401
3402
# File 'lib/stripe/resources/v2/core/account.rb', line 3400

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject (readonly)

Does the business participate in any regulated activity.



3402
3403
3404
# File 'lib/stripe/resources/v2/core/account.rb', line 3402

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject (readonly)

Primary purpose of the stored funds.



3404
3405
3406
# File 'lib/stripe/resources/v2/core/account.rb', line 3404

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject (readonly)

Description of the purpose of the stored funds.



3406
3407
3408
# File 'lib/stripe/resources/v2/core/account.rb', line 3406

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject (readonly)

Details of the regulated activity if the business participates in one.



3408
3409
3410
# File 'lib/stripe/resources/v2/core/account.rb', line 3408

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject (readonly)

The source of funds for the business, e.g. profits, income, venture capital, etc.



3410
3411
3412
# File 'lib/stripe/resources/v2/core/account.rb', line 3410

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject (readonly)

Description of the source of funds for the business’ account.



3412
3413
3414
# File 'lib/stripe/resources/v2/core/account.rb', line 3412

def source_of_funds_description
  @source_of_funds_description
end

Class Method Details

.field_remappingsObject



3421
3422
3423
# File 'lib/stripe/resources/v2/core/account.rb', line 3421

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3414
3415
3416
3417
3418
3419
# File 'lib/stripe/resources/v2/core/account.rb', line 3414

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    regulated_activity: RegulatedActivity,
  }
end