Class: Stripe::V2::Core::Account::Configuration::Storer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Capabilities, RegulatedActivity
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Indicates whether the storer configuration is active.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Storer Configuration.
-
#high_risk_activities ⇒ Object
readonly
List of high-risk activities the business is involved in.
-
#high_risk_activities_description ⇒ Object
readonly
Description of the high-risk activities the business offers.
-
#money_services_description ⇒ Object
readonly
Description of the money services offered by the business.
-
#operates_in_prohibited_countries ⇒ Object
readonly
Indicates whether the business operates in any prohibited countries.
-
#participates_in_regulated_activity ⇒ Object
readonly
Does the business participate in any regulated activity.
-
#purpose_of_funds ⇒ Object
readonly
Primary purpose of the stored funds.
-
#purpose_of_funds_description ⇒ Object
readonly
Description of the purpose of the stored funds.
-
#regulated_activity ⇒ Object
readonly
Details of the regulated activity if the business participates in one.
-
#source_of_funds ⇒ Object
readonly
The source of funds for the business, e.g.
-
#source_of_funds_description ⇒ Object
readonly
Description of the source of funds for the business’ account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Indicates whether the storer configuration is active. You cannot deactivate (or reactivate) the storer configuration by updating this property.
3166 3167 3168 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3166 def applied @applied end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Storer Configuration.
3168 3169 3170 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3168 def capabilities @capabilities end |
#high_risk_activities ⇒ Object (readonly)
List of high-risk activities the business is involved in.
3170 3171 3172 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3170 def high_risk_activities @high_risk_activities end |
#high_risk_activities_description ⇒ Object (readonly)
Description of the high-risk activities the business offers.
3172 3173 3174 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3172 def high_risk_activities_description @high_risk_activities_description end |
#money_services_description ⇒ Object (readonly)
Description of the money services offered by the business.
3174 3175 3176 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3174 def money_services_description @money_services_description end |
#operates_in_prohibited_countries ⇒ Object (readonly)
Indicates whether the business operates in any prohibited countries.
3176 3177 3178 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3176 def operates_in_prohibited_countries @operates_in_prohibited_countries end |
#participates_in_regulated_activity ⇒ Object (readonly)
Does the business participate in any regulated activity.
3178 3179 3180 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3178 def participates_in_regulated_activity @participates_in_regulated_activity end |
#purpose_of_funds ⇒ Object (readonly)
Primary purpose of the stored funds.
3180 3181 3182 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3180 def purpose_of_funds @purpose_of_funds end |
#purpose_of_funds_description ⇒ Object (readonly)
Description of the purpose of the stored funds.
3182 3183 3184 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3182 def purpose_of_funds_description @purpose_of_funds_description end |
#regulated_activity ⇒ Object (readonly)
Details of the regulated activity if the business participates in one.
3184 3185 3186 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3184 def regulated_activity @regulated_activity end |
#source_of_funds ⇒ Object (readonly)
The source of funds for the business, e.g. profits, income, venture capital, etc.
3186 3187 3188 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3186 def source_of_funds @source_of_funds end |
#source_of_funds_description ⇒ Object (readonly)
Description of the source of funds for the business’ account.
3188 3189 3190 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3188 def source_of_funds_description @source_of_funds_description end |
Class Method Details
.field_remappings ⇒ Object
3197 3198 3199 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3197 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3190 3191 3192 3193 3194 3195 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3190 def self.inner_class_types @inner_class_types = { capabilities: Capabilities, regulated_activity: RegulatedActivity, } end |