Class: Stripe::V2::Core::Account::Configuration::Storer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



3193
3194
3195
# File 'lib/stripe/resources/v2/core/account.rb', line 3193

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Storer Configuration.



3195
3196
3197
# File 'lib/stripe/resources/v2/core/account.rb', line 3195

def capabilities
  @capabilities
end

#high_risk_activitiesObject (readonly)

List of high-risk activities the business is involved in.



3197
3198
3199
# File 'lib/stripe/resources/v2/core/account.rb', line 3197

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject (readonly)

An explanation of the high risk activities that the business performs.



3199
3200
3201
# File 'lib/stripe/resources/v2/core/account.rb', line 3199

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject (readonly)

Description of the money services offered by the business.



3201
3202
3203
# File 'lib/stripe/resources/v2/core/account.rb', line 3201

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject (readonly)

Does the business operate in any prohibited countries.



3203
3204
3205
# File 'lib/stripe/resources/v2/core/account.rb', line 3203

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject (readonly)

Does the business participate in any regulated activity.



3205
3206
3207
# File 'lib/stripe/resources/v2/core/account.rb', line 3205

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject (readonly)

Primary purpose of the stored funds.



3207
3208
3209
# File 'lib/stripe/resources/v2/core/account.rb', line 3207

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject (readonly)

Description of the purpose of the stored funds.



3209
3210
3211
# File 'lib/stripe/resources/v2/core/account.rb', line 3209

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject (readonly)

Details of the regulated activity if the business participates in one.



3211
3212
3213
# File 'lib/stripe/resources/v2/core/account.rb', line 3211

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject (readonly)

The source of funds for the business, e.g. profits, income, venture capital, etc.



3213
3214
3215
# File 'lib/stripe/resources/v2/core/account.rb', line 3213

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject (readonly)

Description of the source of funds for the business’ account.



3215
3216
3217
# File 'lib/stripe/resources/v2/core/account.rb', line 3215

def source_of_funds_description
  @source_of_funds_description
end

Class Method Details

.field_remappingsObject



3224
3225
3226
# File 'lib/stripe/resources/v2/core/account.rb', line 3224

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3217
3218
3219
3220
3221
3222
# File 'lib/stripe/resources/v2/core/account.rb', line 3217

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    regulated_activity: RegulatedActivity,
  }
end