Class: Stripe::V2::Core::Account::Configuration::Storer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



3021
3022
3023
# File 'lib/stripe/resources/v2/core/account.rb', line 3021

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Storer Configuration.



3023
3024
3025
# File 'lib/stripe/resources/v2/core/account.rb', line 3023

def capabilities
  @capabilities
end

#high_risk_activitiesObject (readonly)

List of high-risk activities the business is involved in.



3025
3026
3027
# File 'lib/stripe/resources/v2/core/account.rb', line 3025

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject (readonly)

An explanation of the high risk activities that the business performs.



3027
3028
3029
# File 'lib/stripe/resources/v2/core/account.rb', line 3027

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject (readonly)

Description of the money services offered by the business.



3029
3030
3031
# File 'lib/stripe/resources/v2/core/account.rb', line 3029

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject (readonly)

Does the business operate in any prohibited countries.



3031
3032
3033
# File 'lib/stripe/resources/v2/core/account.rb', line 3031

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject (readonly)

Does the business participate in any regulated activity.



3033
3034
3035
# File 'lib/stripe/resources/v2/core/account.rb', line 3033

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject (readonly)

Primary purpose of the stored funds.



3035
3036
3037
# File 'lib/stripe/resources/v2/core/account.rb', line 3035

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject (readonly)

Description of the purpose of the stored funds.



3037
3038
3039
# File 'lib/stripe/resources/v2/core/account.rb', line 3037

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject (readonly)

Details of the regulated activity if the business participates in one.



3039
3040
3041
# File 'lib/stripe/resources/v2/core/account.rb', line 3039

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject (readonly)

The source of funds for the business, e.g. profits, income, venture capital, etc.



3041
3042
3043
# File 'lib/stripe/resources/v2/core/account.rb', line 3041

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject (readonly)

Description of the source of funds for the business’ account.



3043
3044
3045
# File 'lib/stripe/resources/v2/core/account.rb', line 3043

def source_of_funds_description
  @source_of_funds_description
end

Class Method Details

.field_remappingsObject



3052
3053
3054
# File 'lib/stripe/resources/v2/core/account.rb', line 3052

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3045
3046
3047
3048
3049
3050
# File 'lib/stripe/resources/v2/core/account.rb', line 3045

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    regulated_activity: RegulatedActivity,
  }
end