Class: Stripe::V2::Core::Account::Configuration::Storer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



3067
3068
3069
# File 'lib/stripe/resources/v2/core/account.rb', line 3067

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Storer Configuration.



3069
3070
3071
# File 'lib/stripe/resources/v2/core/account.rb', line 3069

def capabilities
  @capabilities
end

#high_risk_activitiesObject (readonly)

List of high-risk activities the business is involved in.



3071
3072
3073
# File 'lib/stripe/resources/v2/core/account.rb', line 3071

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject (readonly)

An explanation of the high risk activities that the business performs.



3073
3074
3075
# File 'lib/stripe/resources/v2/core/account.rb', line 3073

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject (readonly)

Description of the money services offered by the business.



3075
3076
3077
# File 'lib/stripe/resources/v2/core/account.rb', line 3075

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject (readonly)

Does the business operate in any prohibited countries.



3077
3078
3079
# File 'lib/stripe/resources/v2/core/account.rb', line 3077

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject (readonly)

Does the business participate in any regulated activity.



3079
3080
3081
# File 'lib/stripe/resources/v2/core/account.rb', line 3079

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject (readonly)

Primary purpose of the stored funds.



3081
3082
3083
# File 'lib/stripe/resources/v2/core/account.rb', line 3081

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject (readonly)

Description of the purpose of the stored funds.



3083
3084
3085
# File 'lib/stripe/resources/v2/core/account.rb', line 3083

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject (readonly)

Details of the regulated activity if the business participates in one.



3085
3086
3087
# File 'lib/stripe/resources/v2/core/account.rb', line 3085

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject (readonly)

The source of funds for the business, e.g. profits, income, venture capital, etc.



3087
3088
3089
# File 'lib/stripe/resources/v2/core/account.rb', line 3087

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject (readonly)

Description of the source of funds for the business’ account.



3089
3090
3091
# File 'lib/stripe/resources/v2/core/account.rb', line 3089

def source_of_funds_description
  @source_of_funds_description
end

Class Method Details

.field_remappingsObject



3098
3099
3100
# File 'lib/stripe/resources/v2/core/account.rb', line 3098

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3091
3092
3093
3094
3095
3096
# File 'lib/stripe/resources/v2/core/account.rb', line 3091

def self.inner_class_types
  @inner_class_types = {
    capabilities: Capabilities,
    regulated_activity: RegulatedActivity,
  }
end