Class: Stripe::V2::Core::Account::Configuration::Storer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Capabilities
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#applied ⇒ Object
readonly
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
readonly
Capabilities that have been requested on the Storer Configuration.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#applied ⇒ Object (readonly)
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
2868 2869 2870 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2868 def applied @applied end |
#capabilities ⇒ Object (readonly)
Capabilities that have been requested on the Storer Configuration.
2870 2871 2872 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2870 def capabilities @capabilities end |
Class Method Details
.field_remappings ⇒ Object
2876 2877 2878 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2876 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2872 2873 2874 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2872 def self.inner_class_types @inner_class_types = { capabilities: Capabilities } end |