Class: Stripe::V2::Core::Account::Configuration::Storer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Capabilities

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#appliedObject (readonly)

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



2561
2562
2563
# File 'lib/stripe/resources/v2/core/account.rb', line 2561

def applied
  @applied
end

#capabilitiesObject (readonly)

Capabilities that have been requested on the Storer Configuration.



2563
2564
2565
# File 'lib/stripe/resources/v2/core/account.rb', line 2563

def capabilities
  @capabilities
end

Class Method Details

.field_remappingsObject



2569
2570
2571
# File 'lib/stripe/resources/v2/core/account.rb', line 2569

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2565
2566
2567
# File 'lib/stripe/resources/v2/core/account.rb', line 2565

def self.inner_class_types
  @inner_class_types = { capabilities: Capabilities }
end