Class: Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_addresses ⇒ Object
readonly
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
readonly
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
readonly
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by yourself.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_addresses ⇒ Object (readonly)
Can provision a financial address to credit/debit a FinancialAccount.
2536 2537 2538 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2536 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object (readonly)
Can hold storage-type funds on Stripe.
2538 2539 2540 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2538 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object (readonly)
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
2540 2541 2542 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2540 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by someone else.
2542 2543 2544 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2542 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by yourself.
2544 2545 2546 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2544 def outbound_transfers @outbound_transfers end |
Class Method Details
.field_remappings ⇒ Object
2556 2557 2558 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2556 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2546 2547 2548 2549 2550 2551 2552 2553 2554 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2546 def self.inner_class_types @inner_class_types = { financial_addresses: FinancialAddresses, holds_currencies: HoldsCurrencies, inbound_transfers: InboundTransfers, outbound_payments: OutboundPayments, outbound_transfers: OutboundTransfers, } end |