Class: Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_addresses ⇒ Object
readonly
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
readonly
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
readonly
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by yourself.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_addresses ⇒ Object (readonly)
Can provision a financial address to credit/debit a FinancialAccount.
2502 2503 2504 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2502 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object (readonly)
Can hold storage-type funds on Stripe.
2504 2505 2506 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2504 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object (readonly)
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
2506 2507 2508 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2506 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by someone else.
2508 2509 2510 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2508 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by yourself.
2510 2511 2512 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2510 def outbound_transfers @outbound_transfers end |
Class Method Details
.field_remappings ⇒ Object
2522 2523 2524 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2522 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2512 2513 2514 2515 2516 2517 2518 2519 2520 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2512 def self.inner_class_types @inner_class_types = { financial_addresses: FinancialAddresses, holds_currencies: HoldsCurrencies, inbound_transfers: InboundTransfers, outbound_payments: OutboundPayments, outbound_transfers: OutboundTransfers, } end |