Class: Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_addresses ⇒ Object
readonly
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
readonly
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
readonly
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
readonly
Can send funds from a FinancialAccount to a destination owned by yourself.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_addresses ⇒ Object (readonly)
Can provision a financial address to credit/debit a FinancialAccount.
1231 1232 1233 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1231 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object (readonly)
Can hold storage-type funds on Stripe.
1233 1234 1235 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1233 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object (readonly)
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1235 1236 1237 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1235 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by someone else.
1237 1238 1239 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1237 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object (readonly)
Can send funds from a FinancialAccount to a destination owned by yourself.
1239 1240 1241 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1239 def outbound_transfers @outbound_transfers end |