Class: Stripe::V2::Core::Account::Configuration::Storer::RegulatedActivity
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Configuration::Storer::RegulatedActivity
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
A detailed description of the regulated activities the business is licensed to conduct.
-
#license_number ⇒ Object
readonly
The license number or registration number assigned by the business’s primary regulator.
-
#primary_regulatory_authority_country ⇒ Object
readonly
The country of the primary regulatory authority that oversees the business’s regulated activities.
-
#primary_regulatory_authority_name ⇒ Object
readonly
The name of the primary regulatory authority that oversees the business’s regulated activities.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
A detailed description of the regulated activities the business is licensed to conduct.
3004 3005 3006 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3004 def description @description end |
#license_number ⇒ Object (readonly)
The license number or registration number assigned by the business’s primary regulator.
3006 3007 3008 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3006 def license_number @license_number end |
#primary_regulatory_authority_country ⇒ Object (readonly)
The country of the primary regulatory authority that oversees the business’s regulated activities.
3008 3009 3010 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3008 def @primary_regulatory_authority_country end |
#primary_regulatory_authority_name ⇒ Object (readonly)
The name of the primary regulatory authority that oversees the business’s regulated activities.
3010 3011 3012 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3010 def @primary_regulatory_authority_name end |
Class Method Details
.field_remappings ⇒ Object
3016 3017 3018 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3016 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3012 3013 3014 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3012 def self.inner_class_types @inner_class_types = {} end |