Class: Stripe::V2::Core::Account::Defaults
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Defaults
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Profile, Responsibilities
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#locales ⇒ Object
readonly
The Account’s preferred locales (languages), ordered by preference.
-
#profile ⇒ Object
readonly
Account profile information.
-
#responsibilities ⇒ Object
readonly
Default responsibilities held by either Stripe or the platform.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3174 3175 3176 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3174 def currency @currency end |
#locales ⇒ Object (readonly)
The Account’s preferred locales (languages), ordered by preference.
3176 3177 3178 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3176 def locales @locales end |
#profile ⇒ Object (readonly)
Account profile information.
3178 3179 3180 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3178 def profile @profile end |
#responsibilities ⇒ Object (readonly)
Default responsibilities held by either Stripe or the platform.
3180 3181 3182 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3180 def responsibilities @responsibilities end |
Class Method Details
.field_remappings ⇒ Object
3186 3187 3188 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3186 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3182 3183 3184 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3182 def self.inner_class_types @inner_class_types = { profile: Profile, responsibilities: Responsibilities } end |