Class: Stripe::V2::Core::Account::Defaults
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Defaults
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Responsibilities
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#locales ⇒ Object
readonly
The Account’s preferred locales (languages), ordered by preference.
-
#responsibilities ⇒ Object
readonly
Default responsibilities held by either Stripe or the platform.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2578 2579 2580 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2578 def currency @currency end |
#locales ⇒ Object (readonly)
The Account’s preferred locales (languages), ordered by preference.
2580 2581 2582 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2580 def locales @locales end |
#responsibilities ⇒ Object (readonly)
Default responsibilities held by either Stripe or the platform.
2582 2583 2584 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2582 def responsibilities @responsibilities end |
Class Method Details
.field_remappings ⇒ Object
2588 2589 2590 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2588 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2584 2585 2586 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2584 def self.inner_class_types @inner_class_types = { responsibilities: Responsibilities } end |