Class: Stripe::V2::Core::Account::Defaults
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Defaults
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Responsibilities
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#locales ⇒ Object
readonly
The Account’s preferred locales (languages), ordered by preference.
-
#responsibilities ⇒ Object
readonly
Default responsibilities held by either Stripe or the platform.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1098 1099 1100 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1098 def currency @currency end |
#locales ⇒ Object (readonly)
The Account’s preferred locales (languages), ordered by preference.
1100 1101 1102 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1100 def locales @locales end |
#responsibilities ⇒ Object (readonly)
Default responsibilities held by either Stripe or the platform.
1102 1103 1104 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1102 def responsibilities @responsibilities end |