Class: Stripe::V2::Core::Account::Defaults::Profile

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#business_urlObject (readonly)

The business’s publicly-available website.



2909
2910
2911
# File 'lib/stripe/resources/v2/core/account.rb', line 2909

def business_url
  @business_url
end

#doing_business_asObject (readonly)

The company’s legal name.



2911
2912
2913
# File 'lib/stripe/resources/v2/core/account.rb', line 2911

def doing_business_as
  @doing_business_as
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



2913
2914
2915
# File 'lib/stripe/resources/v2/core/account.rb', line 2913

def product_description
  @product_description
end

Class Method Details

.field_remappingsObject



2919
2920
2921
# File 'lib/stripe/resources/v2/core/account.rb', line 2919

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2915
2916
2917
# File 'lib/stripe/resources/v2/core/account.rb', line 2915

def self.inner_class_types
  @inner_class_types = {}
end