Class: Stripe::V2::Core::Account::Defaults::Responsibilities

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fees_collectorObject (readonly)

A value indicating the responsible payer of a bundle of Stripe fees for pricing-control eligible products on this Account.



1257
1258
1259
# File 'lib/stripe/resources/v2/core/account.rb', line 1257

def fees_collector
  @fees_collector
end

#losses_collectorObject (readonly)

A value indicating who is responsible for losses when this Account can’t pay back negative balances from payments.



1259
1260
1261
# File 'lib/stripe/resources/v2/core/account.rb', line 1259

def losses_collector
  @losses_collector
end