Class: Stripe::V2::Core::Account::FutureRequirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.



2211
2212
2213
# File 'lib/stripe/resources/v2/core/account.rb', line 2211

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



2213
2214
2215
# File 'lib/stripe/resources/v2/core/account.rb', line 2213

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



2215
2216
2217
# File 'lib/stripe/resources/v2/core/account.rb', line 2215

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



2217
2218
2219
# File 'lib/stripe/resources/v2/core/account.rb', line 2217

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



2219
2220
2221
# File 'lib/stripe/resources/v2/core/account.rb', line 2219

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



2221
2222
2223
# File 'lib/stripe/resources/v2/core/account.rb', line 2221

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



2223
2224
2225
# File 'lib/stripe/resources/v2/core/account.rb', line 2223

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



2235
2236
2237
# File 'lib/stripe/resources/v2/core/account.rb', line 2235

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2225
2226
2227
2228
2229
2230
2231
2232
2233
# File 'lib/stripe/resources/v2/core/account.rb', line 2225

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end