Class: Stripe::V2::Core::Account::FutureRequirements::Entry
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::FutureRequirements::Entry
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#awaiting_action_from ⇒ Object
readonly
Indicates whether the platform or Stripe is currently responsible for taking action on the requirement.
-
#description ⇒ Object
readonly
Machine-readable string describing the requirement.
-
#errors ⇒ Object
readonly
Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.
-
#impact ⇒ Object
readonly
A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
-
#minimum_deadline ⇒ Object
readonly
The soonest point when the account will be impacted by not providing the requirement.
-
#reference ⇒ Object
readonly
A reference to the location of the requirement.
-
#requested_reasons ⇒ Object
readonly
A list of reasons why Stripe is collecting the requirement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#awaiting_action_from ⇒ Object (readonly)
Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.
3607 3608 3609 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3607 def awaiting_action_from @awaiting_action_from end |
#description ⇒ Object (readonly)
Machine-readable string describing the requirement.
3609 3610 3611 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3609 def description @description end |
#errors ⇒ Object (readonly)
Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.
3611 3612 3613 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3611 def errors @errors end |
#impact ⇒ Object (readonly)
A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
3613 3614 3615 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3613 def impact @impact end |
#minimum_deadline ⇒ Object (readonly)
The soonest point when the account will be impacted by not providing the requirement.
3615 3616 3617 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3615 def minimum_deadline @minimum_deadline end |
#reference ⇒ Object (readonly)
A reference to the location of the requirement.
3617 3618 3619 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3617 def reference @reference end |
#requested_reasons ⇒ Object (readonly)
A list of reasons why Stripe is collecting the requirement.
3619 3620 3621 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3619 def requested_reasons @requested_reasons end |
Class Method Details
.field_remappings ⇒ Object
3631 3632 3633 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3631 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3621 3622 3623 3624 3625 3626 3627 3628 3629 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3621 def self.inner_class_types @inner_class_types = { errors: Error, impact: Impact, minimum_deadline: MinimumDeadline, reference: Reference, requested_reasons: RequestedReason, } end |