Class: Stripe::V2::Core::Account::FutureRequirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.



2753
2754
2755
# File 'lib/stripe/resources/v2/core/account.rb', line 2753

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



2755
2756
2757
# File 'lib/stripe/resources/v2/core/account.rb', line 2755

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



2757
2758
2759
# File 'lib/stripe/resources/v2/core/account.rb', line 2757

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



2759
2760
2761
# File 'lib/stripe/resources/v2/core/account.rb', line 2759

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



2761
2762
2763
# File 'lib/stripe/resources/v2/core/account.rb', line 2761

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



2763
2764
2765
# File 'lib/stripe/resources/v2/core/account.rb', line 2763

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



2765
2766
2767
# File 'lib/stripe/resources/v2/core/account.rb', line 2765

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



2777
2778
2779
# File 'lib/stripe/resources/v2/core/account.rb', line 2777

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2767
2768
2769
2770
2771
2772
2773
2774
2775
# File 'lib/stripe/resources/v2/core/account.rb', line 2767

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end