Class: Stripe::V2::Core::Account::FutureRequirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.



3293
3294
3295
# File 'lib/stripe/resources/v2/core/account.rb', line 3293

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



3295
3296
3297
# File 'lib/stripe/resources/v2/core/account.rb', line 3295

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



3297
3298
3299
# File 'lib/stripe/resources/v2/core/account.rb', line 3297

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



3299
3300
3301
# File 'lib/stripe/resources/v2/core/account.rb', line 3299

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



3301
3302
3303
# File 'lib/stripe/resources/v2/core/account.rb', line 3301

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



3303
3304
3305
# File 'lib/stripe/resources/v2/core/account.rb', line 3303

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



3305
3306
3307
# File 'lib/stripe/resources/v2/core/account.rb', line 3305

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



3317
3318
3319
# File 'lib/stripe/resources/v2/core/account.rb', line 3317

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3307
3308
3309
3310
3311
3312
3313
3314
3315
# File 'lib/stripe/resources/v2/core/account.rb', line 3307

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end