Class: Stripe::V2::Core::Account::FutureRequirements::Entry::Impact::RestrictsCapability

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Deadline

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capabilityObject (readonly)

The name of the Capability which will be restricted.



3600
3601
3602
# File 'lib/stripe/resources/v2/core/account.rb', line 3600

def capability
  @capability
end

#configurationObject (readonly)

The configuration which specifies the Capability which will be restricted.



3602
3603
3604
# File 'lib/stripe/resources/v2/core/account.rb', line 3602

def configuration
  @configuration
end

#deadlineObject (readonly)

Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.



3604
3605
3606
# File 'lib/stripe/resources/v2/core/account.rb', line 3604

def deadline
  @deadline
end

Class Method Details

.field_remappingsObject



3610
3611
3612
# File 'lib/stripe/resources/v2/core/account.rb', line 3610

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3606
3607
3608
# File 'lib/stripe/resources/v2/core/account.rb', line 3606

def self.inner_class_types
  @inner_class_types = { deadline: Deadline }
end