Class: Stripe::V2::Core::Account::FutureRequirements::Entry::Impact::RestrictsCapability

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Deadline

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capabilityObject (readonly)

The name of the Capability which will be restricted.



3338
3339
3340
# File 'lib/stripe/resources/v2/core/account.rb', line 3338

def capability
  @capability
end

#configurationObject (readonly)

The configuration which specifies the Capability which will be restricted.



3340
3341
3342
# File 'lib/stripe/resources/v2/core/account.rb', line 3340

def configuration
  @configuration
end

#deadlineObject (readonly)

Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.



3342
3343
3344
# File 'lib/stripe/resources/v2/core/account.rb', line 3342

def deadline
  @deadline
end

Class Method Details

.field_remappingsObject



3348
3349
3350
# File 'lib/stripe/resources/v2/core/account.rb', line 3348

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3344
3345
3346
# File 'lib/stripe/resources/v2/core/account.rb', line 3344

def self.inner_class_types
  @inner_class_types = { deadline: Deadline }
end