Class: Stripe::V2::Core::Account::FutureRequirements::Entry::Reference

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#inquiryObject (readonly)

If inquiry is the type, the inquiry token.



3076
3077
3078
# File 'lib/stripe/resources/v2/core/account.rb', line 3076

def inquiry
  @inquiry
end

#resourceObject (readonly)

If resource is the type, the resource token.



3078
3079
3080
# File 'lib/stripe/resources/v2/core/account.rb', line 3078

def resource
  @resource
end

#typeObject (readonly)

The type of the reference. If the type is "inquiry", the inquiry token can be found in the "inquiry" field. Otherwise the type is an API resource, the token for which can be found in the "resource" field.



3081
3082
3083
# File 'lib/stripe/resources/v2/core/account.rb', line 3081

def type
  @type
end

Class Method Details

.field_remappingsObject



3087
3088
3089
# File 'lib/stripe/resources/v2/core/account.rb', line 3087

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3083
3084
3085
# File 'lib/stripe/resources/v2/core/account.rb', line 3083

def self.inner_class_types
  @inner_class_types = {}
end