Class: Stripe::V2::Core::Account::FutureRequirements::Entry::Reference

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#inquiryObject (readonly)

If ‘inquiry` is the type, the inquiry token.



3672
3673
3674
# File 'lib/stripe/resources/v2/core/account.rb', line 3672

def inquiry
  @inquiry
end

#resourceObject (readonly)

If ‘resource` is the type, the resource token.



3674
3675
3676
# File 'lib/stripe/resources/v2/core/account.rb', line 3674

def resource
  @resource
end

#typeObject (readonly)

The type of the reference. If the type is “inquiry”, the inquiry token can be found in the “inquiry” field. Otherwise the type is an API resource, the token for which can be found in the “resource” field.



3677
3678
3679
# File 'lib/stripe/resources/v2/core/account.rb', line 3677

def type
  @type
end

Class Method Details

.field_remappingsObject



3683
3684
3685
# File 'lib/stripe/resources/v2/core/account.rb', line 3683

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3679
3680
3681
# File 'lib/stripe/resources/v2/core/account.rb', line 3679

def self.inner_class_types
  @inner_class_types = {}
end