Class: Stripe::V2::Core::Account::Identity

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#attestationsObject (readonly)

Attestations from the identity's key people, e.g. owners, executives, directors, representatives.



19912
19913
19914
# File 'lib/stripe/resources/v2/core/account.rb', line 19912

def attestations
  @attestations
end

#business_detailsObject (readonly)

Information about the company or business.



19914
19915
19916
# File 'lib/stripe/resources/v2/core/account.rb', line 19914

def business_details
  @business_details
end

#countryObject (readonly)

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code.



19916
19917
19918
# File 'lib/stripe/resources/v2/core/account.rb', line 19916

def country
  @country
end

#entity_typeObject (readonly)

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



19918
19919
19920
# File 'lib/stripe/resources/v2/core/account.rb', line 19918

def entity_type
  @entity_type
end

#individualObject (readonly)

Information about the individual represented by the Account. This property is null unless entity_type is set to individual.



19920
19921
19922
# File 'lib/stripe/resources/v2/core/account.rb', line 19920

def individual
  @individual
end

Class Method Details

.field_encodingsObject



19934
19935
19936
19937
19938
19939
19940
19941
19942
19943
# File 'lib/stripe/resources/v2/core/account.rb', line 19934

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end

.field_remappingsObject



19930
19931
19932
# File 'lib/stripe/resources/v2/core/account.rb', line 19930

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



19922
19923
19924
19925
19926
19927
19928
# File 'lib/stripe/resources/v2/core/account.rb', line 19922

def self.inner_class_types
  @inner_class_types = {
    attestations: Attestations,
    business_details: BusinessDetails,
    individual: Individual,
  }
end