Class: Stripe::V2::Core::Account::Identity

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#attestationsObject (readonly)

Attestations from the identity's key people, e.g. owners, executives, directors, representatives.



4285
4286
4287
# File 'lib/stripe/resources/v2/core/account.rb', line 4285

def attestations
  @attestations
end

#business_detailsObject (readonly)

Information about the company or business.



4287
4288
4289
# File 'lib/stripe/resources/v2/core/account.rb', line 4287

def business_details
  @business_details
end

#countryObject (readonly)

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code.



4289
4290
4291
# File 'lib/stripe/resources/v2/core/account.rb', line 4289

def country
  @country
end

#entity_typeObject (readonly)

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



4291
4292
4293
# File 'lib/stripe/resources/v2/core/account.rb', line 4291

def entity_type
  @entity_type
end

#individualObject (readonly)

Information about the individual represented by the Account. This property is null unless entity_type is set to individual.



4293
4294
4295
# File 'lib/stripe/resources/v2/core/account.rb', line 4293

def individual
  @individual
end

Class Method Details

.field_encodingsObject



4307
4308
4309
4310
4311
4312
4313
4314
4315
4316
# File 'lib/stripe/resources/v2/core/account.rb', line 4307

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end

.field_remappingsObject



4303
4304
4305
# File 'lib/stripe/resources/v2/core/account.rb', line 4303

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4295
4296
4297
4298
4299
4300
4301
# File 'lib/stripe/resources/v2/core/account.rb', line 4295

def self.inner_class_types
  @inner_class_types = {
    attestations: Attestations,
    business_details: BusinessDetails,
    individual: Individual,
  }
end