Class: Stripe::V2::Core::Account::Identity

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#attestationsObject (readonly)

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



4255
4256
4257
# File 'lib/stripe/resources/v2/core/account.rb', line 4255

def attestations
  @attestations
end

#business_detailsObject (readonly)

Information about the company or business.



4257
4258
4259
# File 'lib/stripe/resources/v2/core/account.rb', line 4257

def business_details
  @business_details
end

#countryObject (readonly)

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



4259
4260
4261
# File 'lib/stripe/resources/v2/core/account.rb', line 4259

def country
  @country
end

#entity_typeObject (readonly)

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



4261
4262
4263
# File 'lib/stripe/resources/v2/core/account.rb', line 4261

def entity_type
  @entity_type
end

#individualObject (readonly)

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



4263
4264
4265
# File 'lib/stripe/resources/v2/core/account.rb', line 4263

def individual
  @individual
end

Class Method Details

.field_encodingsObject



4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
# File 'lib/stripe/resources/v2/core/account.rb', line 4277

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end

.field_remappingsObject



4273
4274
4275
# File 'lib/stripe/resources/v2/core/account.rb', line 4273

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4265
4266
4267
4268
4269
4270
4271
# File 'lib/stripe/resources/v2/core/account.rb', line 4265

def self.inner_class_types
  @inner_class_types = {
    attestations: Attestations,
    business_details: BusinessDetails,
    individual: Individual,
  }
end