Class: Stripe::V2::Core::Account::Identity

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#attestationsObject (readonly)

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



5992
5993
5994
# File 'lib/stripe/resources/v2/core/account.rb', line 5992

def attestations
  @attestations
end

#business_detailsObject (readonly)

Information about the company or business.



5994
5995
5996
# File 'lib/stripe/resources/v2/core/account.rb', line 5994

def business_details
  @business_details
end

#countryObject (readonly)

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



5996
5997
5998
# File 'lib/stripe/resources/v2/core/account.rb', line 5996

def country
  @country
end

#entity_typeObject (readonly)

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



5998
5999
6000
# File 'lib/stripe/resources/v2/core/account.rb', line 5998

def entity_type
  @entity_type
end

#individualObject (readonly)

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



6000
6001
6002
# File 'lib/stripe/resources/v2/core/account.rb', line 6000

def individual
  @individual
end

Class Method Details

.field_encodingsObject



6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
# File 'lib/stripe/resources/v2/core/account.rb', line 6014

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end

.field_remappingsObject



6010
6011
6012
# File 'lib/stripe/resources/v2/core/account.rb', line 6010

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



6002
6003
6004
6005
6006
6007
6008
# File 'lib/stripe/resources/v2/core/account.rb', line 6002

def self.inner_class_types
  @inner_class_types = {
    attestations: Attestations,
    business_details: BusinessDetails,
    individual: Individual,
  }
end