Class: Stripe::V2::Core::Account::Identity

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#attestationsObject (readonly)

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



3344
3345
3346
# File 'lib/stripe/resources/v2/core/account.rb', line 3344

def attestations
  @attestations
end

#business_detailsObject (readonly)

Information about the company or business.



3346
3347
3348
# File 'lib/stripe/resources/v2/core/account.rb', line 3346

def business_details
  @business_details
end

#countryObject (readonly)

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



3348
3349
3350
# File 'lib/stripe/resources/v2/core/account.rb', line 3348

def country
  @country
end

#entity_typeObject (readonly)

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



3350
3351
3352
# File 'lib/stripe/resources/v2/core/account.rb', line 3350

def entity_type
  @entity_type
end

#individualObject (readonly)

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



3352
3353
3354
# File 'lib/stripe/resources/v2/core/account.rb', line 3352

def individual
  @individual
end

Class Method Details

.field_encodingsObject



3366
3367
3368
3369
3370
3371
3372
3373
3374
3375
# File 'lib/stripe/resources/v2/core/account.rb', line 3366

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end

.field_remappingsObject



3362
3363
3364
# File 'lib/stripe/resources/v2/core/account.rb', line 3362

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3354
3355
3356
3357
3358
3359
3360
# File 'lib/stripe/resources/v2/core/account.rb', line 3354

def self.inner_class_types
  @inner_class_types = {
    attestations: Attestations,
    business_details: BusinessDetails,
    individual: Individual,
  }
end