Class: Stripe::V2::Core::Account::Identity

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#attestationsObject (readonly)

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



5964
5965
5966
# File 'lib/stripe/resources/v2/core/account.rb', line 5964

def attestations
  @attestations
end

#business_detailsObject (readonly)

Information about the company or business.



5966
5967
5968
# File 'lib/stripe/resources/v2/core/account.rb', line 5966

def business_details
  @business_details
end

#countryObject (readonly)

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



5968
5969
5970
# File 'lib/stripe/resources/v2/core/account.rb', line 5968

def country
  @country
end

#entity_typeObject (readonly)

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



5970
5971
5972
# File 'lib/stripe/resources/v2/core/account.rb', line 5970

def entity_type
  @entity_type
end

#individualObject (readonly)

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



5972
5973
5974
# File 'lib/stripe/resources/v2/core/account.rb', line 5972

def individual
  @individual
end

Class Method Details

.field_encodingsObject



5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/stripe/resources/v2/core/account.rb', line 5986

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end

.field_remappingsObject



5982
5983
5984
# File 'lib/stripe/resources/v2/core/account.rb', line 5982

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5974
5975
5976
5977
5978
5979
5980
# File 'lib/stripe/resources/v2/core/account.rb', line 5974

def self.inner_class_types
  @inner_class_types = {
    attestations: Attestations,
    business_details: BusinessDetails,
    individual: Individual,
  }
end