Class: Stripe::V2::Core::Account::Identity
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#attestations ⇒ Object
readonly
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
readonly
Information about the company or business.
-
#country ⇒ Object
readonly
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
readonly
The entity type.
-
#individual ⇒ Object
readonly
Information about the individual represented by the Account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#attestations ⇒ Object (readonly)
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3911 3912 3913 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3911 def attestations @attestations end |
#business_details ⇒ Object (readonly)
Information about the company or business.
3913 3914 3915 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3913 def business_details @business_details end |
#country ⇒ Object (readonly)
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3915 3916 3917 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3915 def country @country end |
#entity_type ⇒ Object (readonly)
The entity type.
3917 3918 3919 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3917 def entity_type @entity_type end |
#individual ⇒ Object (readonly)
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
3919 3920 3921 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3919 def individual @individual end |
Class Method Details
.field_encodings ⇒ Object
3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3933 def self.field_encodings @field_encodings = { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, } end |
.field_remappings ⇒ Object
3929 3930 3931 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3929 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3921 3922 3923 3924 3925 3926 3927 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3921 def self.inner_class_types @inner_class_types = { attestations: Attestations, business_details: BusinessDetails, individual: Individual, } end |