Class: Stripe::V2::Core::Account::Identity::Attestations
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Attestations
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
readonly
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
readonly
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
readonly
Attestation that all Persons with a specific Relationship value have been provided.
-
#representative_declaration ⇒ Object
readonly
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#terms_of_service ⇒ Object
readonly
Attestations of accepted terms of service agreements.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#directorship_declaration ⇒ Object (readonly)
This hash is used to attest that the directors information provided to Stripe is both current and correct.
2978 2979 2980 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2978 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object (readonly)
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
2980 2981 2982 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2980 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object (readonly)
Attestation that all Persons with a specific Relationship value have been provided.
2982 2983 2984 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2982 def persons_provided @persons_provided end |
#representative_declaration ⇒ Object (readonly)
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
2984 2985 2986 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2984 def representative_declaration @representative_declaration end |
#terms_of_service ⇒ Object (readonly)
Attestations of accepted terms of service agreements.
2986 2987 2988 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2986 def terms_of_service @terms_of_service end |
Class Method Details
.field_remappings ⇒ Object
2998 2999 3000 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2998 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2988 2989 2990 2991 2992 2993 2994 2995 2996 |
# File 'lib/stripe/resources/v2/core/account.rb', line 2988 def self.inner_class_types @inner_class_types = { directorship_declaration: DirectorshipDeclaration, ownership_declaration: OwnershipDeclaration, persons_provided: PersonsProvided, representative_declaration: RepresentativeDeclaration, terms_of_service: TermsOfService, } end |