Class: Stripe::V2::Core::Account::Identity::Attestations

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#directorship_declarationObject (readonly)

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3468
3469
3470
# File 'lib/stripe/resources/v2/core/account.rb', line 3468

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject (readonly)

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3470
3471
3472
# File 'lib/stripe/resources/v2/core/account.rb', line 3470

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject (readonly)

Attestation that all Persons with a specific Relationship value have been provided.



3472
3473
3474
# File 'lib/stripe/resources/v2/core/account.rb', line 3472

def persons_provided
  @persons_provided
end

#representative_declarationObject (readonly)

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



3474
3475
3476
# File 'lib/stripe/resources/v2/core/account.rb', line 3474

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject (readonly)

Attestations of accepted terms of service agreements.



3476
3477
3478
# File 'lib/stripe/resources/v2/core/account.rb', line 3476

def terms_of_service
  @terms_of_service
end

Class Method Details

.field_remappingsObject



3488
3489
3490
# File 'lib/stripe/resources/v2/core/account.rb', line 3488

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3478
3479
3480
3481
3482
3483
3484
3485
3486
# File 'lib/stripe/resources/v2/core/account.rb', line 3478

def self.inner_class_types
  @inner_class_types = {
    directorship_declaration: DirectorshipDeclaration,
    ownership_declaration: OwnershipDeclaration,
    persons_provided: PersonsProvided,
    representative_declaration: RepresentativeDeclaration,
    terms_of_service: TermsOfService,
  }
end