Class: Stripe::V2::Core::Account::Identity::Attestations
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Attestations
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
readonly
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
readonly
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
readonly
Attestation that all Persons with a specific Relationship value have been provided.
-
#terms_of_service ⇒ Object
readonly
Attestations of accepted terms of service agreements.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#directorship_declaration ⇒ Object (readonly)
This hash is used to attest that the directors information provided to Stripe is both current and correct.
3418 3419 3420 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3418 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object (readonly)
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
3420 3421 3422 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3420 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object (readonly)
Attestation that all Persons with a specific Relationship value have been provided.
3422 3423 3424 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3422 def persons_provided @persons_provided end |
#terms_of_service ⇒ Object (readonly)
Attestations of accepted terms of service agreements.
3424 3425 3426 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3424 def terms_of_service @terms_of_service end |
Class Method Details
.field_remappings ⇒ Object
3435 3436 3437 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3435 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3426 3427 3428 3429 3430 3431 3432 3433 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3426 def self.inner_class_types @inner_class_types = { directorship_declaration: DirectorshipDeclaration, ownership_declaration: OwnershipDeclaration, persons_provided: PersonsProvided, terms_of_service: TermsOfService, } end |