Class: Stripe::V2::Core::Account::Identity::Attestations

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#directorship_declarationObject (readonly)

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1332
1333
1334
# File 'lib/stripe/resources/v2/core/account.rb', line 1332

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject (readonly)

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1334
1335
1336
# File 'lib/stripe/resources/v2/core/account.rb', line 1334

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject (readonly)

Attestation that all Persons with a specific Relationship value have been provided.



1336
1337
1338
# File 'lib/stripe/resources/v2/core/account.rb', line 1336

def persons_provided
  @persons_provided
end

#terms_of_serviceObject (readonly)

Attestations of accepted terms of service agreements.



1338
1339
1340
# File 'lib/stripe/resources/v2/core/account.rb', line 1338

def terms_of_service
  @terms_of_service
end