Class: Stripe::V2::Core::Account::Identity::Attestations
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Attestations
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
readonly
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
readonly
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
readonly
Attestation that all Persons with a specific Relationship value have been provided.
-
#terms_of_service ⇒ Object
readonly
Attestations of accepted terms of service agreements.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#directorship_declaration ⇒ Object (readonly)
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1149 1150 1151 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1149 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object (readonly)
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1151 1152 1153 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1151 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object (readonly)
Attestation that all Persons with a specific Relationship value have been provided.
1153 1154 1155 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1153 def persons_provided @persons_provided end |
#terms_of_service ⇒ Object (readonly)
Attestations of accepted terms of service agreements.
1155 1156 1157 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1155 def terms_of_service @terms_of_service end |