Class: Stripe::V2::Core::Account::Identity::Attestations::DirectorshipDeclaration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3682
3683
3684
# File 'lib/stripe/resources/v2/core/account.rb', line 3682

def date
  @date
end

#ipObject (readonly)

The IP address from which the director attestation was made.



3684
3685
3686
# File 'lib/stripe/resources/v2/core/account.rb', line 3684

def ip
  @ip
end

#user_agentObject (readonly)

The user agent of the browser from which the director attestation was made.



3686
3687
3688
# File 'lib/stripe/resources/v2/core/account.rb', line 3686

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



3692
3693
3694
# File 'lib/stripe/resources/v2/core/account.rb', line 3692

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3688
3689
3690
# File 'lib/stripe/resources/v2/core/account.rb', line 3688

def self.inner_class_types
  @inner_class_types = {}
end