Class: Stripe::V2::Core::Account::Identity::Attestations::OwnershipDeclaration

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#dateObject (readonly)

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



2879
2880
2881
# File 'lib/stripe/resources/v2/core/account.rb', line 2879

def date
  @date
end

#ipObject (readonly)

The IP address from which the beneficial owner attestation was made.



2881
2882
2883
# File 'lib/stripe/resources/v2/core/account.rb', line 2881

def ip
  @ip
end

#user_agentObject (readonly)

The user agent of the browser from which the beneficial owner attestation was made.



2883
2884
2885
# File 'lib/stripe/resources/v2/core/account.rb', line 2883

def user_agent
  @user_agent
end

Class Method Details

.field_remappingsObject



2889
2890
2891
# File 'lib/stripe/resources/v2/core/account.rb', line 2889

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2885
2886
2887
# File 'lib/stripe/resources/v2/core/account.rb', line 2885

def self.inner_class_types
  @inner_class_types = {}
end