Class: Stripe::V2::Core::Account::Identity::Attestations::OwnershipDeclaration
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Attestations::OwnershipDeclaration
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#date ⇒ Object
readonly
The time marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
readonly
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
readonly
The user agent of the browser from which the beneficial owner attestation was made.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#date ⇒ Object (readonly)
The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1080 1081 1082 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1080 def date @date end |
#ip ⇒ Object (readonly)
The IP address from which the beneficial owner attestation was made.
1082 1083 1084 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1082 def ip @ip end |
#user_agent ⇒ Object (readonly)
The user agent of the browser from which the beneficial owner attestation was made.
1084 1085 1086 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1084 def user_agent @user_agent end |