Class: Stripe::V2::Core::Account::Identity::Attestations::PersonsProvided

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#directorsObject (readonly)

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



2896
2897
2898
# File 'lib/stripe/resources/v2/core/account.rb', line 2896

def directors
  @directors
end

#executivesObject (readonly)

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



2898
2899
2900
# File 'lib/stripe/resources/v2/core/account.rb', line 2898

def executives
  @executives
end

#ownersObject (readonly)

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



2900
2901
2902
# File 'lib/stripe/resources/v2/core/account.rb', line 2900

def owners
  @owners
end

#ownership_exemption_reasonObject (readonly)

Reason for why the company is exempt from providing ownership information.



2902
2903
2904
# File 'lib/stripe/resources/v2/core/account.rb', line 2902

def ownership_exemption_reason
  @ownership_exemption_reason
end

Class Method Details

.field_remappingsObject



2908
2909
2910
# File 'lib/stripe/resources/v2/core/account.rb', line 2908

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2904
2905
2906
# File 'lib/stripe/resources/v2/core/account.rb', line 2904

def self.inner_class_types
  @inner_class_types = {}
end