Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the business.
-
#address ⇒ Object
readonly
The company's primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
readonly
A detailed description of the business's compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company's phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#registration_date ⇒ Object
readonly
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the business.
19394 19395 19396 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19394 def additional_addresses @additional_addresses end |
#address ⇒ Object (readonly)
The company's primary address.
19396 19397 19398 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19396 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
19398 19399 19400 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19398 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object (readonly)
A detailed description of the business's compliance and anti-money laundering controls and practices.
19400 19401 19402 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19400 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
19402 19403 19404 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19402 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
19404 19405 19406 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19404 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
19406 19407 19408 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19406 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
19408 19409 19410 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19408 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company's phone number (used for verification).
19410 19411 19412 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19410 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
19412 19413 19414 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19412 def registered_name @registered_name end |
#registration_date ⇒ Object (readonly)
When the business was incorporated or registered.
19414 19415 19416 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19414 def registration_date @registration_date end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
19416 19417 19418 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19416 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
19418 19419 19420 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19418 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
19420 19421 19422 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19420 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
19436 19437 19438 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19436 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
19422 19423 19424 19425 19426 19427 19428 19429 19430 19431 19432 19433 19434 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19422 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, registration_date: RegistrationDate, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |