Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#additional_addressesObject (readonly)

Additional addresses associated with the business.



3769
3770
3771
# File 'lib/stripe/resources/v2/core/account.rb', line 3769

def additional_addresses
  @additional_addresses
end

#addressObject (readonly)

The company’s primary address.



3771
3772
3773
# File 'lib/stripe/resources/v2/core/account.rb', line 3771

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



3773
3774
3775
# File 'lib/stripe/resources/v2/core/account.rb', line 3773

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3775
3776
3777
# File 'lib/stripe/resources/v2/core/account.rb', line 3775

def documents
  @documents
end

#estimated_worker_countObject (readonly)

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3777
3778
3779
# File 'lib/stripe/resources/v2/core/account.rb', line 3777

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



3779
3780
3781
# File 'lib/stripe/resources/v2/core/account.rb', line 3779

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3781
3782
3783
# File 'lib/stripe/resources/v2/core/account.rb', line 3781

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



3783
3784
3785
# File 'lib/stripe/resources/v2/core/account.rb', line 3783

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



3785
3786
3787
# File 'lib/stripe/resources/v2/core/account.rb', line 3785

def registered_name
  @registered_name
end

#registration_dateObject (readonly)

When the business was incorporated or registered.



3787
3788
3789
# File 'lib/stripe/resources/v2/core/account.rb', line 3787

def registration_date
  @registration_date
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



3789
3790
3791
# File 'lib/stripe/resources/v2/core/account.rb', line 3789

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



3791
3792
3793
# File 'lib/stripe/resources/v2/core/account.rb', line 3791

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



3793
3794
3795
# File 'lib/stripe/resources/v2/core/account.rb', line 3793

def structure
  @structure
end

Class Method Details

.field_remappingsObject



3809
3810
3811
# File 'lib/stripe/resources/v2/core/account.rb', line 3809

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
# File 'lib/stripe/resources/v2/core/account.rb', line 3795

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    registration_date: RegistrationDate,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end