Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The company’s primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
readonly
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#registration_date ⇒ Object
readonly
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The company’s primary address.
5477 5478 5479 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5477 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
5479 5480 5481 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5479 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object (readonly)
A detailed description of the business’s compliance and anti-money laundering controls and practices.
5481 5482 5483 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5481 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
5483 5484 5485 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5483 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
5485 5486 5487 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5485 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
5487 5488 5489 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5487 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
5489 5490 5491 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5489 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
5491 5492 5493 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5491 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
5493 5494 5495 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5493 def registered_name @registered_name end |
#registration_date ⇒ Object (readonly)
When the business was incorporated or registered.
5495 5496 5497 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5495 def registration_date @registration_date end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
5497 5498 5499 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5497 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
5499 5500 5501 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5499 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
5501 5502 5503 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5501 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
5516 5517 5518 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5516 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5503 def self.inner_class_types @inner_class_types = { address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, registration_date: RegistrationDate, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |