Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The company’s primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#registration_date ⇒ Object
readonly
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The company’s primary address.
3425 3426 3427 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3425 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
3427 3428 3429 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3427 def annual_revenue @annual_revenue end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
3429 3430 3431 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3429 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
3431 3432 3433 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3431 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
3433 3434 3435 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3433 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
3435 3436 3437 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3435 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
3437 3438 3439 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3437 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
3439 3440 3441 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3439 def registered_name @registered_name end |
#registration_date ⇒ Object (readonly)
When the business was incorporated or registered.
3441 3442 3443 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3441 def registration_date @registration_date end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
3443 3444 3445 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3443 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
3445 3446 3447 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3445 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
3447 3448 3449 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3447 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
3462 3463 3464 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3462 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3449 def self.inner_class_types @inner_class_types = { address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, registration_date: RegistrationDate, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |