Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



5335
5336
5337
# File 'lib/stripe/resources/v2/core/account.rb', line 5335

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



5337
5338
5339
# File 'lib/stripe/resources/v2/core/account.rb', line 5337

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject (readonly)

A detailed description of the business’s compliance and anti-money laundering controls and practices.



5339
5340
5341
# File 'lib/stripe/resources/v2/core/account.rb', line 5339

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



5341
5342
5343
# File 'lib/stripe/resources/v2/core/account.rb', line 5341

def documents
  @documents
end

#estimated_worker_countObject (readonly)

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



5343
5344
5345
# File 'lib/stripe/resources/v2/core/account.rb', line 5343

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



5345
5346
5347
# File 'lib/stripe/resources/v2/core/account.rb', line 5345

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



5347
5348
5349
# File 'lib/stripe/resources/v2/core/account.rb', line 5347

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



5349
5350
5351
# File 'lib/stripe/resources/v2/core/account.rb', line 5349

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



5351
5352
5353
# File 'lib/stripe/resources/v2/core/account.rb', line 5351

def registered_name
  @registered_name
end

#registration_dateObject (readonly)

When the business was incorporated or registered.



5353
5354
5355
# File 'lib/stripe/resources/v2/core/account.rb', line 5353

def registration_date
  @registration_date
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



5355
5356
5357
# File 'lib/stripe/resources/v2/core/account.rb', line 5355

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



5357
5358
5359
# File 'lib/stripe/resources/v2/core/account.rb', line 5357

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



5359
5360
5361
# File 'lib/stripe/resources/v2/core/account.rb', line 5359

def structure
  @structure
end

Class Method Details

.field_remappingsObject



5374
5375
5376
# File 'lib/stripe/resources/v2/core/account.rb', line 5374

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5361
5362
5363
5364
5365
5366
5367
5368
5369
5370
5371
5372
# File 'lib/stripe/resources/v2/core/account.rb', line 5361

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    registration_date: RegistrationDate,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end