Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



3398
3399
3400
# File 'lib/stripe/resources/v2/core/account.rb', line 3398

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



3400
3401
3402
# File 'lib/stripe/resources/v2/core/account.rb', line 3400

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3402
3403
3404
# File 'lib/stripe/resources/v2/core/account.rb', line 3402

def documents
  @documents
end

#estimated_worker_countObject (readonly)

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3404
3405
3406
# File 'lib/stripe/resources/v2/core/account.rb', line 3404

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



3406
3407
3408
# File 'lib/stripe/resources/v2/core/account.rb', line 3406

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



3408
3409
3410
# File 'lib/stripe/resources/v2/core/account.rb', line 3408

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



3410
3411
3412
# File 'lib/stripe/resources/v2/core/account.rb', line 3410

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



3412
3413
3414
# File 'lib/stripe/resources/v2/core/account.rb', line 3412

def registered_name
  @registered_name
end

#registration_dateObject (readonly)

When the business was incorporated or registered.



3414
3415
3416
# File 'lib/stripe/resources/v2/core/account.rb', line 3414

def registration_date
  @registration_date
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



3416
3417
3418
# File 'lib/stripe/resources/v2/core/account.rb', line 3416

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



3418
3419
3420
# File 'lib/stripe/resources/v2/core/account.rb', line 3418

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



3420
3421
3422
# File 'lib/stripe/resources/v2/core/account.rb', line 3420

def structure
  @structure
end

Class Method Details

.field_remappingsObject



3435
3436
3437
# File 'lib/stripe/resources/v2/core/account.rb', line 3435

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
# File 'lib/stripe/resources/v2/core/account.rb', line 3422

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    registration_date: RegistrationDate,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end