Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The company’s primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
readonly
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#registration_date ⇒ Object
readonly
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The company’s primary address.
5258 5259 5260 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5258 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
5260 5261 5262 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5260 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object (readonly)
A detailed description of the business’s compliance and anti-money laundering controls and practices.
5262 5263 5264 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5262 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
5264 5265 5266 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5264 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
5266 5267 5268 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5266 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
5268 5269 5270 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5268 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
5270 5271 5272 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5270 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
5272 5273 5274 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5272 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
5274 5275 5276 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5274 def registered_name @registered_name end |
#registration_date ⇒ Object (readonly)
When the business was incorporated or registered.
5276 5277 5278 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5276 def registration_date @registration_date end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
5278 5279 5280 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5278 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
5280 5281 5282 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5280 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
5282 5283 5284 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5282 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
5297 5298 5299 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5297 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5284 5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5284 def self.inner_class_types @inner_class_types = { address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, registration_date: RegistrationDate, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |