Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



2832
2833
2834
# File 'lib/stripe/resources/v2/core/account.rb', line 2832

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



2834
2835
2836
# File 'lib/stripe/resources/v2/core/account.rb', line 2834

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



2836
2837
2838
# File 'lib/stripe/resources/v2/core/account.rb', line 2836

def documents
  @documents
end

#estimated_worker_countObject (readonly)

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



2838
2839
2840
# File 'lib/stripe/resources/v2/core/account.rb', line 2838

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



2840
2841
2842
# File 'lib/stripe/resources/v2/core/account.rb', line 2840

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2842
2843
2844
# File 'lib/stripe/resources/v2/core/account.rb', line 2842

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



2844
2845
2846
# File 'lib/stripe/resources/v2/core/account.rb', line 2844

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



2846
2847
2848
# File 'lib/stripe/resources/v2/core/account.rb', line 2846

def registered_name
  @registered_name
end

#registration_dateObject (readonly)

When the business was incorporated or registered.



2848
2849
2850
# File 'lib/stripe/resources/v2/core/account.rb', line 2848

def registration_date
  @registration_date
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



2850
2851
2852
# File 'lib/stripe/resources/v2/core/account.rb', line 2850

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



2852
2853
2854
# File 'lib/stripe/resources/v2/core/account.rb', line 2852

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



2854
2855
2856
# File 'lib/stripe/resources/v2/core/account.rb', line 2854

def structure
  @structure
end

Class Method Details

.field_remappingsObject



2869
2870
2871
# File 'lib/stripe/resources/v2/core/account.rb', line 2869

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2856
2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
# File 'lib/stripe/resources/v2/core/account.rb', line 2856

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    registration_date: RegistrationDate,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end