Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



4458
4459
4460
# File 'lib/stripe/resources/v2/core/account.rb', line 4458

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



4460
4461
4462
# File 'lib/stripe/resources/v2/core/account.rb', line 4460

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject (readonly)

A detailed description of the business’s compliance and anti-money laundering controls and practices.



4462
4463
4464
# File 'lib/stripe/resources/v2/core/account.rb', line 4462

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



4464
4465
4466
# File 'lib/stripe/resources/v2/core/account.rb', line 4464

def documents
  @documents
end

#estimated_worker_countObject (readonly)

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



4466
4467
4468
# File 'lib/stripe/resources/v2/core/account.rb', line 4466

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



4468
4469
4470
# File 'lib/stripe/resources/v2/core/account.rb', line 4468

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



4470
4471
4472
# File 'lib/stripe/resources/v2/core/account.rb', line 4470

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



4472
4473
4474
# File 'lib/stripe/resources/v2/core/account.rb', line 4472

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



4474
4475
4476
# File 'lib/stripe/resources/v2/core/account.rb', line 4474

def registered_name
  @registered_name
end

#registration_dateObject (readonly)

When the business was incorporated or registered.



4476
4477
4478
# File 'lib/stripe/resources/v2/core/account.rb', line 4476

def registration_date
  @registration_date
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



4478
4479
4480
# File 'lib/stripe/resources/v2/core/account.rb', line 4478

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



4480
4481
4482
# File 'lib/stripe/resources/v2/core/account.rb', line 4480

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



4482
4483
4484
# File 'lib/stripe/resources/v2/core/account.rb', line 4482

def structure
  @structure
end

Class Method Details

.field_remappingsObject



4497
4498
4499
# File 'lib/stripe/resources/v2/core/account.rb', line 4497

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4484
4485
4486
4487
4488
4489
4490
4491
4492
4493
4494
4495
# File 'lib/stripe/resources/v2/core/account.rb', line 4484

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    registration_date: RegistrationDate,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end