Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The company’s primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
readonly
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The company’s primary address.
4556 4557 4558 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4556 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
4558 4559 4560 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4558 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object (readonly)
A detailed description of the business’s compliance and anti-money laundering controls and practices.
4560 4561 4562 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4560 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
4562 4563 4564 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4562 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
4564 4565 4566 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4564 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
4566 4567 4568 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4566 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business.
4568 4569 4570 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4568 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
4570 4571 4572 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4570 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
4572 4573 4574 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4572 def registered_name @registered_name end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
4574 4575 4576 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4574 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
4576 4577 4578 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4576 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
4578 4579 4580 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4578 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
4592 4593 4594 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4592 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4580 def self.inner_class_types @inner_class_types = { address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |