Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The company’s primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
readonly
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The company’s primary address.
4227 4228 4229 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4227 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
4229 4230 4231 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4229 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object (readonly)
A detailed description of the business’s compliance and anti-money laundering controls and practices.
4231 4232 4233 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4231 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
4233 4234 4235 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4233 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
4235 4236 4237 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4235 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
4237 4238 4239 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4237 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business.
4239 4240 4241 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4239 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
4241 4242 4243 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4241 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
4243 4244 4245 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4243 def registered_name @registered_name end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
4245 4246 4247 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4245 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
4247 4248 4249 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4247 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
4249 4250 4251 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4249 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
4263 4264 4265 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4263 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4251 def self.inner_class_types @inner_class_types = { address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |