Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



3871
3872
3873
# File 'lib/stripe/resources/v2/core/account.rb', line 3871

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



3873
3874
3875
# File 'lib/stripe/resources/v2/core/account.rb', line 3873

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3875
3876
3877
# File 'lib/stripe/resources/v2/core/account.rb', line 3875

def documents
  @documents
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3877
3878
3879
# File 'lib/stripe/resources/v2/core/account.rb', line 3877

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



3879
3880
3881
# File 'lib/stripe/resources/v2/core/account.rb', line 3879

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



3881
3882
3883
# File 'lib/stripe/resources/v2/core/account.rb', line 3881

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



3883
3884
3885
# File 'lib/stripe/resources/v2/core/account.rb', line 3883

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



3885
3886
3887
# File 'lib/stripe/resources/v2/core/account.rb', line 3885

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



3887
3888
3889
# File 'lib/stripe/resources/v2/core/account.rb', line 3887

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



3889
3890
3891
# File 'lib/stripe/resources/v2/core/account.rb', line 3889

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



3891
3892
3893
# File 'lib/stripe/resources/v2/core/account.rb', line 3891

def structure
  @structure
end

Class Method Details

.field_remappingsObject



3905
3906
3907
# File 'lib/stripe/resources/v2/core/account.rb', line 3905

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
# File 'lib/stripe/resources/v2/core/account.rb', line 3893

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end