Class: Stripe::V2::Core::Account::Identity::BusinessDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The company’s primary address.
-
#annual_revenue ⇒ Object
readonly
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#estimated_worker_count ⇒ Object
readonly
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
readonly
The provided ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
readonly
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
readonly
The company’s phone number (used for verification).
-
#registered_name ⇒ Object
readonly
The business legal name.
-
#script_addresses ⇒ Object
readonly
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
readonly
The business legal name in non latin script.
-
#structure ⇒ Object
readonly
The category identifying the legal structure of the business.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The company’s primary address.
3818 3819 3820 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3818 def address @address end |
#annual_revenue ⇒ Object (readonly)
The business gross annual revenue for its preceding fiscal year.
3820 3821 3822 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3820 def annual_revenue @annual_revenue end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
3822 3823 3824 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3822 def documents @documents end |
#estimated_worker_count ⇒ Object (readonly)
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
3824 3825 3826 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3824 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object (readonly)
The provided ID numbers of a business entity.
3826 3827 3828 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3826 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object (readonly)
An estimate of the monthly revenue of the business.
3828 3829 3830 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3828 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object (readonly)
The company’s phone number (used for verification).
3830 3831 3832 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3830 def phone @phone end |
#registered_name ⇒ Object (readonly)
The business legal name.
3832 3833 3834 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3832 def registered_name @registered_name end |
#script_addresses ⇒ Object (readonly)
The business registration address of the business entity in non latin script.
3834 3835 3836 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3834 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The business legal name in non latin script.
3836 3837 3838 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3836 def script_names @script_names end |
#structure ⇒ Object (readonly)
The category identifying the legal structure of the business.
3838 3839 3840 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3838 def structure @structure end |
Class Method Details
.field_remappings ⇒ Object
3852 3853 3854 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3852 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3840 def self.inner_class_types @inner_class_types = { address: Address, annual_revenue: AnnualRevenue, documents: Documents, id_numbers: IdNumber, monthly_estimated_revenue: MonthlyEstimatedRevenue, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |