Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



3149
3150
3151
# File 'lib/stripe/resources/v2/core/account.rb', line 3149

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



3151
3152
3153
# File 'lib/stripe/resources/v2/core/account.rb', line 3151

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3153
3154
3155
# File 'lib/stripe/resources/v2/core/account.rb', line 3153

def documents
  @documents
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3155
3156
3157
# File 'lib/stripe/resources/v2/core/account.rb', line 3155

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



3157
3158
3159
# File 'lib/stripe/resources/v2/core/account.rb', line 3157

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



3159
3160
3161
# File 'lib/stripe/resources/v2/core/account.rb', line 3159

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



3161
3162
3163
# File 'lib/stripe/resources/v2/core/account.rb', line 3161

def phone
  @phone
end

#registered_nameObject (readonly)

The business legal name.



3163
3164
3165
# File 'lib/stripe/resources/v2/core/account.rb', line 3163

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



3165
3166
3167
# File 'lib/stripe/resources/v2/core/account.rb', line 3165

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



3167
3168
3169
# File 'lib/stripe/resources/v2/core/account.rb', line 3167

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



3169
3170
3171
# File 'lib/stripe/resources/v2/core/account.rb', line 3169

def structure
  @structure
end

Class Method Details

.field_remappingsObject



3183
3184
3185
# File 'lib/stripe/resources/v2/core/account.rb', line 3183

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3171
3172
3173
3174
3175
3176
3177
3178
3179
3180
3181
# File 'lib/stripe/resources/v2/core/account.rb', line 3171

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end