Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



3096
3097
3098
# File 'lib/stripe/resources/v2/core/account.rb', line 3096

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



3098
3099
3100
# File 'lib/stripe/resources/v2/core/account.rb', line 3098

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3100
3101
3102
# File 'lib/stripe/resources/v2/core/account.rb', line 3100

def documents
  @documents
end

#doing_business_asObject (readonly)

The company’s legal name.



3102
3103
3104
# File 'lib/stripe/resources/v2/core/account.rb', line 3102

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3104
3105
3106
# File 'lib/stripe/resources/v2/core/account.rb', line 3104

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



3106
3107
3108
# File 'lib/stripe/resources/v2/core/account.rb', line 3106

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



3108
3109
3110
# File 'lib/stripe/resources/v2/core/account.rb', line 3108

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



3110
3111
3112
# File 'lib/stripe/resources/v2/core/account.rb', line 3110

def phone
  @phone
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



3112
3113
3114
# File 'lib/stripe/resources/v2/core/account.rb', line 3112

def product_description
  @product_description
end

#registered_nameObject (readonly)

The business legal name.



3114
3115
3116
# File 'lib/stripe/resources/v2/core/account.rb', line 3114

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



3116
3117
3118
# File 'lib/stripe/resources/v2/core/account.rb', line 3116

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



3118
3119
3120
# File 'lib/stripe/resources/v2/core/account.rb', line 3118

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



3120
3121
3122
# File 'lib/stripe/resources/v2/core/account.rb', line 3120

def structure
  @structure
end

#urlObject (readonly)

The business’s publicly available website.



3122
3123
3124
# File 'lib/stripe/resources/v2/core/account.rb', line 3122

def url
  @url
end

Class Method Details

.field_remappingsObject



3136
3137
3138
# File 'lib/stripe/resources/v2/core/account.rb', line 3136

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/stripe/resources/v2/core/account.rb', line 3124

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    annual_revenue: AnnualRevenue,
    documents: Documents,
    id_numbers: IdNumber,
    monthly_estimated_revenue: MonthlyEstimatedRevenue,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end