Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



1524
1525
1526
# File 'lib/stripe/resources/v2/core/account.rb', line 1524

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



1526
1527
1528
# File 'lib/stripe/resources/v2/core/account.rb', line 1526

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



1528
1529
1530
# File 'lib/stripe/resources/v2/core/account.rb', line 1528

def documents
  @documents
end

#doing_business_asObject (readonly)

The company’s legal name.



1530
1531
1532
# File 'lib/stripe/resources/v2/core/account.rb', line 1530

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1532
1533
1534
# File 'lib/stripe/resources/v2/core/account.rb', line 1532

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



1534
1535
1536
# File 'lib/stripe/resources/v2/core/account.rb', line 1534

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



1536
1537
1538
# File 'lib/stripe/resources/v2/core/account.rb', line 1536

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



1538
1539
1540
# File 'lib/stripe/resources/v2/core/account.rb', line 1538

def phone
  @phone
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1540
1541
1542
# File 'lib/stripe/resources/v2/core/account.rb', line 1540

def product_description
  @product_description
end

#registered_nameObject (readonly)

The business legal name.



1542
1543
1544
# File 'lib/stripe/resources/v2/core/account.rb', line 1542

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



1544
1545
1546
# File 'lib/stripe/resources/v2/core/account.rb', line 1544

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



1546
1547
1548
# File 'lib/stripe/resources/v2/core/account.rb', line 1546

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



1548
1549
1550
# File 'lib/stripe/resources/v2/core/account.rb', line 1548

def structure
  @structure
end

#urlObject (readonly)

The business’s publicly available website.



1550
1551
1552
# File 'lib/stripe/resources/v2/core/account.rb', line 1550

def url
  @url
end