Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



1349
1350
1351
# File 'lib/stripe/resources/v2/core/account.rb', line 1349

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



1351
1352
1353
# File 'lib/stripe/resources/v2/core/account.rb', line 1351

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



1353
1354
1355
# File 'lib/stripe/resources/v2/core/account.rb', line 1353

def documents
  @documents
end

#doing_business_asObject (readonly)

The company’s legal name.



1355
1356
1357
# File 'lib/stripe/resources/v2/core/account.rb', line 1355

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1357
1358
1359
# File 'lib/stripe/resources/v2/core/account.rb', line 1357

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



1359
1360
1361
# File 'lib/stripe/resources/v2/core/account.rb', line 1359

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



1361
1362
1363
# File 'lib/stripe/resources/v2/core/account.rb', line 1361

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



1363
1364
1365
# File 'lib/stripe/resources/v2/core/account.rb', line 1363

def phone
  @phone
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1365
1366
1367
# File 'lib/stripe/resources/v2/core/account.rb', line 1365

def product_description
  @product_description
end

#registered_nameObject (readonly)

The business legal name.



1367
1368
1369
# File 'lib/stripe/resources/v2/core/account.rb', line 1367

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



1369
1370
1371
# File 'lib/stripe/resources/v2/core/account.rb', line 1369

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



1371
1372
1373
# File 'lib/stripe/resources/v2/core/account.rb', line 1371

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



1373
1374
1375
# File 'lib/stripe/resources/v2/core/account.rb', line 1373

def structure
  @structure
end

#urlObject (readonly)

The business’s publicly available website.



1375
1376
1377
# File 'lib/stripe/resources/v2/core/account.rb', line 1375

def url
  @url
end