Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



1340
1341
1342
# File 'lib/stripe/resources/v2/core/account.rb', line 1340

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



1342
1343
1344
# File 'lib/stripe/resources/v2/core/account.rb', line 1342

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



1344
1345
1346
# File 'lib/stripe/resources/v2/core/account.rb', line 1344

def documents
  @documents
end

#doing_business_asObject (readonly)

The company’s legal name.



1346
1347
1348
# File 'lib/stripe/resources/v2/core/account.rb', line 1346

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1348
1349
1350
# File 'lib/stripe/resources/v2/core/account.rb', line 1348

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



1350
1351
1352
# File 'lib/stripe/resources/v2/core/account.rb', line 1350

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



1352
1353
1354
# File 'lib/stripe/resources/v2/core/account.rb', line 1352

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



1354
1355
1356
# File 'lib/stripe/resources/v2/core/account.rb', line 1354

def phone
  @phone
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1356
1357
1358
# File 'lib/stripe/resources/v2/core/account.rb', line 1356

def product_description
  @product_description
end

#registered_nameObject (readonly)

The business legal name.



1358
1359
1360
# File 'lib/stripe/resources/v2/core/account.rb', line 1358

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



1360
1361
1362
# File 'lib/stripe/resources/v2/core/account.rb', line 1360

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



1362
1363
1364
# File 'lib/stripe/resources/v2/core/account.rb', line 1362

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



1364
1365
1366
# File 'lib/stripe/resources/v2/core/account.rb', line 1364

def structure
  @structure
end

#urlObject (readonly)

The business’s publicly available website.



1366
1367
1368
# File 'lib/stripe/resources/v2/core/account.rb', line 1366

def url
  @url
end