Class: Stripe::V2::Core::Account::Identity::BusinessDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The company’s primary address.



1302
1303
1304
# File 'lib/stripe/resources/v2/core/account.rb', line 1302

def address
  @address
end

#annual_revenueObject (readonly)

The business gross annual revenue for its preceding fiscal year.



1304
1305
1306
# File 'lib/stripe/resources/v2/core/account.rb', line 1304

def annual_revenue
  @annual_revenue
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



1306
1307
1308
# File 'lib/stripe/resources/v2/core/account.rb', line 1306

def documents
  @documents
end

#doing_business_asObject (readonly)

The company’s legal name.



1308
1309
1310
# File 'lib/stripe/resources/v2/core/account.rb', line 1308

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject (readonly)

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1310
1311
1312
# File 'lib/stripe/resources/v2/core/account.rb', line 1310

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject (readonly)

The provided ID numbers of a business entity.



1312
1313
1314
# File 'lib/stripe/resources/v2/core/account.rb', line 1312

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject (readonly)

An estimate of the monthly revenue of the business.



1314
1315
1316
# File 'lib/stripe/resources/v2/core/account.rb', line 1314

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject (readonly)

The company’s phone number (used for verification).



1316
1317
1318
# File 'lib/stripe/resources/v2/core/account.rb', line 1316

def phone
  @phone
end

#product_descriptionObject (readonly)

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1318
1319
1320
# File 'lib/stripe/resources/v2/core/account.rb', line 1318

def product_description
  @product_description
end

#registered_nameObject (readonly)

The business legal name.



1320
1321
1322
# File 'lib/stripe/resources/v2/core/account.rb', line 1320

def registered_name
  @registered_name
end

#script_addressesObject (readonly)

The business registration address of the business entity in non latin script.



1322
1323
1324
# File 'lib/stripe/resources/v2/core/account.rb', line 1322

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The business legal name in non latin script.



1324
1325
1326
# File 'lib/stripe/resources/v2/core/account.rb', line 1324

def script_names
  @script_names
end

#structureObject (readonly)

The category identifying the legal structure of the business.



1326
1327
1328
# File 'lib/stripe/resources/v2/core/account.rb', line 1326

def structure
  @structure
end

#urlObject (readonly)

The business’s publicly available website.



1328
1329
1330
# File 'lib/stripe/resources/v2/core/account.rb', line 1328

def url
  @url
end