Class: Stripe::V2::Core::Account::Identity::BusinessDetails::AnnualRevenue
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::AnnualRevenue
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A non-negative integer representing the amount in the smallest currency unit.
-
#fiscal_year_end ⇒ Object
readonly
The close-out date of the preceding fiscal year in ISO 8601 format.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A non-negative integer representing the amount in the smallest currency unit.
1178 1179 1180 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1178 def amount @amount end |
#fiscal_year_end ⇒ Object (readonly)
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
1180 1181 1182 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1180 def fiscal_year_end @fiscal_year_end end |