Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_account_ownership_verificationObject (readonly)

One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



3553
3554
3555
# File 'lib/stripe/resources/v2/core/account.rb', line 3553

def 
  @bank_account_ownership_verification
end

#company_licenseObject (readonly)

One or more documents that demonstrate proof of a company’s license to operate.



3555
3556
3557
# File 'lib/stripe/resources/v2/core/account.rb', line 3555

def company_license
  @company_license
end

#company_memorandum_of_associationObject (readonly)

One or more documents showing the company’s Memorandum of Association.



3557
3558
3559
# File 'lib/stripe/resources/v2/core/account.rb', line 3557

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject (readonly)

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



3559
3560
3561
# File 'lib/stripe/resources/v2/core/account.rb', line 3559

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



3561
3562
3563
# File 'lib/stripe/resources/v2/core/account.rb', line 3561

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s tax ID.



3563
3564
3565
# File 'lib/stripe/resources/v2/core/account.rb', line 3563

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject (readonly)

A document verifying the business.



3565
3566
3567
# File 'lib/stripe/resources/v2/core/account.rb', line 3565

def primary_verification
  @primary_verification
end

#proof_of_addressObject (readonly)

One or more documents that demonstrate proof of address.



3567
3568
3569
# File 'lib/stripe/resources/v2/core/account.rb', line 3567

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject (readonly)

One or more documents showing the company’s proof of registration with the national business registry.



3569
3570
3571
# File 'lib/stripe/resources/v2/core/account.rb', line 3569

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject (readonly)

One or more documents that demonstrate proof of ultimate beneficial ownership.



3571
3572
3573
# File 'lib/stripe/resources/v2/core/account.rb', line 3571

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end

Class Method Details

.field_remappingsObject



3588
3589
3590
# File 'lib/stripe/resources/v2/core/account.rb', line 3588

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
# File 'lib/stripe/resources/v2/core/account.rb', line 3573

def self.inner_class_types
  @inner_class_types = {
    bank_account_ownership_verification: BankAccountOwnershipVerification,
    company_license: CompanyLicense,
    company_memorandum_of_association: CompanyMemorandumOfAssociation,
    company_ministerial_decree: CompanyMinisterialDecree,
    company_registration_verification: CompanyRegistrationVerification,
    company_tax_id_verification: CompanyTaxIdVerification,
    primary_verification: PrimaryVerification,
    proof_of_address: ProofOfAddress,
    proof_of_registration: ProofOfRegistration,
    proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership,
  }
end