Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
readonly
One or more documents that support the Bank account ownership verification requirement.
-
#company_license ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
readonly
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
readonly
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
readonly
A document verifying the business.
-
#proof_of_address ⇒ Object
readonly
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
readonly
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
readonly
One or more documents that demonstrate proof of ultimate beneficial ownership.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object (readonly)
One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
3236 3237 3238 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3236 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s license to operate.
3238 3239 3240 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3238 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object (readonly)
One or more documents showing the company’s Memorandum of Association.
3240 3241 3242 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3240 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object (readonly)
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
3242 3243 3244 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3242 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
3244 3245 3246 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3244 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s tax ID.
3246 3247 3248 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3246 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object (readonly)
A document verifying the business.
3248 3249 3250 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3248 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object (readonly)
One or more documents that demonstrate proof of address.
3250 3251 3252 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3250 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object (readonly)
One or more documents showing the company’s proof of registration with the national business registry.
3252 3253 3254 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3252 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object (readonly)
One or more documents that demonstrate proof of ultimate beneficial ownership.
3254 3255 3256 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3254 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |
Class Method Details
.field_remappings ⇒ Object
3271 3272 3273 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3271 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3256 def self.inner_class_types @inner_class_types = { bank_account_ownership_verification: BankAccountOwnershipVerification, company_license: CompanyLicense, company_memorandum_of_association: CompanyMemorandumOfAssociation, company_ministerial_decree: CompanyMinisterialDecree, company_registration_verification: CompanyRegistrationVerification, company_tax_id_verification: CompanyTaxIdVerification, primary_verification: PrimaryVerification, proof_of_address: ProofOfAddress, proof_of_registration: ProofOfRegistration, proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership, } end |