Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
readonly
One or more documents that support the Bank account ownership verification requirement.
-
#company_license ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
readonly
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
readonly
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
readonly
A document verifying the business.
-
#proof_of_address ⇒ Object
readonly
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
readonly
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
readonly
One or more documents that demonstrate proof of ultimate beneficial ownership.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object (readonly)
One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
3209 3210 3211 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3209 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s license to operate.
3211 3212 3213 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3211 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object (readonly)
One or more documents showing the company’s Memorandum of Association.
3213 3214 3215 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3213 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object (readonly)
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
3215 3216 3217 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3215 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
3217 3218 3219 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3217 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s tax ID.
3219 3220 3221 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3219 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object (readonly)
A document verifying the business.
3221 3222 3223 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3221 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object (readonly)
One or more documents that demonstrate proof of address.
3223 3224 3225 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3223 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object (readonly)
One or more documents showing the company’s proof of registration with the national business registry.
3225 3226 3227 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3225 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object (readonly)
One or more documents that demonstrate proof of ultimate beneficial ownership.
3227 3228 3229 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3227 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |
Class Method Details
.field_remappings ⇒ Object
3244 3245 3246 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3244 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3229 3230 3231 3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3229 def self.inner_class_types @inner_class_types = { bank_account_ownership_verification: BankAccountOwnershipVerification, company_license: CompanyLicense, company_memorandum_of_association: CompanyMemorandumOfAssociation, company_ministerial_decree: CompanyMinisterialDecree, company_registration_verification: CompanyRegistrationVerification, company_tax_id_verification: CompanyTaxIdVerification, primary_verification: PrimaryVerification, proof_of_address: ProofOfAddress, proof_of_registration: ProofOfRegistration, proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership, } end |