Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_account_ownership_verificationObject (readonly)

One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



4343
4344
4345
# File 'lib/stripe/resources/v2/core/account.rb', line 4343

def 
  @bank_account_ownership_verification
end

#company_licenseObject (readonly)

One or more documents that demonstrate proof of a company’s license to operate.



4345
4346
4347
# File 'lib/stripe/resources/v2/core/account.rb', line 4345

def company_license
  @company_license
end

#company_memorandum_of_associationObject (readonly)

One or more documents showing the company’s Memorandum of Association.



4347
4348
4349
# File 'lib/stripe/resources/v2/core/account.rb', line 4347

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject (readonly)

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



4349
4350
4351
# File 'lib/stripe/resources/v2/core/account.rb', line 4349

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



4351
4352
4353
# File 'lib/stripe/resources/v2/core/account.rb', line 4351

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s tax ID.



4353
4354
4355
# File 'lib/stripe/resources/v2/core/account.rb', line 4353

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject (readonly)

A document verifying the business.



4355
4356
4357
# File 'lib/stripe/resources/v2/core/account.rb', line 4355

def primary_verification
  @primary_verification
end

#proof_of_addressObject (readonly)

One or more documents that demonstrate proof of address.



4357
4358
4359
# File 'lib/stripe/resources/v2/core/account.rb', line 4357

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject (readonly)

One or more documents showing the company’s proof of registration with the national business registry.



4359
4360
4361
# File 'lib/stripe/resources/v2/core/account.rb', line 4359

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject (readonly)

One or more documents that demonstrate proof of ultimate beneficial ownership.



4361
4362
4363
# File 'lib/stripe/resources/v2/core/account.rb', line 4361

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end

Class Method Details

.field_remappingsObject



4378
4379
4380
# File 'lib/stripe/resources/v2/core/account.rb', line 4378

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
# File 'lib/stripe/resources/v2/core/account.rb', line 4363

def self.inner_class_types
  @inner_class_types = {
    bank_account_ownership_verification: BankAccountOwnershipVerification,
    company_license: CompanyLicense,
    company_memorandum_of_association: CompanyMemorandumOfAssociation,
    company_ministerial_decree: CompanyMinisterialDecree,
    company_registration_verification: CompanyRegistrationVerification,
    company_tax_id_verification: CompanyTaxIdVerification,
    primary_verification: PrimaryVerification,
    proof_of_address: ProofOfAddress,
    proof_of_registration: ProofOfRegistration,
    proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership,
  }
end