Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_account_ownership_verificationObject (readonly)

One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



4370
4371
4372
# File 'lib/stripe/resources/v2/core/account.rb', line 4370

def 
  @bank_account_ownership_verification
end

#company_licenseObject (readonly)

One or more documents that demonstrate proof of a company’s license to operate.



4372
4373
4374
# File 'lib/stripe/resources/v2/core/account.rb', line 4372

def company_license
  @company_license
end

#company_memorandum_of_associationObject (readonly)

One or more documents showing the company’s Memorandum of Association.



4374
4375
4376
# File 'lib/stripe/resources/v2/core/account.rb', line 4374

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject (readonly)

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



4376
4377
4378
# File 'lib/stripe/resources/v2/core/account.rb', line 4376

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



4378
4379
4380
# File 'lib/stripe/resources/v2/core/account.rb', line 4378

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s tax ID.



4380
4381
4382
# File 'lib/stripe/resources/v2/core/account.rb', line 4380

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject (readonly)

A document verifying the business.



4382
4383
4384
# File 'lib/stripe/resources/v2/core/account.rb', line 4382

def primary_verification
  @primary_verification
end

#proof_of_addressObject (readonly)

One or more documents that demonstrate proof of address.



4384
4385
4386
# File 'lib/stripe/resources/v2/core/account.rb', line 4384

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject (readonly)

One or more documents showing the company’s proof of registration with the national business registry.



4386
4387
4388
# File 'lib/stripe/resources/v2/core/account.rb', line 4386

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject (readonly)

One or more documents that demonstrate proof of ultimate beneficial ownership.



4388
4389
4390
# File 'lib/stripe/resources/v2/core/account.rb', line 4388

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end

Class Method Details

.field_remappingsObject



4405
4406
4407
# File 'lib/stripe/resources/v2/core/account.rb', line 4405

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
# File 'lib/stripe/resources/v2/core/account.rb', line 4390

def self.inner_class_types
  @inner_class_types = {
    bank_account_ownership_verification: BankAccountOwnershipVerification,
    company_license: CompanyLicense,
    company_memorandum_of_association: CompanyMemorandumOfAssociation,
    company_ministerial_decree: CompanyMinisterialDecree,
    company_registration_verification: CompanyRegistrationVerification,
    company_tax_id_verification: CompanyTaxIdVerification,
    primary_verification: PrimaryVerification,
    proof_of_address: ProofOfAddress,
    proof_of_registration: ProofOfRegistration,
    proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership,
  }
end