Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
readonly
One or more documents that support the Bank account ownership verification requirement.
-
#company_license ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
readonly
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
readonly
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
readonly
A document verifying the business.
-
#proof_of_address ⇒ Object
readonly
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
readonly
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
readonly
One or more documents that demonstrate proof of ultimate beneficial ownership.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object (readonly)
One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
3646 3647 3648 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3646 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s license to operate.
3648 3649 3650 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3648 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object (readonly)
One or more documents showing the company’s Memorandum of Association.
3650 3651 3652 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3650 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object (readonly)
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
3652 3653 3654 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3652 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
3654 3655 3656 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3654 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s tax ID.
3656 3657 3658 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3656 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object (readonly)
A document verifying the business.
3658 3659 3660 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3658 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object (readonly)
One or more documents that demonstrate proof of address.
3660 3661 3662 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3660 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object (readonly)
One or more documents showing the company’s proof of registration with the national business registry.
3662 3663 3664 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3662 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object (readonly)
One or more documents that demonstrate proof of ultimate beneficial ownership.
3664 3665 3666 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3664 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |
Class Method Details
.field_remappings ⇒ Object
3681 3682 3683 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3681 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3666 def self.inner_class_types @inner_class_types = { bank_account_ownership_verification: BankAccountOwnershipVerification, company_license: CompanyLicense, company_memorandum_of_association: CompanyMemorandumOfAssociation, company_ministerial_decree: CompanyMinisterialDecree, company_registration_verification: CompanyRegistrationVerification, company_tax_id_verification: CompanyTaxIdVerification, primary_verification: PrimaryVerification, proof_of_address: ProofOfAddress, proof_of_registration: ProofOfRegistration, proof_of_ultimate_beneficial_ownership: ProofOfUltimateBeneficialOwnership, } end |