Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
readonly
One or more documents that support the Bank account ownership verification requirement.
-
#company_license ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
readonly
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
readonly
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
readonly
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
readonly
A document verifying the business.
-
#proof_of_address ⇒ Object
readonly
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
readonly
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
readonly
One or more documents that demonstrate proof of ultimate beneficial ownership.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object (readonly)
One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
1443 1444 1445 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1443 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s license to operate.
1445 1446 1447 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1445 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object (readonly)
One or more documents showing the company’s Memorandum of Association.
1447 1448 1449 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1447 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object (readonly)
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
1449 1450 1451 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1449 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
1451 1452 1453 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1451 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object (readonly)
One or more documents that demonstrate proof of a company’s tax ID.
1453 1454 1455 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1453 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object (readonly)
A document verifying the business.
1455 1456 1457 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1455 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object (readonly)
One or more documents that demonstrate proof of address.
1457 1458 1459 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1457 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object (readonly)
One or more documents showing the company’s proof of registration with the national business registry.
1459 1460 1461 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1459 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object (readonly)
One or more documents that demonstrate proof of ultimate beneficial ownership.
1461 1462 1463 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1461 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |