Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_account_ownership_verificationObject (readonly)

One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



1435
1436
1437
# File 'lib/stripe/resources/v2/core/account.rb', line 1435

def 
  @bank_account_ownership_verification
end

#company_licenseObject (readonly)

One or more documents that demonstrate proof of a company’s license to operate.



1437
1438
1439
# File 'lib/stripe/resources/v2/core/account.rb', line 1437

def company_license
  @company_license
end

#company_memorandum_of_associationObject (readonly)

One or more documents showing the company’s Memorandum of Association.



1439
1440
1441
# File 'lib/stripe/resources/v2/core/account.rb', line 1439

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject (readonly)

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



1441
1442
1443
# File 'lib/stripe/resources/v2/core/account.rb', line 1441

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



1443
1444
1445
# File 'lib/stripe/resources/v2/core/account.rb', line 1443

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s tax ID.



1445
1446
1447
# File 'lib/stripe/resources/v2/core/account.rb', line 1445

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject (readonly)

A document verifying the business.



1447
1448
1449
# File 'lib/stripe/resources/v2/core/account.rb', line 1447

def primary_verification
  @primary_verification
end

#proof_of_addressObject (readonly)

One or more documents that demonstrate proof of address.



1449
1450
1451
# File 'lib/stripe/resources/v2/core/account.rb', line 1449

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject (readonly)

One or more documents showing the company’s proof of registration with the national business registry.



1451
1452
1453
# File 'lib/stripe/resources/v2/core/account.rb', line 1451

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject (readonly)

One or more documents that demonstrate proof of ultimate beneficial ownership.



1453
1454
1455
# File 'lib/stripe/resources/v2/core/account.rb', line 1453

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end