Class: Stripe::V2::Core::Account::Identity::BusinessDetails::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_account_ownership_verificationObject (readonly)

One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



1215
1216
1217
# File 'lib/stripe/resources/v2/core/account.rb', line 1215

def 
  @bank_account_ownership_verification
end

#company_licenseObject (readonly)

One or more documents that demonstrate proof of a company’s license to operate.



1217
1218
1219
# File 'lib/stripe/resources/v2/core/account.rb', line 1217

def company_license
  @company_license
end

#company_memorandum_of_associationObject (readonly)

One or more documents showing the company’s Memorandum of Association.



1219
1220
1221
# File 'lib/stripe/resources/v2/core/account.rb', line 1219

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject (readonly)

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



1221
1222
1223
# File 'lib/stripe/resources/v2/core/account.rb', line 1221

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



1223
1224
1225
# File 'lib/stripe/resources/v2/core/account.rb', line 1223

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject (readonly)

One or more documents that demonstrate proof of a company’s tax ID.



1225
1226
1227
# File 'lib/stripe/resources/v2/core/account.rb', line 1225

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject (readonly)

A document verifying the business.



1227
1228
1229
# File 'lib/stripe/resources/v2/core/account.rb', line 1227

def primary_verification
  @primary_verification
end

#proof_of_registrationObject (readonly)

One or more documents showing the company’s proof of registration with the national business registry.



1229
1230
1231
# File 'lib/stripe/resources/v2/core/account.rb', line 1229

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject (readonly)

One or more documents that demonstrate proof of ultimate beneficial ownership.



1231
1232
1233
# File 'lib/stripe/resources/v2/core/account.rb', line 1231

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end