Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual's residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual's date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual's email address.
-
#given_name ⇒ Object
readonly
The individual's first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual's gender (International regulations require either "male" or "female").
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#phone ⇒ Object
readonly
The individual's phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account's identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual's last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
19840 19841 19842 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19840 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
19842 19843 19844 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19842 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
19844 19845 19846 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19844 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
19846 19847 19848 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19846 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual's residential address.
19848 19849 19850 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19848 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
19850 19851 19852 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19850 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual's date of birth.
19852 19853 19854 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19852 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
19854 19855 19856 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19854 def documents @documents end |
#email ⇒ Object (readonly)
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
19856 19857 19858 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19856 def email @email end |
#given_name ⇒ Object (readonly)
The individual's first name.
19858 19859 19860 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19858 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
19860 19861 19862 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19860 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
19862 19863 19864 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19862 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual's gender (International regulations require either "male" or "female").
19864 19865 19866 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19864 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
19866 19867 19868 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19866 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
19868 19869 19870 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19868 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
19870 19871 19872 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19870 def object @object end |
#phone ⇒ Object (readonly)
The individual's phone number.
19872 19873 19874 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19872 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
19874 19875 19876 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19874 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account's identity.
19876 19877 19878 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19876 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
19878 19879 19880 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19878 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
19880 19881 19882 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19880 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual's last name.
19882 19883 19884 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19882 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
19884 19885 19886 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19884 def updated @updated end |
Class Method Details
.field_encodings ⇒ Object
19905 19906 19907 19908 19909 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19905 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |
.field_remappings ⇒ Object
19901 19902 19903 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19901 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
19886 19887 19888 19889 19890 19891 19892 19893 19894 19895 19896 19897 19898 19899 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19886 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |