Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



3334
3335
3336
# File 'lib/stripe/resources/v2/core/account.rb', line 3334

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



3336
3337
3338
# File 'lib/stripe/resources/v2/core/account.rb', line 3336

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



3338
3339
3340
# File 'lib/stripe/resources/v2/core/account.rb', line 3338

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



3340
3341
3342
# File 'lib/stripe/resources/v2/core/account.rb', line 3340

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual's residential address.



3342
3343
3344
# File 'lib/stripe/resources/v2/core/account.rb', line 3342

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3344
3345
3346
# File 'lib/stripe/resources/v2/core/account.rb', line 3344

def created
  @created
end

#date_of_birthObject (readonly)

The individual's date of birth.



3346
3347
3348
# File 'lib/stripe/resources/v2/core/account.rb', line 3346

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3348
3349
3350
# File 'lib/stripe/resources/v2/core/account.rb', line 3348

def documents
  @documents
end

#emailObject (readonly)

The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.



3350
3351
3352
# File 'lib/stripe/resources/v2/core/account.rb', line 3350

def email
  @email
end

#given_nameObject (readonly)

The individual's first name.



3352
3353
3354
# File 'lib/stripe/resources/v2/core/account.rb', line 3352

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



3354
3355
3356
# File 'lib/stripe/resources/v2/core/account.rb', line 3354

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



3356
3357
3358
# File 'lib/stripe/resources/v2/core/account.rb', line 3356

def id_numbers
  @id_numbers
end

The individual's gender (International regulations require either "male” or "female").



3358
3359
3360
# File 'lib/stripe/resources/v2/core/account.rb', line 3358

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3360
3361
3362
# File 'lib/stripe/resources/v2/core/account.rb', line 3360

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).



3362
3363
3364
# File 'lib/stripe/resources/v2/core/account.rb', line 3362

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



3364
3365
3366
# File 'lib/stripe/resources/v2/core/account.rb', line 3364

def object
  @object
end

#phoneObject (readonly)

The individual's phone number.



3366
3367
3368
# File 'lib/stripe/resources/v2/core/account.rb', line 3366

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



3368
3369
3370
# File 'lib/stripe/resources/v2/core/account.rb', line 3368

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account's identity.



3370
3371
3372
# File 'lib/stripe/resources/v2/core/account.rb', line 3370

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



3372
3373
3374
# File 'lib/stripe/resources/v2/core/account.rb', line 3372

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



3374
3375
3376
# File 'lib/stripe/resources/v2/core/account.rb', line 3374

def script_names
  @script_names
end

#surnameObject (readonly)

The individual's last name.



3376
3377
3378
# File 'lib/stripe/resources/v2/core/account.rb', line 3376

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



3378
3379
3380
# File 'lib/stripe/resources/v2/core/account.rb', line 3378

def updated
  @updated
end

Class Method Details

.field_encodingsObject



3399
3400
3401
3402
3403
# File 'lib/stripe/resources/v2/core/account.rb', line 3399

def self.field_encodings
  @field_encodings = {
    relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
  }
end

.field_remappingsObject



3395
3396
3397
# File 'lib/stripe/resources/v2/core/account.rb', line 3395

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/stripe/resources/v2/core/account.rb', line 3380

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end