Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual's residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual's date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual's email address.
-
#given_name ⇒ Object
readonly
The individual's first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual's gender (International regulations require either "male” or "female").
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#phone ⇒ Object
readonly
The individual's phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account's identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual's last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
4213 4214 4215 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4213 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
4215 4216 4217 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4215 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
4217 4218 4219 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4217 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
4219 4220 4221 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4219 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual's residential address.
4221 4222 4223 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4221 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
4223 4224 4225 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4223 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual's date of birth.
4225 4226 4227 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4225 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
4227 4228 4229 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4227 def documents @documents end |
#email ⇒ Object (readonly)
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
4229 4230 4231 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4229 def email @email end |
#given_name ⇒ Object (readonly)
The individual's first name.
4231 4232 4233 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4231 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
4233 4234 4235 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4233 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
4235 4236 4237 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4235 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual's gender (International regulations require either "male” or "female").
4237 4238 4239 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4237 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4239 4240 4241 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4239 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
4241 4242 4243 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4241 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
4243 4244 4245 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4243 def object @object end |
#phone ⇒ Object (readonly)
The individual's phone number.
4245 4246 4247 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4245 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
4247 4248 4249 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4247 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account's identity.
4249 4250 4251 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4249 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
4251 4252 4253 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4251 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
4253 4254 4255 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4253 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual's last name.
4255 4256 4257 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4255 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
4257 4258 4259 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4257 def updated @updated end |
Class Method Details
.field_encodings ⇒ Object
4278 4279 4280 4281 4282 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4278 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |
.field_remappings ⇒ Object
4274 4275 4276 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4274 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4259 4260 4261 4262 4263 4264 4265 4266 4267 4268 4269 4270 4271 4272 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4259 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |