Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



5920
5921
5922
# File 'lib/stripe/resources/v2/core/account.rb', line 5920

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



5922
5923
5924
# File 'lib/stripe/resources/v2/core/account.rb', line 5922

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



5924
5925
5926
# File 'lib/stripe/resources/v2/core/account.rb', line 5924

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



5926
5927
5928
# File 'lib/stripe/resources/v2/core/account.rb', line 5926

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



5928
5929
5930
# File 'lib/stripe/resources/v2/core/account.rb', line 5928

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



5930
5931
5932
# File 'lib/stripe/resources/v2/core/account.rb', line 5930

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



5932
5933
5934
# File 'lib/stripe/resources/v2/core/account.rb', line 5932

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



5934
5935
5936
# File 'lib/stripe/resources/v2/core/account.rb', line 5934

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.



5936
5937
5938
# File 'lib/stripe/resources/v2/core/account.rb', line 5936

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



5938
5939
5940
# File 'lib/stripe/resources/v2/core/account.rb', line 5938

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



5940
5941
5942
# File 'lib/stripe/resources/v2/core/account.rb', line 5940

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



5942
5943
5944
# File 'lib/stripe/resources/v2/core/account.rb', line 5942

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



5944
5945
5946
# File 'lib/stripe/resources/v2/core/account.rb', line 5944

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5946
5947
5948
# File 'lib/stripe/resources/v2/core/account.rb', line 5946

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



5948
5949
5950
# File 'lib/stripe/resources/v2/core/account.rb', line 5948

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



5950
5951
5952
# File 'lib/stripe/resources/v2/core/account.rb', line 5950

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



5952
5953
5954
# File 'lib/stripe/resources/v2/core/account.rb', line 5952

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



5954
5955
5956
# File 'lib/stripe/resources/v2/core/account.rb', line 5954

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



5956
5957
5958
# File 'lib/stripe/resources/v2/core/account.rb', line 5956

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



5958
5959
5960
# File 'lib/stripe/resources/v2/core/account.rb', line 5958

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



5960
5961
5962
# File 'lib/stripe/resources/v2/core/account.rb', line 5960

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



5962
5963
5964
# File 'lib/stripe/resources/v2/core/account.rb', line 5962

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



5964
5965
5966
# File 'lib/stripe/resources/v2/core/account.rb', line 5964

def updated
  @updated
end

Class Method Details

.field_encodingsObject



5985
5986
5987
5988
5989
# File 'lib/stripe/resources/v2/core/account.rb', line 5985

def self.field_encodings
  @field_encodings = {
    relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
  }
end

.field_remappingsObject



5981
5982
5983
# File 'lib/stripe/resources/v2/core/account.rb', line 5981

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
5979
# File 'lib/stripe/resources/v2/core/account.rb', line 5966

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end