Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



3272
3273
3274
# File 'lib/stripe/resources/v2/core/account.rb', line 3272

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



3274
3275
3276
# File 'lib/stripe/resources/v2/core/account.rb', line 3274

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



3276
3277
3278
# File 'lib/stripe/resources/v2/core/account.rb', line 3276

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



3278
3279
3280
# File 'lib/stripe/resources/v2/core/account.rb', line 3278

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



3280
3281
3282
# File 'lib/stripe/resources/v2/core/account.rb', line 3280

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3282
3283
3284
# File 'lib/stripe/resources/v2/core/account.rb', line 3282

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



3284
3285
3286
# File 'lib/stripe/resources/v2/core/account.rb', line 3284

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3286
3287
3288
# File 'lib/stripe/resources/v2/core/account.rb', line 3286

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.



3288
3289
3290
# File 'lib/stripe/resources/v2/core/account.rb', line 3288

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



3290
3291
3292
# File 'lib/stripe/resources/v2/core/account.rb', line 3290

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



3292
3293
3294
# File 'lib/stripe/resources/v2/core/account.rb', line 3292

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



3294
3295
3296
# File 'lib/stripe/resources/v2/core/account.rb', line 3294

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



3296
3297
3298
# File 'lib/stripe/resources/v2/core/account.rb', line 3296

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3298
3299
3300
# File 'lib/stripe/resources/v2/core/account.rb', line 3298

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



3300
3301
3302
# File 'lib/stripe/resources/v2/core/account.rb', line 3300

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3302
3303
3304
# File 'lib/stripe/resources/v2/core/account.rb', line 3302

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



3304
3305
3306
# File 'lib/stripe/resources/v2/core/account.rb', line 3304

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



3306
3307
3308
# File 'lib/stripe/resources/v2/core/account.rb', line 3306

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



3308
3309
3310
# File 'lib/stripe/resources/v2/core/account.rb', line 3308

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



3310
3311
3312
# File 'lib/stripe/resources/v2/core/account.rb', line 3310

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



3312
3313
3314
# File 'lib/stripe/resources/v2/core/account.rb', line 3312

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



3314
3315
3316
# File 'lib/stripe/resources/v2/core/account.rb', line 3314

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



3316
3317
3318
# File 'lib/stripe/resources/v2/core/account.rb', line 3316

def updated
  @updated
end

Class Method Details

.field_encodingsObject



3337
3338
3339
3340
3341
# File 'lib/stripe/resources/v2/core/account.rb', line 3337

def self.field_encodings
  @field_encodings = {
    relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
  }
end

.field_remappingsObject



3333
3334
3335
# File 'lib/stripe/resources/v2/core/account.rb', line 3333

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
# File 'lib/stripe/resources/v2/core/account.rb', line 3318

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end