Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
5778 5779 5780 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5778 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
5780 5781 5782 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5780 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
5782 5783 5784 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5782 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
5784 5785 5786 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5784 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
5786 5787 5788 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5786 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
5788 5789 5790 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5788 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
5790 5791 5792 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5790 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
5792 5793 5794 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5792 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
5794 5795 5796 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5794 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
5796 5797 5798 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5796 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
5798 5799 5800 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5798 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
5800 5801 5802 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5800 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
5802 5803 5804 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5802 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
5804 5805 5806 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5804 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
5806 5807 5808 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5806 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
5808 5809 5810 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5808 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
5810 5811 5812 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5810 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
5812 5813 5814 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5812 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
5814 5815 5816 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5814 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
5816 5817 5818 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5816 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
5818 5819 5820 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5818 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
5820 5821 5822 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5820 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
5822 5823 5824 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5822 def updated @updated end |
Class Method Details
.field_encodings ⇒ Object
5843 5844 5845 5846 5847 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5843 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |
.field_remappings ⇒ Object
5839 5840 5841 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5839 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5824 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |