Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



3839
3840
3841
# File 'lib/stripe/resources/v2/core/account.rb', line 3839

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



3841
3842
3843
# File 'lib/stripe/resources/v2/core/account.rb', line 3841

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



3843
3844
3845
# File 'lib/stripe/resources/v2/core/account.rb', line 3843

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



3845
3846
3847
# File 'lib/stripe/resources/v2/core/account.rb', line 3845

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



3847
3848
3849
# File 'lib/stripe/resources/v2/core/account.rb', line 3847

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3849
3850
3851
# File 'lib/stripe/resources/v2/core/account.rb', line 3849

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



3851
3852
3853
# File 'lib/stripe/resources/v2/core/account.rb', line 3851

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3853
3854
3855
# File 'lib/stripe/resources/v2/core/account.rb', line 3853

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



3855
3856
3857
# File 'lib/stripe/resources/v2/core/account.rb', line 3855

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



3857
3858
3859
# File 'lib/stripe/resources/v2/core/account.rb', line 3857

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



3859
3860
3861
# File 'lib/stripe/resources/v2/core/account.rb', line 3859

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



3861
3862
3863
# File 'lib/stripe/resources/v2/core/account.rb', line 3861

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



3863
3864
3865
# File 'lib/stripe/resources/v2/core/account.rb', line 3863

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3865
3866
3867
# File 'lib/stripe/resources/v2/core/account.rb', line 3865

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



3867
3868
3869
# File 'lib/stripe/resources/v2/core/account.rb', line 3867

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3869
3870
3871
# File 'lib/stripe/resources/v2/core/account.rb', line 3869

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



3871
3872
3873
# File 'lib/stripe/resources/v2/core/account.rb', line 3871

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



3873
3874
3875
# File 'lib/stripe/resources/v2/core/account.rb', line 3873

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



3875
3876
3877
# File 'lib/stripe/resources/v2/core/account.rb', line 3875

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



3877
3878
3879
# File 'lib/stripe/resources/v2/core/account.rb', line 3877

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



3879
3880
3881
# File 'lib/stripe/resources/v2/core/account.rb', line 3879

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



3881
3882
3883
# File 'lib/stripe/resources/v2/core/account.rb', line 3881

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



3883
3884
3885
# File 'lib/stripe/resources/v2/core/account.rb', line 3883

def updated
  @updated
end

Class Method Details

.field_encodingsObject



3904
3905
3906
3907
3908
# File 'lib/stripe/resources/v2/core/account.rb', line 3904

def self.field_encodings
  @field_encodings = {
    relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
  }
end

.field_remappingsObject



3900
3901
3902
# File 'lib/stripe/resources/v2/core/account.rb', line 3900

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
3895
3896
3897
3898
# File 'lib/stripe/resources/v2/core/account.rb', line 3885

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end