Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



5779
5780
5781
# File 'lib/stripe/resources/v2/core/account.rb', line 5779

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



5781
5782
5783
# File 'lib/stripe/resources/v2/core/account.rb', line 5781

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



5783
5784
5785
# File 'lib/stripe/resources/v2/core/account.rb', line 5783

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



5785
5786
5787
# File 'lib/stripe/resources/v2/core/account.rb', line 5785

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



5787
5788
5789
# File 'lib/stripe/resources/v2/core/account.rb', line 5787

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



5789
5790
5791
# File 'lib/stripe/resources/v2/core/account.rb', line 5789

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



5791
5792
5793
# File 'lib/stripe/resources/v2/core/account.rb', line 5791

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



5793
5794
5795
# File 'lib/stripe/resources/v2/core/account.rb', line 5793

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



5795
5796
5797
# File 'lib/stripe/resources/v2/core/account.rb', line 5795

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



5797
5798
5799
# File 'lib/stripe/resources/v2/core/account.rb', line 5797

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



5799
5800
5801
# File 'lib/stripe/resources/v2/core/account.rb', line 5799

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



5801
5802
5803
# File 'lib/stripe/resources/v2/core/account.rb', line 5801

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



5803
5804
5805
# File 'lib/stripe/resources/v2/core/account.rb', line 5803

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5805
5806
5807
# File 'lib/stripe/resources/v2/core/account.rb', line 5805

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



5807
5808
5809
# File 'lib/stripe/resources/v2/core/account.rb', line 5807

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



5809
5810
5811
# File 'lib/stripe/resources/v2/core/account.rb', line 5809

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



5811
5812
5813
# File 'lib/stripe/resources/v2/core/account.rb', line 5811

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



5813
5814
5815
# File 'lib/stripe/resources/v2/core/account.rb', line 5813

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



5815
5816
5817
# File 'lib/stripe/resources/v2/core/account.rb', line 5815

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



5817
5818
5819
# File 'lib/stripe/resources/v2/core/account.rb', line 5817

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



5819
5820
5821
# File 'lib/stripe/resources/v2/core/account.rb', line 5819

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



5821
5822
5823
# File 'lib/stripe/resources/v2/core/account.rb', line 5821

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



5823
5824
5825
# File 'lib/stripe/resources/v2/core/account.rb', line 5823

def updated
  @updated
end

Class Method Details

.field_encodingsObject



5844
5845
5846
5847
5848
# File 'lib/stripe/resources/v2/core/account.rb', line 5844

def self.field_encodings
  @field_encodings = {
    relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
  }
end

.field_remappingsObject



5840
5841
5842
# File 'lib/stripe/resources/v2/core/account.rb', line 5840

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5825
5826
5827
5828
5829
5830
5831
5832
5833
5834
5835
5836
5837
5838
# File 'lib/stripe/resources/v2/core/account.rb', line 5825

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end