Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



5715
5716
5717
# File 'lib/stripe/resources/v2/core/account.rb', line 5715

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



5717
5718
5719
# File 'lib/stripe/resources/v2/core/account.rb', line 5717

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



5719
5720
5721
# File 'lib/stripe/resources/v2/core/account.rb', line 5719

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



5721
5722
5723
# File 'lib/stripe/resources/v2/core/account.rb', line 5721

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



5723
5724
5725
# File 'lib/stripe/resources/v2/core/account.rb', line 5723

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



5725
5726
5727
# File 'lib/stripe/resources/v2/core/account.rb', line 5725

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



5727
5728
5729
# File 'lib/stripe/resources/v2/core/account.rb', line 5727

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



5729
5730
5731
# File 'lib/stripe/resources/v2/core/account.rb', line 5729

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



5731
5732
5733
# File 'lib/stripe/resources/v2/core/account.rb', line 5731

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



5733
5734
5735
# File 'lib/stripe/resources/v2/core/account.rb', line 5733

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



5735
5736
5737
# File 'lib/stripe/resources/v2/core/account.rb', line 5735

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



5737
5738
5739
# File 'lib/stripe/resources/v2/core/account.rb', line 5737

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



5739
5740
5741
# File 'lib/stripe/resources/v2/core/account.rb', line 5739

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5741
5742
5743
# File 'lib/stripe/resources/v2/core/account.rb', line 5741

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



5743
5744
5745
# File 'lib/stripe/resources/v2/core/account.rb', line 5743

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



5745
5746
5747
# File 'lib/stripe/resources/v2/core/account.rb', line 5745

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



5747
5748
5749
# File 'lib/stripe/resources/v2/core/account.rb', line 5747

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



5749
5750
5751
# File 'lib/stripe/resources/v2/core/account.rb', line 5749

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



5751
5752
5753
# File 'lib/stripe/resources/v2/core/account.rb', line 5751

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



5753
5754
5755
# File 'lib/stripe/resources/v2/core/account.rb', line 5753

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



5755
5756
5757
# File 'lib/stripe/resources/v2/core/account.rb', line 5755

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



5757
5758
5759
# File 'lib/stripe/resources/v2/core/account.rb', line 5757

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



5759
5760
5761
# File 'lib/stripe/resources/v2/core/account.rb', line 5759

def updated
  @updated
end

Class Method Details

.field_encodingsObject



5780
5781
5782
5783
5784
# File 'lib/stripe/resources/v2/core/account.rb', line 5780

def self.field_encodings
  @field_encodings = {
    relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
  }
end

.field_remappingsObject



5776
5777
5778
# File 'lib/stripe/resources/v2/core/account.rb', line 5776

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5761
5762
5763
5764
5765
5766
5767
5768
5769
5770
5771
5772
5773
5774
# File 'lib/stripe/resources/v2/core/account.rb', line 5761

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end