Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
4985 4986 4987 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4985 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
4987 4988 4989 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4987 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
4989 4990 4991 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4989 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
4991 4992 4993 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4991 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
4993 4994 4995 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4993 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
4995 4996 4997 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4995 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
4997 4998 4999 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4997 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
4999 5000 5001 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4999 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
5001 5002 5003 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5001 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
5003 5004 5005 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5003 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
5005 5006 5007 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5005 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
5007 5008 5009 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5007 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
5009 5010 5011 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5009 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
5011 5012 5013 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5011 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
5013 5014 5015 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5013 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
5015 5016 5017 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5015 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
5017 5018 5019 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5017 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
5019 5020 5021 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5019 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
5021 5022 5023 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5021 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
5023 5024 5025 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5023 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
5025 5026 5027 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5025 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
5027 5028 5029 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5027 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
5029 5030 5031 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5029 def updated @updated end |
Class Method Details
.field_remappings ⇒ Object
5046 5047 5048 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5046 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5031 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |