Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
5697 5698 5699 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5697 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
5699 5700 5701 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5699 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
5701 5702 5703 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5701 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
5703 5704 5705 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5703 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
5705 5706 5707 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5705 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
5707 5708 5709 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5707 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
5709 5710 5711 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5709 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
5711 5712 5713 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5711 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
5713 5714 5715 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5713 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
5715 5716 5717 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5715 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
5717 5718 5719 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5717 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
5719 5720 5721 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5719 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
5721 5722 5723 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5721 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
5723 5724 5725 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5723 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
5725 5726 5727 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5725 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
5727 5728 5729 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5727 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
5729 5730 5731 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5729 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
5731 5732 5733 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5731 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
5733 5734 5735 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5733 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
5735 5736 5737 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5735 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
5737 5738 5739 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5737 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
5739 5740 5741 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5739 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
5741 5742 5743 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5741 def updated @updated end |
Class Method Details
.field_remappings ⇒ Object
5758 5759 5760 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5758 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
5743 5744 5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 |
# File 'lib/stripe/resources/v2/core/account.rb', line 5743 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |