Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



4877
4878
4879
# File 'lib/stripe/resources/v2/core/account.rb', line 4877

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



4879
4880
4881
# File 'lib/stripe/resources/v2/core/account.rb', line 4879

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



4881
4882
4883
# File 'lib/stripe/resources/v2/core/account.rb', line 4881

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



4883
4884
4885
# File 'lib/stripe/resources/v2/core/account.rb', line 4883

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



4885
4886
4887
# File 'lib/stripe/resources/v2/core/account.rb', line 4885

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4887
4888
4889
# File 'lib/stripe/resources/v2/core/account.rb', line 4887

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



4889
4890
4891
# File 'lib/stripe/resources/v2/core/account.rb', line 4889

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



4891
4892
4893
# File 'lib/stripe/resources/v2/core/account.rb', line 4891

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



4893
4894
4895
# File 'lib/stripe/resources/v2/core/account.rb', line 4893

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



4895
4896
4897
# File 'lib/stripe/resources/v2/core/account.rb', line 4895

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



4897
4898
4899
# File 'lib/stripe/resources/v2/core/account.rb', line 4897

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



4899
4900
4901
# File 'lib/stripe/resources/v2/core/account.rb', line 4899

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



4901
4902
4903
# File 'lib/stripe/resources/v2/core/account.rb', line 4901

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4903
4904
4905
# File 'lib/stripe/resources/v2/core/account.rb', line 4903

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



4905
4906
4907
# File 'lib/stripe/resources/v2/core/account.rb', line 4905

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



4907
4908
4909
# File 'lib/stripe/resources/v2/core/account.rb', line 4907

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



4909
4910
4911
# File 'lib/stripe/resources/v2/core/account.rb', line 4909

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4911
4912
4913
# File 'lib/stripe/resources/v2/core/account.rb', line 4911

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



4913
4914
4915
# File 'lib/stripe/resources/v2/core/account.rb', line 4913

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



4915
4916
4917
# File 'lib/stripe/resources/v2/core/account.rb', line 4915

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



4917
4918
4919
# File 'lib/stripe/resources/v2/core/account.rb', line 4917

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



4919
4920
4921
# File 'lib/stripe/resources/v2/core/account.rb', line 4919

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



4921
4922
4923
# File 'lib/stripe/resources/v2/core/account.rb', line 4921

def updated
  @updated
end

Class Method Details

.field_remappingsObject



4938
4939
4940
# File 'lib/stripe/resources/v2/core/account.rb', line 4938

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4923
4924
4925
4926
4927
4928
4929
4930
4931
4932
4933
4934
4935
4936
# File 'lib/stripe/resources/v2/core/account.rb', line 4923

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end