Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



4992
4993
4994
# File 'lib/stripe/resources/v2/core/account.rb', line 4992

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



4994
4995
4996
# File 'lib/stripe/resources/v2/core/account.rb', line 4994

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



4996
4997
4998
# File 'lib/stripe/resources/v2/core/account.rb', line 4996

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



4998
4999
5000
# File 'lib/stripe/resources/v2/core/account.rb', line 4998

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



5000
5001
5002
# File 'lib/stripe/resources/v2/core/account.rb', line 5000

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



5002
5003
5004
# File 'lib/stripe/resources/v2/core/account.rb', line 5002

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



5004
5005
5006
# File 'lib/stripe/resources/v2/core/account.rb', line 5004

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



5006
5007
5008
# File 'lib/stripe/resources/v2/core/account.rb', line 5006

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



5008
5009
5010
# File 'lib/stripe/resources/v2/core/account.rb', line 5008

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



5010
5011
5012
# File 'lib/stripe/resources/v2/core/account.rb', line 5010

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



5012
5013
5014
# File 'lib/stripe/resources/v2/core/account.rb', line 5012

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



5014
5015
5016
# File 'lib/stripe/resources/v2/core/account.rb', line 5014

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



5016
5017
5018
# File 'lib/stripe/resources/v2/core/account.rb', line 5016

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



5018
5019
5020
# File 'lib/stripe/resources/v2/core/account.rb', line 5018

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



5020
5021
5022
# File 'lib/stripe/resources/v2/core/account.rb', line 5020

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



5022
5023
5024
# File 'lib/stripe/resources/v2/core/account.rb', line 5022

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



5024
5025
5026
# File 'lib/stripe/resources/v2/core/account.rb', line 5024

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



5026
5027
5028
# File 'lib/stripe/resources/v2/core/account.rb', line 5026

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



5028
5029
5030
# File 'lib/stripe/resources/v2/core/account.rb', line 5028

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



5030
5031
5032
# File 'lib/stripe/resources/v2/core/account.rb', line 5030

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



5032
5033
5034
# File 'lib/stripe/resources/v2/core/account.rb', line 5032

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



5034
5035
5036
# File 'lib/stripe/resources/v2/core/account.rb', line 5034

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



5036
5037
5038
# File 'lib/stripe/resources/v2/core/account.rb', line 5036

def updated
  @updated
end

Class Method Details

.field_remappingsObject



5053
5054
5055
# File 'lib/stripe/resources/v2/core/account.rb', line 5053

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5038
5039
5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
# File 'lib/stripe/resources/v2/core/account.rb', line 5038

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end