Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
4663 4664 4665 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4663 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
4665 4666 4667 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4665 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
4667 4668 4669 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4667 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
4669 4670 4671 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4669 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
4671 4672 4673 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4671 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
4673 4674 4675 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4673 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
4675 4676 4677 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4675 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
4677 4678 4679 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4677 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
4679 4680 4681 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4679 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
4681 4682 4683 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4681 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
4683 4684 4685 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4683 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
4685 4686 4687 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4685 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
4687 4688 4689 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4687 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4689 4690 4691 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4689 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
4691 4692 4693 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4691 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
4693 4694 4695 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4693 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
4695 4696 4697 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4695 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
4697 4698 4699 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4697 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
4699 4700 4701 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4699 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
4701 4702 4703 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4701 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
4703 4704 4705 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4703 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
4705 4706 4707 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4705 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
4707 4708 4709 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4707 def updated @updated end |
Class Method Details
.field_remappings ⇒ Object
4724 4725 4726 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4724 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4709 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |