Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



4507
4508
4509
# File 'lib/stripe/resources/v2/core/account.rb', line 4507

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



4509
4510
4511
# File 'lib/stripe/resources/v2/core/account.rb', line 4509

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



4511
4512
4513
# File 'lib/stripe/resources/v2/core/account.rb', line 4511

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



4513
4514
4515
# File 'lib/stripe/resources/v2/core/account.rb', line 4513

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



4515
4516
4517
# File 'lib/stripe/resources/v2/core/account.rb', line 4515

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4517
4518
4519
# File 'lib/stripe/resources/v2/core/account.rb', line 4517

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



4519
4520
4521
# File 'lib/stripe/resources/v2/core/account.rb', line 4519

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



4521
4522
4523
# File 'lib/stripe/resources/v2/core/account.rb', line 4521

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



4523
4524
4525
# File 'lib/stripe/resources/v2/core/account.rb', line 4523

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



4525
4526
4527
# File 'lib/stripe/resources/v2/core/account.rb', line 4525

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



4527
4528
4529
# File 'lib/stripe/resources/v2/core/account.rb', line 4527

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



4529
4530
4531
# File 'lib/stripe/resources/v2/core/account.rb', line 4529

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



4531
4532
4533
# File 'lib/stripe/resources/v2/core/account.rb', line 4531

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4533
4534
4535
# File 'lib/stripe/resources/v2/core/account.rb', line 4533

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



4535
4536
4537
# File 'lib/stripe/resources/v2/core/account.rb', line 4535

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



4537
4538
4539
# File 'lib/stripe/resources/v2/core/account.rb', line 4537

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



4539
4540
4541
# File 'lib/stripe/resources/v2/core/account.rb', line 4539

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4541
4542
4543
# File 'lib/stripe/resources/v2/core/account.rb', line 4541

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



4543
4544
4545
# File 'lib/stripe/resources/v2/core/account.rb', line 4543

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



4545
4546
4547
# File 'lib/stripe/resources/v2/core/account.rb', line 4545

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



4547
4548
4549
# File 'lib/stripe/resources/v2/core/account.rb', line 4547

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



4549
4550
4551
# File 'lib/stripe/resources/v2/core/account.rb', line 4549

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



4551
4552
4553
# File 'lib/stripe/resources/v2/core/account.rb', line 4551

def updated
  @updated
end

Class Method Details

.field_remappingsObject



4568
4569
4570
# File 'lib/stripe/resources/v2/core/account.rb', line 4568

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4553
4554
4555
4556
4557
4558
4559
4560
4561
4562
4563
4564
4565
4566
# File 'lib/stripe/resources/v2/core/account.rb', line 4553

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end