Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



4305
4306
4307
# File 'lib/stripe/resources/v2/core/account.rb', line 4305

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



4307
4308
4309
# File 'lib/stripe/resources/v2/core/account.rb', line 4307

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



4309
4310
4311
# File 'lib/stripe/resources/v2/core/account.rb', line 4309

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



4311
4312
4313
# File 'lib/stripe/resources/v2/core/account.rb', line 4311

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



4313
4314
4315
# File 'lib/stripe/resources/v2/core/account.rb', line 4313

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



4315
4316
4317
# File 'lib/stripe/resources/v2/core/account.rb', line 4315

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



4317
4318
4319
# File 'lib/stripe/resources/v2/core/account.rb', line 4317

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



4319
4320
4321
# File 'lib/stripe/resources/v2/core/account.rb', line 4319

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



4321
4322
4323
# File 'lib/stripe/resources/v2/core/account.rb', line 4321

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



4323
4324
4325
# File 'lib/stripe/resources/v2/core/account.rb', line 4323

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



4325
4326
4327
# File 'lib/stripe/resources/v2/core/account.rb', line 4325

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



4327
4328
4329
# File 'lib/stripe/resources/v2/core/account.rb', line 4327

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



4329
4330
4331
# File 'lib/stripe/resources/v2/core/account.rb', line 4329

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4331
4332
4333
# File 'lib/stripe/resources/v2/core/account.rb', line 4331

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



4333
4334
4335
# File 'lib/stripe/resources/v2/core/account.rb', line 4333

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



4335
4336
4337
# File 'lib/stripe/resources/v2/core/account.rb', line 4335

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



4337
4338
4339
# File 'lib/stripe/resources/v2/core/account.rb', line 4337

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4339
4340
4341
# File 'lib/stripe/resources/v2/core/account.rb', line 4339

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



4341
4342
4343
# File 'lib/stripe/resources/v2/core/account.rb', line 4341

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



4343
4344
4345
# File 'lib/stripe/resources/v2/core/account.rb', line 4343

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



4345
4346
4347
# File 'lib/stripe/resources/v2/core/account.rb', line 4345

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



4347
4348
4349
# File 'lib/stripe/resources/v2/core/account.rb', line 4347

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



4349
4350
4351
# File 'lib/stripe/resources/v2/core/account.rb', line 4349

def updated
  @updated
end

Class Method Details

.field_remappingsObject



4366
4367
4368
# File 'lib/stripe/resources/v2/core/account.rb', line 4366

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
4361
4362
4363
4364
# File 'lib/stripe/resources/v2/core/account.rb', line 4351

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end