Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
4252 4253 4254 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4252 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
4254 4255 4256 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4254 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
4256 4257 4258 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4256 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
4258 4259 4260 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4258 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
4260 4261 4262 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4260 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
4262 4263 4264 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4262 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
4264 4265 4266 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4264 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
4266 4267 4268 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4266 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
4268 4269 4270 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4268 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
4270 4271 4272 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4270 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
4272 4273 4274 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4272 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
4274 4275 4276 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4274 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
4276 4277 4278 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4276 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4278 4279 4280 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4278 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
4280 4281 4282 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4280 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
4282 4283 4284 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4282 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
4284 4285 4286 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4284 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
4286 4287 4288 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4286 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
4288 4289 4290 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4288 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
4290 4291 4292 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4290 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
4292 4293 4294 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4292 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
4294 4295 4296 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4294 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
4296 4297 4298 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4296 def updated @updated end |
Class Method Details
.field_remappings ⇒ Object
4313 4314 4315 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4313 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 4311 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4298 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |