Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



3583
3584
3585
# File 'lib/stripe/resources/v2/core/account.rb', line 3583

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



3585
3586
3587
# File 'lib/stripe/resources/v2/core/account.rb', line 3585

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



3587
3588
3589
# File 'lib/stripe/resources/v2/core/account.rb', line 3587

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



3589
3590
3591
# File 'lib/stripe/resources/v2/core/account.rb', line 3589

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



3591
3592
3593
# File 'lib/stripe/resources/v2/core/account.rb', line 3591

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3593
3594
3595
# File 'lib/stripe/resources/v2/core/account.rb', line 3593

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



3595
3596
3597
# File 'lib/stripe/resources/v2/core/account.rb', line 3595

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



3597
3598
3599
# File 'lib/stripe/resources/v2/core/account.rb', line 3597

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



3599
3600
3601
# File 'lib/stripe/resources/v2/core/account.rb', line 3599

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



3601
3602
3603
# File 'lib/stripe/resources/v2/core/account.rb', line 3601

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



3603
3604
3605
# File 'lib/stripe/resources/v2/core/account.rb', line 3603

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



3605
3606
3607
# File 'lib/stripe/resources/v2/core/account.rb', line 3605

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



3607
3608
3609
# File 'lib/stripe/resources/v2/core/account.rb', line 3607

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3609
3610
3611
# File 'lib/stripe/resources/v2/core/account.rb', line 3609

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



3611
3612
3613
# File 'lib/stripe/resources/v2/core/account.rb', line 3611

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3613
3614
3615
# File 'lib/stripe/resources/v2/core/account.rb', line 3613

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



3615
3616
3617
# File 'lib/stripe/resources/v2/core/account.rb', line 3615

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



3617
3618
3619
# File 'lib/stripe/resources/v2/core/account.rb', line 3617

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



3619
3620
3621
# File 'lib/stripe/resources/v2/core/account.rb', line 3619

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



3621
3622
3623
# File 'lib/stripe/resources/v2/core/account.rb', line 3621

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



3623
3624
3625
# File 'lib/stripe/resources/v2/core/account.rb', line 3623

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



3625
3626
3627
# File 'lib/stripe/resources/v2/core/account.rb', line 3625

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



3627
3628
3629
# File 'lib/stripe/resources/v2/core/account.rb', line 3627

def updated
  @updated
end

Class Method Details

.field_remappingsObject



3644
3645
3646
# File 'lib/stripe/resources/v2/core/account.rb', line 3644

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3629
3630
3631
3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
# File 'lib/stripe/resources/v2/core/account.rb', line 3629

def self.inner_class_types
  @inner_class_types = {
    additional_addresses: AdditionalAddress,
    additional_names: AdditionalName,
    additional_terms_of_service: AdditionalTermsOfService,
    address: Address,
    date_of_birth: DateOfBirth,
    documents: Documents,
    id_numbers: IdNumber,
    relationship: Relationship,
    script_addresses: ScriptAddresses,
    script_names: ScriptNames,
  }
end