Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
3536 3537 3538 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3536 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
3538 3539 3540 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3538 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
3540 3541 3542 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3540 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
3542 3543 3544 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3542 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
3544 3545 3546 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3544 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
3546 3547 3548 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3546 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
3548 3549 3550 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3548 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
3550 3551 3552 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3550 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
3552 3553 3554 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3552 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
3554 3555 3556 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3554 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
3556 3557 3558 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3556 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
3558 3559 3560 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3558 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
3560 3561 3562 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3560 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3562 3563 3564 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3562 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3564 3565 3566 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3564 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
3566 3567 3568 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3566 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
3568 3569 3570 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3568 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
3570 3571 3572 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3570 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
3572 3573 3574 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3572 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
3574 3575 3576 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3574 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
3576 3577 3578 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3576 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
3578 3579 3580 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3578 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
3580 3581 3582 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3580 def updated @updated end |
Class Method Details
.field_remappings ⇒ Object
3597 3598 3599 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3597 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3582 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |