Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
1774 1775 1776 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1774 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
1776 1777 1778 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1776 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
1778 1779 1780 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1778 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
1780 1781 1782 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1780 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
1782 1783 1784 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1782 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1784 1785 1786 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1784 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
1786 1787 1788 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1786 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
1788 1789 1790 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1788 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
1790 1791 1792 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1790 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
1792 1793 1794 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1792 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1794 1795 1796 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1794 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
1796 1797 1798 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1796 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
1798 1799 1800 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1798 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1800 1801 1802 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1800 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
1802 1803 1804 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1802 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1804 1805 1806 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1804 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
1806 1807 1808 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1806 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1808 1809 1810 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1808 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
1810 1811 1812 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1810 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
1812 1813 1814 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1812 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
1814 1815 1816 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1814 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
1816 1817 1818 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1816 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
1818 1819 1820 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1818 def updated @updated end |