Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



1591
1592
1593
# File 'lib/stripe/resources/v2/core/account.rb', line 1591

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



1593
1594
1595
# File 'lib/stripe/resources/v2/core/account.rb', line 1593

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



1595
1596
1597
# File 'lib/stripe/resources/v2/core/account.rb', line 1595

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



1597
1598
1599
# File 'lib/stripe/resources/v2/core/account.rb', line 1597

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



1599
1600
1601
# File 'lib/stripe/resources/v2/core/account.rb', line 1599

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1601
1602
1603
# File 'lib/stripe/resources/v2/core/account.rb', line 1601

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



1603
1604
1605
# File 'lib/stripe/resources/v2/core/account.rb', line 1603

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



1605
1606
1607
# File 'lib/stripe/resources/v2/core/account.rb', line 1605

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



1607
1608
1609
# File 'lib/stripe/resources/v2/core/account.rb', line 1607

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



1609
1610
1611
# File 'lib/stripe/resources/v2/core/account.rb', line 1609

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



1611
1612
1613
# File 'lib/stripe/resources/v2/core/account.rb', line 1611

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



1613
1614
1615
# File 'lib/stripe/resources/v2/core/account.rb', line 1613

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



1615
1616
1617
# File 'lib/stripe/resources/v2/core/account.rb', line 1615

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1617
1618
1619
# File 'lib/stripe/resources/v2/core/account.rb', line 1617

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1619
1620
1621
# File 'lib/stripe/resources/v2/core/account.rb', line 1619

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1621
1622
1623
# File 'lib/stripe/resources/v2/core/account.rb', line 1621

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



1623
1624
1625
# File 'lib/stripe/resources/v2/core/account.rb', line 1623

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1625
1626
1627
# File 'lib/stripe/resources/v2/core/account.rb', line 1625

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



1627
1628
1629
# File 'lib/stripe/resources/v2/core/account.rb', line 1627

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



1629
1630
1631
# File 'lib/stripe/resources/v2/core/account.rb', line 1629

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



1631
1632
1633
# File 'lib/stripe/resources/v2/core/account.rb', line 1631

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



1633
1634
1635
# File 'lib/stripe/resources/v2/core/account.rb', line 1633

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



1635
1636
1637
# File 'lib/stripe/resources/v2/core/account.rb', line 1635

def updated
  @updated
end