Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual’s residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual’s date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual’s email address.
-
#given_name ⇒ Object
readonly
The individual’s first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual’s gender (International regulations require either “male” or ”female“).
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The individual’s phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account’s identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual’s last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
1591 1592 1593 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1591 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
1593 1594 1595 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1593 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
1595 1596 1597 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1595 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
1597 1598 1599 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1597 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual’s residential address.
1599 1600 1601 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1599 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1601 1602 1603 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1601 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual’s date of birth.
1603 1604 1605 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1603 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
1605 1606 1607 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1605 def documents @documents end |
#email ⇒ Object (readonly)
The individual’s email address.
1607 1608 1609 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1607 def email @email end |
#given_name ⇒ Object (readonly)
The individual’s first name.
1609 1610 1611 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1609 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1611 1612 1613 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1611 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
1613 1614 1615 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1613 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual’s gender (International regulations require either “male” or ”female“).
1615 1616 1617 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1615 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1617 1618 1619 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1617 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
1619 1620 1621 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1619 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1621 1622 1623 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1621 def object @object end |
#phone ⇒ Object (readonly)
The individual’s phone number.
1623 1624 1625 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1623 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1625 1626 1627 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1625 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account’s identity.
1627 1628 1629 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1627 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
1629 1630 1631 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1629 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
1631 1632 1633 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1631 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual’s last name.
1633 1634 1635 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1633 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
1635 1636 1637 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1635 def updated @updated end |