Class: Stripe::V2::Core::Account::Identity::Individual

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



1542
1543
1544
# File 'lib/stripe/resources/v2/core/account.rb', line 1542

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the individual.



1544
1545
1546
# File 'lib/stripe/resources/v2/core/account.rb', line 1544

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the individual.



1546
1547
1548
# File 'lib/stripe/resources/v2/core/account.rb', line 1546

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Terms of service acceptances.



1548
1549
1550
# File 'lib/stripe/resources/v2/core/account.rb', line 1548

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The individual’s residential address.



1550
1551
1552
# File 'lib/stripe/resources/v2/core/account.rb', line 1550

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1552
1553
1554
# File 'lib/stripe/resources/v2/core/account.rb', line 1552

def created
  @created
end

#date_of_birthObject (readonly)

The individual’s date of birth.



1554
1555
1556
# File 'lib/stripe/resources/v2/core/account.rb', line 1554

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



1556
1557
1558
# File 'lib/stripe/resources/v2/core/account.rb', line 1556

def documents
  @documents
end

#emailObject (readonly)

The individual’s email address.



1558
1559
1560
# File 'lib/stripe/resources/v2/core/account.rb', line 1558

def email
  @email
end

#given_nameObject (readonly)

The individual’s first name.



1560
1561
1562
# File 'lib/stripe/resources/v2/core/account.rb', line 1560

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the object.



1562
1563
1564
# File 'lib/stripe/resources/v2/core/account.rb', line 1562

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the individual.



1564
1565
1566
# File 'lib/stripe/resources/v2/core/account.rb', line 1564

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or ”female“).



1566
1567
1568
# File 'lib/stripe/resources/v2/core/account.rb', line 1566

def legal_gender
  @legal_gender
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1568
1569
1570
# File 'lib/stripe/resources/v2/core/account.rb', line 1568

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1570
1571
1572
# File 'lib/stripe/resources/v2/core/account.rb', line 1570

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1572
1573
1574
# File 'lib/stripe/resources/v2/core/account.rb', line 1572

def object
  @object
end

#phoneObject (readonly)

The individual’s phone number.



1574
1575
1576
# File 'lib/stripe/resources/v2/core/account.rb', line 1574

def phone
  @phone
end

#political_exposureObject (readonly)

Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1576
1577
1578
# File 'lib/stripe/resources/v2/core/account.rb', line 1576

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this individual has with the Account’s identity.



1578
1579
1580
# File 'lib/stripe/resources/v2/core/account.rb', line 1578

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the individual.



1580
1581
1582
# File 'lib/stripe/resources/v2/core/account.rb', line 1580

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the individual.



1582
1583
1584
# File 'lib/stripe/resources/v2/core/account.rb', line 1582

def script_names
  @script_names
end

#surnameObject (readonly)

The individual’s last name.



1584
1585
1586
# File 'lib/stripe/resources/v2/core/account.rb', line 1584

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated.



1586
1587
1588
# File 'lib/stripe/resources/v2/core/account.rb', line 1586

def updated
  @updated
end