Class: Stripe::V2::Core::Account::Identity::Individual
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account ID which the individual belongs to.
-
#additional_addresses ⇒ Object
readonly
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
readonly
Additional names (e.g. aliases) associated with the individual.
-
#additional_terms_of_service ⇒ Object
readonly
Terms of service acceptances.
-
#address ⇒ Object
readonly
The individual's residential address.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#date_of_birth ⇒ Object
readonly
The individual's date of birth.
-
#documents ⇒ Object
readonly
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
readonly
The individual's email address.
-
#given_name ⇒ Object
readonly
The individual's first name.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_numbers ⇒ Object
readonly
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
readonly
The individual's gender (International regulations require either "male" or "female").
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
readonly
The countries where the individual is a national.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#phone ⇒ Object
readonly
The individual's phone number.
-
#political_exposure ⇒ Object
readonly
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#relationship ⇒ Object
readonly
The relationship that this individual has with the Account's identity.
-
#script_addresses ⇒ Object
readonly
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
readonly
The script names (e.g. non-Latin characters) associated with the individual.
-
#surname ⇒ Object
readonly
The individual's last name.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account ID which the individual belongs to.
3430 3431 3432 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3430 def account @account end |
#additional_addresses ⇒ Object (readonly)
Additional addresses associated with the individual.
3432 3433 3434 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3432 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object (readonly)
Additional names (e.g. aliases) associated with the individual.
3434 3435 3436 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3434 def additional_names @additional_names end |
#additional_terms_of_service ⇒ Object (readonly)
Terms of service acceptances.
3436 3437 3438 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3436 def additional_terms_of_service @additional_terms_of_service end |
#address ⇒ Object (readonly)
The individual's residential address.
3438 3439 3440 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3438 def address @address end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
3440 3441 3442 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3440 def created @created end |
#date_of_birth ⇒ Object (readonly)
The individual's date of birth.
3442 3443 3444 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3442 def date_of_birth @date_of_birth end |
#documents ⇒ Object (readonly)
Documents that may be submitted to satisfy various informational requests.
3444 3445 3446 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3444 def documents @documents end |
#email ⇒ Object (readonly)
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
3446 3447 3448 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3446 def email @email end |
#given_name ⇒ Object (readonly)
The individual's first name.
3448 3449 3450 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3448 def given_name @given_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
3450 3451 3452 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3450 def id @id end |
#id_numbers ⇒ Object (readonly)
The identification numbers (e.g., SSN) associated with the individual.
3452 3453 3454 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3452 def id_numbers @id_numbers end |
#legal_gender ⇒ Object (readonly)
The individual's gender (International regulations require either "male" or "female").
3454 3455 3456 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3454 def legal_gender @legal_gender end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3456 3457 3458 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3456 def @metadata end |
#nationalities ⇒ Object (readonly)
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
3458 3459 3460 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3458 def nationalities @nationalities end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
3460 3461 3462 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3460 def object @object end |
#phone ⇒ Object (readonly)
The individual's phone number.
3462 3463 3464 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3462 def phone @phone end |
#political_exposure ⇒ Object (readonly)
Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
3464 3465 3466 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3464 def political_exposure @political_exposure end |
#relationship ⇒ Object (readonly)
The relationship that this individual has with the Account's identity.
3466 3467 3468 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3466 def relationship @relationship end |
#script_addresses ⇒ Object (readonly)
The script addresses (e.g., non-Latin characters) associated with the individual.
3468 3469 3470 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3468 def script_addresses @script_addresses end |
#script_names ⇒ Object (readonly)
The script names (e.g. non-Latin characters) associated with the individual.
3470 3471 3472 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3470 def script_names @script_names end |
#surname ⇒ Object (readonly)
The individual's last name.
3472 3473 3474 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3472 def surname @surname end |
#updated ⇒ Object (readonly)
Time at which the object was last updated.
3474 3475 3476 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3474 def updated @updated end |
Class Method Details
.field_encodings ⇒ Object
3495 3496 3497 3498 3499 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3495 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |
.field_remappings ⇒ Object
3491 3492 3493 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3491 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 3489 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3476 def self.inner_class_types @inner_class_types = { additional_addresses: AdditionalAddress, additional_names: AdditionalName, additional_terms_of_service: AdditionalTermsOfService, address: Address, date_of_birth: DateOfBirth, documents: Documents, id_numbers: IdNumber, relationship: Relationship, script_addresses: ScriptAddresses, script_names: ScriptNames, } end |