Class: Stripe::V2::Core::Account::Identity::Individual::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
readonly
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
readonly
One or more documents showing the person's passport page with photo and personal data.
-
#primary_verification ⇒ Object
readonly
An identifying document showing the person's name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
readonly
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
readonly
One or more documents showing the person's visa required for living in the country where they are residing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#company_authorization ⇒ Object (readonly)
One or more documents that demonstrate proof that this person is authorized to represent the company.
19663 19664 19665 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19663 def @company_authorization end |
#passport ⇒ Object (readonly)
One or more documents showing the person's passport page with photo and personal data.
19665 19666 19667 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19665 def passport @passport end |
#primary_verification ⇒ Object (readonly)
An identifying document showing the person's name, either a passport or local ID card.
19667 19668 19669 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19667 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object (readonly)
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
19669 19670 19671 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19669 def secondary_verification @secondary_verification end |
#visa ⇒ Object (readonly)
One or more documents showing the person's visa required for living in the country where they are residing.
19671 19672 19673 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19671 def visa @visa end |
Class Method Details
.field_remappings ⇒ Object
19683 19684 19685 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19683 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
19673 19674 19675 19676 19677 19678 19679 19680 19681 |
# File 'lib/stripe/resources/v2/core/account.rb', line 19673 def self.inner_class_types @inner_class_types = { company_authorization: CompanyAuthorization, passport: Passport, primary_verification: PrimaryVerification, secondary_verification: SecondaryVerification, visa: Visa, } end |