Class: Stripe::V2::Core::Account::Identity::Individual::Documents
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Documents
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
readonly
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
readonly
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
readonly
An identifying document showing the person's name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
readonly
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
readonly
One or more documents showing the person’s visa required for living in the country where they are residing.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#company_authorization ⇒ Object (readonly)
One or more documents that demonstrate proof that this person is authorized to represent the company.
4036 4037 4038 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4036 def @company_authorization end |
#passport ⇒ Object (readonly)
One or more documents showing the person’s passport page with photo and personal data.
4038 4039 4040 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4038 def passport @passport end |
#primary_verification ⇒ Object (readonly)
An identifying document showing the person's name, either a passport or local ID card.
4040 4041 4042 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4040 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object (readonly)
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
4042 4043 4044 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4042 def secondary_verification @secondary_verification end |
#visa ⇒ Object (readonly)
One or more documents showing the person’s visa required for living in the country where they are residing.
4044 4045 4046 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4044 def visa @visa end |
Class Method Details
.field_remappings ⇒ Object
4056 4057 4058 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4056 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4046 4047 4048 4049 4050 4051 4052 4053 4054 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4046 def self.inner_class_types @inner_class_types = { company_authorization: CompanyAuthorization, passport: Passport, primary_verification: PrimaryVerification, secondary_verification: SecondaryVerification, visa: Visa, } end |