Class: Stripe::V2::Core::Account::Identity::Individual::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#company_authorizationObject (readonly)

One or more documents that demonstrate proof that this person is authorized to represent the company.



5602
5603
5604
# File 'lib/stripe/resources/v2/core/account.rb', line 5602

def company_authorization
  @company_authorization
end

#passportObject (readonly)

One or more documents showing the person’s passport page with photo and personal data.



5604
5605
5606
# File 'lib/stripe/resources/v2/core/account.rb', line 5604

def passport
  @passport
end

#primary_verificationObject (readonly)

An identifying document showing the person’s name, either a passport or local ID card.



5606
5607
5608
# File 'lib/stripe/resources/v2/core/account.rb', line 5606

def primary_verification
  @primary_verification
end

#secondary_verificationObject (readonly)

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



5608
5609
5610
# File 'lib/stripe/resources/v2/core/account.rb', line 5608

def secondary_verification
  @secondary_verification
end

#visaObject (readonly)

One or more documents showing the person’s visa required for living in the country where they are residing.



5610
5611
5612
# File 'lib/stripe/resources/v2/core/account.rb', line 5610

def visa
  @visa
end

Class Method Details

.field_remappingsObject



5622
5623
5624
# File 'lib/stripe/resources/v2/core/account.rb', line 5622

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5612
5613
5614
5615
5616
5617
5618
5619
5620
# File 'lib/stripe/resources/v2/core/account.rb', line 5612

def self.inner_class_types
  @inner_class_types = {
    company_authorization: CompanyAuthorization,
    passport: Passport,
    primary_verification: PrimaryVerification,
    secondary_verification: SecondaryVerification,
    visa: Visa,
  }
end