Class: Stripe::V2::Core::Account::Identity::Individual::Documents

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#company_authorizationObject (readonly)

One or more documents that demonstrate proof that this person is authorized to represent the company.



1671
1672
1673
# File 'lib/stripe/resources/v2/core/account.rb', line 1671

def company_authorization
  @company_authorization
end

#passportObject (readonly)

One or more documents showing the person’s passport page with photo and personal data.



1673
1674
1675
# File 'lib/stripe/resources/v2/core/account.rb', line 1673

def passport
  @passport
end

#primary_verificationObject (readonly)

An identifying document showing the person’s name, either a passport or local ID card.



1675
1676
1677
# File 'lib/stripe/resources/v2/core/account.rb', line 1675

def primary_verification
  @primary_verification
end

#secondary_verificationObject (readonly)

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



1677
1678
1679
# File 'lib/stripe/resources/v2/core/account.rb', line 1677

def secondary_verification
  @secondary_verification
end

#visaObject (readonly)

One or more documents showing the person’s visa required for living in the country where they are residing.



1679
1680
1681
# File 'lib/stripe/resources/v2/core/account.rb', line 1679

def visa
  @visa
end