Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the individual is an authorizer of the Account's identity.



3197
3198
3199
# File 'lib/stripe/resources/v2/core/account.rb', line 3197

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the individual is a director of the Account's identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.



3199
3200
3201
# File 'lib/stripe/resources/v2/core/account.rb', line 3199

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



3201
3202
3203
# File 'lib/stripe/resources/v2/core/account.rb', line 3201

def executive
  @executive
end

Whether the individual is the legal guardian of the Account's representative.



3203
3204
3205
# File 'lib/stripe/resources/v2/core/account.rb', line 3203

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account's identity.



3205
3206
3207
# File 'lib/stripe/resources/v2/core/account.rb', line 3205

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percentage of the Account's identity that the individual owns.



3207
3208
3209
# File 'lib/stripe/resources/v2/core/account.rb', line 3207

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



3209
3210
3211
# File 'lib/stripe/resources/v2/core/account.rb', line 3209

def representative
  @representative
end

#titleObject (readonly)

The individual's title (e.g., CEO, Support Engineer).



3211
3212
3213
# File 'lib/stripe/resources/v2/core/account.rb', line 3211

def title
  @title
end

Class Method Details

.field_encodingsObject



3221
3222
3223
# File 'lib/stripe/resources/v2/core/account.rb', line 3221

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end

.field_remappingsObject



3217
3218
3219
# File 'lib/stripe/resources/v2/core/account.rb', line 3217

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3213
3214
3215
# File 'lib/stripe/resources/v2/core/account.rb', line 3213

def self.inner_class_types
  @inner_class_types = {}
end