Class: Stripe::V2::Core::Account::Identity::Individual::Relationship
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Relationship
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
readonly
Whether the individual is an authorizer of the Account's identity.
-
#director ⇒ Object
readonly
Whether the individual is a director of the Account's identity.
-
#executive ⇒ Object
readonly
Whether the individual has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
readonly
Whether the individual is the legal guardian of the Account's representative.
-
#owner ⇒ Object
readonly
Whether the individual is an owner of the Account's identity.
-
#percent_ownership ⇒ Object
readonly
The percentage of the Account's identity that the individual owns.
-
#representative ⇒ Object
readonly
Whether the individual is authorized as the primary representative of the Account.
-
#title ⇒ Object
readonly
The individual's title (e.g., CEO, Support Engineer).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorizer ⇒ Object (readonly)
Whether the individual is an authorizer of the Account's identity.
4076 4077 4078 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4076 def @authorizer end |
#director ⇒ Object (readonly)
Whether the individual is a director of the Account's identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.
4078 4079 4080 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4078 def director @director end |
#executive ⇒ Object (readonly)
Whether the individual has significant responsibility to control, manage, or direct the organization.
4080 4081 4082 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4080 def executive @executive end |
#legal_guardian ⇒ Object (readonly)
Whether the individual is the legal guardian of the Account's representative.
4082 4083 4084 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4082 def legal_guardian @legal_guardian end |
#owner ⇒ Object (readonly)
Whether the individual is an owner of the Account's identity.
4084 4085 4086 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4084 def owner @owner end |
#percent_ownership ⇒ Object (readonly)
The percentage of the Account's identity that the individual owns.
4086 4087 4088 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4086 def percent_ownership @percent_ownership end |
#representative ⇒ Object (readonly)
Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
4088 4089 4090 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4088 def representative @representative end |
#title ⇒ Object (readonly)
The individual's title (e.g., CEO, Support Engineer).
4090 4091 4092 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4090 def title @title end |
Class Method Details
.field_encodings ⇒ Object
4100 4101 4102 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4100 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |
.field_remappings ⇒ Object
4096 4097 4098 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4096 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4092 4093 4094 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4092 def self.inner_class_types @inner_class_types = {} end |