Class: Stripe::V2::Core::Account::Identity::Individual::Relationship
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Relationship
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
readonly
Whether the individual is an authorizer of the Account’s identity.
-
#director ⇒ Object
readonly
Whether the individual is a director of the Account’s identity.
-
#executive ⇒ Object
readonly
Whether the individual has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
readonly
Whether the individual is the legal guardian of the Account’s representative.
-
#owner ⇒ Object
readonly
Whether the individual is an owner of the Account’s identity.
-
#percent_ownership ⇒ Object
readonly
The percentage of the Account’s identity that the individual owns.
-
#representative ⇒ Object
readonly
Whether the individual is authorized as the primary representative of the Account.
-
#title ⇒ Object
readonly
The individual’s title (e.g., CEO, Support Engineer).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorizer ⇒ Object (readonly)
Whether the individual is an authorizer of the Account’s identity.
3135 3136 3137 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3135 def @authorizer end |
#director ⇒ Object (readonly)
Whether the individual is a director of the Account’s identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.
3137 3138 3139 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3137 def director @director end |
#executive ⇒ Object (readonly)
Whether the individual has significant responsibility to control, manage, or direct the organization.
3139 3140 3141 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3139 def executive @executive end |
#legal_guardian ⇒ Object (readonly)
Whether the individual is the legal guardian of the Account’s representative.
3141 3142 3143 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3141 def legal_guardian @legal_guardian end |
#owner ⇒ Object (readonly)
Whether the individual is an owner of the Account’s identity.
3143 3144 3145 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3143 def owner @owner end |
#percent_ownership ⇒ Object (readonly)
The percentage of the Account’s identity that the individual owns.
3145 3146 3147 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3145 def percent_ownership @percent_ownership end |
#representative ⇒ Object (readonly)
Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
3147 3148 3149 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3147 def representative @representative end |
#title ⇒ Object (readonly)
The individual’s title (e.g., CEO, Support Engineer).
3149 3150 3151 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3149 def title @title end |
Class Method Details
.field_encodings ⇒ Object
3159 3160 3161 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3159 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |
.field_remappings ⇒ Object
3155 3156 3157 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3155 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3151 3152 3153 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3151 def self.inner_class_types @inner_class_types = {} end |