Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the individual is an authorizer of the Account’s identity.



5578
5579
5580
# File 'lib/stripe/resources/v2/core/account.rb', line 5578

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the individual is a director of the Account’s identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.



5580
5581
5582
# File 'lib/stripe/resources/v2/core/account.rb', line 5580

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



5582
5583
5584
# File 'lib/stripe/resources/v2/core/account.rb', line 5582

def executive
  @executive
end

Whether the individual is the legal guardian of the Account’s representative.



5584
5585
5586
# File 'lib/stripe/resources/v2/core/account.rb', line 5584

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account’s identity.



5586
5587
5588
# File 'lib/stripe/resources/v2/core/account.rb', line 5586

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percentage of the Account’s identity that the individual owns.



5588
5589
5590
# File 'lib/stripe/resources/v2/core/account.rb', line 5588

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



5590
5591
5592
# File 'lib/stripe/resources/v2/core/account.rb', line 5590

def representative
  @representative
end

#titleObject (readonly)

The individual’s title (e.g., CEO, Support Engineer).



5592
5593
5594
# File 'lib/stripe/resources/v2/core/account.rb', line 5592

def title
  @title
end

Class Method Details

.field_encodingsObject



5602
5603
5604
# File 'lib/stripe/resources/v2/core/account.rb', line 5602

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end

.field_remappingsObject



5598
5599
5600
# File 'lib/stripe/resources/v2/core/account.rb', line 5598

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5594
5595
5596
# File 'lib/stripe/resources/v2/core/account.rb', line 5594

def self.inner_class_types
  @inner_class_types = {}
end