Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the individual is an authorizer of the Account’s identity.



4764
4765
4766
# File 'lib/stripe/resources/v2/core/account.rb', line 4764

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the individual is a director of the Account’s identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.



4766
4767
4768
# File 'lib/stripe/resources/v2/core/account.rb', line 4766

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



4768
4769
4770
# File 'lib/stripe/resources/v2/core/account.rb', line 4768

def executive
  @executive
end

Whether the individual is the legal guardian of the Account’s representative.



4770
4771
4772
# File 'lib/stripe/resources/v2/core/account.rb', line 4770

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account’s identity.



4772
4773
4774
# File 'lib/stripe/resources/v2/core/account.rb', line 4772

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percentage of the Account’s identity that the individual owns.



4774
4775
4776
# File 'lib/stripe/resources/v2/core/account.rb', line 4774

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



4776
4777
4778
# File 'lib/stripe/resources/v2/core/account.rb', line 4776

def representative
  @representative
end

#titleObject (readonly)

The individual’s title (e.g., CEO, Support Engineer).



4778
4779
4780
# File 'lib/stripe/resources/v2/core/account.rb', line 4778

def title
  @title
end

Class Method Details

.field_remappingsObject



4784
4785
4786
# File 'lib/stripe/resources/v2/core/account.rb', line 4784

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4780
4781
4782
# File 'lib/stripe/resources/v2/core/account.rb', line 4780

def self.inner_class_types
  @inner_class_types = {}
end