Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the individual is an authorizer of the Account’s identity.



3134
3135
3136
# File 'lib/stripe/resources/v2/core/account.rb', line 3134

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the individual is a director of the Account’s identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.



3136
3137
3138
# File 'lib/stripe/resources/v2/core/account.rb', line 3136

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



3138
3139
3140
# File 'lib/stripe/resources/v2/core/account.rb', line 3138

def executive
  @executive
end

Whether the individual is the legal guardian of the Account’s representative.



3140
3141
3142
# File 'lib/stripe/resources/v2/core/account.rb', line 3140

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account’s identity.



3142
3143
3144
# File 'lib/stripe/resources/v2/core/account.rb', line 3142

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percentage of the Account’s identity that the individual owns.



3144
3145
3146
# File 'lib/stripe/resources/v2/core/account.rb', line 3144

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



3146
3147
3148
# File 'lib/stripe/resources/v2/core/account.rb', line 3146

def representative
  @representative
end

#titleObject (readonly)

The individual’s title (e.g., CEO, Support Engineer).



3148
3149
3150
# File 'lib/stripe/resources/v2/core/account.rb', line 3148

def title
  @title
end

Class Method Details

.field_remappingsObject



3154
3155
3156
# File 'lib/stripe/resources/v2/core/account.rb', line 3154

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3150
3151
3152
# File 'lib/stripe/resources/v2/core/account.rb', line 3150

def self.inner_class_types
  @inner_class_types = {}
end