Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the individual is an authorizer of the Account’s legal entity.



3450
3451
3452
# File 'lib/stripe/resources/v2/core/account.rb', line 3450

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the individual is a director of the Account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3452
3453
3454
# File 'lib/stripe/resources/v2/core/account.rb', line 3452

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



3454
3455
3456
# File 'lib/stripe/resources/v2/core/account.rb', line 3454

def executive
  @executive
end

Whether the individual is the legal guardian of the Account’s representative.



3456
3457
3458
# File 'lib/stripe/resources/v2/core/account.rb', line 3456

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account’s legal entity.



3458
3459
3460
# File 'lib/stripe/resources/v2/core/account.rb', line 3458

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percent owned by the individual of the Account’s legal entity.



3460
3461
3462
# File 'lib/stripe/resources/v2/core/account.rb', line 3460

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



3462
3463
3464
# File 'lib/stripe/resources/v2/core/account.rb', line 3462

def representative
  @representative
end

#titleObject (readonly)

The individual’s title (e.g., CEO, Support Engineer).



3464
3465
3466
# File 'lib/stripe/resources/v2/core/account.rb', line 3464

def title
  @title
end

Class Method Details

.field_remappingsObject



3470
3471
3472
# File 'lib/stripe/resources/v2/core/account.rb', line 3470

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3466
3467
3468
# File 'lib/stripe/resources/v2/core/account.rb', line 3466

def self.inner_class_types
  @inner_class_types = {}
end