Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authorizerObject (readonly)

Whether the individual is an authorizer of the Account’s legal entity.



3403
3404
3405
# File 'lib/stripe/resources/v2/core/account.rb', line 3403

def authorizer
  @authorizer
end

#directorObject (readonly)

Whether the individual is a director of the Account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3405
3406
3407
# File 'lib/stripe/resources/v2/core/account.rb', line 3405

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



3407
3408
3409
# File 'lib/stripe/resources/v2/core/account.rb', line 3407

def executive
  @executive
end

Whether the individual is the legal guardian of the Account’s representative.



3409
3410
3411
# File 'lib/stripe/resources/v2/core/account.rb', line 3409

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account’s legal entity.



3411
3412
3413
# File 'lib/stripe/resources/v2/core/account.rb', line 3411

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percent owned by the individual of the Account’s legal entity.



3413
3414
3415
# File 'lib/stripe/resources/v2/core/account.rb', line 3413

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



3415
3416
3417
# File 'lib/stripe/resources/v2/core/account.rb', line 3415

def representative
  @representative
end

#titleObject (readonly)

The individual’s title (e.g., CEO, Support Engineer).



3417
3418
3419
# File 'lib/stripe/resources/v2/core/account.rb', line 3417

def title
  @title
end

Class Method Details

.field_remappingsObject



3423
3424
3425
# File 'lib/stripe/resources/v2/core/account.rb', line 3423

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



3419
3420
3421
# File 'lib/stripe/resources/v2/core/account.rb', line 3419

def self.inner_class_types
  @inner_class_types = {}
end