Class: Stripe::V2::Core::Account::Identity::Individual::Relationship
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Relationship
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
readonly
Whether the individual is an authorizer of the Account’s legal entity.
-
#director ⇒ Object
readonly
Whether the individual is a director of the Account’s legal entity.
-
#executive ⇒ Object
readonly
Whether the individual has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
readonly
Whether the individual is the legal guardian of the Account’s representative.
-
#owner ⇒ Object
readonly
Whether the individual is an owner of the Account’s legal entity.
-
#percent_ownership ⇒ Object
readonly
The percent owned by the individual of the Account’s legal entity.
-
#representative ⇒ Object
readonly
Whether the individual is authorized as the primary representative of the Account.
-
#title ⇒ Object
readonly
The individual’s title (e.g., CEO, Support Engineer).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorizer ⇒ Object (readonly)
Whether the individual is an authorizer of the Account’s legal entity.
1689 1690 1691 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1689 def @authorizer end |
#director ⇒ Object (readonly)
Whether the individual is a director of the Account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1691 1692 1693 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1691 def director @director end |
#executive ⇒ Object (readonly)
Whether the individual has significant responsibility to control, manage, or direct the organization.
1693 1694 1695 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1693 def executive @executive end |
#legal_guardian ⇒ Object (readonly)
Whether the individual is the legal guardian of the Account’s representative.
1695 1696 1697 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1695 def legal_guardian @legal_guardian end |
#owner ⇒ Object (readonly)
Whether the individual is an owner of the Account’s legal entity.
1697 1698 1699 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1697 def owner @owner end |
#percent_ownership ⇒ Object (readonly)
The percent owned by the individual of the Account’s legal entity.
1699 1700 1701 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1699 def percent_ownership @percent_ownership end |
#representative ⇒ Object (readonly)
Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
1701 1702 1703 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1701 def representative @representative end |
#title ⇒ Object (readonly)
The individual’s title (e.g., CEO, Support Engineer).
1703 1704 1705 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1703 def title @title end |