Class: Stripe::V2::Core::Account::Identity::Individual::Relationship
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Relationship
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
readonly
Whether the individual is an authorizer of the Account’s legal entity.
-
#director ⇒ Object
readonly
Whether the individual is a director of the Account’s legal entity.
-
#executive ⇒ Object
readonly
Whether the individual has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
readonly
Whether the individual is the legal guardian of the Account’s representative.
-
#owner ⇒ Object
readonly
Whether the individual is an owner of the Account’s legal entity.
-
#percent_ownership ⇒ Object
readonly
The percent owned by the individual of the Account’s legal entity.
-
#representative ⇒ Object
readonly
Whether the individual is authorized as the primary representative of the Account.
-
#title ⇒ Object
readonly
The individual’s title (e.g., CEO, Support Engineer).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorizer ⇒ Object (readonly)
Whether the individual is an authorizer of the Account’s legal entity.
1505 1506 1507 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1505 def @authorizer end |
#director ⇒ Object (readonly)
Whether the individual is a director of the Account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1507 1508 1509 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1507 def director @director end |
#executive ⇒ Object (readonly)
Whether the individual has significant responsibility to control, manage, or direct the organization.
1509 1510 1511 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1509 def executive @executive end |
#legal_guardian ⇒ Object (readonly)
Whether the individual is the legal guardian of the Account’s representative.
1511 1512 1513 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1511 def legal_guardian @legal_guardian end |
#owner ⇒ Object (readonly)
Whether the individual is an owner of the Account’s legal entity.
1513 1514 1515 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1513 def owner @owner end |
#percent_ownership ⇒ Object (readonly)
The percent owned by the individual of the Account’s legal entity.
1515 1516 1517 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1515 def percent_ownership @percent_ownership end |
#representative ⇒ Object (readonly)
Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
1517 1518 1519 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1517 def representative @representative end |
#title ⇒ Object (readonly)
The individual’s title (e.g., CEO, Support Engineer).
1519 1520 1521 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1519 def title @title end |