Class: Stripe::V2::Core::Account::Identity::Individual::Relationship

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#directorObject (readonly)

Whether the individual is a director of the Account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1467
1468
1469
# File 'lib/stripe/resources/v2/core/account.rb', line 1467

def director
  @director
end

#executiveObject (readonly)

Whether the individual has significant responsibility to control, manage, or direct the organization.



1469
1470
1471
# File 'lib/stripe/resources/v2/core/account.rb', line 1469

def executive
  @executive
end

Whether the individual is the legal guardian of the Account’s representative.



1471
1472
1473
# File 'lib/stripe/resources/v2/core/account.rb', line 1471

def legal_guardian
  @legal_guardian
end

#ownerObject (readonly)

Whether the individual is an owner of the Account’s legal entity.



1473
1474
1475
# File 'lib/stripe/resources/v2/core/account.rb', line 1473

def owner
  @owner
end

#percent_ownershipObject (readonly)

The percent owned by the individual of the Account’s legal entity.



1475
1476
1477
# File 'lib/stripe/resources/v2/core/account.rb', line 1475

def percent_ownership
  @percent_ownership
end

#representativeObject (readonly)

Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



1477
1478
1479
# File 'lib/stripe/resources/v2/core/account.rb', line 1477

def representative
  @representative
end

#titleObject (readonly)

The individual’s title (e.g., CEO, Support Engineer).



1479
1480
1481
# File 'lib/stripe/resources/v2/core/account.rb', line 1479

def title
  @title
end