Class: Stripe::V2::Core::Account::Identity::Individual::Relationship
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Identity::Individual::Relationship
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
readonly
Whether the individual is an authorizer of the Account's identity.
-
#director ⇒ Object
readonly
Whether the individual is a director of the Account's identity.
-
#executive ⇒ Object
readonly
Whether the individual has significant responsibility to control, manage, or direct the organization.
-
#legal_guardian ⇒ Object
readonly
Whether the individual is the legal guardian of the Account's representative.
-
#owner ⇒ Object
readonly
Whether the individual is an owner of the Account's identity.
-
#percent_ownership ⇒ Object
readonly
The percentage of the Account's identity that the individual owns.
-
#representative ⇒ Object
readonly
Whether the individual is authorized as the primary representative of the Account.
-
#title ⇒ Object
readonly
The individual's title (e.g., CEO, Support Engineer).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorizer ⇒ Object (readonly)
Whether the individual is an authorizer of the Account's identity.
3293 3294 3295 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3293 def @authorizer end |
#director ⇒ Object (readonly)
Whether the individual is a director of the Account's identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.
3295 3296 3297 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3295 def director @director end |
#executive ⇒ Object (readonly)
Whether the individual has significant responsibility to control, manage, or direct the organization.
3297 3298 3299 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3297 def executive @executive end |
#legal_guardian ⇒ Object (readonly)
Whether the individual is the legal guardian of the Account's representative.
3299 3300 3301 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3299 def legal_guardian @legal_guardian end |
#owner ⇒ Object (readonly)
Whether the individual is an owner of the Account's identity.
3301 3302 3303 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3301 def owner @owner end |
#percent_ownership ⇒ Object (readonly)
The percentage of the Account's identity that the individual owns.
3303 3304 3305 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3303 def percent_ownership @percent_ownership end |
#representative ⇒ Object (readonly)
Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.
3305 3306 3307 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3305 def representative @representative end |
#title ⇒ Object (readonly)
The individual's title (e.g., CEO, Support Engineer).
3307 3308 3309 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3307 def title @title end |
Class Method Details
.field_encodings ⇒ Object
3317 3318 3319 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3317 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |
.field_remappings ⇒ Object
3313 3314 3315 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3313 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
3309 3310 3311 |
# File 'lib/stripe/resources/v2/core/account.rb', line 3309 def self.inner_class_types @inner_class_types = {} end |