Class: Stripe::V2::Core::Account::Requirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be user or stripe.



4421
4422
4423
# File 'lib/stripe/resources/v2/core/account.rb', line 4421

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



4423
4424
4425
# File 'lib/stripe/resources/v2/core/account.rb', line 4423

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn't satisfactory to Stripe.



4425
4426
4427
# File 'lib/stripe/resources/v2/core/account.rb', line 4425

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



4427
4428
4429
# File 'lib/stripe/resources/v2/core/account.rb', line 4427

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



4429
4430
4431
# File 'lib/stripe/resources/v2/core/account.rb', line 4429

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



4431
4432
4433
# File 'lib/stripe/resources/v2/core/account.rb', line 4431

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



4433
4434
4435
# File 'lib/stripe/resources/v2/core/account.rb', line 4433

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



4445
4446
4447
# File 'lib/stripe/resources/v2/core/account.rb', line 4445

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4435
4436
4437
4438
4439
4440
4441
4442
4443
# File 'lib/stripe/resources/v2/core/account.rb', line 4435

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end