Class: Stripe::V2::Core::Account::Requirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.



4074
4075
4076
# File 'lib/stripe/resources/v2/core/account.rb', line 4074

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



4076
4077
4078
# File 'lib/stripe/resources/v2/core/account.rb', line 4076

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



4078
4079
4080
# File 'lib/stripe/resources/v2/core/account.rb', line 4078

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



4080
4081
4082
# File 'lib/stripe/resources/v2/core/account.rb', line 4080

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



4082
4083
4084
# File 'lib/stripe/resources/v2/core/account.rb', line 4082

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



4084
4085
4086
# File 'lib/stripe/resources/v2/core/account.rb', line 4084

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



4086
4087
4088
# File 'lib/stripe/resources/v2/core/account.rb', line 4086

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



4098
4099
4100
# File 'lib/stripe/resources/v2/core/account.rb', line 4098

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4088
4089
4090
4091
4092
4093
4094
4095
4096
# File 'lib/stripe/resources/v2/core/account.rb', line 4088

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end