Class: Stripe::V2::Core::Account::Requirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.



5888
5889
5890
# File 'lib/stripe/resources/v2/core/account.rb', line 5888

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



5890
5891
5892
# File 'lib/stripe/resources/v2/core/account.rb', line 5890

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



5892
5893
5894
# File 'lib/stripe/resources/v2/core/account.rb', line 5892

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



5894
5895
5896
# File 'lib/stripe/resources/v2/core/account.rb', line 5894

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



5896
5897
5898
# File 'lib/stripe/resources/v2/core/account.rb', line 5896

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



5898
5899
5900
# File 'lib/stripe/resources/v2/core/account.rb', line 5898

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



5900
5901
5902
# File 'lib/stripe/resources/v2/core/account.rb', line 5900

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



5912
5913
5914
# File 'lib/stripe/resources/v2/core/account.rb', line 5912

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5902
5903
5904
5905
5906
5907
5908
5909
5910
# File 'lib/stripe/resources/v2/core/account.rb', line 5902

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end