Class: Stripe::V2::Core::Account::Requirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be ‘user` or `stripe`.



5068
5069
5070
# File 'lib/stripe/resources/v2/core/account.rb', line 5068

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



5070
5071
5072
# File 'lib/stripe/resources/v2/core/account.rb', line 5070

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



5072
5073
5074
# File 'lib/stripe/resources/v2/core/account.rb', line 5072

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



5074
5075
5076
# File 'lib/stripe/resources/v2/core/account.rb', line 5074

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



5076
5077
5078
# File 'lib/stripe/resources/v2/core/account.rb', line 5076

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



5078
5079
5080
# File 'lib/stripe/resources/v2/core/account.rb', line 5078

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



5080
5081
5082
# File 'lib/stripe/resources/v2/core/account.rb', line 5080

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



5092
5093
5094
# File 'lib/stripe/resources/v2/core/account.rb', line 5092

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5082
5083
5084
5085
5086
5087
5088
5089
5090
# File 'lib/stripe/resources/v2/core/account.rb', line 5082

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end