Class: Stripe::V2::Core::Account::Requirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Whether the responsibility is with the integrator or with Stripe (to review info, to wait for some condition, etc.) to action the requirement.



5183
5184
5185
# File 'lib/stripe/resources/v2/core/account.rb', line 5183

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



5185
5186
5187
# File 'lib/stripe/resources/v2/core/account.rb', line 5185

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



5187
5188
5189
# File 'lib/stripe/resources/v2/core/account.rb', line 5187

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



5189
5190
5191
# File 'lib/stripe/resources/v2/core/account.rb', line 5189

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



5191
5192
5193
# File 'lib/stripe/resources/v2/core/account.rb', line 5191

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



5193
5194
5195
# File 'lib/stripe/resources/v2/core/account.rb', line 5193

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



5195
5196
5197
# File 'lib/stripe/resources/v2/core/account.rb', line 5195

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



5207
5208
5209
# File 'lib/stripe/resources/v2/core/account.rb', line 5207

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



5197
5198
5199
5200
5201
5202
5203
5204
5205
# File 'lib/stripe/resources/v2/core/account.rb', line 5197

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end