Class: Stripe::V2::Core::Account::Requirements::Entry

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#awaiting_action_fromObject (readonly)

Whether the responsibility is with the integrator or with Stripe (to review info, to wait for some condition, etc.) to action the requirement.



4697
4698
4699
# File 'lib/stripe/resources/v2/core/account.rb', line 4697

def awaiting_action_from
  @awaiting_action_from
end

#descriptionObject (readonly)

Machine-readable string describing the requirement.



4699
4700
4701
# File 'lib/stripe/resources/v2/core/account.rb', line 4699

def description
  @description
end

#errorsObject (readonly)

Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.



4701
4702
4703
# File 'lib/stripe/resources/v2/core/account.rb', line 4701

def errors
  @errors
end

#impactObject (readonly)

A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.



4703
4704
4705
# File 'lib/stripe/resources/v2/core/account.rb', line 4703

def impact
  @impact
end

#minimum_deadlineObject (readonly)

The soonest point when the account will be impacted by not providing the requirement.



4705
4706
4707
# File 'lib/stripe/resources/v2/core/account.rb', line 4705

def minimum_deadline
  @minimum_deadline
end

#referenceObject (readonly)

A reference to the location of the requirement.



4707
4708
4709
# File 'lib/stripe/resources/v2/core/account.rb', line 4707

def reference
  @reference
end

#requested_reasonsObject (readonly)

A list of reasons why Stripe is collecting the requirement.



4709
4710
4711
# File 'lib/stripe/resources/v2/core/account.rb', line 4709

def requested_reasons
  @requested_reasons
end

Class Method Details

.field_remappingsObject



4721
4722
4723
# File 'lib/stripe/resources/v2/core/account.rb', line 4721

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4711
4712
4713
4714
4715
4716
4717
4718
4719
# File 'lib/stripe/resources/v2/core/account.rb', line 4711

def self.inner_class_types
  @inner_class_types = {
    errors: Error,
    impact: Impact,
    minimum_deadline: MinimumDeadline,
    reference: Reference,
    requested_reasons: RequestedReason,
  }
end