Class: Stripe::V2::Core::Account::Requirements::Entry
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#awaiting_action_from ⇒ Object
readonly
Whether the responsibility is with the integrator or with Stripe (to review info, to wait for some condition, etc.) to action the requirement.
-
#description ⇒ Object
readonly
Machine-readable string describing the requirement.
-
#errors ⇒ Object
readonly
Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.
-
#impact ⇒ Object
readonly
A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
-
#minimum_deadline ⇒ Object
readonly
The soonest point when the account will be impacted by not providing the requirement.
-
#reference ⇒ Object
readonly
A reference to the location of the requirement.
-
#requested_reasons ⇒ Object
readonly
A list of reasons why Stripe is collecting the requirement.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#awaiting_action_from ⇒ Object (readonly)
Whether the responsibility is with the integrator or with Stripe (to review info, to wait for some condition, etc.) to action the requirement.
4495 4496 4497 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4495 def awaiting_action_from @awaiting_action_from end |
#description ⇒ Object (readonly)
Machine-readable string describing the requirement.
4497 4498 4499 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4497 def description @description end |
#errors ⇒ Object (readonly)
Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.
4499 4500 4501 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4499 def errors @errors end |
#impact ⇒ Object (readonly)
A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
4501 4502 4503 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4501 def impact @impact end |
#minimum_deadline ⇒ Object (readonly)
The soonest point when the account will be impacted by not providing the requirement.
4503 4504 4505 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4503 def minimum_deadline @minimum_deadline end |
#reference ⇒ Object (readonly)
A reference to the location of the requirement.
4505 4506 4507 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4505 def reference @reference end |
#requested_reasons ⇒ Object (readonly)
A list of reasons why Stripe is collecting the requirement.
4507 4508 4509 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4507 def requested_reasons @requested_reasons end |
Class Method Details
.field_remappings ⇒ Object
4519 4520 4521 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4519 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4509 4510 4511 4512 4513 4514 4515 4516 4517 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4509 def self.inner_class_types @inner_class_types = { errors: Error, impact: Impact, minimum_deadline: MinimumDeadline, reference: Reference, requested_reasons: RequestedReason, } end |