Class: Stripe::V2::Core::Account::Requirements::Entry
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Error, Impact, MinimumDeadline, Reference, RequestedReason
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#awaiting_action_from ⇒ Object
readonly
Whether the responsibility is with the integrator or with Stripe (to review info, to wait for some condition, etc.) to action the requirement.
-
#description ⇒ Object
readonly
Machine-readable string describing the requirement.
-
#errors ⇒ Object
readonly
Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.
-
#impact ⇒ Object
readonly
A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
-
#minimum_deadline ⇒ Object
readonly
The soonest point when the account will be impacted by not providing the requirement.
-
#reference ⇒ Object
readonly
A reference to the location of the requirement.
-
#requested_reasons ⇒ Object
readonly
A list of reasons why Stripe is collecting the requirement.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#awaiting_action_from ⇒ Object (readonly)
Whether the responsibility is with the integrator or with Stripe (to review info, to wait for some condition, etc.) to action the requirement.
1685 1686 1687 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1685 def awaiting_action_from @awaiting_action_from end |
#description ⇒ Object (readonly)
Machine-readable string describing the requirement.
1687 1688 1689 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1687 def description @description end |
#errors ⇒ Object (readonly)
Descriptions of why the requirement must be collected, or why the collected information isn’t satisfactory to Stripe.
1689 1690 1691 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1689 def errors @errors end |
#impact ⇒ Object (readonly)
A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
1691 1692 1693 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1691 def impact @impact end |
#minimum_deadline ⇒ Object (readonly)
The soonest point when the account will be impacted by not providing the requirement.
1693 1694 1695 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1693 def minimum_deadline @minimum_deadline end |
#reference ⇒ Object (readonly)
A reference to the location of the requirement.
1695 1696 1697 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1695 def reference @reference end |
#requested_reasons ⇒ Object (readonly)
A list of reasons why Stripe is collecting the requirement.
1697 1698 1699 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1697 def requested_reasons @requested_reasons end |