Class: Stripe::V2::Core::Account::Requirements::Entry::Impact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Impact
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: RestrictsCapability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#restricts_capabilities ⇒ Object
readonly
The Capabilities that will be restricted if the requirement is not collected and satisfactory to Stripe.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#restricts_capabilities ⇒ Object (readonly)
The Capabilities that will be restricted if the requirement is not collected and satisfactory to Stripe.
4388 4389 4390 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4388 def restricts_capabilities @restricts_capabilities end |
Class Method Details
.field_remappings ⇒ Object
4394 4395 4396 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4394 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4390 4391 4392 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4390 def self.inner_class_types @inner_class_types = { restricts_capabilities: RestrictsCapability } end |