Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Deadline

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capabilityObject (readonly)

The name of the Capability which will be restricted.



4004
4005
4006
# File 'lib/stripe/resources/v2/core/account.rb', line 4004

def capability
  @capability
end

#configurationObject (readonly)

The configuration which specifies the Capability which will be restricted.



4006
4007
4008
# File 'lib/stripe/resources/v2/core/account.rb', line 4006

def configuration
  @configuration
end

#deadlineObject (readonly)

Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.



4008
4009
4010
# File 'lib/stripe/resources/v2/core/account.rb', line 4008

def deadline
  @deadline
end

Class Method Details

.field_remappingsObject



4014
4015
4016
# File 'lib/stripe/resources/v2/core/account.rb', line 4014

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4010
4011
4012
# File 'lib/stripe/resources/v2/core/account.rb', line 4010

def self.inner_class_types
  @inner_class_types = { deadline: Deadline }
end