Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Deadline
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capability ⇒ Object
readonly
The name of the Capability which will be restricted.
-
#configuration ⇒ Object
readonly
The configuration which specifies the Capability which will be restricted.
-
#deadline ⇒ Object
readonly
Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capability ⇒ Object (readonly)
The name of the Capability which will be restricted.
6030 6031 6032 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6030 def capability @capability end |
#configuration ⇒ Object (readonly)
The configuration which specifies the Capability which will be restricted.
6032 6033 6034 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6032 def configuration @configuration end |
#deadline ⇒ Object (readonly)
Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.
6034 6035 6036 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6034 def deadline @deadline end |
Class Method Details
.field_remappings ⇒ Object
6040 6041 6042 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6040 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
6036 6037 6038 |
# File 'lib/stripe/resources/v2/core/account.rb', line 6036 def self.inner_class_types @inner_class_types = { deadline: Deadline } end |