Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Deadline
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capability ⇒ Object
readonly
The name of the Capability which will be restricted.
-
#configuration ⇒ Object
readonly
The configuration which specifies the Capability which will be restricted.
-
#deadline ⇒ Object
readonly
Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capability ⇒ Object (readonly)
The name of the Capability which will be restricted.
4784 4785 4786 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4784 def capability @capability end |
#configuration ⇒ Object (readonly)
The configuration which specifies the Capability which will be restricted.
4786 4787 4788 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4786 def configuration @configuration end |
#deadline ⇒ Object (readonly)
Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.
4788 4789 4790 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4788 def deadline @deadline end |
Class Method Details
.field_remappings ⇒ Object
4794 4795 4796 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4794 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4790 4791 4792 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4790 def self.inner_class_types @inner_class_types = { deadline: Deadline } end |