Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Defined Under Namespace
Classes: Deadline
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capability ⇒ Object
readonly
The name of the Capability which will be restricted.
-
#configuration ⇒ Object
readonly
The configuration which specifies the Capability which will be restricted.
-
#deadline ⇒ Object
readonly
Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capability ⇒ Object (readonly)
The name of the Capability which will be restricted.
1665 1666 1667 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1665 def capability @capability end |
#configuration ⇒ Object (readonly)
The configuration which specifies the Capability which will be restricted.
1667 1668 1669 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1667 def configuration @configuration end |
#deadline ⇒ Object (readonly)
Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.
1669 1670 1671 |
# File 'lib/stripe/resources/v2/core/account.rb', line 1669 def deadline @deadline end |