Class: Stripe::V2::Core::Account::Requirements::Entry::Impact::RestrictsCapability

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Defined Under Namespace

Classes: Deadline

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capabilityObject (readonly)

The name of the Capability which will be restricted.



1656
1657
1658
# File 'lib/stripe/resources/v2/core/account.rb', line 1656

def capability
  @capability
end

#configurationObject (readonly)

The configuration which specifies the Capability which will be restricted.



1658
1659
1660
# File 'lib/stripe/resources/v2/core/account.rb', line 1658

def configuration
  @configuration
end

#deadlineObject (readonly)

Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.



1660
1661
1662
# File 'lib/stripe/resources/v2/core/account.rb', line 1660

def deadline
  @deadline
end