Class: Stripe::V2::Core::Account::Requirements::Entry::Reference
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Account::Requirements::Entry::Reference
- Defined in:
- lib/stripe/resources/v2/core/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#inquiry ⇒ Object
readonly
If
inquiryis the type, the inquiry token. -
#resource ⇒ Object
readonly
If
resourceis the type, the resource token. -
#type ⇒ Object
readonly
The type of the reference.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#inquiry ⇒ Object (readonly)
If inquiry is the type, the inquiry token.
4392 4393 4394 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4392 def inquiry @inquiry end |
#resource ⇒ Object (readonly)
If resource is the type, the resource token.
4394 4395 4396 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4394 def resource @resource end |
#type ⇒ Object (readonly)
The type of the reference. If the type is "inquiry", the inquiry token can be found in the "inquiry" field. Otherwise the type is an API resource, the token for which can be found in the "resource" field.
4397 4398 4399 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4397 def type @type end |
Class Method Details
.field_remappings ⇒ Object
4403 4404 4405 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4403 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
4399 4400 4401 |
# File 'lib/stripe/resources/v2/core/account.rb', line 4399 def self.inner_class_types @inner_class_types = {} end |