Class: Stripe::V2::Core::Account::Requirements::Entry::Reference

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#inquiryObject (readonly)

If ‘inquiry` is the type, the inquiry token.



4018
4019
4020
# File 'lib/stripe/resources/v2/core/account.rb', line 4018

def inquiry
  @inquiry
end

#resourceObject (readonly)

If ‘resource` is the type, the resource token.



4020
4021
4022
# File 'lib/stripe/resources/v2/core/account.rb', line 4020

def resource
  @resource
end

#typeObject (readonly)

The type of the reference. If the type is “inquiry”, the inquiry token can be found in the “inquiry” field. Otherwise the type is an API resource, the token for which can be found in the “resource” field.



4023
4024
4025
# File 'lib/stripe/resources/v2/core/account.rb', line 4023

def type
  @type
end

Class Method Details

.field_remappingsObject



4029
4030
4031
# File 'lib/stripe/resources/v2/core/account.rb', line 4029

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



4025
4026
4027
# File 'lib/stripe/resources/v2/core/account.rb', line 4025

def self.inner_class_types
  @inner_class_types = {}
end