Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6205

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



6185
6186
6187
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6185

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



6187
6188
6189
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6187

def configuration
  @configuration
end

#contact_emailObject

The primary contact email address for the Account.



6189
6190
6191
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6189

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



6191
6192
6193
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6191

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



6193
6194
6195
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6193

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



6195
6196
6197
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6195

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



6197
6198
6199
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6197

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



6199
6200
6201
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6199

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



6201
6202
6203
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6201

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



6203
6204
6205
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6203

def 
  @metadata
end

Class Method Details

.field_encodingsObject



6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
6239
6240
6241
6242
6243
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 6229

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end