Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2545 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2525 2526 2527 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2525 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2527 2528 2529 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2527 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
2529 2530 2531 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2529 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2531 2532 2533 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2531 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2533 2534 2535 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2533 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2535 2536 2537 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2535 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2537 2538 2539 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2537 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2539 2540 2541 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2539 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2541 2542 2543 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2541 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2543 2544 2545 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2543 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2569 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |