Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3790 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
3770 3771 3772 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3770 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
3772 3773 3774 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3772 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
3774 3775 3776 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3774 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
3776 3777 3778 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3776 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
3778 3779 3780 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3778 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
3780 3781 3782 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3780 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
3782 3783 3784 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3782 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
3784 3785 3786 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3784 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
3786 3787 3788 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3786 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3788 3789 3790 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3788 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3814 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |