Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2389 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2369 2370 2371 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2369 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2371 2372 2373 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2371 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2373 2374 2375 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2373 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2375 2376 2377 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2375 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2377 2378 2379 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2377 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2379 2380 2381 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2379 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2381 2382 2383 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2381 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2383 2384 2385 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2383 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2385 2386 2387 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2385 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2387 2388 2389 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2387 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2413 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |