Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3690

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3670
3671
3672
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3670

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3672
3673
3674
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3672

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3674
3675
3676
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3674

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3676
3677
3678
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3676

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3678
3679
3680
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3678

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3680
3681
3682
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3680

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3682
3683
3684
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3682

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3684
3685
3686
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3684

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3686
3687
3688
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3686

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3688
3689
3690
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3688

def 
  @metadata
end

Class Method Details

.field_encodingsObject



3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3714

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end