Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3639

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3619
3620
3621
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3619

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3621
3622
3623
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3621

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3623
3624
3625
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3623

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3625
3626
3627
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3625

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3627
3628
3629
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3627

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3629
3630
3631
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3629

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3631
3632
3633
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3631

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3633
3634
3635
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3633

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3635
3636
3637
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3635

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3637
3638
3639
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3637

def 
  @metadata
end