Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3117

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3097
3098
3099
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3097

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3099
3100
3101
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3099

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3101
3102
3103
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3101

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3103
3104
3105
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3103

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3105
3106
3107
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3105

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3107
3108
3109
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3107

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3109
3110
3111
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3109

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3111
3112
3113
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3111

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3113
3114
3115
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3113

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3115
3116
3117
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3115

def 
  @metadata
end