Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
3086
3087
3088
3089
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3067

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3047
3048
3049
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3047

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3049
3050
3051
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3049

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3051
3052
3053
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3051

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3053
3054
3055
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3053

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3055
3056
3057
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3055

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3057
3058
3059
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3057

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3059
3060
3061
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3059

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3061
3062
3063
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3061

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3063
3064
3065
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3063

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3065
3066
3067
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3065

def 
  @metadata
end