Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2360 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2340 2341 2342 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2340 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2342 2343 2344 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2342 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2344 2345 2346 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2344 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2346 2347 2348 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2346 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2348 2349 2350 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2348 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2350 2351 2352 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2350 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2352 2353 2354 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2352 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2354 2355 2356 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2354 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2356 2357 2358 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2356 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2358 2359 2360 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2358 def @metadata end |