Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
3046 3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3046 def initialize( account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
3028 3029 3030 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3028 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
3030 3031 3032 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3030 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
3032 3033 3034 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3032 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
3034 3035 3036 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3034 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
3036 3037 3038 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3036 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
3038 3039 3040 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3038 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
3040 3041 3042 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3040 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
3042 3043 3044 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3042 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3044 3045 3046 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3044 def @metadata end |