Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2921 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2905 2906 2907 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2905 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2907 2908 2909 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2907 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2909 2910 2911 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2909 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2911 2912 2913 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2911 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2913 2914 2915 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2913 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2915 2916 2917 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2915 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2917 2918 2919 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2917 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2919 2920 2921 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2919 def @metadata end |