Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3034 def initialize( account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
3016 3017 3018 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3016 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
3018 3019 3020 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3018 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
3020 3021 3022 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3020 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
3022 3023 3024 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3022 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
3024 3025 3026 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3024 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
3026 3027 3028 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3026 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
3028 3029 3030 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3028 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
3030 3031 3032 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3030 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3032 3033 3034 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3032 def @metadata end |