Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2807 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2791 2792 2793 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2791 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2793 2794 2795 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2793 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2795 2796 2797 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2795 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2797 2798 2799 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2797 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2799 2800 2801 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2799 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2801 2802 2803 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2801 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2803 2804 2805 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2803 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2805 2806 2807 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2805 def @metadata end |