Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2636

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2620
2621
2622
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2620

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2622
2623
2624
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2622

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2624
2625
2626
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2624

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2626
2627
2628
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2626

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2628
2629
2630
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2628

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2630
2631
2632
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2630

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2632
2633
2634
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2632

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2634
2635
2636
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2634

def 
  @metadata
end