Class: Stripe::V2::Core::AccountCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams

Returns a new instance of AccountCreateParams.



2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2212

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2196
2197
2198
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2196

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2198
2199
2200
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2198

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2200
2201
2202
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2200

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2202
2203
2204
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2202

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2204
2205
2206
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2204

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2206
2207
2208
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2206

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2208
2209
2210
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2208

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2210
2211
2212
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2210

def 
  @metadata
end