Class: Stripe::V2::Core::AccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
constructor
A new instance of AccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountCreateParams
Returns a new instance of AccountCreateParams.
2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2112 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2092 2093 2094 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2092 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2094 2095 2096 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2094 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2096 2097 2098 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2096 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2098 2099 2100 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2098 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2100 2101 2102 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2100 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2102 2103 2104 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2102 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2104 2105 2106 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2104 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2106 2107 2108 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2106 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2108 2109 2110 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2108 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2110 2111 2112 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2110 def end |
Class Method Details
.field_encodings ⇒ Object
2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2136 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |