Class: Stripe::V2::Core::AccountCreateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Customer, Merchant, MoneyManager, Recipient
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#money_manager ⇒ Object
The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration
Returns a new instance of Configuration.
1389 1390 1391 1392 1393 1394 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1389 def initialize(customer: nil, merchant: nil, money_manager: nil, recipient: nil) @customer = customer @merchant = merchant @money_manager = money_manager @recipient = recipient end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).
1381 1382 1383 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1381 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1383 1384 1385 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1383 def merchant @merchant end |
#money_manager ⇒ Object
The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
1385 1386 1387 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1385 def money_manager @money_manager end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1387 1388 1389 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1387 def recipient @recipient end |