Class: Stripe::V2::Core::AccountCreateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1714 def initialize( card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil ) @card_creator = card_creator @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
1704 1705 1706 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1704 def card_creator @card_creator end |
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).
1706 1707 1708 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1706 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1708 1709 1710 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1708 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1710 1711 1712 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1710 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1712 1713 1714 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1712 def storer @storer end |