Class: Stripe::V2::Core::AccountCreateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1255 1256 1257 1258 1259 1260 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1255 def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows.
1247 1248 1249 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1247 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1249 1250 1251 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1249 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1251 1252 1253 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1251 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1253 1254 1255 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1253 def storer @storer end |