Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1676

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1666
1667
1668
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1666

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1668
1669
1670
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1668

def customer
  @customer
end

#merchantObject

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



1670
1671
1672
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1670

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



1672
1673
1674
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1672

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1674
1675
1676
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1674

def storer
  @storer
end