Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1570

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1560
1561
1562
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1560

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1562
1563
1564
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1562

def customer
  @customer
end

#merchantObject

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



1564
1565
1566
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1564

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



1566
1567
1568
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1566

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1568
1569
1570
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1568

def storer
  @storer
end