Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1234
1235
1236
1237
1238
1239
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1234

def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1226
1227
1228
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1226

def customer
  @customer
end

#merchantObject

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



1228
1229
1230
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1228

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



1230
1231
1232
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1230

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1232
1233
1234
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1232

def storer
  @storer
end