Class: Stripe::V2::Core::AccountCreateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1520 def initialize( card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil ) @card_creator = card_creator @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
1510 1511 1512 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1510 def card_creator @card_creator end |
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows.
1512 1513 1514 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1512 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1514 1515 1516 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1514 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1516 1517 1518 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1516 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1518 1519 1520 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1518 def storer @storer end |