Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1508

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1498
1499
1500
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1498

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1500
1501
1502
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1500

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1502
1503
1504
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1502

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1504
1505
1506
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1504

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1506
1507
1508
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1506

def storer
  @storer
end