Class: Stripe::V2::Core::AccountCreateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows.
-
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1419 def initialize( card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil ) @card_creator = card_creator @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
1409 1410 1411 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1409 def card_creator @card_creator end |
#customer ⇒ Object
The Customer Configuration allows the Account to be used in inbound payment flows.
1411 1412 1413 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1411 def customer @customer end |
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.
1413 1414 1415 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1413 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
1415 1416 1417 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1415 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1417 1418 1419 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1417 def storer @storer end |