Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1399

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1389
1390
1391
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1389

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1391
1392
1393
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1391

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1393
1394
1395
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1393

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1395
1396
1397
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1395

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1397
1398
1399
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1397

def storer
  @storer
end