Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1269

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1259
1260
1261
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1259

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1261
1262
1263
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1261

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1263
1264
1265
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1263

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1265
1266
1267
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1265

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1267
1268
1269
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1267

def storer
  @storer
end