Class: Stripe::V2::Core::AccountCreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1150
1151
1152
1153
1154
1155
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1150

def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



1142
1143
1144
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1142

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1144
1145
1146
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1144

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1146
1147
1148
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1146

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1148
1149
1150
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1148

def storer
  @storer
end