Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 410

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



400
401
402
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 400

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



402
403
404
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 402

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



404
405
406
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 404

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



406
407
408
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 406

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



408
409
410
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 408

def test_clock
  @test_clock
end