Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping
Instance Attribute Summary collapse
-
#automatic_indirect_tax ⇒ Object
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links.
-
#billing ⇒ Object
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
-
#capabilities ⇒ Object
Capabilities that have been requested on the Customer Configuration.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
Instance Method Summary collapse
-
#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer
constructor
A new instance of Customer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer
Returns a new instance of Customer.
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 155 def initialize( automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil ) @automatic_indirect_tax = automatic_indirect_tax @billing = billing @capabilities = capabilities @shipping = shipping @test_clock = test_clock end |
Instance Attribute Details
#automatic_indirect_tax ⇒ Object
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.
145 146 147 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 145 def automatic_indirect_tax @automatic_indirect_tax end |
#billing ⇒ Object
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
147 148 149 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 147 def billing @billing end |
#capabilities ⇒ Object
Capabilities that have been requested on the Customer Configuration.
149 150 151 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 149 def capabilities @capabilities end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
151 152 153 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 151 def shipping @shipping end |
#test_clock ⇒ Object
ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
153 154 155 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 153 def test_clock @test_clock end |