Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 398

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



388
389
390
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 388

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



390
391
392
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 390

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



392
393
394
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 392

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



394
395
396
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 394

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



396
397
398
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 396

def test_clock
  @test_clock
end