Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 292

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



282
283
284
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 282

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



284
285
286
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 284

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



286
287
288
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 286

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



288
289
290
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 288

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



290
291
292
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 290

def test_clock
  @test_clock
end