Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping
Instance Attribute Summary collapse
-
#automatic_indirect_tax ⇒ Object
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links.
-
#billing ⇒ Object
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
-
#capabilities ⇒ Object
Capabilities that have been requested on the Customer Configuration.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
Instance Method Summary collapse
-
#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer
constructor
A new instance of Customer.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer
Returns a new instance of Customer.
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 272 def initialize( automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil ) @automatic_indirect_tax = automatic_indirect_tax @billing = billing @capabilities = capabilities @shipping = shipping @test_clock = test_clock end |
Instance Attribute Details
#automatic_indirect_tax ⇒ Object
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.
262 263 264 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 262 def automatic_indirect_tax @automatic_indirect_tax end |
#billing ⇒ Object
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
264 265 266 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 264 def billing @billing end |
#capabilities ⇒ Object
Capabilities that have been requested on the Customer Configuration.
266 267 268 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 266 def capabilities @capabilities end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
268 269 270 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 268 def shipping @shipping end |
#test_clock ⇒ Object
ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
270 271 272 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 270 def test_clock @test_clock end |