Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address`.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
18 19 20 21 22 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 18 def initialize(exempt: nil, ip_address: nil, location_source: nil) @exempt = exempt @ip_address = ip_address @location_source = location_source end |
Instance Attribute Details
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.
12 13 14 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 12 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
14 15 16 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 14 def ip_address @ip_address end |
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address`. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions. This behavior is now deprecated for new users.
16 17 18 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 16 def location_source @location_source end |