Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CustomField, Rendering
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#footer ⇒ Object
Default invoice footer.
-
#next_sequence ⇒ Object
Sequence number to use on the customer account’s next invoice.
-
#prefix ⇒ Object
Prefix used to generate unique invoice numbers.
-
#rendering ⇒ Object
Default invoice PDF rendering options.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
Returns a new instance of Invoice.
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 304 def initialize( custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil ) @custom_fields = custom_fields @footer = @next_sequence = next_sequence @prefix = prefix @rendering = rendering end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
294 295 296 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 294 def custom_fields @custom_fields end |
#footer ⇒ Object
Default invoice footer.
296 297 298 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 296 def @footer end |
#next_sequence ⇒ Object
Sequence number to use on the customer account’s next invoice. Defaults to 1.
298 299 300 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 298 def next_sequence @next_sequence end |
#prefix ⇒ Object
Prefix used to generate unique invoice numbers. Must be 3-12 uppercase letters or numbers.
300 301 302 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 300 def prefix @prefix end |
#rendering ⇒ Object
Default invoice PDF rendering options.
302 303 304 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 302 def rendering @rendering end |