Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CustomField, Rendering
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#next_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#rendering ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
Returns a new instance of Invoice.
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 198 def initialize( custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil ) @custom_fields = custom_fields @footer = @next_sequence = next_sequence @prefix = prefix @rendering = rendering end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
188 189 190 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 188 def custom_fields @custom_fields end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
190 191 192 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 190 def @footer end |
#next_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
192 193 194 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 192 def next_sequence @next_sequence end |
#prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
194 195 196 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 194 def prefix @prefix end |
#rendering ⇒ Object
Default options for invoice PDF rendering for this customer.
196 197 198 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 196 def rendering @rendering end |