Class: Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Customer::Billing::Invoice
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CustomField, Rendering
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#next_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#rendering ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
Returns a new instance of Invoice.
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 178 def initialize( custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil ) @custom_fields = custom_fields @footer = @next_sequence = next_sequence @prefix = prefix @rendering = rendering end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
168 169 170 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 168 def custom_fields @custom_fields end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
170 171 172 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 170 def @footer end |
#next_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
172 173 174 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 172 def next_sequence @next_sequence end |
#prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
174 175 176 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 174 def prefix @prefix end |
#rendering ⇒ Object
Default options for invoice PDF rendering for this customer.
176 177 178 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 176 def rendering @rendering end |