Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 979

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  konbini_payments: nil,
  mcc: nil,
  script_statement_descriptor: nil,
  smart_disputes: nil,
  statement_descriptor: nil,
  support: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @konbini_payments = konbini_payments
  @mcc = mcc
  @script_statement_descriptor = script_statement_descriptor
  @smart_disputes = smart_disputes
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings used for Bacs debit payments.



959
960
961
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 959

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



961
962
963
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 961

def branding
  @branding
end

#capabilitiesObject

Capabilities to request on the Merchant Configuration.



963
964
965
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 963

def capabilities
  @capabilities
end

#card_paymentsObject

Card payments settings.



965
966
967
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 965

def card_payments
  @card_payments
end

#konbini_paymentsObject

Settings specific to Konbini payments on the account.



967
968
969
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 967

def konbini_payments
  @konbini_payments
end

#mccObject

The Merchant Category Code (MCC) for the Merchant Configuration. MCCs classify businesses based on the goods or services they provide.



969
970
971
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 969

def mcc
  @mcc
end

#script_statement_descriptorObject

Settings for the default text that appears on statements for language variations.



971
972
973
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 971

def script_statement_descriptor
  @script_statement_descriptor
end

#smart_disputesObject

Settings used for Smart Disputes.



973
974
975
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 973

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject

Statement descriptor.



975
976
977
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 975

def statement_descriptor
  @statement_descriptor
end

#supportObject

Publicly available contact information for sending support issues to.



977
978
979
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 977

def support
  @support
end