Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1103

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  konbini_payments: nil,
  mcc: nil,
  script_statement_descriptor: nil,
  smart_disputes: nil,
  statement_descriptor: nil,
  support: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @konbini_payments = konbini_payments
  @mcc = mcc
  @script_statement_descriptor = script_statement_descriptor
  @smart_disputes = smart_disputes
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings used for Bacs debit payments.



1083
1084
1085
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1083

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



1085
1086
1087
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1085

def branding
  @branding
end

#capabilitiesObject

Capabilities to request on the Merchant Configuration.



1087
1088
1089
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1087

def capabilities
  @capabilities
end

#card_paymentsObject

Card payments settings.



1089
1090
1091
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1089

def card_payments
  @card_payments
end

#konbini_paymentsObject

Settings specific to Konbini payments on the account.



1091
1092
1093
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1091

def konbini_payments
  @konbini_payments
end

#mccObject

The Merchant Category Code (MCC) for the Merchant Configuration. MCCs classify businesses based on the goods or services they provide.



1093
1094
1095
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1093

def mcc
  @mcc
end

#script_statement_descriptorObject

Settings for the default text that appears on statements for language variations.



1095
1096
1097
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1095

def script_statement_descriptor
  @script_statement_descriptor
end

#smart_disputesObject

Settings used for Smart Disputes.



1097
1098
1099
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1097

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject

Statement descriptor.



1099
1100
1101
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1099

def statement_descriptor
  @statement_descriptor
end

#supportObject

Publicly available contact information for sending support issues to.



1101
1102
1103
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1101

def support
  @support
end