Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1209

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  konbini_payments: nil,
  mcc: nil,
  script_statement_descriptor: nil,
  smart_disputes: nil,
  statement_descriptor: nil,
  support: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @konbini_payments = konbini_payments
  @mcc = mcc
  @script_statement_descriptor = script_statement_descriptor
  @smart_disputes = smart_disputes
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings used for Bacs debit payments.



1189
1190
1191
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1189

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



1191
1192
1193
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1191

def branding
  @branding
end

#capabilitiesObject

Capabilities to request on the Merchant Configuration.



1193
1194
1195
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1193

def capabilities
  @capabilities
end

#card_paymentsObject

Card payments settings.



1195
1196
1197
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1195

def card_payments
  @card_payments
end

#konbini_paymentsObject

Settings specific to Konbini payments on the account.



1197
1198
1199
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1197

def konbini_payments
  @konbini_payments
end

#mccObject

The Merchant Category Code (MCC) for the Merchant Configuration. MCCs classify businesses based on the goods or services they provide.



1199
1200
1201
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1199

def mcc
  @mcc
end

#script_statement_descriptorObject

Settings for the default text that appears on statements for language variations.



1201
1202
1203
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1201

def script_statement_descriptor
  @script_statement_descriptor
end

#smart_disputesObject

Settings used for Smart Disputes.



1203
1204
1205
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1203

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject

Statement descriptor.



1205
1206
1207
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1205

def statement_descriptor
  @statement_descriptor
end

#supportObject

Publicly available contact information for sending support issues to.



1207
1208
1209
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1207

def support
  @support
end