Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#mcc ⇒ Object
The merchant category code for the Merchant Configuration.
-
#statement_descriptor ⇒ Object
Statement descriptor.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 991 def initialize( bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @mcc = mcc @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
977 978 979 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 977 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
979 980 981 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 979 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
981 982 983 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 981 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
983 984 985 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 983 def card_payments @card_payments end |
#mcc ⇒ Object
The merchant category code for the Merchant Configuration. MCCs are used to classify businesses based on the goods or services they provide.
985 986 987 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 985 def mcc @mcc end |
#statement_descriptor ⇒ Object
Statement descriptor.
987 988 989 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 987 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
989 990 991 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 989 def support @support end |