Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#mcc ⇒ Object
The merchant category code for the Merchant Configuration.
-
#statement_descriptor ⇒ Object
Statement descriptor.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 874 def initialize( bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @mcc = mcc @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
860 861 862 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 860 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
862 863 864 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 862 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
864 865 866 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 864 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
866 867 868 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 866 def card_payments @card_payments end |
#mcc ⇒ Object
The merchant category code for the Merchant Configuration. MCCs are used to classify businesses based on the goods or services they provide.
868 869 870 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 868 def mcc @mcc end |
#statement_descriptor ⇒ Object
Statement descriptor.
870 871 872 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 870 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
872 873 874 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 872 def support @support end |