Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ach_debit_payments: nil, acss_debit_payments: nil, affirm_payments: nil, afterpay_clearpay_payments: nil, alma_payments: nil, amazon_pay_payments: nil, au_becs_debit_payments: nil, bacs_debit_payments: nil, bancontact_payments: nil, blik_payments: nil, boleto_payments: nil, card_payments: nil, cartes_bancaires_payments: nil, cashapp_payments: nil, eps_payments: nil, fpx_payments: nil, gb_bank_transfer_payments: nil, grabpay_payments: nil, ideal_payments: nil, jcb_payments: nil, jp_bank_transfer_payments: nil, kakao_pay_payments: nil, klarna_payments: nil, konbini_payments: nil, kr_card_payments: nil, link_payments: nil, mobilepay_payments: nil, multibanco_payments: nil, mx_bank_transfer_payments: nil, naver_pay_payments: nil, oxxo_payments: nil, p24_payments: nil, pay_by_bank_payments: nil, payco_payments: nil, paynow_payments: nil, promptpay_payments: nil, revolut_pay_payments: nil, samsung_pay_payments: nil, sepa_bank_transfer_payments: nil, sepa_debit_payments: nil, swish_payments: nil, twint_payments: nil, us_bank_transfer_payments: nil, zip_payments: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 683

def initialize(
  ach_debit_payments: nil,
  acss_debit_payments: nil,
  affirm_payments: nil,
  afterpay_clearpay_payments: nil,
  alma_payments: nil,
  amazon_pay_payments: nil,
  au_becs_debit_payments: nil,
  bacs_debit_payments: nil,
  bancontact_payments: nil,
  blik_payments: nil,
  boleto_payments: nil,
  card_payments: nil,
  cartes_bancaires_payments: nil,
  cashapp_payments: nil,
  eps_payments: nil,
  fpx_payments: nil,
  gb_bank_transfer_payments: nil,
  grabpay_payments: nil,
  ideal_payments: nil,
  jcb_payments: nil,
  jp_bank_transfer_payments: nil,
  kakao_pay_payments: nil,
  klarna_payments: nil,
  konbini_payments: nil,
  kr_card_payments: nil,
  link_payments: nil,
  mobilepay_payments: nil,
  multibanco_payments: nil,
  mx_bank_transfer_payments: nil,
  naver_pay_payments: nil,
  oxxo_payments: nil,
  p24_payments: nil,
  pay_by_bank_payments: nil,
  payco_payments: nil,
  paynow_payments: nil,
  promptpay_payments: nil,
  revolut_pay_payments: nil,
  samsung_pay_payments: nil,
  sepa_bank_transfer_payments: nil,
  sepa_debit_payments: nil,
  swish_payments: nil,
  twint_payments: nil,
  us_bank_transfer_payments: nil,
  zip_payments: nil
)
  @ach_debit_payments = ach_debit_payments
  @acss_debit_payments = acss_debit_payments
  @affirm_payments = affirm_payments
  @afterpay_clearpay_payments = afterpay_clearpay_payments
  @alma_payments = alma_payments
  @amazon_pay_payments = amazon_pay_payments
  @au_becs_debit_payments = au_becs_debit_payments
  @bacs_debit_payments = bacs_debit_payments
  @bancontact_payments = bancontact_payments
  @blik_payments = blik_payments
  @boleto_payments = boleto_payments
  @card_payments = card_payments
  @cartes_bancaires_payments = cartes_bancaires_payments
  @cashapp_payments = cashapp_payments
  @eps_payments = eps_payments
  @fpx_payments = fpx_payments
  @gb_bank_transfer_payments = gb_bank_transfer_payments
  @grabpay_payments = grabpay_payments
  @ideal_payments = ideal_payments
  @jcb_payments = jcb_payments
  @jp_bank_transfer_payments = jp_bank_transfer_payments
  @kakao_pay_payments = kakao_pay_payments
  @klarna_payments = klarna_payments
  @konbini_payments = konbini_payments
  @kr_card_payments = kr_card_payments
  @link_payments = link_payments
  @mobilepay_payments = mobilepay_payments
  @multibanco_payments = multibanco_payments
  @mx_bank_transfer_payments = mx_bank_transfer_payments
  @naver_pay_payments = naver_pay_payments
  @oxxo_payments = oxxo_payments
  @p24_payments = p24_payments
  @pay_by_bank_payments = pay_by_bank_payments
  @payco_payments = payco_payments
  @paynow_payments = paynow_payments
  @promptpay_payments = promptpay_payments
  @revolut_pay_payments = revolut_pay_payments
  @samsung_pay_payments = samsung_pay_payments
  @sepa_bank_transfer_payments = sepa_bank_transfer_payments
  @sepa_debit_payments = sepa_debit_payments
  @swish_payments = swish_payments
  @twint_payments = twint_payments
  @us_bank_transfer_payments = us_bank_transfer_payments
  @zip_payments = zip_payments
end

Instance Attribute Details

#ach_debit_paymentsObject

Allow the merchant to process ACH debit payments.



595
596
597
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 595

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject

Allow the merchant to process ACSS debit payments.



597
598
599
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 597

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject

Allow the merchant to process Affirm payments.



599
600
601
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 599

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject

Allow the merchant to process Afterpay/Clearpay payments.



601
602
603
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 601

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject

Allow the merchant to process Alma payments.



603
604
605
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 603

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject

Allow the merchant to process Amazon Pay payments.



605
606
607
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 605

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject

Allow the merchant to process Australian BECS Direct Debit payments.



607
608
609
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 607

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject

Allow the merchant to process BACS Direct Debit payments.



609
610
611
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 609

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject

Allow the merchant to process Bancontact payments.



611
612
613
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 611

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject

Allow the merchant to process BLIK payments.



613
614
615
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 613

def blik_payments
  @blik_payments
end

#boleto_paymentsObject

Allow the merchant to process Boleto payments.



615
616
617
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 615

def boleto_payments
  @boleto_payments
end

#card_paymentsObject

Allow the merchant to collect card payments.



617
618
619
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 617

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject

Allow the merchant to process Cartes Bancaires payments.



619
620
621
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 619

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject

Allow the merchant to process Cash App payments.



621
622
623
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 621

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject

Allow the merchant to process EPS payments.



623
624
625
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 623

def eps_payments
  @eps_payments
end

#fpx_paymentsObject

Allow the merchant to process FPX payments.



625
626
627
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 625

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject

Allow the merchant to process UK bank transfer payments.



627
628
629
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 627

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject

Allow the merchant to process GrabPay payments.



629
630
631
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 629

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject

Allow the merchant to process iDEAL payments.



631
632
633
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 631

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject

Allow the merchant to process JCB card payments.



633
634
635
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 633

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject

Allow the merchant to process Japanese bank transfer payments.



635
636
637
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 635

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject

Allow the merchant to process Kakao Pay payments.



637
638
639
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 637

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject

Allow the merchant to process Klarna payments.



639
640
641
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 639

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject

Allow the merchant to process Konbini convenience store payments.



641
642
643
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 641

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject

Allow the merchant to process Korean card payments.



643
644
645
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 643

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



645
646
647
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 645

def link_payments
  @link_payments
end

#mobilepay_paymentsObject

Allow the merchant to process MobilePay payments.



647
648
649
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 647

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject

Allow the merchant to process Multibanco payments.



649
650
651
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 649

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject

Allow the merchant to process Mexican bank transfer payments.



651
652
653
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 651

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



653
654
655
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 653

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject

Allow the merchant to process OXXO payments.



655
656
657
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 655

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject

Allow the merchant to process Przelewy24 (P24) payments.



657
658
659
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 657

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject

Allow the merchant to process Pay by Bank payments.



659
660
661
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 659

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject

Allow the merchant to process PAYCO payments.



661
662
663
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 661

def payco_payments
  @payco_payments
end

#paynow_paymentsObject

Allow the merchant to process PayNow payments.



663
664
665
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 663

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject

Allow the merchant to process PromptPay payments.



665
666
667
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 665

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject

Allow the merchant to process Revolut Pay payments.



667
668
669
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 667

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject

Allow the merchant to process Samsung Pay payments.



669
670
671
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 669

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject

Allow the merchant to process SEPA bank transfer payments.



671
672
673
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 671

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject

Allow the merchant to process SEPA Direct Debit payments.



673
674
675
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 673

def sepa_debit_payments
  @sepa_debit_payments
end

#swish_paymentsObject

Allow the merchant to process Swish payments.



675
676
677
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 675

def swish_payments
  @swish_payments
end

#twint_paymentsObject

Allow the merchant to process TWINT payments.



677
678
679
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 677

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject

Allow the merchant to process US bank transfer payments.



679
680
681
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 679

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject

Allow the merchant to process Zip payments.



681
682
683
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 681

def zip_payments
  @zip_payments
end