Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(ach_debit_payments: nil, acss_debit_payments: nil, affirm_payments: nil, afterpay_clearpay_payments: nil, alma_payments: nil, amazon_pay_payments: nil, au_becs_debit_payments: nil, bacs_debit_payments: nil, bancontact_payments: nil, blik_payments: nil, boleto_payments: nil, card_payments: nil, cartes_bancaires_payments: nil, cashapp_payments: nil, eps_payments: nil, fpx_payments: nil, gb_bank_transfer_payments: nil, grabpay_payments: nil, ideal_payments: nil, jcb_payments: nil, jp_bank_transfer_payments: nil, kakao_pay_payments: nil, klarna_payments: nil, konbini_payments: nil, kr_card_payments: nil, link_payments: nil, mobilepay_payments: nil, multibanco_payments: nil, mx_bank_transfer_payments: nil, naver_pay_payments: nil, oxxo_payments: nil, p24_payments: nil, pay_by_bank_payments: nil, payco_payments: nil, paynow_payments: nil, promptpay_payments: nil, revolut_pay_payments: nil, samsung_pay_payments: nil, sepa_bank_transfer_payments: nil, sepa_debit_payments: nil, swish_payments: nil, twint_payments: nil, us_bank_transfer_payments: nil, zip_payments: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 926

def initialize(
  ach_debit_payments: nil,
  acss_debit_payments: nil,
  affirm_payments: nil,
  afterpay_clearpay_payments: nil,
  alma_payments: nil,
  amazon_pay_payments: nil,
  au_becs_debit_payments: nil,
  bacs_debit_payments: nil,
  bancontact_payments: nil,
  blik_payments: nil,
  boleto_payments: nil,
  card_payments: nil,
  cartes_bancaires_payments: nil,
  cashapp_payments: nil,
  eps_payments: nil,
  fpx_payments: nil,
  gb_bank_transfer_payments: nil,
  grabpay_payments: nil,
  ideal_payments: nil,
  jcb_payments: nil,
  jp_bank_transfer_payments: nil,
  kakao_pay_payments: nil,
  klarna_payments: nil,
  konbini_payments: nil,
  kr_card_payments: nil,
  link_payments: nil,
  mobilepay_payments: nil,
  multibanco_payments: nil,
  mx_bank_transfer_payments: nil,
  naver_pay_payments: nil,
  oxxo_payments: nil,
  p24_payments: nil,
  pay_by_bank_payments: nil,
  payco_payments: nil,
  paynow_payments: nil,
  promptpay_payments: nil,
  revolut_pay_payments: nil,
  samsung_pay_payments: nil,
  sepa_bank_transfer_payments: nil,
  sepa_debit_payments: nil,
  swish_payments: nil,
  twint_payments: nil,
  us_bank_transfer_payments: nil,
  zip_payments: nil
)
  @ach_debit_payments = ach_debit_payments
  @acss_debit_payments = acss_debit_payments
  @affirm_payments = affirm_payments
  @afterpay_clearpay_payments = afterpay_clearpay_payments
  @alma_payments = alma_payments
  @amazon_pay_payments = amazon_pay_payments
  @au_becs_debit_payments = au_becs_debit_payments
  @bacs_debit_payments = bacs_debit_payments
  @bancontact_payments = bancontact_payments
  @blik_payments = blik_payments
  @boleto_payments = boleto_payments
  @card_payments = card_payments
  @cartes_bancaires_payments = cartes_bancaires_payments
  @cashapp_payments = cashapp_payments
  @eps_payments = eps_payments
  @fpx_payments = fpx_payments
  @gb_bank_transfer_payments = gb_bank_transfer_payments
  @grabpay_payments = grabpay_payments
  @ideal_payments = ideal_payments
  @jcb_payments = jcb_payments
  @jp_bank_transfer_payments = jp_bank_transfer_payments
  @kakao_pay_payments = kakao_pay_payments
  @klarna_payments = klarna_payments
  @konbini_payments = konbini_payments
  @kr_card_payments = kr_card_payments
  @link_payments = link_payments
  @mobilepay_payments = mobilepay_payments
  @multibanco_payments = multibanco_payments
  @mx_bank_transfer_payments = mx_bank_transfer_payments
  @naver_pay_payments = naver_pay_payments
  @oxxo_payments = oxxo_payments
  @p24_payments = p24_payments
  @pay_by_bank_payments = pay_by_bank_payments
  @payco_payments = payco_payments
  @paynow_payments = paynow_payments
  @promptpay_payments = promptpay_payments
  @revolut_pay_payments = revolut_pay_payments
  @samsung_pay_payments = samsung_pay_payments
  @sepa_bank_transfer_payments = sepa_bank_transfer_payments
  @sepa_debit_payments = sepa_debit_payments
  @swish_payments = swish_payments
  @twint_payments = twint_payments
  @us_bank_transfer_payments = us_bank_transfer_payments
  @zip_payments = zip_payments
end

Instance Attribute Details

#ach_debit_paymentsObject

Allow the merchant to process ACH debit payments.



838
839
840
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 838

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject

Allow the merchant to process ACSS debit payments.



840
841
842
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 840

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject

Allow the merchant to process Affirm payments.



842
843
844
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 842

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject

Allow the merchant to process Afterpay/Clearpay payments.



844
845
846
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 844

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject

Allow the merchant to process Alma payments.



846
847
848
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 846

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject

Allow the merchant to process Amazon Pay payments.



848
849
850
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 848

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject

Allow the merchant to process Australian BECS Direct Debit payments.



850
851
852
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 850

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject

Allow the merchant to process BACS Direct Debit payments.



852
853
854
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 852

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject

Allow the merchant to process Bancontact payments.



854
855
856
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 854

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject

Allow the merchant to process BLIK payments.



856
857
858
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 856

def blik_payments
  @blik_payments
end

#boleto_paymentsObject

Allow the merchant to process Boleto payments.



858
859
860
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 858

def boleto_payments
  @boleto_payments
end

#card_paymentsObject

Allow the merchant to collect card payments.



860
861
862
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 860

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject

Allow the merchant to process Cartes Bancaires payments.



862
863
864
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 862

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject

Allow the merchant to process Cash App payments.



864
865
866
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 864

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject

Allow the merchant to process EPS payments.



866
867
868
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 866

def eps_payments
  @eps_payments
end

#fpx_paymentsObject

Allow the merchant to process FPX payments.



868
869
870
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 868

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject

Allow the merchant to process UK bank transfer payments.



870
871
872
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 870

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject

Allow the merchant to process GrabPay payments.



872
873
874
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 872

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject

Allow the merchant to process iDEAL payments.



874
875
876
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 874

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject

Allow the merchant to process JCB card payments.



876
877
878
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 876

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject

Allow the merchant to process Japanese bank transfer payments.



878
879
880
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 878

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject

Allow the merchant to process Kakao Pay payments.



880
881
882
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 880

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject

Allow the merchant to process Klarna payments.



882
883
884
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 882

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject

Allow the merchant to process Konbini convenience store payments.



884
885
886
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 884

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject

Allow the merchant to process Korean card payments.



886
887
888
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 886

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



888
889
890
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 888

def link_payments
  @link_payments
end

#mobilepay_paymentsObject

Allow the merchant to process MobilePay payments.



890
891
892
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 890

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject

Allow the merchant to process Multibanco payments.



892
893
894
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 892

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject

Allow the merchant to process Mexican bank transfer payments.



894
895
896
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 894

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



896
897
898
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 896

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject

Allow the merchant to process OXXO payments.



898
899
900
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 898

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject

Allow the merchant to process Przelewy24 (P24) payments.



900
901
902
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 900

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject

Allow the merchant to process Pay by Bank payments.



902
903
904
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 902

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject

Allow the merchant to process PAYCO payments.



904
905
906
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 904

def payco_payments
  @payco_payments
end

#paynow_paymentsObject

Allow the merchant to process PayNow payments.



906
907
908
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 906

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject

Allow the merchant to process PromptPay payments.



908
909
910
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 908

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject

Allow the merchant to process Revolut Pay payments.



910
911
912
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 910

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject

Allow the merchant to process Samsung Pay payments.



912
913
914
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 912

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject

Allow the merchant to process SEPA bank transfer payments.



914
915
916
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 914

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject

Allow the merchant to process SEPA Direct Debit payments.



916
917
918
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 916

def sepa_debit_payments
  @sepa_debit_payments
end

#swish_paymentsObject

Allow the merchant to process Swish payments.



918
919
920
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 918

def swish_payments
  @swish_payments
end

#twint_paymentsObject

Allow the merchant to process TWINT payments.



920
921
922
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 920

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject

Allow the merchant to process US bank transfer payments.



922
923
924
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 922

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject

Allow the merchant to process Zip payments.



924
925
926
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 924

def zip_payments
  @zip_payments
end