Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::JcbPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::JcbPayments
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Protections
Instance Attribute Summary collapse
-
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(protections: nil, requested: nil) ⇒ JcbPayments
constructor
A new instance of JcbPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(protections: nil, requested: nil) ⇒ JcbPayments
Returns a new instance of JcbPayments.
1305 1306 1307 1308 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1305 def initialize(protections: nil, requested: nil) @protections = protections @requested = requested end |
Instance Attribute Details
#protections ⇒ Object
Protection types to request for this capability (e.g. "psp_migration").
1301 1302 1303 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1301 def protections @protections end |
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
1303 1304 1305 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1303 def requested @requested end |