Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::JpBankTransferPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::JpBankTransferPayments
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
To request a new Capability for an account, pass true.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ JpBankTransferPayments
constructor
A new instance of JpBankTransferPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(requested: nil) ⇒ JpBankTransferPayments
Returns a new instance of JpBankTransferPayments.
383 384 385 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 383 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
381 382 383 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 381 def requested @requested end |