Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Capabilities::MobilepayPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(requested: nil) ⇒ MobilepayPayments

Returns a new instance of MobilepayPayments.



437
438
439
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 437

def initialize(requested: nil)
  @requested = requested
end

Instance Attribute Details

#requestedObject

To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.



435
436
437
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 435

def requested
  @requested
end