Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::StatementDescriptor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::StatementDescriptor
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan.
-
#prefix ⇒ Object
Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge.
Instance Method Summary collapse
-
#initialize(descriptor: nil, prefix: nil) ⇒ StatementDescriptor
constructor
A new instance of StatementDescriptor.
Methods inherited from RequestParams
Constructor Details
#initialize(descriptor: nil, prefix: nil) ⇒ StatementDescriptor
Returns a new instance of StatementDescriptor.
1131 1132 1133 1134 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1131 def initialize(descriptor: nil, prefix: nil) @descriptor = descriptor @prefix = prefix end |
Instance Attribute Details
#descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
1127 1128 1129 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1127 def descriptor @descriptor end |
#prefix ⇒ Object
Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge. To maximize space for the dynamic part of the descriptor, keep this text short. If you don’t specify this value, statement_descriptor is used as the prefix. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
1129 1130 1131 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1129 def prefix @prefix end |