Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support

Returns a new instance of Support.



931
932
933
934
935
936
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 931

def initialize(address: nil, email: nil, phone: nil, url: nil)
  @address = address
  @email = email
  @phone = phone
  @url = url
end

Instance Attribute Details

#addressObject

A publicly available mailing address for sending support issues to.



923
924
925
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 923

def address
  @address
end

#emailObject

A publicly available email address for sending support issues to.



925
926
927
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 925

def email
  @email
end

#phoneObject

A publicly available phone number to call with support issues.



927
928
929
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 927

def phone
  @phone
end

#urlObject

A publicly available website for handling support issues.



929
930
931
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 929

def url
  @url
end