Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support

Returns a new instance of Support.



938
939
940
941
942
943
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 938

def initialize(address: nil, email: nil, phone: nil, url: nil)
  @address = address
  @email = email
  @phone = phone
  @url = url
end

Instance Attribute Details

#addressObject

A publicly available mailing address for sending support issues to.



930
931
932
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 930

def address
  @address
end

#emailObject

A publicly available email address for sending support issues to.



932
933
934
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 932

def email
  @email
end

#phoneObject

A publicly available phone number to call with support issues.



934
935
936
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 934

def phone
  @phone
end

#urlObject

A publicly available website for handling support issues.



936
937
938
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 936

def url
  @url
end