Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
1181 1182 1183 1184 1185 1186 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1181 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
1173 1174 1175 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1173 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
1175 1176 1177 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1175 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
1177 1178 1179 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1177 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
1179 1180 1181 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1179 def url @url end |