Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
1075 1076 1077 1078 1079 1080 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1075 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
1067 1068 1069 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1067 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
1069 1070 1071 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1069 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
1071 1072 1073 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1071 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
1073 1074 1075 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1073 def url @url end |