Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
921 922 923 924 925 926 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 921 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
913 914 915 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 913 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
915 916 917 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 915 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
917 918 919 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 917 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
919 920 921 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 919 def url @url end |