Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
1058 1059 1060 1061 1062 1063 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1058 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
1050 1051 1052 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1050 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
1052 1053 1054 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1052 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
1054 1055 1056 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1054 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
1056 1057 1058 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1056 def url @url end |