Class: Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
852 853 854 855 856 857 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 852 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
844 845 846 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 844 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
846 847 848 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 846 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
848 849 850 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 848 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
850 851 852 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 850 def url @url end |