Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Capabilities, RegulatedActivity
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Capabilities to request on the Money Manager Configuration.
-
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
-
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
-
#money_services_description ⇒ Object
Description of the money services offered by the business.
-
#operates_in_prohibited_countries ⇒ Object
Indicates whether the business operates in any prohibited countries.
-
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
-
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
-
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
-
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
-
#source_of_funds ⇒ Object
The source of funds for the business, e.g.
-
#source_of_funds_description ⇒ Object
Description of the source of funds for the business' account.
Instance Method Summary collapse
-
#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ MoneyManager
constructor
A new instance of MoneyManager.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ MoneyManager
Returns a new instance of MoneyManager.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3448 def initialize( capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil ) @capabilities = capabilities @high_risk_activities = high_risk_activities @high_risk_activities_description = high_risk_activities_description @money_services_description = money_services_description @operates_in_prohibited_countries = operates_in_prohibited_countries @participates_in_regulated_activity = participates_in_regulated_activity @purpose_of_funds = purpose_of_funds @purpose_of_funds_description = purpose_of_funds_description @regulated_activity = regulated_activity @source_of_funds = source_of_funds @source_of_funds_description = source_of_funds_description end |
Instance Attribute Details
#capabilities ⇒ Object
Capabilities to request on the Money Manager Configuration.
3426 3427 3428 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3426 def capabilities @capabilities end |
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
3428 3429 3430 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3428 def high_risk_activities @high_risk_activities end |
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
3430 3431 3432 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3430 def high_risk_activities_description @high_risk_activities_description end |
#money_services_description ⇒ Object
Description of the money services offered by the business.
3432 3433 3434 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3432 def money_services_description @money_services_description end |
#operates_in_prohibited_countries ⇒ Object
Indicates whether the business operates in any prohibited countries.
3434 3435 3436 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3434 def operates_in_prohibited_countries @operates_in_prohibited_countries end |
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
3436 3437 3438 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3436 def participates_in_regulated_activity @participates_in_regulated_activity end |
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
3438 3439 3440 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3438 def purpose_of_funds @purpose_of_funds end |
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
3440 3441 3442 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3440 def purpose_of_funds_description @purpose_of_funds_description end |
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
3442 3443 3444 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3442 def regulated_activity @regulated_activity end |
#source_of_funds ⇒ Object
The source of funds for the business, e.g. profits, income, venture capital, etc.
3444 3445 3446 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3444 def source_of_funds @source_of_funds end |
#source_of_funds_description ⇒ Object
Description of the source of funds for the business' account.
3446 3447 3448 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3446 def source_of_funds_description @source_of_funds_description end |