Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BusinessStorage, InboundTransfers, OutboundPayments, OutboundTransfers, ReceivedCredits, ReceivedDebits
Instance Attribute Summary collapse
-
#business_storage ⇒ Object
Can send or receive business storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
-
#received_credits ⇒ Object
Can receive funds into a FinancialAccount.
-
#received_debits ⇒ Object
Can receive debits to a FinancialAccount.
Instance Method Summary collapse
-
#initialize(business_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1280 def initialize( business_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil ) @business_storage = business_storage @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers @received_credits = received_credits @received_debits = received_debits end |
Instance Attribute Details
#business_storage ⇒ Object
Can send or receive business storage-type funds on Stripe.
1268 1269 1270 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1268 def business_storage @business_storage end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1270 1271 1272 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1270 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1272 1273 1274 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1272 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1274 1275 1276 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1274 def outbound_transfers @outbound_transfers end |
#received_credits ⇒ Object
Can receive funds into a FinancialAccount.
1276 1277 1278 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1276 def received_credits @received_credits end |
#received_debits ⇒ Object
Can receive debits to a FinancialAccount.
1278 1279 1280 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1278 def received_debits @received_debits end |