Class: Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities::OutboundPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::MoneyManager::Capabilities::OutboundPayments
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, FinancialAccounts
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Can send funds from a FinancialAccount to a bank account owned by someone else.
-
#cards ⇒ Object
Can send funds from a FinancialAccount to a debit card owned by someone else.
-
#financial_accounts ⇒ Object
Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, financial_accounts: nil) ⇒ OutboundPayments
constructor
A new instance of OutboundPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, financial_accounts: nil) ⇒ OutboundPayments
Returns a new instance of OutboundPayments.
1198 1199 1200 1201 1202 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1198 def initialize(bank_accounts: nil, cards: nil, financial_accounts: nil) @bank_accounts = bank_accounts @cards = cards @financial_accounts = financial_accounts end |
Instance Attribute Details
#bank_accounts ⇒ Object
Can send funds from a FinancialAccount to a bank account owned by someone else.
1192 1193 1194 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1192 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Can send funds from a FinancialAccount to a debit card owned by someone else.
1194 1195 1196 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1194 def cards @cards end |
#financial_accounts ⇒ Object
Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
1196 1197 1198 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1196 def financial_accounts @financial_accounts end |