Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1367
1368
1369
1370
1371
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1367

def initialize(bank_accounts: nil, cards: nil, stripe_balance: nil)
  @bank_accounts = bank_accounts
  @cards = cards
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1361
1362
1363
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1361

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



1363
1364
1365
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1363

def cards
  @cards
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1365
1366
1367
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1365

def stripe_balance
  @stripe_balance
end