Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#paper_checks ⇒ Object
Capabilities that enable OutboundPayments via paper check.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1343 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @paper_checks = paper_checks @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1333 1334 1335 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1333 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
1335 1336 1337 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1335 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
1337 1338 1339 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1337 def crypto_wallets @crypto_wallets end |
#paper_checks ⇒ Object
Capabilities that enable OutboundPayments via paper check.
1339 1340 1341 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1339 def paper_checks @paper_checks end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1341 1342 1343 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1341 def stripe_balance @stripe_balance end |