Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1054
1055
1056
1057
1058
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1054

def initialize(bank_accounts: nil, cards: nil, stripe_balance: nil)
  @bank_accounts = bank_accounts
  @cards = cards
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1048
1049
1050
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1048

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



1050
1051
1052
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1050

def cards
  @cards
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1052
1053
1054
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1052

def stripe_balance
  @stripe_balance
end