Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#paper_checks ⇒ Object
Capabilities that enable OutboundPayments via paper check.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1331 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @paper_checks = paper_checks @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1321 1322 1323 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1321 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
1323 1324 1325 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1323 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
1325 1326 1327 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1325 def crypto_wallets @crypto_wallets end |
#paper_checks ⇒ Object
Capabilities that enable OutboundPayments via paper check.
1327 1328 1329 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1327 def paper_checks @paper_checks end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1329 1330 1331 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1329 def stripe_balance @stripe_balance end |