Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1320 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1312 1313 1314 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1312 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
1314 1315 1316 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1314 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
1316 1317 1318 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1316 def crypto_wallets @crypto_wallets end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1318 1319 1320 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1318 def stripe_balance @stripe_balance end |