Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1033
1034
1035
1036
1037
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1033

def initialize(bank_accounts: nil, cards: nil, stripe_balance: nil)
  @bank_accounts = bank_accounts
  @cards = cards
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1027
1028
1029
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1027

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



1029
1030
1031
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1029

def cards
  @cards
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1031
1032
1033
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1031

def stripe_balance
  @stripe_balance
end