Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1193

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1185
1186
1187
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1185

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



1187
1188
1189
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1187

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



1189
1190
1191
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1189

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1191
1192
1193
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1191

def stripe_balance
  @stripe_balance
end