Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1181 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1173 1174 1175 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1173 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capabilities that enable OutboundPayments to a card linked to this Account.
1175 1176 1177 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1175 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
1177 1178 1179 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1177 def crypto_wallets @crypto_wallets end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1179 1180 1181 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1179 def stripe_balance @stripe_balance end |