Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1084

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1076
1077
1078
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1076

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



1078
1079
1080
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1078

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



1080
1081
1082
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1080

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1082
1083
1084
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1082

def stripe_balance
  @stripe_balance
end