Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



967
968
969
970
971
972
973
974
975
976
977
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 967

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



959
960
961
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 959

def bank_accounts
  @bank_accounts
end

#cardsObject

Capabilities that enable OutboundPayments to a card linked to this Account.



961
962
963
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 961

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



963
964
965
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 963

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



965
966
967
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 965

def stripe_balance
  @stripe_balance
end