Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::BankAccounts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::BankAccounts
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
-
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
-
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
Instance Method Summary collapse
-
#initialize(instant: nil, local: nil, wire: nil) ⇒ BankAccounts
constructor
A new instance of BankAccounts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(instant: nil, local: nil, wire: nil) ⇒ BankAccounts
Returns a new instance of BankAccounts.
1282 1283 1284 1285 1286 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1282 def initialize(instant: nil, local: nil, wire: nil) @instant = instant @local = local @wire = wire end |
Instance Attribute Details
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
1276 1277 1278 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1276 def instant @instant end |
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
1278 1279 1280 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1278 def local @local end |
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
1280 1281 1282 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1280 def wire @wire end |