Class: Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::BankAccounts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Recipient::Capabilities::BankAccounts
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
-
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
-
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
Instance Method Summary collapse
-
#initialize(instant: nil, local: nil, wire: nil) ⇒ BankAccounts
constructor
A new instance of BankAccounts.
Methods inherited from RequestParams
Constructor Details
#initialize(instant: nil, local: nil, wire: nil) ⇒ BankAccounts
Returns a new instance of BankAccounts.
1270 1271 1272 1273 1274 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1270 def initialize(instant: nil, local: nil, wire: nil) @instant = instant @local = local @wire = wire end |
Instance Attribute Details
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
1264 1265 1266 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1264 def instant @instant end |
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
1266 1267 1268 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1266 def local @local end |
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
1268 1269 1270 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1268 def wire @wire end |