Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Capabilities, RegulatedActivity
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
-
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
-
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
-
#money_services_description ⇒ Object
Description of the money services offered by the business.
-
#operates_in_prohibited_countries ⇒ Object
Indicates whether the business operates in any prohibited countries.
-
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
-
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
-
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
-
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
-
#source_of_funds ⇒ Object
The source of funds for the business, e.g.
-
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer
Returns a new instance of Storer.
1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1665 def initialize( capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil ) @capabilities = capabilities @high_risk_activities = high_risk_activities @high_risk_activities_description = high_risk_activities_description @money_services_description = money_services_description @operates_in_prohibited_countries = operates_in_prohibited_countries @participates_in_regulated_activity = participates_in_regulated_activity @purpose_of_funds = purpose_of_funds @purpose_of_funds_description = purpose_of_funds_description @regulated_activity = regulated_activity @source_of_funds = source_of_funds @source_of_funds_description = source_of_funds_description end |
Instance Attribute Details
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1643 1644 1645 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1643 def capabilities @capabilities end |
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
1645 1646 1647 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1645 def high_risk_activities @high_risk_activities end |
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
1647 1648 1649 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1647 def high_risk_activities_description @high_risk_activities_description end |
#money_services_description ⇒ Object
Description of the money services offered by the business.
1649 1650 1651 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1649 def money_services_description @money_services_description end |
#operates_in_prohibited_countries ⇒ Object
Indicates whether the business operates in any prohibited countries.
1651 1652 1653 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1651 def operates_in_prohibited_countries @operates_in_prohibited_countries end |
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
1653 1654 1655 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1653 def participates_in_regulated_activity @participates_in_regulated_activity end |
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
1655 1656 1657 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1655 def purpose_of_funds @purpose_of_funds end |
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
1657 1658 1659 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1657 def purpose_of_funds_description @purpose_of_funds_description end |
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
1659 1660 1661 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1659 def regulated_activity @regulated_activity end |
#source_of_funds ⇒ Object
The source of funds for the business, e.g. profits, income, venture capital, etc.
1661 1662 1663 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1661 def source_of_funds @source_of_funds end |
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
1663 1664 1665 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1663 def source_of_funds_description @source_of_funds_description end |