Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1639

def initialize(
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1617
1618
1619
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1617

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1619
1620
1621
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1619

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

Description of the high-risk activities the business offers.



1621
1622
1623
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1621

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1623
1624
1625
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1623

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Indicates whether the business operates in any prohibited countries.



1625
1626
1627
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1625

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Indicates whether the business participates in any regulated activity.



1627
1628
1629
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1627

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1629
1630
1631
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1629

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1631
1632
1633
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1631

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1633
1634
1635
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1633

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1635
1636
1637
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1635

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1637
1638
1639
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1637

def source_of_funds_description
  @source_of_funds_description
end