Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Capabilities, RegulatedActivity
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
-
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
-
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
-
#money_services_description ⇒ Object
Description of the money services offered by the business.
-
#operates_in_prohibited_countries ⇒ Object
Indicates whether the business operates in any prohibited countries.
-
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
-
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
-
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
-
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
-
#source_of_funds ⇒ Object
The source of funds for the business, e.g.
-
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer
Returns a new instance of Storer.
1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1533 def initialize( capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil ) @capabilities = capabilities @high_risk_activities = high_risk_activities @high_risk_activities_description = high_risk_activities_description @money_services_description = money_services_description @operates_in_prohibited_countries = operates_in_prohibited_countries @participates_in_regulated_activity = participates_in_regulated_activity @purpose_of_funds = purpose_of_funds @purpose_of_funds_description = purpose_of_funds_description @regulated_activity = regulated_activity @source_of_funds = source_of_funds @source_of_funds_description = source_of_funds_description end |
Instance Attribute Details
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1511 1512 1513 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1511 def capabilities @capabilities end |
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
1513 1514 1515 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1513 def high_risk_activities @high_risk_activities end |
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
1515 1516 1517 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1515 def high_risk_activities_description @high_risk_activities_description end |
#money_services_description ⇒ Object
Description of the money services offered by the business.
1517 1518 1519 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1517 def money_services_description @money_services_description end |
#operates_in_prohibited_countries ⇒ Object
Indicates whether the business operates in any prohibited countries.
1519 1520 1521 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1519 def operates_in_prohibited_countries @operates_in_prohibited_countries end |
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
1521 1522 1523 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1521 def participates_in_regulated_activity @participates_in_regulated_activity end |
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
1523 1524 1525 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1523 def purpose_of_funds @purpose_of_funds end |
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
1525 1526 1527 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1525 def purpose_of_funds_description @purpose_of_funds_description end |
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
1527 1528 1529 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1527 def regulated_activity @regulated_activity end |
#source_of_funds ⇒ Object
The source of funds for the business, e.g. profits, income, venture capital, etc.
1529 1530 1531 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1529 def source_of_funds @source_of_funds end |
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
1531 1532 1533 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1531 def source_of_funds_description @source_of_funds_description end |