Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1483

def initialize(
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1461
1462
1463
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1461

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1463
1464
1465
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1463

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

Description of the high-risk activities the business offers.



1465
1466
1467
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1465

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1467
1468
1469
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1467

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Indicates whether the business operates in any prohibited countries.



1469
1470
1471
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1469

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Indicates whether the business participates in any regulated activity.



1471
1472
1473
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1471

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1473
1474
1475
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1473

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1475
1476
1477
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1475

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1477
1478
1479
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1477

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1479
1480
1481
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1479

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1481
1482
1483
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1481

def source_of_funds_description
  @source_of_funds_description
end