Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Capabilities, RegulatedActivity
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
-
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
-
#high_risk_activities_description ⇒ Object
An explanation of the high risk activities that the business performs.
-
#money_services_description ⇒ Object
Description of the money services offered by the business.
-
#operates_in_prohibited_countries ⇒ Object
Does the business operate in any prohibited countries.
-
#participates_in_regulated_activity ⇒ Object
Does the business participate in any regulated activity.
-
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
-
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
-
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
-
#source_of_funds ⇒ Object
The source of funds for the business, e.g.
-
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer
Returns a new instance of Storer.
1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1471 def initialize( capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil ) @capabilities = capabilities @high_risk_activities = high_risk_activities @high_risk_activities_description = high_risk_activities_description @money_services_description = money_services_description @operates_in_prohibited_countries = operates_in_prohibited_countries @participates_in_regulated_activity = participates_in_regulated_activity @purpose_of_funds = purpose_of_funds @purpose_of_funds_description = purpose_of_funds_description @regulated_activity = regulated_activity @source_of_funds = source_of_funds @source_of_funds_description = source_of_funds_description end |
Instance Attribute Details
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1449 1450 1451 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1449 def capabilities @capabilities end |
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
1451 1452 1453 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1451 def high_risk_activities @high_risk_activities end |
#high_risk_activities_description ⇒ Object
An explanation of the high risk activities that the business performs.
1453 1454 1455 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1453 def high_risk_activities_description @high_risk_activities_description end |
#money_services_description ⇒ Object
Description of the money services offered by the business.
1455 1456 1457 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1455 def money_services_description @money_services_description end |
#operates_in_prohibited_countries ⇒ Object
Does the business operate in any prohibited countries.
1457 1458 1459 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1457 def operates_in_prohibited_countries @operates_in_prohibited_countries end |
#participates_in_regulated_activity ⇒ Object
Does the business participate in any regulated activity.
1459 1460 1461 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1459 def participates_in_regulated_activity @participates_in_regulated_activity end |
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
1461 1462 1463 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1461 def purpose_of_funds @purpose_of_funds end |
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
1463 1464 1465 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1463 def purpose_of_funds_description @purpose_of_funds_description end |
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
1465 1466 1467 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1465 def regulated_activity @regulated_activity end |
#source_of_funds ⇒ Object
The source of funds for the business, e.g. profits, income, venture capital, etc.
1467 1468 1469 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1467 def source_of_funds @source_of_funds end |
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
1469 1470 1471 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1469 def source_of_funds_description @source_of_funds_description end |