Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1382

def initialize(
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1360
1361
1362
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1360

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1362
1363
1364
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1362

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

An explanation of the high risk activities that the business performs.



1364
1365
1366
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1364

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1366
1367
1368
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1366

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Does the business operate in any prohibited countries.



1368
1369
1370
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1368

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Does the business participate in any regulated activity.



1370
1371
1372
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1370

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1372
1373
1374
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1372

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1374
1375
1376
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1374

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1376
1377
1378
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1376

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1378
1379
1380
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1378

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1380
1381
1382
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1380

def source_of_funds_description
  @source_of_funds_description
end