Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Consumer, FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#consumer ⇒ Object
Can provision a consumer financial account on Stripe.
-
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
Instance Method Summary collapse
-
#initialize(consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1577 def initialize( consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil ) @consumer = consumer @financial_addresses = financial_addresses @holds_currencies = holds_currencies @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#consumer ⇒ Object
Can provision a consumer financial account on Stripe.
1565 1566 1567 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1565 def consumer @consumer end |
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
1567 1568 1569 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1567 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
1569 1570 1571 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1569 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1571 1572 1573 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1571 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1573 1574 1575 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1573 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1575 1576 1577 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1575 def outbound_transfers @outbound_transfers end |