Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Consumer, FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#consumer ⇒ Object
Can provision a consumer financial account on Stripe.
-
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
Instance Method Summary collapse
-
#initialize(consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1471 def initialize( consumer: nil, financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil ) @consumer = consumer @financial_addresses = financial_addresses @holds_currencies = holds_currencies @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#consumer ⇒ Object
Can provision a consumer financial account on Stripe.
1459 1460 1461 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1459 def consumer @consumer end |
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
1461 1462 1463 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1461 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
1463 1464 1465 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1463 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1465 1466 1467 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1465 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1467 1468 1469 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1467 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1469 1470 1471 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1469 def outbound_transfers @outbound_transfers end |