Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
Instance Method Summary collapse
-
#initialize(financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1204 def initialize( financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil ) @financial_addresses = financial_addresses @holds_currencies = holds_currencies @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
1194 1195 1196 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1194 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
1196 1197 1198 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1196 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1198 1199 1200 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1198 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1200 1201 1202 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1200 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1202 1203 1204 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1202 def outbound_transfers @outbound_transfers end |