Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: FinancialAddresses, HoldsCurrencies, InboundTransfers, OutboundPayments, OutboundTransfers
Instance Attribute Summary collapse
-
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
-
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
Instance Method Summary collapse
-
#initialize(financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1411 def initialize( financial_addresses: nil, holds_currencies: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil ) @financial_addresses = financial_addresses @holds_currencies = holds_currencies @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers end |
Instance Attribute Details
#financial_addresses ⇒ Object
Can provision a financial address to credit/debit a FinancialAccount.
1401 1402 1403 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1401 def financial_addresses @financial_addresses end |
#holds_currencies ⇒ Object
Can hold storage-type funds on Stripe.
1403 1404 1405 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1403 def holds_currencies @holds_currencies end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1405 1406 1407 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1405 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1407 1408 1409 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1407 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1409 1410 1411 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1409 def outbound_transfers @outbound_transfers end |