Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1498

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



1490
1491
1492
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1490

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business’s primary regulator.



1492
1493
1494
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1492

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business’s regulated activities.



1494
1495
1496
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1494

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business’s regulated activities.



1496
1497
1498
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1496

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end