Class: Stripe::V2::Core::AccountCreateParams::Configuration::Storer::RegulatedActivity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Configuration::Storer::RegulatedActivity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
-
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
-
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
-
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
Instance Method Summary collapse
-
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
constructor
A new instance of RegulatedActivity.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
Returns a new instance of RegulatedActivity.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1327 def initialize( description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil ) @description = description @license_number = license_number @primary_regulatory_authority_country = @primary_regulatory_authority_name = end |
Instance Attribute Details
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
1319 1320 1321 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1319 def description @description end |
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
1321 1322 1323 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1321 def license_number @license_number end |
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
1323 1324 1325 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1323 def @primary_regulatory_authority_country end |
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
1325 1326 1327 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1325 def @primary_regulatory_authority_name end |