Class: Stripe::V2::Core::AccountCreateParams::Defaults::Profile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Defaults::Profile
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#business_url ⇒ Object
The business’s publicly-available website.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
Instance Method Summary collapse
-
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
constructor
A new instance of Profile.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
Returns a new instance of Profile.
1738 1739 1740 1741 1742 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1738 def initialize(business_url: nil, doing_business_as: nil, product_description: nil) @business_url = business_url @doing_business_as = doing_business_as @product_description = product_description end |
Instance Attribute Details
#business_url ⇒ Object
The business’s publicly-available website.
1732 1733 1734 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1732 def business_url @business_url end |
#doing_business_as ⇒ Object
The name which is used by the business.
1734 1735 1736 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1734 def doing_business_as @doing_business_as end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
1736 1737 1738 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1736 def product_description @product_description end |