Class: Stripe::V2::Core::AccountCreateParams::Defaults::Profile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Defaults::Profile
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#business_url ⇒ Object
The business’s publicly-available website.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
Instance Method Summary collapse
-
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
constructor
A new instance of Profile.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
Returns a new instance of Profile.
1272 1273 1274 1275 1276 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1272 def initialize(business_url: nil, doing_business_as: nil, product_description: nil) @business_url = business_url @doing_business_as = doing_business_as @product_description = product_description end |
Instance Attribute Details
#business_url ⇒ Object
The business’s publicly-available website.
1266 1267 1268 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1266 def business_url @business_url end |
#doing_business_as ⇒ Object
The name which is used by the business.
1268 1269 1270 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1268 def doing_business_as @doing_business_as end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
1270 1271 1272 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1270 def product_description @product_description end |