Class: Stripe::V2::Core::AccountCreateParams::Defaults::Profile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile

Returns a new instance of Profile.



1594
1595
1596
1597
1598
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1594

def initialize(business_url: nil, doing_business_as: nil, product_description: nil)
  @business_url = business_url
  @doing_business_as = doing_business_as
  @product_description = product_description
end

Instance Attribute Details

#business_urlObject

The business’s publicly-available website.



1588
1589
1590
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1588

def business_url
  @business_url
end

#doing_business_asObject

The name which is used by the business.



1590
1591
1592
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1590

def doing_business_as
  @doing_business_as
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1592
1593
1594
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1592

def product_description
  @product_description
end