Class: Stripe::V2::Core::AccountCreateParams::Defaults::Profile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile

Returns a new instance of Profile.



1544
1545
1546
1547
1548
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1544

def initialize(business_url: nil, doing_business_as: nil, product_description: nil)
  @business_url = business_url
  @doing_business_as = doing_business_as
  @product_description = product_description
end

Instance Attribute Details

#business_urlObject

The business’s publicly-available website.



1538
1539
1540
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1538

def business_url
  @business_url
end

#doing_business_asObject

The name which is used by the business.



1540
1541
1542
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1540

def doing_business_as
  @doing_business_as
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1542
1543
1544
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1542

def product_description
  @product_description
end