Class: Stripe::V2::Core::AccountCreateParams::Defaults::Profile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Defaults::Profile
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#business_url ⇒ Object
The business’s publicly-available website.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
Instance Method Summary collapse
-
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
constructor
A new instance of Profile.
Methods inherited from RequestParams
Constructor Details
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
Returns a new instance of Profile.
1423 1424 1425 1426 1427 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1423 def initialize(business_url: nil, doing_business_as: nil, product_description: nil) @business_url = business_url @doing_business_as = doing_business_as @product_description = product_description end |
Instance Attribute Details
#business_url ⇒ Object
The business’s publicly-available website.
1417 1418 1419 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1417 def business_url @business_url end |
#doing_business_as ⇒ Object
The name which is used by the business.
1419 1420 1421 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1419 def doing_business_as @doing_business_as end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
1421 1422 1423 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1421 def product_description @product_description end |