Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2144

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity's key people, e.g. owners, executives, directors, representatives.



2134
2135
2136
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2134

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



2136
2137
2138
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2136

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code.



2138
2139
2140
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2138

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



2140
2141
2142
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2140

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



2142
2143
2144
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2142

def individual
  @individual
end

Class Method Details

.field_encodingsObject



2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2158

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end