Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2499

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



2489
2490
2491
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2489

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



2491
2492
2493
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2491

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



2493
2494
2495
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2493

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



2495
2496
2497
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2495

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



2497
2498
2499
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2497

def individual
  @individual
end

Class Method Details

.field_encodingsObject



2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2513

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end