Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3766

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



3756
3757
3758
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3756

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



3758
3759
3760
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3758

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



3760
3761
3762
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3760

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



3762
3763
3764
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3762

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



3764
3765
3766
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3764

def individual
  @individual
end

Class Method Details

.field_encodingsObject



3780
3781
3782
3783
3784
3785
3786
3787
3788
3789
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3780

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end