Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2365

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



2355
2356
2357
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2355

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



2357
2358
2359
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2357

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



2359
2360
2361
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2359

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



2361
2362
2363
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2361

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



2363
2364
2365
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2363

def individual
  @individual
end

Class Method Details

.field_encodingsObject



2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2379

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end