Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2088

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



2078
2079
2080
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2078

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



2080
2081
2082
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2080

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



2082
2083
2084
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2082

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



2084
2085
2086
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2084

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



2086
2087
2088
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2086

def individual
  @individual
end

Class Method Details

.field_encodingsObject



2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2102

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end