Class: Stripe::V2::Core::AccountCreateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



3670
3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3670

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



3660
3661
3662
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3660

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



3662
3663
3664
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3662

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



3664
3665
3666
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3664

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



3666
3667
3668
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3666

def entity_type
  @entity_type
end

#individualObject

Information about the person represented by the account.



3668
3669
3670
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3668

def individual
  @individual
end

Class Method Details

.field_encodingsObject



3684
3685
3686
3687
3688
3689
3690
3691
3692
3693
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3684

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end