Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2343 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
2333 2334 2335 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2333 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2335 2336 2337 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2335 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2337 2338 2339 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2337 def country @country end |
#entity_type ⇒ Object
The entity type.
2339 2340 2341 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2339 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
2341 2342 2343 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2341 def individual @individual end |
Class Method Details
.field_encodings ⇒ Object
2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2357 def self.field_encodings @field_encodings = { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, } end |