Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3644 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3634 3635 3636 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3634 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
3636 3637 3638 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3636 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3638 3639 3640 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3638 def country @country end |
#entity_type ⇒ Object
The entity type.
3640 3641 3642 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3640 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
3642 3643 3644 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3642 def individual @individual end |
Class Method Details
.field_encodings ⇒ Object
3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3658 def self.field_encodings @field_encodings = { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, } end |