Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 3616 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3604 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3594 3595 3596 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3594 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
3596 3597 3598 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3596 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3598 3599 3600 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3598 def country @country end |
#entity_type ⇒ Object
The entity type.
3600 3601 3602 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3600 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
3602 3603 3604 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3602 def individual @individual end |