Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3082 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3072 3073 3074 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3072 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
3074 3075 3076 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3074 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3076 3077 3078 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3076 def country @country end |
#entity_type ⇒ Object
The entity type.
3078 3079 3080 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3078 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
3080 3081 3082 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3080 def individual @individual end |