Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3013 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3003 3004 3005 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3003 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
3005 3006 3007 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3005 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3007 3008 3009 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3007 def country @country end |
#entity_type ⇒ Object
The entity type.
3009 3010 3011 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3009 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
3011 3012 3013 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3011 def individual @individual end |