Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2776 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
2766 2767 2768 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2766 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2768 2769 2770 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2768 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2770 2771 2772 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2770 def country @country end |
#entity_type ⇒ Object
The entity type.
2772 2773 2774 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2772 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
2774 2775 2776 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2774 def individual @individual end |