Class: Stripe::V2::Core::AccountCreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2605 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors.
2595 2596 2597 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2595 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2597 2598 2599 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2597 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2599 2600 2601 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2599 def country @country end |
#entity_type ⇒ Object
The entity type.
2601 2602 2603 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2601 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
2603 2604 2605 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2603 def individual @individual end |