Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1571 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @representative_declaration = representative_declaration @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1561 1562 1563 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1561 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1563 1564 1565 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1563 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
1565 1566 1567 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1565 def persons_provided @persons_provided end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
1567 1568 1569 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1567 def representative_declaration @representative_declaration end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
1569 1570 1571 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1569 def terms_of_service @terms_of_service end |