Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2160

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  representative_declaration: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @representative_declaration = representative_declaration
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



2150
2151
2152
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2150

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



2152
2153
2154
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2152

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



2154
2155
2156
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2154

def persons_provided
  @persons_provided
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



2156
2157
2158
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2156

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



2158
2159
2160
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2158

def terms_of_service
  @terms_of_service
end