Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2682 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @representative_declaration = representative_declaration @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
2672 2673 2674 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2672 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
2674 2675 2676 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2674 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
2676 2677 2678 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2676 def persons_provided @persons_provided end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
2678 2679 2680 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2678 def representative_declaration @representative_declaration end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
2680 2681 2682 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2680 def terms_of_service @terms_of_service end |