Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2009

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  representative_declaration: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @representative_declaration = representative_declaration
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1999
2000
2001
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1999

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



2001
2002
2003
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2001

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



2003
2004
2005
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2003

def persons_provided
  @persons_provided
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



2005
2006
2007
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2005

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



2007
2008
2009
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2007

def terms_of_service
  @terms_of_service
end