Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1730 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1722 1723 1724 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1722 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1724 1725 1726 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1724 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
1726 1727 1728 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1726 def persons_provided @persons_provided end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
1728 1729 1730 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1728 def terms_of_service @terms_of_service end |