Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the director attestation was made.
-
#ip ⇒ Object
The IP address from which the director attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the director attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1326 1327 1328 1329 1330 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1326 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1320 1321 1322 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1320 def date @date end |
#ip ⇒ Object
The IP address from which the director attestation was made.
1322 1323 1324 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1322 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the director attestation was made.
1324 1325 1326 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1324 def user_agent @user_agent end |