Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1296
1297
1298
1299
1300
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1296

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1290
1291
1292
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1290

def date
  @date
end

#ipObject

The IP address from which the director attestation was made.



1292
1293
1294
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1292

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the director attestation was made.



1294
1295
1296
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1294

def user_agent
  @user_agent
end