Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1589
1590
1591
1592
1593
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1589

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1583
1584
1585
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1583

def date
  @date
end

#ipObject

The IP address from which the director attestation was made.



1585
1586
1587
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1585

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the director attestation was made.



1587
1588
1589
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1587

def user_agent
  @user_agent
end