Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the director attestation was made.
-
#ip ⇒ Object
The IP address from which the director attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the director attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1488 1489 1490 1491 1492 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1488 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1482 1483 1484 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1482 def date @date end |
#ip ⇒ Object
The IP address from which the director attestation was made.
1484 1485 1486 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1484 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the director attestation was made.
1486 1487 1488 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1486 def user_agent @user_agent end |