Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1341
1342
1343
1344
1345
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1341

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1335
1336
1337
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1335

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1337
1338
1339
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1337

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1339
1340
1341
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1339

def user_agent
  @user_agent
end