Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1654
1655
1656
1657
1658
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1654

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1648
1649
1650
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1648

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1650
1651
1652
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1650

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1652
1653
1654
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1652

def user_agent
  @user_agent
end