Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1365
1366
1367
1368
1369
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1365

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1359
1360
1361
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1359

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1361
1362
1363
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1361

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1363
1364
1365
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1363

def user_agent
  @user_agent
end