Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1353
1354
1355
1356
1357
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1353

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1347
1348
1349
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1347

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1349
1350
1351
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1349

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1351
1352
1353
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1351

def user_agent
  @user_agent
end