Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1358

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1350
1351
1352
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1350

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1352
1353
1354
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1352

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1354
1355
1356
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1354

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



1356
1357
1358
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1356

def ownership_exemption_reason
  @ownership_exemption_reason
end