Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1812

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1804
1805
1806
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1804

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1806
1807
1808
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1806

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1808
1809
1810
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1808

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



1810
1811
1812
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1810

def ownership_exemption_reason
  @ownership_exemption_reason
end