Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1621

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1613
1614
1615
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1613

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1615
1616
1617
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1615

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1617
1618
1619
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1617

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



1619
1620
1621
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1619

def ownership_exemption_reason
  @ownership_exemption_reason
end