Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1500

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1492
1493
1494
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1492

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1494
1495
1496
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1494

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1496
1497
1498
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1496

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



1498
1499
1500
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1498

def ownership_exemption_reason
  @ownership_exemption_reason
end