Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1692
1693
1694
1695
1696
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1692

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1686
1687
1688
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1686

def date
  @date
end

#ipObject

The IP address from which the representative attestation was made.



1688
1689
1690
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1688

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative attestation was made.



1690
1691
1692
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1690

def user_agent
  @user_agent
end