Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1642
1643
1644
1645
1646
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1642

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1636
1637
1638
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1636

def date
  @date
end

#ipObject

The IP address from which the representative attestation was made.



1638
1639
1640
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1638

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative attestation was made.



1640
1641
1642
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1640

def user_agent
  @user_agent
end