Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::RepresentativeDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Attestations::RepresentativeDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the representative attestation was made.
-
#ip ⇒ Object
The IP address from which the representative attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the representative attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
constructor
A new instance of RepresentativeDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
Returns a new instance of RepresentativeDeclaration.
1541 1542 1543 1544 1545 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1541 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1535 1536 1537 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1535 def date @date end |
#ip ⇒ Object
The IP address from which the representative attestation was made.
1537 1538 1539 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1537 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the representative attestation was made.
1539 1540 1541 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1539 def user_agent @user_agent end |