Class: Stripe::V2::Core::AccountCreateParams::Identity::Attestations::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1403
1404
1405
1406
1407
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1403

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1397
1398
1399
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1397

def date
  @date
end

#ipObject

The IP address from which the representative attestation was made.



1399
1400
1401
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1399

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative attestation was made.



1401
1402
1403
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1401

def user_agent
  @user_agent
end