Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business's compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
5662 5663 5664 5665 5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5662 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
5634 5635 5636 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5634 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
5636 5637 5638 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5636 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
5638 5639 5640 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5638 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business's compliance and anti-money laundering controls and practices.
5640 5641 5642 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5640 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
5642 5643 5644 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5642 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
5644 5645 5646 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5644 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
5646 5647 5648 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5646 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
5648 5649 5650 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5648 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
5650 5651 5652 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5650 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
5652 5653 5654 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5652 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
5654 5655 5656 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5654 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
5656 5657 5658 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5656 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
5658 5659 5660 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5658 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
5660 5661 5662 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5660 def structure @structure end |