Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1649 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
1623 1624 1625 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1623 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
1625 1626 1627 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1625 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1627 1628 1629 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1627 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1629 1630 1631 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1629 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1631 1632 1633 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1631 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1633 1634 1635 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1633 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1635 1636 1637 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1635 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1637 1638 1639 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1637 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1639 1640 1641 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1639 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1641 1642 1643 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1641 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1643 1644 1645 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1643 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1645 1646 1647 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1645 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1647 1648 1649 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1647 def structure @structure end |