Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2047 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
2021 2022 2023 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2021 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
2023 2024 2025 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2023 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
2025 2026 2027 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2025 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
2027 2028 2029 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2027 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
2029 2030 2031 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2029 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
2031 2032 2033 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2031 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
2033 2034 2035 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2033 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
2035 2036 2037 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2035 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
2037 2038 2039 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2037 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
2039 2040 2041 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2039 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
2041 2042 2043 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2041 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
2043 2044 2045 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2043 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
2045 2046 2047 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2045 def structure @structure end |