Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2006 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
1982 1983 1984 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1982 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1984 1985 1986 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1984 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1986 1987 1988 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1986 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1988 1989 1990 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1988 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1990 1991 1992 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1990 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1992 1993 1994 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1992 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1994 1995 1996 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1994 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1996 1997 1998 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1996 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1998 1999 2000 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1998 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
2000 2001 2002 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2000 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
2002 2003 2004 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2002 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
2004 2005 2006 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2004 def structure @structure end |