Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
3300
3301
3302
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3274

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3248
3249
3250
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3248

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3250
3251
3252
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3250

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



3252
3253
3254
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3252

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



3254
3255
3256
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3254

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3256
3257
3258
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3256

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3258
3259
3260
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3258

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3260
3261
3262
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3260

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3262
3263
3264
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3262

def phone
  @phone
end

#registered_nameObject

The business legal name.



3264
3265
3266
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3264

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



3266
3267
3268
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3266

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3268
3269
3270
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3268

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3270
3271
3272
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3270

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3272
3273
3274
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3272

def structure
  @structure
end