Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
3276
3277
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3249

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3223
3224
3225
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3223

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3225
3226
3227
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3225

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



3227
3228
3229
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3227

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



3229
3230
3231
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3229

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3231
3232
3233
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3231

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3233
3234
3235
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3233

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3235
3236
3237
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3235

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3237
3238
3239
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3237

def phone
  @phone
end

#registered_nameObject

The business legal name.



3239
3240
3241
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3239

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



3241
3242
3243
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3241

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3243
3244
3245
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3243

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3245
3246
3247
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3245

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3247
3248
3249
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3247

def structure
  @structure
end