Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3175 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
3149 3150 3151 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3149 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
3151 3152 3153 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3151 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
3153 3154 3155 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3153 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
3155 3156 3157 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3155 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
3157 3158 3159 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3157 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
3159 3160 3161 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3159 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
3161 3162 3163 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3161 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
3163 3164 3165 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3163 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
3165 3166 3167 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3165 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
3167 3168 3169 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3167 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
3169 3170 3171 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3169 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
3171 3172 3173 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3171 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
3173 3174 3175 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3173 def structure @structure end |