Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1850

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



1826
1827
1828
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1826

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



1828
1829
1830
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1828

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



1830
1831
1832
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1830

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



1832
1833
1834
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1832

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



1834
1835
1836
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1834

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



1836
1837
1838
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1836

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



1838
1839
1840
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1838

def phone
  @phone
end

#registered_nameObject

The business legal name.



1840
1841
1842
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1840

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



1842
1843
1844
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1842

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



1844
1845
1846
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1844

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



1846
1847
1848
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1846

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



1848
1849
1850
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1848

def structure
  @structure
end