Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1573 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
1549 1550 1551 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1549 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1551 1552 1553 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1551 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1553 1554 1555 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1553 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1555 1556 1557 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1555 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1557 1558 1559 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1557 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1559 1560 1561 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1559 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1561 1562 1563 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1561 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1563 1564 1565 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1563 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1565 1566 1567 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1565 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1567 1568 1569 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1567 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1569 1570 1571 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1569 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1571 1572 1573 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1571 def structure @structure end |