Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2597 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
2571 2572 2573 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2571 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
2573 2574 2575 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2573 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
2575 2576 2577 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2575 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
2577 2578 2579 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2577 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
2579 2580 2581 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2579 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
2581 2582 2583 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2581 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
2583 2584 2585 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2583 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
2585 2586 2587 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2585 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
2587 2588 2589 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2587 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
2589 2590 2591 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2589 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
2591 2592 2593 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2591 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
2593 2594 2595 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2593 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
2595 2596 2597 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2595 def structure @structure end |