Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3119
3120
3121
3122
3123
3124
3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
3137
3138
3139
3140
3141
3142
3143
3144
3145
3146
3147
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3119

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3093
3094
3095
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3093

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3095
3096
3097
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3095

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



3097
3098
3099
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3097

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



3099
3100
3101
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3099

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3101
3102
3103
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3101

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3103
3104
3105
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3103

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3105
3106
3107
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3105

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3107
3108
3109
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3107

def phone
  @phone
end

#registered_nameObject

The business legal name.



3109
3110
3111
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3109

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



3111
3112
3113
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3111

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3113
3114
3115
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3113

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3115
3116
3117
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3115

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3117
3118
3119
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3117

def structure
  @structure
end