Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2547

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2521
2522
2523
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2521

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2523
2524
2525
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2523

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2525
2526
2527
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2525

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2527
2528
2529
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2527

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



2529
2530
2531
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2529

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2531
2532
2533
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2531

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2533
2534
2535
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2533

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2535
2536
2537
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2535

def phone
  @phone
end

#registered_nameObject

The business legal name.



2537
2538
2539
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2537

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



2539
2540
2541
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2539

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2541
2542
2543
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2541

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2543
2544
2545
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2543

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2545
2546
2547
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2545

def structure
  @structure
end