Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2518

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2494
2495
2496
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2494

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2496
2497
2498
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2496

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2498
2499
2500
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2498

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2500
2501
2502
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2500

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2502
2503
2504
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2502

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2504
2505
2506
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2504

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2506
2507
2508
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2506

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2508
2509
2510
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2508

def phone
  @phone
end

#registered_nameObject

The business legal name.



2510
2511
2512
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2510

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2512
2513
2514
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2512

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2514
2515
2516
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2514

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2516
2517
2518
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2516

def structure
  @structure
end