Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2293

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2269
2270
2271
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2269

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2271
2272
2273
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2271

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2273
2274
2275
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2273

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2275
2276
2277
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2275

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2277
2278
2279
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2277

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2279
2280
2281
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2279

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2281
2282
2283
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2281

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2283
2284
2285
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2283

def phone
  @phone
end

#registered_nameObject

The business legal name.



2285
2286
2287
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2285

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2287
2288
2289
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2287

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2289
2290
2291
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2289

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2291
2292
2293
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2291

def structure
  @structure
end