Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2407

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2383
2384
2385
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2383

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2385
2386
2387
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2385

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2387
2388
2389
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2387

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2389
2390
2391
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2389

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2391
2392
2393
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2391

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2393
2394
2395
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2393

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2395
2396
2397
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2395

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2397
2398
2399
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2397

def phone
  @phone
end

#registered_nameObject

The business legal name.



2399
2400
2401
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2399

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2401
2402
2403
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2401

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2403
2404
2405
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2403

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2405
2406
2407
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2405

def structure
  @structure
end