Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2124

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2102
2103
2104
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2102

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2104
2105
2106
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2104

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



2106
2107
2108
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2106

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2108
2109
2110
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2108

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2110
2111
2112
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2110

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2112
2113
2114
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2112

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2114
2115
2116
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2114

def phone
  @phone
end

#registered_nameObject

The business legal name.



2116
2117
2118
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2116

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2118
2119
2120
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2118

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2120
2121
2122
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2120

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2122
2123
2124
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2122

def structure
  @structure
end