Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::AnnualRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::AnnualRevenue
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
-
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
constructor
A new instance of AnnualRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
Returns a new instance of AnnualRevenue.
2066 2067 2068 2069 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2066 def initialize(amount: nil, fiscal_year_end: nil) @amount = amount @fiscal_year_end = fiscal_year_end end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
2062 2063 2064 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2062 def amount @amount end |
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
2064 2065 2066 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2064 def fiscal_year_end @fiscal_year_end end |