Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::AnnualRevenue

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue

Returns a new instance of AnnualRevenue.



1785
1786
1787
1788
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1785

def initialize(amount: nil, fiscal_year_end: nil)
  @amount = amount
  @fiscal_year_end = fiscal_year_end
end

Instance Attribute Details

#amountObject

A non-negative integer representing the amount in the smallest currency unit.



1781
1782
1783
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1781

def amount
  @amount
end

#fiscal_year_endObject

The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.



1783
1784
1785
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1783

def fiscal_year_end
  @fiscal_year_end
end