Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1397

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  primary_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @primary_verification = primary_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



1377
1378
1379
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1377

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



1379
1380
1381
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1379

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



1381
1382
1383
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1381

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



1383
1384
1385
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1383

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



1385
1386
1387
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1385

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



1387
1388
1389
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1387

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject

A document verifying the business.



1389
1390
1391
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1389

def primary_verification
  @primary_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



1391
1392
1393
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1391

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



1393
1394
1395
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1393

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



1395
1396
1397
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1395

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end