Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1652

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  primary_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @primary_verification = primary_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



1632
1633
1634
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1632

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



1634
1635
1636
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1634

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



1636
1637
1638
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1636

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



1638
1639
1640
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1638

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



1640
1641
1642
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1640

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



1642
1643
1644
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1642

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject

A document verifying the business.



1644
1645
1646
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1644

def primary_verification
  @primary_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



1646
1647
1648
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1646

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



1648
1649
1650
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1648

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



1650
1651
1652
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 1650

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end