Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2975

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  primary_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @primary_verification = primary_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



2955
2956
2957
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2955

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



2957
2958
2959
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2957

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



2959
2960
2961
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2959

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



2961
2962
2963
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2961

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



2963
2964
2965
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2963

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



2965
2966
2967
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2965

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject

A document verifying the business.



2967
2968
2969
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2967

def primary_verification
  @primary_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



2969
2970
2971
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2969

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



2971
2972
2973
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2971

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



2973
2974
2975
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2973

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end