Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
A document verifying the business.
-
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
Returns a new instance of Documents.
2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2336 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @primary_verification = primary_verification @proof_of_address = proof_of_address @proof_of_registration = proof_of_registration @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
2316 2317 2318 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2316 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
2318 2319 2320 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2318 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
2320 2321 2322 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2320 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
2322 2323 2324 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2322 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
2324 2325 2326 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2324 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
2326 2327 2328 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2326 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object
A document verifying the business.
2328 2329 2330 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2328 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
2330 2331 2332 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2330 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
2332 2333 2334 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2332 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
2334 2335 2336 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2334 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |