Class: Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::BusinessDetails::MonthlyEstimatedRevenue
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: Amount
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ MonthlyEstimatedRevenue
constructor
A new instance of MonthlyEstimatedRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ MonthlyEstimatedRevenue
Returns a new instance of MonthlyEstimatedRevenue.
2379 2380 2381 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2379 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
2377 2378 2379 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2377 def amount @amount end |