Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person's passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person's name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person's visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5896 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
5886 5887 5888 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5886 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person's passport page with photo and personal data.
5888 5889 5890 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5888 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person's name, either a passport or local ID card.
5890 5891 5892 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5890 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
5892 5893 5894 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5892 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person's visa required for living in the country where they are residing.
5894 5895 5896 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 5894 def visa @visa end |