Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3481

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



3471
3472
3473
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3471

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



3473
3474
3475
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3473

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



3475
3476
3477
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3475

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



3477
3478
3479
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3477

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



3479
3480
3481
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3479

def visa
  @visa
end