Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3381 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
3371 3372 3373 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3371 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
3373 3374 3375 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3373 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
3375 3376 3377 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3375 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
3377 3378 3379 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3377 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
3379 3380 3381 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3379 def visa @visa end |