Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2072

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



2062
2063
2064
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2062

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



2064
2065
2066
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2064

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



2066
2067
2068
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2066

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



2068
2069
2070
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2068

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



2070
2071
2072
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2070

def visa
  @visa
end