Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2637 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
2627 2628 2629 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2627 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
2629 2630 2631 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2629 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
2631 2632 2633 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2631 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
2633 2634 2635 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2633 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
2635 2636 2637 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2635 def visa @visa end |