Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2352 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
2342 2343 2344 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2342 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
2344 2345 2346 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2344 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
2346 2347 2348 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2346 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
2348 2349 2350 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2348 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
2350 2351 2352 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2350 def visa @visa end |