Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2275 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2265 2266 2267 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2265 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2267 2268 2269 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2267 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2269 2270 2271 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2269 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2271 2272 2273 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2271 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2273 2274 2275 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2273 def title @title end |
Class Method Details
.field_encodings ⇒ Object
2289 2290 2291 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2289 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |