Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3545

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3535
3536
3537
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3535

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3537
3538
3539
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3537

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



3539
3540
3541
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3539

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3541
3542
3543
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3541

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3543
3544
3545
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3543

def title
  @title
end

Class Method Details

.field_encodingsObject



3559
3560
3561
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3559

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end