Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2141 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2131 2132 2133 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2131 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2133 2134 2135 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2133 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2135 2136 2137 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2135 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2137 2138 2139 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2137 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2139 2140 2141 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2139 def title @title end |
Class Method Details
.field_encodings ⇒ Object
2155 2156 2157 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2155 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |