Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3520

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3510
3511
3512
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3510

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3512
3513
3514
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3512

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



3514
3515
3516
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3514

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3516
3517
3518
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3516

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3518
3519
3520
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3518

def title
  @title
end

Class Method Details

.field_encodingsObject



3534
3535
3536
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3534

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end