Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
3446 3447 3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3446 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
3436 3437 3438 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3436 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
3438 3439 3440 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3438 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
3440 3441 3442 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3440 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
3442 3443 3444 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3442 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
3444 3445 3446 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3444 def title @title end |
Class Method Details
.field_encodings ⇒ Object
3460 3461 3462 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3460 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |