Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2119

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2109
2110
2111
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2109

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2111
2112
2113
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2111

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



2113
2114
2115
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2113

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2115
2116
2117
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2115

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2117
2118
2119
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2117

def title
  @title
end

Class Method Details

.field_encodingsObject



2133
2134
2135
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2133

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end