Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
3420 3421 3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3420 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
3410 3411 3412 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3410 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
3412 3413 3414 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3412 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
3414 3415 3416 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3414 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
3416 3417 3418 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3416 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
3418 3419 3420 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3418 def title @title end |
Class Method Details
.field_encodings ⇒ Object
3434 3435 3436 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3434 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |