Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3390

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3380
3381
3382
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3380

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3382
3383
3384
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3382

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



3384
3385
3386
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3384

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3386
3387
3388
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3386

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3388
3389
3390
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 3388

def title
  @title
end