Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2868 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2858 2859 2860 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2858 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2860 2861 2862 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2860 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2862 2863 2864 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2862 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2864 2865 2866 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2864 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2866 2867 2868 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2866 def title @title end |