Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2787

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2777
2778
2779
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2777

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2779
2780
2781
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2779

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



2781
2782
2783
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2781

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2783
2784
2785
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2783

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2785
2786
2787
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2785

def title
  @title
end