Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2787 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2777 2778 2779 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2777 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2779 2780 2781 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2779 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2781 2782 2783 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2781 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2783 2784 2785 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2783 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2785 2786 2787 |
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2785 def title @title end |