Class: Stripe::V2::Core::AccountCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2676
2677
2678
2679
2680
2681
2682
2683
2684
2685
2686
2687
2688
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2676

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2666
2667
2668
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2666

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2668
2669
2670
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2668

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



2670
2671
2672
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2670

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2672
2673
2674
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2672

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2674
2675
2676
# File 'lib/stripe/params/v2/core/account_create_params.rb', line 2674

def title
  @title
end