Class: Stripe::V2::Core::AccountEvaluation

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account_evaluation.rb

Overview

Account Evaluation resource.

Defined Under Namespace

Classes: AccountData

Constant Summary collapse

OBJECT_NAME =
"v2.core.account_evaluation"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID if this evaluation is for an existing account.



82
83
84
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 82

def 
  @account
end

#account_dataObject (readonly)

Account data if this evaluation is for an account without an existing Stripe entity.



84
85
86
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 84

def 
  @account_data
end

#createdObject (readonly)

Timestamp at which the evaluation was created.



86
87
88
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 86

def created
  @created
end

#evaluations_triggeredObject (readonly)

List of signals that were triggered for evaluation.



88
89
90
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 88

def evaluations_triggered
  @evaluations_triggered
end

#idObject (readonly)

Unique identifier for the account evaluation.



90
91
92
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 90

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



94
95
96
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 94

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



92
93
94
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 92

def object
  @object
end

Class Method Details

.field_remappingsObject



100
101
102
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 100

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



96
97
98
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 96

def self.inner_class_types
  @inner_class_types = { account_data: AccountData }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account_evaluation.rb', line 10

def self.object_name
  "v2.core.account_evaluation"
end