Class: Stripe::V2::Core::AccountLink

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account_link.rb

Overview

AccountLinks are the means by which a Merchant grants an Account permission to access Stripe-hosted applications, such as Recipient Onboarding. This API is only available for users enrolled in the public preview for Accounts v2.

Defined Under Namespace

Classes: UseCase

Constant Summary collapse

OBJECT_NAME =
"v2.core.account_link"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The ID of the Account the link was created for.



56
57
58
# File 'lib/stripe/resources/v2/core/account_link.rb', line 56

def 
  @account
end

#createdObject (readonly)

The timestamp at which this AccountLink was created.



58
59
60
# File 'lib/stripe/resources/v2/core/account_link.rb', line 58

def created
  @created
end

#expires_atObject (readonly)

The timestamp at which this AccountLink will expire.



60
61
62
# File 'lib/stripe/resources/v2/core/account_link.rb', line 60

def expires_at
  @expires_at
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



68
69
70
# File 'lib/stripe/resources/v2/core/account_link.rb', line 68

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



62
63
64
# File 'lib/stripe/resources/v2/core/account_link.rb', line 62

def object
  @object
end

#urlObject (readonly)

The URL for the AccountLink.



64
65
66
# File 'lib/stripe/resources/v2/core/account_link.rb', line 64

def url
  @url
end

#use_caseObject (readonly)

The use case of AccountLink the user is requesting.



66
67
68
# File 'lib/stripe/resources/v2/core/account_link.rb', line 66

def use_case
  @use_case
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account_link.rb', line 10

def self.object_name
  "v2.core.account_link"
end