Class: Stripe::V2::Core::AccountLink

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/account_link.rb

Overview

AccountLinks are the means by which a Merchant grants an Account permission to access Stripe-hosted application, such as Recipient Onboarding.

Defined Under Namespace

Classes: UseCase

Constant Summary collapse

OBJECT_NAME =
"v2.core.account_link"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The ID of the Account the link was created for.



40
41
42
# File 'lib/stripe/resources/v2/core/account_link.rb', line 40

def 
  @account
end

#createdObject (readonly)

The timestamp at which this AccountLink was created.



42
43
44
# File 'lib/stripe/resources/v2/core/account_link.rb', line 42

def created
  @created
end

#expires_atObject (readonly)

The timestamp at which this AccountLink will expire.



44
45
46
# File 'lib/stripe/resources/v2/core/account_link.rb', line 44

def expires_at
  @expires_at
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



46
47
48
# File 'lib/stripe/resources/v2/core/account_link.rb', line 46

def object
  @object
end

#urlObject (readonly)

The URL for the AccountLink.



48
49
50
# File 'lib/stripe/resources/v2/core/account_link.rb', line 48

def url
  @url
end

#use_caseObject (readonly)

The use case of AccountLink the user is requesting.



50
51
52
# File 'lib/stripe/resources/v2/core/account_link.rb', line 50

def use_case
  @use_case
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/account_link.rb', line 10

def self.object_name
  "v2.core.account_link"
end