Class: Stripe::V2::Core::AccountLink::UseCase::AccountUpdate
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::AccountLink::UseCase::AccountUpdate
- Defined in:
- lib/stripe/resources/v2/core/account_link.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#configurations ⇒ Object
readonly
Open Enum.
-
#refresh_url ⇒ Object
readonly
The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid.
-
#return_url ⇒ Object
readonly
The URL that the user will be redirected to upon completing the linked flow.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#configurations ⇒ Object (readonly)
Open Enum. A v2/account can be configured to enable certain functionality. The configuration param targets the v2/account_link to collect information for the specified v2/account configuration/s.
26 27 28 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 26 def configurations @configurations end |
#refresh_url ⇒ Object (readonly)
The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new AccountLink with the same parameters used to create the original AccountLink, then redirect the user to the new AccountLink’s URL so they can continue the flow. If a new AccountLink cannot be generated or the redirect fails you should display a useful error to the user. Please make sure to implement authentication before redirecting the user in case this URL is leaked to a third party.
28 29 30 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 28 def refresh_url @refresh_url end |
#return_url ⇒ Object (readonly)
The URL that the user will be redirected to upon completing the linked flow.
30 31 32 |
# File 'lib/stripe/resources/v2/core/account_link.rb', line 30 def return_url @return_url end |