Class: Stripe::V2::Core::AccountLinkCreateParams::UseCase::RecipientUpdate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountLinkCreateParams::UseCase::RecipientUpdate
- Defined in:
- lib/stripe/params/v2/core/account_link_create_params.rb
Defined Under Namespace
Classes: CollectionOptions
Instance Attribute Summary collapse
-
#collection_options ⇒ Object
Specifies the requirements that Stripe collects from v2/core/accounts in the Update flow.
-
#configurations ⇒ Object
Open Enum.
-
#refresh_url ⇒ Object
The URL the user will be redirected to if the Account Link is expired, has been used, or is otherwise invalid.
-
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the linked flow.
Instance Method Summary collapse
-
#initialize(collection_options: nil, configurations: nil, refresh_url: nil, return_url: nil) ⇒ RecipientUpdate
constructor
A new instance of RecipientUpdate.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_options: nil, configurations: nil, refresh_url: nil, return_url: nil) ⇒ RecipientUpdate
Returns a new instance of RecipientUpdate.
132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 132 def initialize( collection_options: nil, configurations: nil, refresh_url: nil, return_url: nil ) @collection_options = @configurations = configurations @refresh_url = refresh_url @return_url = return_url end |
Instance Attribute Details
#collection_options ⇒ Object
Specifies the requirements that Stripe collects from v2/core/accounts in the Update flow.
124 125 126 |
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 124 def @collection_options end |
#configurations ⇒ Object
Open Enum. A v2/account can be configured to enable certain functionality. The configuration param targets the v2/account_link to collect information for the specified v2/account configuration/s.
126 127 128 |
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 126 def configurations @configurations end |
#refresh_url ⇒ Object
The URL the user will be redirected to if the Account Link is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new Account Link with the same parameters used to create the original Account Link, then redirect the user to the new Account Link URL so they can continue the flow. Make sure to authenticate the user before redirecting to the new Account Link, in case the URL leaks to a third party. If a new Account Link can’t be generated, or if the redirect fails, you should display a useful error to the user.
128 129 130 |
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 128 def refresh_url @refresh_url end |
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the linked flow.
130 131 132 |
# File 'lib/stripe/params/v2/core/account_link_create_params.rb', line 130 def return_url @return_url end |