Class: Stripe::V2::Core::AccountService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Core::AccountService
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: CloseParams, CreateParams, ListParams, RetrieveParams, UpdateParams
Instance Attribute Summary collapse
-
#persons ⇒ Object
readonly
Returns the value of attribute persons.
Instance Method Summary collapse
-
#close(id, params = {}, opts = {}) ⇒ Object
Removes access to the Account and its associated resources.
-
#create(params = {}, opts = {}) ⇒ Object
An Account is a representation of a company, individual or other entity that a user interacts with.
-
#initialize(requestor) ⇒ AccountService
constructor
A new instance of AccountService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Accounts.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an Account.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates the details of an Account.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ AccountService
Returns a new instance of AccountService.
10 11 12 13 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 10 def initialize(requestor) super @persons = Stripe::V2::Core::Accounts::PersonService.new(@requestor) end |
Instance Attribute Details
#persons ⇒ Object (readonly)
Returns the value of attribute persons.
8 9 10 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 8 def persons @persons end |
Instance Method Details
#close(id, params = {}, opts = {}) ⇒ Object
Removes access to the Account and its associated resources.
4430 4431 4432 4433 4434 4435 4436 4437 4438 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4430 def close(id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/accounts/%<id>s/close", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
An Account is a representation of a company, individual or other entity that a user interacts with. Accounts contain identifying information about the entity, and configurations that store the features an account has access to. An account can be configured as any or all of the following configurations: Customer, Merchant and/or Recipient.
4441 4442 4443 4444 4445 4446 4447 4448 4449 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4441 def create(params = {}, opts = {}) request( method: :post, path: "/v2/core/accounts", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Accounts.
4452 4453 4454 4455 4456 4457 4458 4459 4460 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4452 def list(params = {}, opts = {}) request( method: :get, path: "/v2/core/accounts", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an Account.
4463 4464 4465 4466 4467 4468 4469 4470 4471 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4463 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates the details of an Account.
4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 4474 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |