Class: Stripe::V2::Core::AccountService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: CloseParams, CreateParams, ListParams, RetrieveParams, UpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from StripeService

#request, #request_stream

Constructor Details

#initialize(requestor) ⇒ AccountService

Returns a new instance of AccountService.



10
11
12
13
# File 'lib/stripe/services/v2/core/account_service.rb', line 10

def initialize(requestor)
  super
  @persons = Stripe::V2::Core::Accounts::PersonService.new(@requestor)
end

Instance Attribute Details

#personsObject (readonly)

Returns the value of attribute persons.



8
9
10
# File 'lib/stripe/services/v2/core/account_service.rb', line 8

def persons
  @persons
end

Instance Method Details

#close(id, params = {}, opts = {}) ⇒ Object

Removes access to the Account and its associated resources.



4074
4075
4076
4077
4078
4079
4080
4081
4082
# File 'lib/stripe/services/v2/core/account_service.rb', line 4074

def close(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/accounts/%<id>s/close", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

An Account is a representation of a company, individual or other entity that a user interacts with. Accounts contain identifying information about the entity, and configurations that store the features an account has access to. An account can be configured as any or all of the following configurations: Customer, Merchant and/or Recipient.



4085
4086
4087
4088
4089
4090
4091
4092
4093
# File 'lib/stripe/services/v2/core/account_service.rb', line 4085

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v2/core/accounts",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of Accounts.



4096
4097
4098
4099
4100
4101
4102
4103
4104
# File 'lib/stripe/services/v2/core/account_service.rb', line 4096

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v2/core/accounts",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieves the details of an Account.



4107
4108
4109
4110
4111
4112
4113
4114
4115
# File 'lib/stripe/services/v2/core/account_service.rb', line 4107

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/core/accounts/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(id, params = {}, opts = {}) ⇒ Object

Updates the details of an Account.



4118
4119
4120
4121
4122
4123
4124
4125
4126
# File 'lib/stripe/services/v2/core/account_service.rb', line 4118

def update(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/accounts/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end