Class: Stripe::V2::Core::AccountService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2033 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2017 2018 2019 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2017 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2019 2020 2021 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2019 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2021 2022 2023 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2021 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2023 2024 2025 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2023 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2025 2026 2027 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2025 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2027 2028 2029 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2027 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2029 2030 2031 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2029 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2031 2032 2033 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2031 def @metadata end |