Class: Stripe::V2::Core::AccountService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2191 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2175 2176 2177 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2175 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2177 2178 2179 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2177 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2179 2180 2181 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2179 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2181 2182 2183 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2181 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2183 2184 2185 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2183 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2185 2186 2187 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2185 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2187 2188 2189 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2187 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2189 2190 2191 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2189 def @metadata end |