Class: Stripe::V2::Core::AccountService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
# File 'lib/stripe/services/v2/core/account_service.rb', line 2014

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



1998
1999
2000
# File 'lib/stripe/services/v2/core/account_service.rb', line 1998

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2000
2001
2002
# File 'lib/stripe/services/v2/core/account_service.rb', line 2000

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2002
2003
2004
# File 'lib/stripe/services/v2/core/account_service.rb', line 2002

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2004
2005
2006
# File 'lib/stripe/services/v2/core/account_service.rb', line 2004

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2006
2007
2008
# File 'lib/stripe/services/v2/core/account_service.rb', line 2006

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2008
2009
2010
# File 'lib/stripe/services/v2/core/account_service.rb', line 2008

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2010
2011
2012
# File 'lib/stripe/services/v2/core/account_service.rb', line 2010

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2012
2013
2014
# File 'lib/stripe/services/v2/core/account_service.rb', line 2012

def 
  @metadata
end