Class: Stripe::V2::Core::AccountService::CreateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil) ⇒ Configuration

Returns a new instance of Configuration.



993
994
995
996
997
# File 'lib/stripe/services/v2/core/account_service.rb', line 993

def initialize(customer: nil, merchant: nil, recipient: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be used in inbound payment flows.



987
988
989
# File 'lib/stripe/services/v2/core/account_service.rb', line 987

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



989
990
991
# File 'lib/stripe/services/v2/core/account_service.rb', line 989

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



991
992
993
# File 'lib/stripe/services/v2/core/account_service.rb', line 991

def recipient
  @recipient
end