Class: Stripe::V2::Core::AccountService::CreateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/stripe/services/v2/core/account_service.rb', line 172

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



162
163
164
# File 'lib/stripe/services/v2/core/account_service.rb', line 162

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



164
165
166
# File 'lib/stripe/services/v2/core/account_service.rb', line 164

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



166
167
168
# File 'lib/stripe/services/v2/core/account_service.rb', line 166

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



168
169
170
# File 'lib/stripe/services/v2/core/account_service.rb', line 168

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



170
171
172
# File 'lib/stripe/services/v2/core/account_service.rb', line 170

def test_clock
  @test_clock
end