Class: Stripe::V2::Core::AccountService::CreateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address’.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
38 39 40 41 42 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 38 def initialize(exempt: nil, ip_address: nil, location_source: nil) @exempt = exempt @ip_address = ip_address @location_source = location_source end |
Instance Attribute Details
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.
32 33 34 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 32 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
34 35 36 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 34 def ip_address @ip_address end |
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address’. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.
36 37 38 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 36 def location_source @location_source end |