Class: Stripe::V2::Core::AccountService::CreateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Identity
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the person represented by the account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2002 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors.
1992 1993 1994 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1992 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
1994 1995 1996 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1994 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
1996 1997 1998 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1996 def country @country end |
#entity_type ⇒ Object
The entity type.
1998 1999 2000 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1998 def entity_type @entity_type end |
#individual ⇒ Object
Information about the person represented by the account.
2000 2001 2002 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2000 def individual @individual end |