Class: Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
# File 'lib/stripe/services/v2/core/account_service.rb', line 1273

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1265
1266
1267
# File 'lib/stripe/services/v2/core/account_service.rb', line 1265

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1267
1268
1269
# File 'lib/stripe/services/v2/core/account_service.rb', line 1267

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



1269
1270
1271
# File 'lib/stripe/services/v2/core/account_service.rb', line 1269

def persons_provided
  @persons_provided
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



1271
1272
1273
# File 'lib/stripe/services/v2/core/account_service.rb', line 1271

def terms_of_service
  @terms_of_service
end