Class: Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1112 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1104 1105 1106 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1104 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1106 1107 1108 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1106 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
1108 1109 1110 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1108 def persons_provided @persons_provided end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
1110 1111 1112 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1110 def terms_of_service @terms_of_service end |