Class: Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1051
1052
1053
1054
1055
# File 'lib/stripe/services/v2/core/account_service.rb', line 1051

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1045
1046
1047
# File 'lib/stripe/services/v2/core/account_service.rb', line 1045

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1047
1048
1049
# File 'lib/stripe/services/v2/core/account_service.rb', line 1047

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1049
1050
1051
# File 'lib/stripe/services/v2/core/account_service.rb', line 1049

def user_agent
  @user_agent
end