Class: Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations::PersonsProvided
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Identity::Attestations::PersonsProvided
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#directors ⇒ Object
Whether the company’s directors have been provided.
-
#executives ⇒ Object
Whether the company’s executives have been provided.
-
#owners ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
Instance Method Summary collapse
-
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
constructor
A new instance of PersonsProvided.
Methods inherited from RequestParams
Constructor Details
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
Returns a new instance of PersonsProvided.
1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1068 def initialize( directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil ) @directors = directors @executives = executives @owners = owners @ownership_exemption_reason = ownership_exemption_reason end |
Instance Attribute Details
#directors ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1060 1061 1062 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1060 def directors @directors end |
#executives ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1062 1063 1064 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1062 def executives @executives end |
#owners ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1064 1065 1066 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1064 def owners @owners end |
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
1066 1067 1068 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1066 def ownership_exemption_reason @ownership_exemption_reason end |