Class: Stripe::V2::Core::AccountService::CreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
# File 'lib/stripe/services/v2/core/account_service.rb', line 1673

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  doing_business_as: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  product_description: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil,
  url: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @doing_business_as = doing_business_as
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @product_description = product_description
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
  @url = url
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



1645
1646
1647
# File 'lib/stripe/services/v2/core/account_service.rb', line 1645

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



1647
1648
1649
# File 'lib/stripe/services/v2/core/account_service.rb', line 1647

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



1649
1650
1651
# File 'lib/stripe/services/v2/core/account_service.rb', line 1649

def documents
  @documents
end

#doing_business_asObject

The name which is used by the business.



1651
1652
1653
# File 'lib/stripe/services/v2/core/account_service.rb', line 1651

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1653
1654
1655
# File 'lib/stripe/services/v2/core/account_service.rb', line 1653

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



1655
1656
1657
# File 'lib/stripe/services/v2/core/account_service.rb', line 1655

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



1657
1658
1659
# File 'lib/stripe/services/v2/core/account_service.rb', line 1657

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



1659
1660
1661
# File 'lib/stripe/services/v2/core/account_service.rb', line 1659

def phone
  @phone
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1661
1662
1663
# File 'lib/stripe/services/v2/core/account_service.rb', line 1661

def product_description
  @product_description
end

#registered_nameObject

The business legal name.



1663
1664
1665
# File 'lib/stripe/services/v2/core/account_service.rb', line 1663

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



1665
1666
1667
# File 'lib/stripe/services/v2/core/account_service.rb', line 1665

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



1667
1668
1669
# File 'lib/stripe/services/v2/core/account_service.rb', line 1667

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



1669
1670
1671
# File 'lib/stripe/services/v2/core/account_service.rb', line 1669

def structure
  @structure
end

#urlObject

The business’s publicly available website.



1671
1672
1673
# File 'lib/stripe/services/v2/core/account_service.rb', line 1671

def url
  @url
end