Class: Stripe::V2::Core::AccountService::CreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
# File 'lib/stripe/services/v2/core/account_service.rb', line 1515

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  doing_business_as: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  product_description: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil,
  url: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @doing_business_as = doing_business_as
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @product_description = product_description
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
  @url = url
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



1487
1488
1489
# File 'lib/stripe/services/v2/core/account_service.rb', line 1487

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



1489
1490
1491
# File 'lib/stripe/services/v2/core/account_service.rb', line 1489

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



1491
1492
1493
# File 'lib/stripe/services/v2/core/account_service.rb', line 1491

def documents
  @documents
end

#doing_business_asObject

The name which is used by the business.



1493
1494
1495
# File 'lib/stripe/services/v2/core/account_service.rb', line 1493

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



1495
1496
1497
# File 'lib/stripe/services/v2/core/account_service.rb', line 1495

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



1497
1498
1499
# File 'lib/stripe/services/v2/core/account_service.rb', line 1497

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



1499
1500
1501
# File 'lib/stripe/services/v2/core/account_service.rb', line 1499

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



1501
1502
1503
# File 'lib/stripe/services/v2/core/account_service.rb', line 1501

def phone
  @phone
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1503
1504
1505
# File 'lib/stripe/services/v2/core/account_service.rb', line 1503

def product_description
  @product_description
end

#registered_nameObject

The business legal name.



1505
1506
1507
# File 'lib/stripe/services/v2/core/account_service.rb', line 1505

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



1507
1508
1509
# File 'lib/stripe/services/v2/core/account_service.rb', line 1507

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



1509
1510
1511
# File 'lib/stripe/services/v2/core/account_service.rb', line 1509

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



1511
1512
1513
# File 'lib/stripe/services/v2/core/account_service.rb', line 1511

def structure
  @structure
end

#urlObject

The business’s publicly available website.



1513
1514
1515
# File 'lib/stripe/services/v2/core/account_service.rb', line 1513

def url
  @url
end