Class: Stripe::V2::Core::AccountService::CreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::CreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
-
#registered_name ⇒ Object
The business legal name.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1496 def initialize( address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @doing_business_as = doing_business_as @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @product_description = product_description @registered_name = registered_name @script_addresses = script_addresses @script_names = script_names @structure = structure @url = url end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
1468 1469 1470 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1468 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1470 1471 1472 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1470 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1472 1473 1474 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1472 def documents @documents end |
#doing_business_as ⇒ Object
The name which is used by the business.
1474 1475 1476 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1474 def doing_business_as @doing_business_as end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
1476 1477 1478 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1476 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1478 1479 1480 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1478 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1480 1481 1482 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1480 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1482 1483 1484 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1482 def phone @phone end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
1484 1485 1486 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1484 def product_description @product_description end |
#registered_name ⇒ Object
The business legal name.
1486 1487 1488 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1486 def registered_name @registered_name end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1488 1489 1490 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1488 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1490 1491 1492 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1490 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1492 1493 1494 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1492 def structure @structure end |
#url ⇒ Object
The business’s publicly available website.
1494 1495 1496 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 1494 def url @url end |