Class: Stripe::V2::Core::AccountService::CreateParams::Identity::BusinessDetails::AnnualRevenue

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue

Returns a new instance of AnnualRevenue.



1167
1168
1169
1170
# File 'lib/stripe/services/v2/core/account_service.rb', line 1167

def initialize(amount: nil, fiscal_year_end: nil)
  @amount = amount
  @fiscal_year_end = fiscal_year_end
end

Instance Attribute Details

#amountObject

A non-negative integer representing the amount in the smallest currency unit.



1163
1164
1165
# File 'lib/stripe/services/v2/core/account_service.rb', line 1163

def amount
  @amount
end

#fiscal_year_endObject

The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.



1165
1166
1167
# File 'lib/stripe/services/v2/core/account_service.rb', line 1165

def fiscal_year_end
  @fiscal_year_end
end