Class: Stripe::V2::Core::AccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4435
4436
4437
4438
4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
4453
# File 'lib/stripe/services/v2/core/account_service.rb', line 4435

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



4419
4420
4421
# File 'lib/stripe/services/v2/core/account_service.rb', line 4419

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4421
4422
4423
# File 'lib/stripe/services/v2/core/account_service.rb', line 4421

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4423
4424
4425
# File 'lib/stripe/services/v2/core/account_service.rb', line 4423

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



4425
4426
4427
# File 'lib/stripe/services/v2/core/account_service.rb', line 4425

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4427
4428
4429
# File 'lib/stripe/services/v2/core/account_service.rb', line 4427

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



4429
4430
4431
# File 'lib/stripe/services/v2/core/account_service.rb', line 4429

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



4431
4432
4433
# File 'lib/stripe/services/v2/core/account_service.rb', line 4431

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4433
4434
4435
# File 'lib/stripe/services/v2/core/account_service.rb', line 4433

def 
  @metadata
end