Class: Stripe::V2::Core::AccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
# File 'lib/stripe/services/v2/core/account_service.rb', line 4399

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



4383
4384
4385
# File 'lib/stripe/services/v2/core/account_service.rb', line 4383

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4385
4386
4387
# File 'lib/stripe/services/v2/core/account_service.rb', line 4385

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4387
4388
4389
# File 'lib/stripe/services/v2/core/account_service.rb', line 4387

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



4389
4390
4391
# File 'lib/stripe/services/v2/core/account_service.rb', line 4389

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4391
4392
4393
# File 'lib/stripe/services/v2/core/account_service.rb', line 4391

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



4393
4394
4395
# File 'lib/stripe/services/v2/core/account_service.rb', line 4393

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



4395
4396
4397
# File 'lib/stripe/services/v2/core/account_service.rb', line 4395

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4397
4398
4399
# File 'lib/stripe/services/v2/core/account_service.rb', line 4397

def 
  @metadata
end