Class: Stripe::V2::Core::AccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4083
4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
4097
4098
4099
4100
4101
# File 'lib/stripe/services/v2/core/account_service.rb', line 4083

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



4067
4068
4069
# File 'lib/stripe/services/v2/core/account_service.rb', line 4067

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4069
4070
4071
# File 'lib/stripe/services/v2/core/account_service.rb', line 4069

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4071
4072
4073
# File 'lib/stripe/services/v2/core/account_service.rb', line 4071

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



4073
4074
4075
# File 'lib/stripe/services/v2/core/account_service.rb', line 4073

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4075
4076
4077
# File 'lib/stripe/services/v2/core/account_service.rb', line 4075

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



4077
4078
4079
# File 'lib/stripe/services/v2/core/account_service.rb', line 4077

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



4079
4080
4081
# File 'lib/stripe/services/v2/core/account_service.rb', line 4079

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4081
4082
4083
# File 'lib/stripe/services/v2/core/account_service.rb', line 4081

def 
  @metadata
end