Class: Stripe::V2::Core::AccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
# File 'lib/stripe/services/v2/core/account_service.rb', line 4052

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



4036
4037
4038
# File 'lib/stripe/services/v2/core/account_service.rb', line 4036

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



4038
4039
4040
# File 'lib/stripe/services/v2/core/account_service.rb', line 4038

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



4040
4041
4042
# File 'lib/stripe/services/v2/core/account_service.rb', line 4040

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



4042
4043
4044
# File 'lib/stripe/services/v2/core/account_service.rb', line 4042

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



4044
4045
4046
# File 'lib/stripe/services/v2/core/account_service.rb', line 4044

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



4046
4047
4048
# File 'lib/stripe/services/v2/core/account_service.rb', line 4046

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



4048
4049
4050
# File 'lib/stripe/services/v2/core/account_service.rb', line 4048

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



4050
4051
4052
# File 'lib/stripe/services/v2/core/account_service.rb', line 4050

def 
  @metadata
end