Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
3393 3394 3395 3396 3397 3398 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3393 def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
3385 3386 3387 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3385 def customer @customer end |
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.
3387 3388 3389 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3387 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
3389 3390 3391 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3389 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
3391 3392 3393 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3391 def storer @storer end |