Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



3379
3380
3381
3382
3383
3384
# File 'lib/stripe/services/v2/core/account_service.rb', line 3379

def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be charged.



3371
3372
3373
# File 'lib/stripe/services/v2/core/account_service.rb', line 3371

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



3373
3374
3375
# File 'lib/stripe/services/v2/core/account_service.rb', line 3373

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



3375
3376
3377
# File 'lib/stripe/services/v2/core/account_service.rb', line 3375

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



3377
3378
3379
# File 'lib/stripe/services/v2/core/account_service.rb', line 3377

def storer
  @storer
end