Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil) ⇒ Configuration

Returns a new instance of Configuration.



3046
3047
3048
3049
3050
# File 'lib/stripe/services/v2/core/account_service.rb', line 3046

def initialize(customer: nil, merchant: nil, recipient: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be charged.



3040
3041
3042
# File 'lib/stripe/services/v2/core/account_service.rb', line 3040

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



3042
3043
3044
# File 'lib/stripe/services/v2/core/account_service.rb', line 3042

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



3044
3045
3046
# File 'lib/stripe/services/v2/core/account_service.rb', line 3044

def recipient
  @recipient
end