Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
3361 3362 3363 3364 3365 3366 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3361 def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
3353 3354 3355 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3353 def customer @customer end |
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.
3355 3356 3357 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3355 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
3357 3358 3359 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3357 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
3359 3360 3361 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3359 def storer @storer end |