Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Customer, Merchant, Recipient
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, recipient: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, merchant: nil, recipient: nil) ⇒ Configuration
Returns a new instance of Configuration.
3039 3040 3041 3042 3043 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3039 def initialize(customer: nil, merchant: nil, recipient: nil) @customer = customer @merchant = merchant @recipient = recipient end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
3033 3034 3035 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3033 def customer @customer end |
#merchant ⇒ Object
The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.
3035 3036 3037 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3035 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
3037 3038 3039 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3037 def recipient @recipient end |