Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil) ⇒ Configuration

Returns a new instance of Configuration.



3031
3032
3033
3034
3035
# File 'lib/stripe/services/v2/core/account_service.rb', line 3031

def initialize(customer: nil, merchant: nil, recipient: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be charged.



3025
3026
3027
# File 'lib/stripe/services/v2/core/account_service.rb', line 3025

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



3027
3028
3029
# File 'lib/stripe/services/v2/core/account_service.rb', line 3027

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



3029
3030
3031
# File 'lib/stripe/services/v2/core/account_service.rb', line 3029

def recipient
  @recipient
end