Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
# File 'lib/stripe/services/v2/core/account_service.rb', line 2398

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



2388
2389
2390
# File 'lib/stripe/services/v2/core/account_service.rb', line 2388

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



2390
2391
2392
# File 'lib/stripe/services/v2/core/account_service.rb', line 2390

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



2392
2393
2394
# File 'lib/stripe/services/v2/core/account_service.rb', line 2392

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



2394
2395
2396
# File 'lib/stripe/services/v2/core/account_service.rb', line 2394

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



2396
2397
2398
# File 'lib/stripe/services/v2/core/account_service.rb', line 2396

def test_clock
  @test_clock
end