Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
# File 'lib/stripe/services/v2/core/account_service.rb', line 2380

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



2370
2371
2372
# File 'lib/stripe/services/v2/core/account_service.rb', line 2370

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



2372
2373
2374
# File 'lib/stripe/services/v2/core/account_service.rb', line 2372

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



2374
2375
2376
# File 'lib/stripe/services/v2/core/account_service.rb', line 2374

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



2376
2377
2378
# File 'lib/stripe/services/v2/core/account_service.rb', line 2376

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



2378
2379
2380
# File 'lib/stripe/services/v2/core/account_service.rb', line 2378

def test_clock
  @test_clock
end