Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping
Instance Attribute Summary collapse
-
#automatic_indirect_tax ⇒ Object
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links.
-
#billing ⇒ Object
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
-
#capabilities ⇒ Object
Capabilities that have been requested on the Customer Configuration.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
Instance Method Summary collapse
-
#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer
constructor
A new instance of Customer.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer
Returns a new instance of Customer.
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2222 def initialize( automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil ) @automatic_indirect_tax = automatic_indirect_tax @billing = billing @capabilities = capabilities @shipping = shipping @test_clock = test_clock end |
Instance Attribute Details
#automatic_indirect_tax ⇒ Object
Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.
2212 2213 2214 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2212 def automatic_indirect_tax @automatic_indirect_tax end |
#billing ⇒ Object
Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
2214 2215 2216 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2214 def billing @billing end |
#capabilities ⇒ Object
Capabilities that have been requested on the Customer Configuration.
2216 2217 2218 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2216 def capabilities @capabilities end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
2218 2219 2220 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2218 def shipping @shipping end |
#test_clock ⇒ Object
ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
2220 2221 2222 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2220 def test_clock @test_clock end |