Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
# File 'lib/stripe/services/v2/core/account_service.rb', line 2207

def initialize(
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



2197
2198
2199
# File 'lib/stripe/services/v2/core/account_service.rb', line 2197

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



2199
2200
2201
# File 'lib/stripe/services/v2/core/account_service.rb', line 2199

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



2201
2202
2203
# File 'lib/stripe/services/v2/core/account_service.rb', line 2201

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



2203
2204
2205
# File 'lib/stripe/services/v2/core/account_service.rb', line 2203

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



2205
2206
2207
# File 'lib/stripe/services/v2/core/account_service.rb', line 2205

def test_clock
  @test_clock
end