Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::AutomaticIndirectTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax

Returns a new instance of AutomaticIndirectTax.



2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
# File 'lib/stripe/services/v2/core/account_service.rb', line 2234

def initialize(
  exempt: nil,
  ip_address: nil,
  location_source: nil,
  validate_location: nil
)
  @exempt = exempt
  @ip_address = ip_address
  @location_source = location_source
  @validate_location = validate_location
end

Instance Attribute Details

#exemptObject

Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.



2226
2227
2228
# File 'lib/stripe/services/v2/core/account_service.rb', line 2226

def exempt
  @exempt
end

#ip_addressObject

A recent IP address of the customer used for tax reporting and tax location inference.



2228
2229
2230
# File 'lib/stripe/services/v2/core/account_service.rb', line 2228

def ip_address
  @ip_address
end

#location_sourceObject

The data source used to identify the customer’s tax location - defaults to ‘identity_address’. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.



2230
2231
2232
# File 'lib/stripe/services/v2/core/account_service.rb', line 2230

def location_source
  @location_source
end

#validate_locationObject

A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto’.



2232
2233
2234
# File 'lib/stripe/services/v2/core/account_service.rb', line 2232

def validate_location
  @validate_location
end