Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::Billing
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Customer::Billing
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Invoice
Instance Attribute Summary collapse
-
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
-
#invoice ⇒ Object
Default settings used on invoices for this customer.
Instance Method Summary collapse
-
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
constructor
A new instance of Billing.
Methods inherited from RequestParams
Constructor Details
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
Returns a new instance of Billing.
2137 2138 2139 2140 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2137 def initialize(default_payment_method: nil, invoice: nil) @default_payment_method = default_payment_method @invoice = invoice end |
Instance Attribute Details
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
2133 2134 2135 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2133 def default_payment_method @default_payment_method end |
#invoice ⇒ Object
Default settings used on invoices for this customer.
2135 2136 2137 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2135 def invoice @invoice end |