Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#mcc ⇒ Object
The merchant category code for the merchant.
-
#statement_descriptor ⇒ Object
Statement descriptor.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3123 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @mcc = mcc @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
3107 3108 3109 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3107 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
3109 3110 3111 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3109 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
3111 3112 3113 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3111 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
3113 3114 3115 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3113 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
3115 3116 3117 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3115 def card_payments @card_payments end |
#mcc ⇒ Object
The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.
3117 3118 3119 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3117 def mcc @mcc end |
#statement_descriptor ⇒ Object
Statement descriptor.
3119 3120 3121 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3119 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
3121 3122 3123 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3121 def support @support end |