Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Merchant::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: AchDebitPayments, AcssDebitPayments, AffirmPayments, AfterpayClearpayPayments, AlmaPayments, AmazonPayPayments, AuBecsDebitPayments, BacsDebitPayments, BancontactPayments, BlikPayments, BoletoPayments, CardPayments, CartesBancairesPayments, CashappPayments, EpsPayments, FpxPayments, GbBankTransferPayments, GrabpayPayments, IdealPayments, JcbPayments, JpBankTransferPayments, KakaoPayPayments, KlarnaPayments, KonbiniPayments, KrCardPayments, LinkPayments, MobilepayPayments, MultibancoPayments, MxBankTransferPayments, NaverPayPayments, OxxoPayments, P24Payments, PayByBankPayments, PaycoPayments, PaynowPayments, PromptpayPayments, RevolutPayPayments, SamsungPayPayments, SepaBankTransferPayments, SepaDebitPayments, SwishPayments, TwintPayments, UsBankTransferPayments, ZipPayments

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ach_debit_payments: nil, acss_debit_payments: nil, affirm_payments: nil, afterpay_clearpay_payments: nil, alma_payments: nil, amazon_pay_payments: nil, au_becs_debit_payments: nil, bacs_debit_payments: nil, bancontact_payments: nil, blik_payments: nil, boleto_payments: nil, card_payments: nil, cartes_bancaires_payments: nil, cashapp_payments: nil, eps_payments: nil, fpx_payments: nil, gb_bank_transfer_payments: nil, grabpay_payments: nil, ideal_payments: nil, jcb_payments: nil, jp_bank_transfer_payments: nil, kakao_pay_payments: nil, klarna_payments: nil, konbini_payments: nil, kr_card_payments: nil, link_payments: nil, mobilepay_payments: nil, multibanco_payments: nil, mx_bank_transfer_payments: nil, naver_pay_payments: nil, oxxo_payments: nil, p24_payments: nil, pay_by_bank_payments: nil, payco_payments: nil, paynow_payments: nil, promptpay_payments: nil, revolut_pay_payments: nil, samsung_pay_payments: nil, sepa_bank_transfer_payments: nil, sepa_debit_payments: nil, swish_payments: nil, twint_payments: nil, us_bank_transfer_payments: nil, zip_payments: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
2970
2971
2972
2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/stripe/services/v2/core/account_service.rb', line 2908

def initialize(
  ach_debit_payments: nil,
  acss_debit_payments: nil,
  affirm_payments: nil,
  afterpay_clearpay_payments: nil,
  alma_payments: nil,
  amazon_pay_payments: nil,
  au_becs_debit_payments: nil,
  bacs_debit_payments: nil,
  bancontact_payments: nil,
  blik_payments: nil,
  boleto_payments: nil,
  card_payments: nil,
  cartes_bancaires_payments: nil,
  cashapp_payments: nil,
  eps_payments: nil,
  fpx_payments: nil,
  gb_bank_transfer_payments: nil,
  grabpay_payments: nil,
  ideal_payments: nil,
  jcb_payments: nil,
  jp_bank_transfer_payments: nil,
  kakao_pay_payments: nil,
  klarna_payments: nil,
  konbini_payments: nil,
  kr_card_payments: nil,
  link_payments: nil,
  mobilepay_payments: nil,
  multibanco_payments: nil,
  mx_bank_transfer_payments: nil,
  naver_pay_payments: nil,
  oxxo_payments: nil,
  p24_payments: nil,
  pay_by_bank_payments: nil,
  payco_payments: nil,
  paynow_payments: nil,
  promptpay_payments: nil,
  revolut_pay_payments: nil,
  samsung_pay_payments: nil,
  sepa_bank_transfer_payments: nil,
  sepa_debit_payments: nil,
  swish_payments: nil,
  twint_payments: nil,
  us_bank_transfer_payments: nil,
  zip_payments: nil
)
  @ach_debit_payments = ach_debit_payments
  @acss_debit_payments = acss_debit_payments
  @affirm_payments = affirm_payments
  @afterpay_clearpay_payments = afterpay_clearpay_payments
  @alma_payments = alma_payments
  @amazon_pay_payments = amazon_pay_payments
  @au_becs_debit_payments = au_becs_debit_payments
  @bacs_debit_payments = bacs_debit_payments
  @bancontact_payments = bancontact_payments
  @blik_payments = blik_payments
  @boleto_payments = boleto_payments
  @card_payments = card_payments
  @cartes_bancaires_payments = cartes_bancaires_payments
  @cashapp_payments = cashapp_payments
  @eps_payments = eps_payments
  @fpx_payments = fpx_payments
  @gb_bank_transfer_payments = gb_bank_transfer_payments
  @grabpay_payments = grabpay_payments
  @ideal_payments = ideal_payments
  @jcb_payments = jcb_payments
  @jp_bank_transfer_payments = jp_bank_transfer_payments
  @kakao_pay_payments = kakao_pay_payments
  @klarna_payments = klarna_payments
  @konbini_payments = konbini_payments
  @kr_card_payments = kr_card_payments
  @link_payments = link_payments
  @mobilepay_payments = mobilepay_payments
  @multibanco_payments = multibanco_payments
  @mx_bank_transfer_payments = mx_bank_transfer_payments
  @naver_pay_payments = naver_pay_payments
  @oxxo_payments = oxxo_payments
  @p24_payments = p24_payments
  @pay_by_bank_payments = pay_by_bank_payments
  @payco_payments = payco_payments
  @paynow_payments = paynow_payments
  @promptpay_payments = promptpay_payments
  @revolut_pay_payments = revolut_pay_payments
  @samsung_pay_payments = samsung_pay_payments
  @sepa_bank_transfer_payments = sepa_bank_transfer_payments
  @sepa_debit_payments = sepa_debit_payments
  @swish_payments = swish_payments
  @twint_payments = twint_payments
  @us_bank_transfer_payments = us_bank_transfer_payments
  @zip_payments = zip_payments
end

Instance Attribute Details

#ach_debit_paymentsObject

Allow the merchant to process ACH debit payments.



2820
2821
2822
# File 'lib/stripe/services/v2/core/account_service.rb', line 2820

def ach_debit_payments
  @ach_debit_payments
end

#acss_debit_paymentsObject

Allow the merchant to process ACSS debit payments.



2822
2823
2824
# File 'lib/stripe/services/v2/core/account_service.rb', line 2822

def acss_debit_payments
  @acss_debit_payments
end

#affirm_paymentsObject

Allow the merchant to process Affirm payments.



2824
2825
2826
# File 'lib/stripe/services/v2/core/account_service.rb', line 2824

def affirm_payments
  @affirm_payments
end

#afterpay_clearpay_paymentsObject

Allow the merchant to process Afterpay/Clearpay payments.



2826
2827
2828
# File 'lib/stripe/services/v2/core/account_service.rb', line 2826

def afterpay_clearpay_payments
  @afterpay_clearpay_payments
end

#alma_paymentsObject

Allow the merchant to process Alma payments.



2828
2829
2830
# File 'lib/stripe/services/v2/core/account_service.rb', line 2828

def alma_payments
  @alma_payments
end

#amazon_pay_paymentsObject

Allow the merchant to process Amazon Pay payments.



2830
2831
2832
# File 'lib/stripe/services/v2/core/account_service.rb', line 2830

def amazon_pay_payments
  @amazon_pay_payments
end

#au_becs_debit_paymentsObject

Allow the merchant to process Australian BECS Direct Debit payments.



2832
2833
2834
# File 'lib/stripe/services/v2/core/account_service.rb', line 2832

def au_becs_debit_payments
  @au_becs_debit_payments
end

#bacs_debit_paymentsObject

Allow the merchant to process BACS Direct Debit payments.



2834
2835
2836
# File 'lib/stripe/services/v2/core/account_service.rb', line 2834

def bacs_debit_payments
  @bacs_debit_payments
end

#bancontact_paymentsObject

Allow the merchant to process Bancontact payments.



2836
2837
2838
# File 'lib/stripe/services/v2/core/account_service.rb', line 2836

def bancontact_payments
  @bancontact_payments
end

#blik_paymentsObject

Allow the merchant to process BLIK payments.



2838
2839
2840
# File 'lib/stripe/services/v2/core/account_service.rb', line 2838

def blik_payments
  @blik_payments
end

#boleto_paymentsObject

Allow the merchant to process Boleto payments.



2840
2841
2842
# File 'lib/stripe/services/v2/core/account_service.rb', line 2840

def boleto_payments
  @boleto_payments
end

#card_paymentsObject

Allow the merchant to collect card payments.



2842
2843
2844
# File 'lib/stripe/services/v2/core/account_service.rb', line 2842

def card_payments
  @card_payments
end

#cartes_bancaires_paymentsObject

Allow the merchant to process Cartes Bancaires payments.



2844
2845
2846
# File 'lib/stripe/services/v2/core/account_service.rb', line 2844

def cartes_bancaires_payments
  @cartes_bancaires_payments
end

#cashapp_paymentsObject

Allow the merchant to process Cash App payments.



2846
2847
2848
# File 'lib/stripe/services/v2/core/account_service.rb', line 2846

def cashapp_payments
  @cashapp_payments
end

#eps_paymentsObject

Allow the merchant to process EPS payments.



2848
2849
2850
# File 'lib/stripe/services/v2/core/account_service.rb', line 2848

def eps_payments
  @eps_payments
end

#fpx_paymentsObject

Allow the merchant to process FPX payments.



2850
2851
2852
# File 'lib/stripe/services/v2/core/account_service.rb', line 2850

def fpx_payments
  @fpx_payments
end

#gb_bank_transfer_paymentsObject

Allow the merchant to process UK bank transfer payments.



2852
2853
2854
# File 'lib/stripe/services/v2/core/account_service.rb', line 2852

def gb_bank_transfer_payments
  @gb_bank_transfer_payments
end

#grabpay_paymentsObject

Allow the merchant to process GrabPay payments.



2854
2855
2856
# File 'lib/stripe/services/v2/core/account_service.rb', line 2854

def grabpay_payments
  @grabpay_payments
end

#ideal_paymentsObject

Allow the merchant to process iDEAL payments.



2856
2857
2858
# File 'lib/stripe/services/v2/core/account_service.rb', line 2856

def ideal_payments
  @ideal_payments
end

#jcb_paymentsObject

Allow the merchant to process JCB card payments.



2858
2859
2860
# File 'lib/stripe/services/v2/core/account_service.rb', line 2858

def jcb_payments
  @jcb_payments
end

#jp_bank_transfer_paymentsObject

Allow the merchant to process Japanese bank transfer payments.



2860
2861
2862
# File 'lib/stripe/services/v2/core/account_service.rb', line 2860

def jp_bank_transfer_payments
  @jp_bank_transfer_payments
end

#kakao_pay_paymentsObject

Allow the merchant to process Kakao Pay payments.



2862
2863
2864
# File 'lib/stripe/services/v2/core/account_service.rb', line 2862

def kakao_pay_payments
  @kakao_pay_payments
end

#klarna_paymentsObject

Allow the merchant to process Klarna payments.



2864
2865
2866
# File 'lib/stripe/services/v2/core/account_service.rb', line 2864

def klarna_payments
  @klarna_payments
end

#konbini_paymentsObject

Allow the merchant to process Konbini convenience store payments.



2866
2867
2868
# File 'lib/stripe/services/v2/core/account_service.rb', line 2866

def konbini_payments
  @konbini_payments
end

#kr_card_paymentsObject

Allow the merchant to process Korean card payments.



2868
2869
2870
# File 'lib/stripe/services/v2/core/account_service.rb', line 2868

def kr_card_payments
  @kr_card_payments
end

Allow the merchant to process Link payments.



2870
2871
2872
# File 'lib/stripe/services/v2/core/account_service.rb', line 2870

def link_payments
  @link_payments
end

#mobilepay_paymentsObject

Allow the merchant to process MobilePay payments.



2872
2873
2874
# File 'lib/stripe/services/v2/core/account_service.rb', line 2872

def mobilepay_payments
  @mobilepay_payments
end

#multibanco_paymentsObject

Allow the merchant to process Multibanco payments.



2874
2875
2876
# File 'lib/stripe/services/v2/core/account_service.rb', line 2874

def multibanco_payments
  @multibanco_payments
end

#mx_bank_transfer_paymentsObject

Allow the merchant to process Mexican bank transfer payments.



2876
2877
2878
# File 'lib/stripe/services/v2/core/account_service.rb', line 2876

def mx_bank_transfer_payments
  @mx_bank_transfer_payments
end

Allow the merchant to process Naver Pay payments.



2878
2879
2880
# File 'lib/stripe/services/v2/core/account_service.rb', line 2878

def naver_pay_payments
  @naver_pay_payments
end

#oxxo_paymentsObject

Allow the merchant to process OXXO payments.



2880
2881
2882
# File 'lib/stripe/services/v2/core/account_service.rb', line 2880

def oxxo_payments
  @oxxo_payments
end

#p24_paymentsObject

Allow the merchant to process Przelewy24 (P24) payments.



2882
2883
2884
# File 'lib/stripe/services/v2/core/account_service.rb', line 2882

def p24_payments
  @p24_payments
end

#pay_by_bank_paymentsObject

Allow the merchant to process Pay by Bank payments.



2884
2885
2886
# File 'lib/stripe/services/v2/core/account_service.rb', line 2884

def pay_by_bank_payments
  @pay_by_bank_payments
end

#payco_paymentsObject

Allow the merchant to process PAYCO payments.



2886
2887
2888
# File 'lib/stripe/services/v2/core/account_service.rb', line 2886

def payco_payments
  @payco_payments
end

#paynow_paymentsObject

Allow the merchant to process PayNow payments.



2888
2889
2890
# File 'lib/stripe/services/v2/core/account_service.rb', line 2888

def paynow_payments
  @paynow_payments
end

#promptpay_paymentsObject

Allow the merchant to process PromptPay payments.



2890
2891
2892
# File 'lib/stripe/services/v2/core/account_service.rb', line 2890

def promptpay_payments
  @promptpay_payments
end

#revolut_pay_paymentsObject

Allow the merchant to process Revolut Pay payments.



2892
2893
2894
# File 'lib/stripe/services/v2/core/account_service.rb', line 2892

def revolut_pay_payments
  @revolut_pay_payments
end

#samsung_pay_paymentsObject

Allow the merchant to process Samsung Pay payments.



2894
2895
2896
# File 'lib/stripe/services/v2/core/account_service.rb', line 2894

def samsung_pay_payments
  @samsung_pay_payments
end

#sepa_bank_transfer_paymentsObject

Allow the merchant to process SEPA bank transfer payments.



2896
2897
2898
# File 'lib/stripe/services/v2/core/account_service.rb', line 2896

def sepa_bank_transfer_payments
  @sepa_bank_transfer_payments
end

#sepa_debit_paymentsObject

Allow the merchant to process SEPA Direct Debit payments.



2898
2899
2900
# File 'lib/stripe/services/v2/core/account_service.rb', line 2898

def sepa_debit_payments
  @sepa_debit_payments
end

#swish_paymentsObject

Allow the merchant to process Swish payments.



2900
2901
2902
# File 'lib/stripe/services/v2/core/account_service.rb', line 2900

def swish_payments
  @swish_payments
end

#twint_paymentsObject

Allow the merchant to process TWINT payments.



2902
2903
2904
# File 'lib/stripe/services/v2/core/account_service.rb', line 2902

def twint_payments
  @twint_payments
end

#us_bank_transfer_paymentsObject

Allow the merchant to process US bank transfer payments.



2904
2905
2906
# File 'lib/stripe/services/v2/core/account_service.rb', line 2904

def us_bank_transfer_payments
  @us_bank_transfer_payments
end

#zip_paymentsObject

Allow the merchant to process Zip payments.



2906
2907
2908
# File 'lib/stripe/services/v2/core/account_service.rb', line 2906

def zip_payments
  @zip_payments
end