Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Merchant::CardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Merchant::CardPayments
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: DeclineOn
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
Instance Method Summary collapse
-
#initialize(decline_on: nil) ⇒ CardPayments
constructor
A new instance of CardPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(decline_on: nil) ⇒ CardPayments
Returns a new instance of CardPayments.
2843 2844 2845 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2843 def initialize(decline_on: nil) @decline_on = decline_on end |
Instance Attribute Details
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
2841 2842 2843 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 2841 def decline_on @decline_on end |