Class: Stripe::V2::Core::AccountService::UpdateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: BankAccounts, Cards, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
3181 3182 3183 3184 3185 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3181 def initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) @bank_accounts = bank_accounts @cards = cards @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
3175 3176 3177 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3175 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
3177 3178 3179 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3177 def cards @cards end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
3179 3180 3181 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3179 def stripe_balance @stripe_balance end |