Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



3165
3166
3167
3168
3169
3170
3171
3172
3173
3174
3175
# File 'lib/stripe/services/v2/core/account_service.rb', line 3165

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3157
3158
3159
# File 'lib/stripe/services/v2/core/account_service.rb', line 3157

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3159
3160
3161
# File 'lib/stripe/services/v2/core/account_service.rb', line 3159

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



3161
3162
3163
# File 'lib/stripe/services/v2/core/account_service.rb', line 3161

def persons_provided
  @persons_provided
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



3163
3164
3165
# File 'lib/stripe/services/v2/core/account_service.rb', line 3163

def terms_of_service
  @terms_of_service
end