Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
# File 'lib/stripe/services/v2/core/account_service.rb', line 3150

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3142
3143
3144
# File 'lib/stripe/services/v2/core/account_service.rb', line 3142

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3144
3145
3146
# File 'lib/stripe/services/v2/core/account_service.rb', line 3144

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



3146
3147
3148
# File 'lib/stripe/services/v2/core/account_service.rb', line 3146

def persons_provided
  @persons_provided
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



3148
3149
3150
# File 'lib/stripe/services/v2/core/account_service.rb', line 3148

def terms_of_service
  @terms_of_service
end