Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3104
3105
3106
3107
3108
# File 'lib/stripe/services/v2/core/account_service.rb', line 3104

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3098
3099
3100
# File 'lib/stripe/services/v2/core/account_service.rb', line 3098

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3100
3101
3102
# File 'lib/stripe/services/v2/core/account_service.rb', line 3100

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3102
3103
3104
# File 'lib/stripe/services/v2/core/account_service.rb', line 3102

def user_agent
  @user_agent
end