Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3089
3090
3091
3092
3093
# File 'lib/stripe/services/v2/core/account_service.rb', line 3089

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



3083
3084
3085
# File 'lib/stripe/services/v2/core/account_service.rb', line 3083

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3085
3086
3087
# File 'lib/stripe/services/v2/core/account_service.rb', line 3085

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3087
3088
3089
# File 'lib/stripe/services/v2/core/account_service.rb', line 3087

def user_agent
  @user_agent
end