Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



3437
3438
3439
3440
3441
3442
3443
3444
3445
3446
3447
# File 'lib/stripe/services/v2/core/account_service.rb', line 3437

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3429
3430
3431
# File 'lib/stripe/services/v2/core/account_service.rb', line 3429

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3431
3432
3433
# File 'lib/stripe/services/v2/core/account_service.rb', line 3431

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3433
3434
3435
# File 'lib/stripe/services/v2/core/account_service.rb', line 3433

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



3435
3436
3437
# File 'lib/stripe/services/v2/core/account_service.rb', line 3435

def ownership_exemption_reason
  @ownership_exemption_reason
end