Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
# File 'lib/stripe/services/v2/core/account_service.rb', line 3106

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3098
3099
3100
# File 'lib/stripe/services/v2/core/account_service.rb', line 3098

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3100
3101
3102
# File 'lib/stripe/services/v2/core/account_service.rb', line 3100

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



3102
3103
3104
# File 'lib/stripe/services/v2/core/account_service.rb', line 3102

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



3104
3105
3106
# File 'lib/stripe/services/v2/core/account_service.rb', line 3104

def ownership_exemption_reason
  @ownership_exemption_reason
end