Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
-
#registered_name ⇒ Object
The business legal name.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
3931 3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 3953 3954 3955 3956 3957 3958 3959 3960 3961 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3931 def initialize( address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @doing_business_as = doing_business_as @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @product_description = product_description @registered_name = registered_name @script_addresses = script_addresses @script_names = script_names @structure = structure @url = url end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
3903 3904 3905 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3903 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
3905 3906 3907 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3905 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
3907 3908 3909 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3907 def documents @documents end |
#doing_business_as ⇒ Object
The name which is used by the business.
3909 3910 3911 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3909 def doing_business_as @doing_business_as end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
3911 3912 3913 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3911 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
3913 3914 3915 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3913 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
3915 3916 3917 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3915 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
3917 3918 3919 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3917 def phone @phone end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
3919 3920 3921 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3919 def product_description @product_description end |
#registered_name ⇒ Object
The business legal name.
3921 3922 3923 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3921 def registered_name @registered_name end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
3923 3924 3925 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3923 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
3925 3926 3927 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3925 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
3927 3928 3929 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3927 def structure @structure end |
#url ⇒ Object
The business’s publicly available website.
3929 3930 3931 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3929 def url @url end |