Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3917
3918
3919
3920
3921
3922
3923
3924
3925
3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
# File 'lib/stripe/services/v2/core/account_service.rb', line 3917

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  doing_business_as: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  product_description: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil,
  url: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @doing_business_as = doing_business_as
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @product_description = product_description
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
  @url = url
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3889
3890
3891
# File 'lib/stripe/services/v2/core/account_service.rb', line 3889

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3891
3892
3893
# File 'lib/stripe/services/v2/core/account_service.rb', line 3891

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



3893
3894
3895
# File 'lib/stripe/services/v2/core/account_service.rb', line 3893

def documents
  @documents
end

#doing_business_asObject

The name which is used by the business.



3895
3896
3897
# File 'lib/stripe/services/v2/core/account_service.rb', line 3895

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3897
3898
3899
# File 'lib/stripe/services/v2/core/account_service.rb', line 3897

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3899
3900
3901
# File 'lib/stripe/services/v2/core/account_service.rb', line 3899

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3901
3902
3903
# File 'lib/stripe/services/v2/core/account_service.rb', line 3901

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3903
3904
3905
# File 'lib/stripe/services/v2/core/account_service.rb', line 3903

def phone
  @phone
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



3905
3906
3907
# File 'lib/stripe/services/v2/core/account_service.rb', line 3905

def product_description
  @product_description
end

#registered_nameObject

The business legal name.



3907
3908
3909
# File 'lib/stripe/services/v2/core/account_service.rb', line 3907

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3909
3910
3911
# File 'lib/stripe/services/v2/core/account_service.rb', line 3909

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3911
3912
3913
# File 'lib/stripe/services/v2/core/account_service.rb', line 3911

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3913
3914
3915
# File 'lib/stripe/services/v2/core/account_service.rb', line 3913

def structure
  @structure
end

#urlObject

The business’s publicly available website.



3915
3916
3917
# File 'lib/stripe/services/v2/core/account_service.rb', line 3915

def url
  @url
end