Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
-
#registered_name ⇒ Object
The business legal name.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3565 def initialize( address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @doing_business_as = doing_business_as @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @product_description = product_description @registered_name = registered_name @script_addresses = script_addresses @script_names = script_names @structure = structure @url = url end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
3537 3538 3539 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3537 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
3539 3540 3541 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3539 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
3541 3542 3543 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3541 def documents @documents end |
#doing_business_as ⇒ Object
The name which is used by the business.
3543 3544 3545 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3543 def doing_business_as @doing_business_as end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
3545 3546 3547 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3545 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
3547 3548 3549 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3547 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
3549 3550 3551 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3549 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
3551 3552 3553 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3551 def phone @phone end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
3553 3554 3555 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3553 def product_description @product_description end |
#registered_name ⇒ Object
The business legal name.
3555 3556 3557 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3555 def registered_name @registered_name end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
3557 3558 3559 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3557 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
3559 3560 3561 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3559 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
3561 3562 3563 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3561 def structure @structure end |
#url ⇒ Object
The business’s publicly available website.
3563 3564 3565 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3563 def url @url end |