Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, doing_business_as: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, product_description: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil, url: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3881
3882
3883
3884
3885
3886
3887
3888
3889
3890
3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
3904
3905
3906
3907
3908
3909
3910
3911
# File 'lib/stripe/services/v2/core/account_service.rb', line 3881

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  doing_business_as: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  product_description: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil,
  url: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @doing_business_as = doing_business_as
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @product_description = product_description
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
  @url = url
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3853
3854
3855
# File 'lib/stripe/services/v2/core/account_service.rb', line 3853

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3855
3856
3857
# File 'lib/stripe/services/v2/core/account_service.rb', line 3855

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



3857
3858
3859
# File 'lib/stripe/services/v2/core/account_service.rb', line 3857

def documents
  @documents
end

#doing_business_asObject

The name which is used by the business.



3859
3860
3861
# File 'lib/stripe/services/v2/core/account_service.rb', line 3859

def doing_business_as
  @doing_business_as
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



3861
3862
3863
# File 'lib/stripe/services/v2/core/account_service.rb', line 3861

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3863
3864
3865
# File 'lib/stripe/services/v2/core/account_service.rb', line 3863

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3865
3866
3867
# File 'lib/stripe/services/v2/core/account_service.rb', line 3865

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3867
3868
3869
# File 'lib/stripe/services/v2/core/account_service.rb', line 3867

def phone
  @phone
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



3869
3870
3871
# File 'lib/stripe/services/v2/core/account_service.rb', line 3869

def product_description
  @product_description
end

#registered_nameObject

The business legal name.



3871
3872
3873
# File 'lib/stripe/services/v2/core/account_service.rb', line 3871

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3873
3874
3875
# File 'lib/stripe/services/v2/core/account_service.rb', line 3873

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3875
3876
3877
# File 'lib/stripe/services/v2/core/account_service.rb', line 3875

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3877
3878
3879
# File 'lib/stripe/services/v2/core/account_service.rb', line 3877

def structure
  @structure
end

#urlObject

The business’s publicly available website.



3879
3880
3881
# File 'lib/stripe/services/v2/core/account_service.rb', line 3879

def url
  @url
end