Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
A document verifying the business.
-
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
Returns a new instance of Documents.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3744 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @primary_verification = primary_verification @proof_of_address = proof_of_address @proof_of_registration = proof_of_registration @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
3724 3725 3726 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3724 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
3726 3727 3728 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3726 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
3728 3729 3730 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3728 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
3730 3731 3732 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3730 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
3732 3733 3734 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3732 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
3734 3735 3736 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3734 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object
A document verifying the business.
3736 3737 3738 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3736 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
3738 3739 3740 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3738 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
3740 3741 3742 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3740 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
3742 3743 3744 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3742 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |