Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
# File 'lib/stripe/services/v2/core/account_service.rb', line 4151

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



4141
4142
4143
# File 'lib/stripe/services/v2/core/account_service.rb', line 4141

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



4143
4144
4145
# File 'lib/stripe/services/v2/core/account_service.rb', line 4143

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



4145
4146
4147
# File 'lib/stripe/services/v2/core/account_service.rb', line 4145

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



4147
4148
4149
# File 'lib/stripe/services/v2/core/account_service.rb', line 4147

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



4149
4150
4151
# File 'lib/stripe/services/v2/core/account_service.rb', line 4149

def visa
  @visa
end