Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
# File 'lib/stripe/services/v2/core/account_service.rb', line 4154

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



4144
4145
4146
# File 'lib/stripe/services/v2/core/account_service.rb', line 4144

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



4146
4147
4148
# File 'lib/stripe/services/v2/core/account_service.rb', line 4146

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



4148
4149
4150
# File 'lib/stripe/services/v2/core/account_service.rb', line 4148

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



4150
4151
4152
# File 'lib/stripe/services/v2/core/account_service.rb', line 4150

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



4152
4153
4154
# File 'lib/stripe/services/v2/core/account_service.rb', line 4152

def title
  @title
end