Class: Stripe::V2::Core::AccountService::UpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountService::UpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/services/v2/core/account_service.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3815 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
3805 3806 3807 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3805 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
3807 3808 3809 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3807 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
3809 3810 3811 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3809 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
3811 3812 3813 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3811 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
3813 3814 3815 |
# File 'lib/stripe/services/v2/core/account_service.rb', line 3813 def title @title end |