Class: Stripe::V2::Core::AccountTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams

Returns a new instance of AccountTokenCreateParams.



1341
1342
1343
1344
1345
1346
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1341

def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil)
  @contact_email = contact_email
  @contact_phone = contact_phone
  @display_name = display_name
  @identity = identity
end

Instance Attribute Details

#contact_emailObject

The primary contact email address for the Account.



1333
1334
1335
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1333

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



1335
1336
1337
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1335

def contact_phone
  @contact_phone
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



1337
1338
1339
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1337

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



1339
1340
1341
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1339

def identity
  @identity
end

Class Method Details

.field_encodingsObject



1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1348

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end