Class: Stripe::V2::Core::AccountTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams

Returns a new instance of AccountTokenCreateParams.



1100
1101
1102
1103
1104
1105
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1100

def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil)
  @contact_email = contact_email
  @contact_phone = contact_phone
  @display_name = display_name
  @identity = identity
end

Instance Attribute Details

#contact_emailObject

The primary contact email address for the Account.



1092
1093
1094
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1092

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



1094
1095
1096
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1094

def contact_phone
  @contact_phone
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



1096
1097
1098
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1096

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



1098
1099
1100
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1098

def identity
  @identity
end

Class Method Details

.field_encodingsObject



1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1107

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end