Class: Stripe::V2::Core::AccountTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Identity
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
constructor
A new instance of AccountTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
Returns a new instance of AccountTokenCreateParams.
1293 1294 1295 1296 1297 1298 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1293 def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) @contact_email = contact_email @contact_phone = contact_phone @display_name = display_name @identity = identity end |
Instance Attribute Details
#contact_email ⇒ Object
The primary contact email address for the Account.
1285 1286 1287 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1285 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
1287 1288 1289 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1287 def contact_phone @contact_phone end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1289 1290 1291 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1289 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
1291 1292 1293 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1291 def identity @identity end |
Class Method Details
.field_encodings ⇒ Object
1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1300 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |