Class: Stripe::V2::Core::AccountTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Identity
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
constructor
A new instance of AccountTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
Returns a new instance of AccountTokenCreateParams.
1057 1058 1059 1060 1061 1062 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1057 def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) @contact_email = contact_email @contact_phone = contact_phone @display_name = display_name @identity = identity end |
Instance Attribute Details
#contact_email ⇒ Object
The primary contact email address for the Account.
1049 1050 1051 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1049 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
1051 1052 1053 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1051 def contact_phone @contact_phone end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1053 1054 1055 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1053 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
1055 1056 1057 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1055 def identity @identity end |
Class Method Details
.field_encodings ⇒ Object
1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1064 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |