Class: Stripe::V2::Core::AccountTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Identity
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
constructor
A new instance of AccountTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
Returns a new instance of AccountTokenCreateParams.
1045 1046 1047 1048 1049 1050 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1045 def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) @contact_email = contact_email @contact_phone = contact_phone @display_name = display_name @identity = identity end |
Instance Attribute Details
#contact_email ⇒ Object
The primary contact email address for the Account.
1037 1038 1039 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1037 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
1039 1040 1041 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1039 def contact_phone @contact_phone end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1041 1042 1043 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1041 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
1043 1044 1045 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1043 def identity @identity end |
Class Method Details
.field_encodings ⇒ Object
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1052 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |