Class: Stripe::V2::Core::AccountTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams

Returns a new instance of AccountTokenCreateParams.



1271
1272
1273
1274
1275
1276
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1271

def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil)
  @contact_email = contact_email
  @contact_phone = contact_phone
  @display_name = display_name
  @identity = identity
end

Instance Attribute Details

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



1263
1264
1265
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1263

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



1265
1266
1267
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1265

def contact_phone
  @contact_phone
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



1267
1268
1269
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1267

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



1269
1270
1271
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1269

def identity
  @identity
end

Class Method Details

.field_encodingsObject



1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1278

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end