Class: Stripe::V2::Core::AccountTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Identity
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
Instance Method Summary collapse
-
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
constructor
A new instance of AccountTokenCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
Returns a new instance of AccountTokenCreateParams.
1272 1273 1274 1275 1276 1277 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1272 def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) @contact_email = contact_email @contact_phone = contact_phone @display_name = display_name @identity = identity end |
Instance Attribute Details
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
1264 1265 1266 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1264 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
1266 1267 1268 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1266 def contact_phone @contact_phone end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1268 1269 1270 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1268 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
1270 1271 1272 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1270 def identity @identity end |