Class: Stripe::V2::Core::AccountTokenCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams

Returns a new instance of AccountTokenCreateParams.



1036
1037
1038
1039
1040
1041
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1036

def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil)
  @contact_email = contact_email
  @contact_phone = contact_phone
  @display_name = display_name
  @identity = identity
end

Instance Attribute Details

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



1028
1029
1030
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1028

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



1030
1031
1032
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1030

def contact_phone
  @contact_phone
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



1032
1033
1034
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1032

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



1034
1035
1036
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1034

def identity
  @identity
end