Class: Stripe::V2::Core::AccountTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Identity
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
Instance Method Summary collapse
-
#initialize(contact_email: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
constructor
A new instance of AccountTokenCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(contact_email: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
Returns a new instance of AccountTokenCreateParams.
1251 1252 1253 1254 1255 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1251 def initialize(contact_email: nil, display_name: nil, identity: nil) @contact_email = contact_email @display_name = display_name @identity = identity end |
Instance Attribute Details
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
1245 1246 1247 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1245 def contact_email @contact_email end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1247 1248 1249 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1247 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
1249 1250 1251 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1249 def identity @identity end |