Class: Stripe::V2::Core::AccountTokenCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Identity
Instance Attribute Summary collapse
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
constructor
A new instance of AccountTokenCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) ⇒ AccountTokenCreateParams
Returns a new instance of AccountTokenCreateParams.
1023 1024 1025 1026 1027 1028 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1023 def initialize(contact_email: nil, contact_phone: nil, display_name: nil, identity: nil) @contact_email = contact_email @contact_phone = contact_phone @display_name = display_name @identity = identity end |
Instance Attribute Details
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
1015 1016 1017 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1015 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
1017 1018 1019 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1017 def contact_phone @contact_phone end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
1019 1020 1021 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1019 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
1021 1022 1023 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1021 def identity @identity end |
Class Method Details
.field_encodings ⇒ Object
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1030 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |