Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct; IP, date, and User Agent are expanded by Stripe.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct; IP, date, and User Agent are expanded by Stripe.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity; IP, date, and User Agent are expanded by Stripe.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 331 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @representative_declaration = representative_declaration @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct; IP, date, and User Agent are expanded by Stripe.
321 322 323 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 321 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct; IP, date, and User Agent are expanded by Stripe.
323 324 325 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 323 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
325 326 327 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 325 def persons_provided @persons_provided end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity; IP, date, and User Agent are expanded by Stripe.
327 328 329 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 327 def representative_declaration @representative_declaration end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
329 330 331 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 329 def terms_of_service @terms_of_service end |