Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Attestations::TermsOfService

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Account, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, storer: nil) ⇒ TermsOfService

Returns a new instance of TermsOfService.



83
84
85
86
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 83

def initialize(account: nil, storer: nil)
  @account = 
  @storer = storer
end

Instance Attribute Details

#accountObject

Details on the Account’s acceptance of the [Stripe Services Agreement]; IP, date, and User Agent are expanded by Stripe.



79
80
81
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 79

def 
  @account
end

#storerObject

Details on the Account’s acceptance of Treasury-specific terms of service; IP, date, and User Agent are expanded by Stripe.



81
82
83
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 81

def storer
  @storer
end