Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Attestations::TermsOfService
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Attestations::TermsOfService
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Account, CardCreator, CryptoStorer, Storer
Instance Attribute Summary collapse
-
#account ⇒ Object
Details on the Account’s acceptance of the [Stripe Services Agreement]; IP, date, and User Agent are expanded by Stripe.
-
#card_creator ⇒ Object
Details on the Account’s acceptance of Issuing-specific terms of service.
-
#crypto_storer ⇒ Object
Details on the Account’s acceptance of Crypto-storer-specific terms of service; IP, date, and User Agent are expanded by Stripe.
-
#storer ⇒ Object
Details on the Account’s acceptance of Treasury-specific terms of service; IP, date, and User Agent are expanded by Stripe.
Instance Method Summary collapse
-
#initialize(account: nil, card_creator: nil, crypto_storer: nil, storer: nil) ⇒ TermsOfService
constructor
A new instance of TermsOfService.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, card_creator: nil, crypto_storer: nil, storer: nil) ⇒ TermsOfService
Returns a new instance of TermsOfService.
313 314 315 316 317 318 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 313 def initialize(account: nil, card_creator: nil, crypto_storer: nil, storer: nil) @account = account @card_creator = card_creator @crypto_storer = crypto_storer @storer = storer end |
Instance Attribute Details
#account ⇒ Object
Details on the Account’s acceptance of the [Stripe Services Agreement]; IP, date, and User Agent are expanded by Stripe.
305 306 307 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 305 def account @account end |
#card_creator ⇒ Object
Details on the Account’s acceptance of Issuing-specific terms of service.
307 308 309 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 307 def card_creator @card_creator end |
#crypto_storer ⇒ Object
Details on the Account’s acceptance of Crypto-storer-specific terms of service; IP, date, and User Agent are expanded by Stripe.
309 310 311 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 309 def crypto_storer @crypto_storer end |
#storer ⇒ Object
Details on the Account’s acceptance of Treasury-specific terms of service; IP, date, and User Agent are expanded by Stripe.
311 312 313 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 311 def storer @storer end |