Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business's compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 814 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
786 787 788 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 786 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
788 789 790 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 788 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
790 791 792 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 790 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business's compliance and anti-money laundering controls and practices.
792 793 794 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 792 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
794 795 796 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 794 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
796 797 798 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 796 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
798 799 800 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 798 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
800 801 802 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 800 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
802 803 804 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 802 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
804 805 806 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 804 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
806 807 808 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 806 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
808 809 810 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 808 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
810 811 812 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 810 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
812 813 814 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 812 def structure @structure end |