Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 563

def initialize(
  additional_addresses: nil,
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @additional_addresses = additional_addresses
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#additional_addressesObject

Additional addresses associated with the business.



537
538
539
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 537

def additional_addresses
  @additional_addresses
end

#addressObject

The business registration address of the business entity.



539
540
541
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 539

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



541
542
543
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 541

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



543
544
545
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 543

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



545
546
547
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 545

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



547
548
549
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 547

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



549
550
551
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 549

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



551
552
553
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 551

def phone
  @phone
end

#registered_nameObject

The business legal name.



553
554
555
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 553

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



555
556
557
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 555

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



557
558
559
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 557

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



559
560
561
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 559

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



561
562
563
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 561

def structure
  @structure
end