Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 534

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



510
511
512
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 510

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



512
513
514
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 512

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



514
515
516
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 514

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



516
517
518
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 516

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



518
519
520
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 518

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



520
521
522
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 520

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



522
523
524
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 522

def phone
  @phone
end

#registered_nameObject

The business legal name.



524
525
526
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 524

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



526
527
528
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 526

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



528
529
530
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 528

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



530
531
532
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 530

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



532
533
534
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 532

def structure
  @structure
end