Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 746

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



720
721
722
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 720

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



722
723
724
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 722

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



724
725
726
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 724

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



726
727
728
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 726

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



728
729
730
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 728

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



730
731
732
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 730

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



732
733
734
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 732

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



734
735
736
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 734

def phone
  @phone
end

#registered_nameObject

The business legal name.



736
737
738
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 736

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



738
739
740
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 738

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



740
741
742
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 740

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



742
743
744
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 742

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



744
745
746
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 744

def structure
  @structure
end