Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 512 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
488 489 490 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 488 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
490 491 492 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 490 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
492 493 494 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 492 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
494 495 496 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 494 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
496 497 498 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 496 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
498 499 500 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 498 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
500 501 502 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 500 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
502 503 504 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 502 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
504 505 506 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 504 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
506 507 508 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 506 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
508 509 510 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 508 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
510 511 512 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 510 def structure @structure end |