Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 768 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
742 743 744 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 742 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
744 745 746 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 744 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
746 747 748 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 746 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
748 749 750 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 748 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
750 751 752 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 750 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
752 753 754 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 752 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
754 755 756 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 754 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
756 757 758 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 756 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
758 759 760 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 758 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
760 761 762 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 760 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
762 763 764 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 762 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
764 765 766 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 764 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
766 767 768 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 766 def structure @structure end |