Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 751 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
727 728 729 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 727 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
729 730 731 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 729 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
731 732 733 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 731 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
733 734 735 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 733 def documents @documents end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
735 736 737 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 735 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
737 738 739 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 737 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
739 740 741 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 739 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
741 742 743 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 741 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
743 744 745 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 743 def registered_name @registered_name end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
745 746 747 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 745 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
747 748 749 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 747 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
749 750 751 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 749 def structure @structure end |