Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
A document verifying the business.
-
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
Returns a new instance of Documents.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 375 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @primary_verification = primary_verification @proof_of_address = proof_of_address @proof_of_registration = proof_of_registration @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
355 356 357 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 355 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
357 358 359 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 357 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
359 360 361 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 359 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
361 362 363 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 361 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
363 364 365 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 363 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
365 366 367 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 365 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object
A document verifying the business.
367 368 369 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 367 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
369 370 371 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 369 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
371 372 373 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 371 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
373 374 375 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 373 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |