Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 972 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
938 939 940 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 938 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
940 941 942 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 940 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
942 943 944 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 942 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
944 945 946 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 944 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
946 947 948 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 946 def documents @documents end |
#email ⇒ Object
The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
948 949 950 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 948 def email @email end |
#given_name ⇒ Object
The individual’s first name.
950 951 952 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 950 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
952 953 954 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 952 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
954 955 956 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 954 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
956 957 958 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 956 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
958 959 960 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 958 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
960 961 962 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 960 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
962 963 964 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 962 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
964 965 966 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 964 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
966 967 968 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 966 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
968 969 970 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 968 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
970 971 972 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 970 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
1010 1011 1012 1013 1014 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1010 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |