Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person's passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person's name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person's visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1048 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
1038 1039 1040 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1038 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person's passport page with photo and personal data.
1040 1041 1042 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1040 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person's name, either a passport or local ID card.
1042 1043 1044 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1042 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
1044 1045 1046 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1044 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person's visa required for living in the country where they are residing.
1046 1047 1048 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1046 def visa @visa end |