Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



795
796
797
798
799
800
801
802
803
804
805
806
807
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 795

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



785
786
787
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 785

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



787
788
789
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 787

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person's name, either a passport or local ID card.



789
790
791
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 789

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



791
792
793
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 791

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



793
794
795
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 793

def visa
  @visa
end