Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 764

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



754
755
756
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 754

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



756
757
758
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 756

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



758
759
760
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 758

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



760
761
762
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 760

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



762
763
764
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 762

def visa
  @visa
end