Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



981
982
983
984
985
986
987
988
989
990
991
992
993
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 981

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



971
972
973
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 971

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



973
974
975
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 973

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



975
976
977
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 975

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



977
978
979
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 977

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



979
980
981
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 979

def visa
  @visa
end