Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 846

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



836
837
838
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 836

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



838
839
840
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 838

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



840
841
842
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 840

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account's legal entity.



842
843
844
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 842

def percent_ownership
  @percent_ownership
end

#titleObject

The person's title (e.g., CEO, Support Engineer).



844
845
846
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 844

def title
  @title
end

Class Method Details

.field_encodingsObject



860
861
862
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 860

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end