Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_token_create_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



781
782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 781

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



771
772
773
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 771

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



773
774
775
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 773

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



775
776
777
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 775

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



777
778
779
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 777

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



779
780
781
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 779

def title
  @title
end

Class Method Details

.field_encodingsObject



795
796
797
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 795

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end