Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 781 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
771 772 773 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 771 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
773 774 775 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 773 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
775 776 777 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 775 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
777 778 779 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 777 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
779 780 781 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 779 def title @title end |
Class Method Details
.field_encodings ⇒ Object
795 796 797 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 795 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |