Class: Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountTokenCreateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_token_create_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1017 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1007 1008 1009 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1007 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1009 1010 1011 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1009 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
1011 1012 1013 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1011 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
1013 1014 1015 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1013 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
1015 1016 1017 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1015 def title @title end |
Class Method Details
.field_encodings ⇒ Object
1031 1032 1033 |
# File 'lib/stripe/params/v2/core/account_token_create_params.rb', line 1031 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |