Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
6237 6238 6239 6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6237 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
6217 6218 6219 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6217 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
6219 6220 6221 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6219 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
6221 6222 6223 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6221 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
6223 6224 6225 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6223 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
6225 6226 6227 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6225 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
6227 6228 6229 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6227 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
6229 6230 6231 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6229 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
6231 6232 6233 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6231 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
6233 6234 6235 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6233 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
6235 6236 6237 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6235 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
6261 6262 6263 6264 6265 6266 6267 6268 6269 6270 6271 6272 6273 6274 6275 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6261 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |