Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2243

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



2223
2224
2225
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2223

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2225
2226
2227
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2225

def configuration
  @configuration
end

#contact_emailObject

The primary contact email address for the Account.



2227
2228
2229
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2227

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



2229
2230
2231
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2229

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2231
2232
2233
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2231

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2233
2234
2235
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2233

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2235
2236
2237
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2235

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2237
2238
2239
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2237

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2239
2240
2241
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2239

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2241
2242
2243
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2241

def 
  @metadata
end

Class Method Details

.field_encodingsObject



2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2267

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end