Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2634 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2614 2615 2616 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2614 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2616 2617 2618 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2616 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
2618 2619 2620 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2618 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2620 2621 2622 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2620 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2622 2623 2624 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2622 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2624 2625 2626 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2624 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2626 2627 2628 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2626 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2628 2629 2630 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2628 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2630 2631 2632 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2630 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2632 2633 2634 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2632 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2658 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |