Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2591 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2571 2572 2573 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2571 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2573 2574 2575 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2573 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
2575 2576 2577 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2575 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2577 2578 2579 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2577 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2579 2580 2581 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2579 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2581 2582 2583 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2581 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2583 2584 2585 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2583 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2585 2586 2587 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2585 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2587 2588 2589 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2587 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2589 2590 2591 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2589 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2615 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |