Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3847

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3827
3828
3829
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3827

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3829
3830
3831
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3829

def configuration
  @configuration
end

#contact_emailObject

The primary contact email address for the Account.



3831
3832
3833
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3831

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3833
3834
3835
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3833

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3835
3836
3837
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3835

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3837
3838
3839
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3837

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3839
3840
3841
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3839

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3841
3842
3843
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3841

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3843
3844
3845
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3843

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3845
3846
3847
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3845

def 
  @metadata
end

Class Method Details

.field_encodingsObject



3871
3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3871

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end