Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2457 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2437 2438 2439 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2437 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2439 2440 2441 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2439 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
2441 2442 2443 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2441 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2443 2444 2445 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2443 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2445 2446 2447 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2445 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2447 2448 2449 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2447 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2449 2450 2451 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2449 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2451 2452 2453 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2451 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2453 2454 2455 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2453 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2455 2456 2457 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2455 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2481 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |