Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2187

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



2167
2168
2169
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2167

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2169
2170
2171
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2169

def configuration
  @configuration
end

#contact_emailObject

The primary contact email address for the Account.



2171
2172
2173
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2171

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



2173
2174
2175
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2173

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2175
2176
2177
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2175

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2177
2178
2179
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2177

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2179
2180
2181
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2179

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2181
2182
2183
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2181

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2183
2184
2185
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2183

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2185
2186
2187
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2185

def 
  @metadata
end

Class Method Details

.field_encodingsObject



2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2211

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end