Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The primary contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
3822 3823 3824 3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3822 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
3802 3803 3804 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3802 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
3804 3805 3806 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3804 def configuration @configuration end |
#contact_email ⇒ Object
The primary contact email address for the Account.
3806 3807 3808 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3806 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
3808 3809 3810 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3808 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
3810 3811 3812 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3810 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
3812 3813 3814 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3812 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
3814 3815 3816 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3814 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
3816 3817 3818 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3816 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
3818 3819 3820 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3818 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3820 3821 3822 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3820 def @metadata end |
Class Method Details
.field_encodings ⇒ Object
3846 3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3846 def self.field_encodings @field_encodings = { identity: { kind: :object, fields: { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, }, }, } end |