Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3722

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3702
3703
3704
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3702

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3704
3705
3706
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3704

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3706
3707
3708
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3706

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3708
3709
3710
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3708

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3710
3711
3712
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3710

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3712
3713
3714
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3712

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3714
3715
3716
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3714

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3716
3717
3718
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3716

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3718
3719
3720
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3718

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3720
3721
3722
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3720

def 
  @metadata
end

Class Method Details

.field_encodingsObject



3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3746

def self.field_encodings
  @field_encodings = {
    identity: {
      kind: :object,
      fields: {
        individual: {
          kind: :object,
          fields: {
            relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
          },
        },
      },
    },
  }
end