Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



3149
3150
3151
3152
3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
3165
3166
3167
3168
3169
3170
3171
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3149

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3129
3130
3131
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3129

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3131
3132
3133
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3131

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3133
3134
3135
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3133

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3135
3136
3137
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3135

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3137
3138
3139
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3137

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3139
3140
3141
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3139

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3141
3142
3143
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3141

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3143
3144
3145
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3143

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3145
3146
3147
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3145

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3147
3148
3149
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3147

def 
  @metadata
end