Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



3671
3672
3673
3674
3675
3676
3677
3678
3679
3680
3681
3682
3683
3684
3685
3686
3687
3688
3689
3690
3691
3692
3693
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3671

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3651
3652
3653
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3651

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3653
3654
3655
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3653

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3655
3656
3657
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3655

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3657
3658
3659
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3657

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3659
3660
3661
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3659

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3661
3662
3663
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3661

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3663
3664
3665
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3663

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3665
3666
3667
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3665

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3667
3668
3669
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3667

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3669
3670
3671
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3669

def 
  @metadata
end