Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3099

def initialize(
  account_token: nil,
  configuration: nil,
  contact_email: nil,
  contact_phone: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @account_token = 
  @configuration = configuration
  @contact_email = contact_email
  @contact_phone = contact_phone
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#account_tokenObject

The account token generated by the account token api.



3079
3080
3081
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3079

def 
  @account_token
end

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



3081
3082
3083
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3081

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



3083
3084
3085
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3083

def contact_email
  @contact_email
end

#contact_phoneObject

The default contact phone for the Account.



3085
3086
3087
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3085

def contact_phone
  @contact_phone
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



3087
3088
3089
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3087

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



3089
3090
3091
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3089

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



3091
3092
3093
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3091

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



3093
3094
3095
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3093

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



3095
3096
3097
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3095

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



3097
3098
3099
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3097

def 
  @metadata
end