Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#contact_phone ⇒ Object
The default contact phone for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2406 def initialize( account_token: nil, configuration: nil, contact_email: nil, contact_phone: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @contact_phone = contact_phone @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
2386 2387 2388 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2386 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2388 2389 2390 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2388 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2390 2391 2392 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2390 def contact_email @contact_email end |
#contact_phone ⇒ Object
The default contact phone for the Account.
2392 2393 2394 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2392 def contact_phone @contact_phone end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2394 2395 2396 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2394 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2396 2397 2398 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2396 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2398 2399 2400 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2398 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2400 2401 2402 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2400 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2402 2403 2404 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2402 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2404 2405 2406 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2404 def @metadata end |