Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#account_token ⇒ Object
The account token generated by the account token api.
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3078 def initialize( account_token: nil, configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @account_token = account_token @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#account_token ⇒ Object
The account token generated by the account token api.
3060 3061 3062 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3060 def account_token @account_token end |
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
3062 3063 3064 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3062 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
3064 3065 3066 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3064 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
3066 3067 3068 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3066 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
3068 3069 3070 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3068 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
3070 3071 3072 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3070 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
3072 3073 3074 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3072 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
3074 3075 3076 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3074 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3076 3077 3078 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3076 def @metadata end |