Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2953 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2937 2938 2939 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2937 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2939 2940 2941 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2939 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2941 2942 2943 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2941 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2943 2944 2945 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2943 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2945 2946 2947 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2945 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2947 2948 2949 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2947 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2949 2950 2951 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2949 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2951 2952 2953 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2951 def @metadata end |