Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2839

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2823
2824
2825
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2823

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2825
2826
2827
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2825

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2827
2828
2829
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2827

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2829
2830
2831
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2829

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2831
2832
2833
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2831

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2833
2834
2835
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2833

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2835
2836
2837
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2835

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2837
2838
2839
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2837

def 
  @metadata
end