Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2698 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2682 2683 2684 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2682 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2684 2685 2686 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2684 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2686 2687 2688 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2686 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2688 2689 2690 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2688 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2690 2691 2692 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2690 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2692 2693 2694 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2692 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2694 2695 2696 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2694 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2696 2697 2698 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2696 def @metadata end |