Class: Stripe::V2::Core::AccountUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Configuration, Defaults, Identity
Instance Attribute Summary collapse
-
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
-
#contact_email ⇒ Object
The default contact email address for the Account.
-
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to.
-
#defaults ⇒ Object
Default values to be used on Account Configurations.
-
#display_name ⇒ Object
A descriptive name for the Account.
-
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
-
#include ⇒ Object
Additional fields to include in the response.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
Instance Method Summary collapse
-
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
constructor
A new instance of AccountUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams
Returns a new instance of AccountUpdateParams.
2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2667 def initialize( configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil ) @configuration = configuration @contact_email = contact_email @dashboard = dashboard @defaults = defaults @display_name = display_name @identity = identity @include = include @metadata = end |
Instance Attribute Details
#configuration ⇒ Object
An Account Configuration which allows the Account to take on a key persona across Stripe products.
2651 2652 2653 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2651 def configuration @configuration end |
#contact_email ⇒ Object
The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
2653 2654 2655 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2653 def contact_email @contact_email end |
#dashboard ⇒ Object
A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
2655 2656 2657 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2655 def dashboard @dashboard end |
#defaults ⇒ Object
Default values to be used on Account Configurations.
2657 2658 2659 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2657 def defaults @defaults end |
#display_name ⇒ Object
A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
2659 2660 2661 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2659 def display_name @display_name end |
#identity ⇒ Object
Information about the company, individual, and business represented by the Account.
2661 2662 2663 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2661 def identity @identity end |
#include ⇒ Object
Additional fields to include in the response.
2663 2664 2665 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2663 def include @include end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2665 2666 2667 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2665 def @metadata end |