Class: Stripe::V2::Core::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Configuration, Defaults, Identity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(configuration: nil, contact_email: nil, dashboard: nil, defaults: nil, display_name: nil, identity: nil, include: nil, metadata: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2240

def initialize(
  configuration: nil,
  contact_email: nil,
  dashboard: nil,
  defaults: nil,
  display_name: nil,
  identity: nil,
  include: nil,
  metadata: nil
)
  @configuration = configuration
  @contact_email = contact_email
  @dashboard = dashboard
  @defaults = defaults
  @display_name = display_name
  @identity = identity
  @include = include
  @metadata = 
end

Instance Attribute Details

#configurationObject

An Account Configuration which allows the Account to take on a key persona across Stripe products.



2224
2225
2226
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2224

def configuration
  @configuration
end

#contact_emailObject

The default contact email address for the Account. Required when configuring the account as a merchant or recipient.



2226
2227
2228
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2226

def contact_email
  @contact_email
end

#dashboardObject

A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.



2228
2229
2230
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2228

def dashboard
  @dashboard
end

#defaultsObject

Default values to be used on Account Configurations.



2230
2231
2232
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2230

def defaults
  @defaults
end

#display_nameObject

A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.



2232
2233
2234
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2232

def display_name
  @display_name
end

#identityObject

Information about the company, individual, and business represented by the Account.



2234
2235
2236
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2234

def identity
  @identity
end

#includeObject

Additional fields to include in the response.



2236
2237
2238
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2236

def include
  @include
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2238
2239
2240
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2238

def 
  @metadata
end