Class: Stripe::V2::Core::AccountUpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, MoneyManager, Recipient
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#money_manager ⇒ Object
The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
Instance Method Summary collapse
-
#initialize(card_creator: nil, customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card_creator: nil, customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration
Returns a new instance of Configuration.
4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4093 def initialize( card_creator: nil, customer: nil, merchant: nil, money_manager: nil, recipient: nil ) @card_creator = card_creator @customer = customer @merchant = merchant @money_manager = money_manager @recipient = recipient end |
Instance Attribute Details
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
4083 4084 4085 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4083 def card_creator @card_creator end |
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
4085 4086 4087 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4085 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
4087 4088 4089 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4087 def merchant @merchant end |
#money_manager ⇒ Object
The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
4089 4090 4091 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4089 def money_manager @money_manager end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
4091 4092 4093 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 4091 def recipient @recipient end |