Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil) ⇒ Configuration

Returns a new instance of Configuration.



1036
1037
1038
1039
1040
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1036

def initialize(customer: nil, merchant: nil, recipient: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be charged.



1030
1031
1032
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1030

def customer
  @customer
end

#merchantObject

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



1032
1033
1034
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1032

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



1034
1035
1036
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1034

def recipient
  @recipient
end