Class: Stripe::V2::Core::AccountUpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Customer, Merchant, MoneyManager, Recipient
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#money_manager ⇒ Object
The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, merchant: nil, money_manager: nil, recipient: nil) ⇒ Configuration
Returns a new instance of Configuration.
1417 1418 1419 1420 1421 1422 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1417 def initialize(customer: nil, merchant: nil, money_manager: nil, recipient: nil) @customer = customer @merchant = merchant @money_manager = money_manager @recipient = recipient end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
1409 1410 1411 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1409 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1411 1412 1413 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1411 def merchant @merchant end |
#money_manager ⇒ Object
The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
1413 1414 1415 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1413 def money_manager @money_manager end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1415 1416 1417 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1415 def recipient @recipient end |