Class: Stripe::V2::Core::AccountUpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1283 1284 1285 1286 1287 1288 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1283 def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
1275 1276 1277 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1275 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1277 1278 1279 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1277 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1279 1280 1281 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1279 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1281 1282 1283 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1281 def storer @storer end |