Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1602

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1592
1593
1594
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1592

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be charged.



1594
1595
1596
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1594

def customer
  @customer
end

#merchantObject

Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.



1596
1597
1598
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1596

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.



1598
1599
1600
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1598

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1600
1601
1602
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1600

def storer
  @storer
end