Class: Stripe::V2::Core::AccountUpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1262 1263 1264 1265 1266 1267 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1262 def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
1254 1255 1256 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1254 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1256 1257 1258 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1256 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1258 1259 1260 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1258 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1260 1261 1262 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1260 def storer @storer end |