Class: Stripe::V2::Core::AccountUpdateParams::Configuration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: CardCreator, Customer, Merchant, Recipient, Storer
Instance Attribute Summary collapse
-
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
-
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
-
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform.
-
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds.
-
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
Instance Method Summary collapse
-
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
constructor
A new instance of Configuration.
Methods inherited from RequestParams
Constructor Details
#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration
Returns a new instance of Configuration.
1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1552 def initialize( card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil ) @card_creator = card_creator @customer = customer @merchant = merchant @recipient = recipient @storer = storer end |
Instance Attribute Details
#card_creator ⇒ Object
The CardCreator Configuration allows the Account to create and issue cards to users.
1542 1543 1544 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1542 def card_creator @card_creator end |
#customer ⇒ Object
The Customer Configuration allows the Account to be charged.
1544 1545 1546 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1544 def customer @customer end |
#merchant ⇒ Object
Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
1546 1547 1548 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1546 def merchant @merchant end |
#recipient ⇒ Object
The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
1548 1549 1550 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1548 def recipient @recipient end |
#storer ⇒ Object
The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.
1550 1551 1552 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1550 def storer @storer end |