Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1540

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1530
1531
1532
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1530

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be charged.



1532
1533
1534
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1532

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1534
1535
1536
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1534

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1536
1537
1538
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1536

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1538
1539
1540
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1538

def storer
  @storer
end