Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1451

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1441
1442
1443
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1441

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be charged.



1443
1444
1445
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1443

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1445
1446
1447
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1445

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1447
1448
1449
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1447

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1449
1450
1451
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1449

def storer
  @storer
end