Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1431

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1421
1422
1423
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1421

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be charged.



1423
1424
1425
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1423

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1425
1426
1427
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1425

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1427
1428
1429
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1427

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1429
1430
1431
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1429

def storer
  @storer
end