Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CardCreator, Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_creator: nil, customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1300

def initialize(
  card_creator: nil,
  customer: nil,
  merchant: nil,
  recipient: nil,
  storer: nil
)
  @card_creator = card_creator
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#card_creatorObject

The CardCreator Configuration allows the Account to create and issue cards to users.



1290
1291
1292
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1290

def card_creator
  @card_creator
end

#customerObject

The Customer Configuration allows the Account to be charged.



1292
1293
1294
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1292

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1294
1295
1296
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1294

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1296
1297
1298
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1296

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1298
1299
1300
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1298

def storer
  @storer
end