Class: Stripe::V2::Core::AccountUpdateParams::Configuration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Customer, Merchant, Recipient, Storer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, merchant: nil, recipient: nil, storer: nil) ⇒ Configuration

Returns a new instance of Configuration.



1178
1179
1180
1181
1182
1183
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1178

def initialize(customer: nil, merchant: nil, recipient: nil, storer: nil)
  @customer = customer
  @merchant = merchant
  @recipient = recipient
  @storer = storer
end

Instance Attribute Details

#customerObject

The Customer Configuration allows the Account to be charged.



1170
1171
1172
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1170

def customer
  @customer
end

#merchantObject

The Merchant configuration allows the Account to act as a connected account and collect payments facilitated by a Connect platform. You can add this configuration to your connected accounts only if you’ve completed onboarding as a Connect platform.



1172
1173
1174
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1172

def merchant
  @merchant
end

#recipientObject

The Recipient Configuration allows the Account to receive funds.



1174
1175
1176
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1174

def recipient
  @recipient
end

#storerObject

The Storer Configuration allows the Account to store and move funds using stored-value FinancialAccounts.



1176
1177
1178
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1176

def storer
  @storer
end