Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 426

def initialize(
  applied: nil,
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @applied = applied
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



414
415
416
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 414

def applied
  @applied
end

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



416
417
418
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 416

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



418
419
420
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 418

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



420
421
422
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 420

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



422
423
424
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 422

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



424
425
426
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 424

def test_clock
  @test_clock
end