Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 168

def initialize(
  applied: nil,
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @applied = applied
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



156
157
158
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 156

def applied
  @applied
end

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



158
159
160
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 158

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



160
161
162
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 160

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



162
163
164
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 162

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



164
165
166
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 164

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



166
167
168
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 166

def test_clock
  @test_clock
end