Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: AutomaticIndirectTax, Billing, Capabilities, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(applied: nil, automatic_indirect_tax: nil, billing: nil, capabilities: nil, shipping: nil, test_clock: nil) ⇒ Customer

Returns a new instance of Customer.



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 308

def initialize(
  applied: nil,
  automatic_indirect_tax: nil,
  billing: nil,
  capabilities: nil,
  shipping: nil,
  test_clock: nil
)
  @applied = applied
  @automatic_indirect_tax = automatic_indirect_tax
  @billing = billing
  @capabilities = capabilities
  @shipping = shipping
  @test_clock = test_clock
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



296
297
298
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 296

def applied
  @applied
end

#automatic_indirect_taxObject

Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer’s invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.



298
299
300
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 298

def automatic_indirect_tax
  @automatic_indirect_tax
end

#billingObject

Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.



300
301
302
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 300

def billing
  @billing
end

#capabilitiesObject

Capabilities that have been requested on the Customer Configuration.



302
303
304
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 302

def capabilities
  @capabilities
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



304
305
306
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 304

def shipping
  @shipping
end

#test_clockObject

ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.



306
307
308
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 306

def test_clock
  @test_clock
end