Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
Data source used to identify the customer account’s tax location.
-
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 278 def initialize( exempt: nil, ip_address: nil, location_source: nil, validate_location: nil ) @exempt = exempt @ip_address = ip_address @location_source = location_source @validate_location = validate_location end |
Instance Attribute Details
#exempt ⇒ Object
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`. When `reverse`, invoice and receipt PDFs include “Reverse charge”.
270 271 272 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 270 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
272 273 274 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 272 def ip_address @ip_address end |
#location_source ⇒ Object
Data source used to identify the customer account’s tax location. Defaults to ‘identity_address`. Used for automatic indirect tax calculation.
274 275 276 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 274 def location_source @location_source end |
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.
276 277 278 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 276 def validate_location @validate_location end |