Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
Data source used to identify the customer account’s tax location.
-
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 20 def initialize( exempt: nil, ip_address: nil, location_source: nil, validate_location: nil ) @exempt = exempt @ip_address = ip_address @location_source = location_source @validate_location = validate_location end |
Instance Attribute Details
#exempt ⇒ Object
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`. When `reverse`, invoice and receipt PDFs include “Reverse charge”.
12 13 14 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 12 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
14 15 16 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 14 def ip_address @ip_address end |
#location_source ⇒ Object
Data source used to identify the customer account’s tax location. Defaults to ‘identity_address`. Used for automatic indirect tax calculation.
16 17 18 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 16 def location_source @location_source end |
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.
18 19 20 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 18 def validate_location @validate_location end |