Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
Data source used to identify the customer account’s tax location.
-
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 266 def initialize( exempt: nil, ip_address: nil, location_source: nil, validate_location: nil ) @exempt = exempt @ip_address = ip_address @location_source = location_source @validate_location = validate_location end |
Instance Attribute Details
#exempt ⇒ Object
The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`. When `reverse`, invoice and receipt PDFs include “Reverse charge”.
258 259 260 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 258 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
260 261 262 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 260 def ip_address @ip_address end |
#location_source ⇒ Object
Data source used to identify the customer account’s tax location. Defaults to ‘identity_address`. Used for automatic indirect tax calculation.
262 263 264 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 262 def location_source @location_source end |
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.
264 265 266 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 264 def validate_location @validate_location end |