Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax

Returns a new instance of AutomaticIndirectTax.



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 160

def initialize(
  exempt: nil,
  ip_address: nil,
  location_source: nil,
  validate_location: nil
)
  @exempt = exempt
  @ip_address = ip_address
  @location_source = location_source
  @validate_location = validate_location
end

Instance Attribute Details

#exemptObject

The customer account’s tax exemption status: ‘none`, `exempt`, or `reverse`. When `reverse`, invoice and receipt PDFs include “Reverse charge”.



152
153
154
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 152

def exempt
  @exempt
end

#ip_addressObject

A recent IP address of the customer used for tax reporting and tax location inference.



154
155
156
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 154

def ip_address
  @ip_address
end

#location_sourceObject

Data source used to identify the customer account’s tax location. Defaults to ‘identity_address`. Used for automatic indirect tax calculation.



156
157
158
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 156

def location_source
  @location_source
end

#validate_locationObject

A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto`.



158
159
160
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 158

def validate_location
  @validate_location
end