Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address’.
-
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto’.
Instance Method Summary collapse
-
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
constructor
A new instance of AutomaticIndirectTax.
Methods inherited from RequestParams
Constructor Details
#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax
Returns a new instance of AutomaticIndirectTax.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 140 def initialize( exempt: nil, ip_address: nil, location_source: nil, validate_location: nil ) @exempt = exempt @ip_address = ip_address @location_source = location_source @validate_location = validate_location end |
Instance Attribute Details
#exempt ⇒ Object
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.
132 133 134 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 132 def exempt @exempt end |
#ip_address ⇒ Object
A recent IP address of the customer used for tax reporting and tax location inference.
134 135 136 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 134 def ip_address @ip_address end |
#location_source ⇒ Object
The data source used to identify the customer’s tax location - defaults to ‘identity_address’. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.
136 137 138 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 136 def location_source @location_source end |
#validate_location ⇒ Object
A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto’.
138 139 140 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 138 def validate_location @validate_location end |