Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::AutomaticIndirectTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(exempt: nil, ip_address: nil, location_source: nil, validate_location: nil) ⇒ AutomaticIndirectTax

Returns a new instance of AutomaticIndirectTax.



20
21
22
23
24
25
26
27
28
29
30
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 20

def initialize(
  exempt: nil,
  ip_address: nil,
  location_source: nil,
  validate_location: nil
)
  @exempt = exempt
  @ip_address = ip_address
  @location_source = location_source
  @validate_location = validate_location
end

Instance Attribute Details

#exemptObject

Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.



12
13
14
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 12

def exempt
  @exempt
end

#ip_addressObject

A recent IP address of the customer used for tax reporting and tax location inference.



14
15
16
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 14

def ip_address
  @ip_address
end

#location_sourceObject

The data source used to identify the customer’s tax location - defaults to ‘identity_address’. Will only be used for automatic tax calculation on the customer’s Invoices and Subscriptions.



16
17
18
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 16

def location_source
  @location_source
end

#validate_locationObject

A per-request flag that indicates when Stripe should validate the customer tax location - defaults to ‘auto’.



18
19
20
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 18

def validate_location
  @validate_location
end