Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Invoice
Instance Attribute Summary collapse
-
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
-
#invoice ⇒ Object
Default settings used on invoices for this customer.
Instance Method Summary collapse
-
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
constructor
A new instance of Billing.
Methods inherited from RequestParams
Constructor Details
#initialize(default_payment_method: nil, invoice: nil) ⇒ Billing
Returns a new instance of Billing.
228 229 230 231 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 228 def initialize(default_payment_method: nil, invoice: nil) @default_payment_method = default_payment_method @invoice = invoice end |
Instance Attribute Details
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for invoices and subscriptions.
224 225 226 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 224 def default_payment_method @default_payment_method end |
#invoice ⇒ Object
Default settings used on invoices for this customer.
226 227 228 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 226 def invoice @invoice end |