Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing::Invoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing::Invoice
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: CustomField, Rendering
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#footer ⇒ Object
Default invoice footer.
-
#next_sequence ⇒ Object
Sequence number to use on the customer account’s next invoice.
-
#prefix ⇒ Object
Prefix used to generate unique invoice numbers.
-
#rendering ⇒ Object
Default invoice PDF rendering options.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
constructor
A new instance of Invoice.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice
Returns a new instance of Invoice.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 69 def initialize( custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil ) @custom_fields = custom_fields @footer = @next_sequence = next_sequence @prefix = prefix @rendering = rendering end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
59 60 61 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 59 def custom_fields @custom_fields end |
#footer ⇒ Object
Default invoice footer.
61 62 63 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 61 def @footer end |
#next_sequence ⇒ Object
Sequence number to use on the customer account’s next invoice. Defaults to 1.
63 64 65 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 63 def next_sequence @next_sequence end |
#prefix ⇒ Object
Prefix used to generate unique invoice numbers. Must be 3-12 uppercase letters or numbers.
65 66 67 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 65 def prefix @prefix end |
#rendering ⇒ Object
Default invoice PDF rendering options.
67 68 69 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 67 def rendering @rendering end |