Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Customer::Billing::Invoice

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CustomField, Rendering

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_fields: nil, footer: nil, next_sequence: nil, prefix: nil, rendering: nil) ⇒ Invoice

Returns a new instance of Invoice.



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 189

def initialize(
  custom_fields: nil,
  footer: nil,
  next_sequence: nil,
  prefix: nil,
  rendering: nil
)
  @custom_fields = custom_fields
  @footer = footer
  @next_sequence = next_sequence
  @prefix = prefix
  @rendering = rendering
end

Instance Attribute Details

#custom_fieldsObject

The list of up to 4 default custom fields to be displayed on invoices for this customer.



179
180
181
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 179

def custom_fields
  @custom_fields
end

Default footer to be displayed on invoices for this customer.



181
182
183
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 181

def footer
  @footer
end

#next_sequenceObject

The sequence to be used on the customer’s next invoice. Defaults to 1.



183
184
185
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 183

def next_sequence
  @next_sequence
end

#prefixObject

The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.



185
186
187
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 185

def prefix
  @prefix
end

#renderingObject

Default options for invoice PDF rendering for this customer.



187
188
189
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 187

def rendering
  @rendering
end