Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 996

def initialize(
  applied: nil,
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  konbini_payments: nil,
  mcc: nil,
  script_statement_descriptor: nil,
  smart_disputes: nil,
  statement_descriptor: nil,
  support: nil
)
  @applied = applied
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @konbini_payments = konbini_payments
  @mcc = mcc
  @script_statement_descriptor = script_statement_descriptor
  @smart_disputes = smart_disputes
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



974
975
976
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 974

def applied
  @applied
end

#bacs_debit_paymentsObject

Settings for Bacs Direct Debit payments.



976
977
978
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 976

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



978
979
980
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 978

def branding
  @branding
end

#capabilitiesObject

Capabilities to request on the Merchant Configuration.



980
981
982
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 980

def capabilities
  @capabilities
end

#card_paymentsObject

Card payments settings.



982
983
984
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 982

def card_payments
  @card_payments
end

#konbini_paymentsObject

Settings specific to Konbini payments on the account.



984
985
986
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 984

def konbini_payments
  @konbini_payments
end

#mccObject

The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.



986
987
988
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 986

def mcc
  @mcc
end

#script_statement_descriptorObject

Settings for the default text that appears on statements for language variations.



988
989
990
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 988

def script_statement_descriptor
  @script_statement_descriptor
end

#smart_disputesObject

Settings for Smart Disputes automatic response feature.



990
991
992
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 990

def smart_disputes
  @smart_disputes
end

#statement_descriptorObject

Settings for the default [statement descriptor](/connect/statement-descriptors) text.



992
993
994
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 992

def statement_descriptor
  @statement_descriptor
end

#supportObject

Publicly available contact information for sending support issues to.



994
995
996
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 994

def support
  @support
end