Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
-
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant.
-
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
-
#smart_disputes ⇒ Object
Settings for Smart Disputes automatic response feature.
-
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 983 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @konbini_payments = konbini_payments @mcc = mcc @script_statement_descriptor = script_statement_descriptor @smart_disputes = smart_disputes @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
961 962 963 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 961 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
963 964 965 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 963 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
965 966 967 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 965 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
967 968 969 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 967 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
969 970 971 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 969 def card_payments @card_payments end |
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
971 972 973 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 971 def konbini_payments @konbini_payments end |
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
973 974 975 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 973 def mcc @mcc end |
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
975 976 977 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 975 def script_statement_descriptor @script_statement_descriptor end |
#smart_disputes ⇒ Object
Settings for Smart Disputes automatic response feature.
977 978 979 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 977 def smart_disputes @smart_disputes end |
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
979 980 981 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 979 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
981 982 983 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 981 def support @support end |