Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
-
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant.
-
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
-
#smart_disputes ⇒ Object
Settings for Smart Disputes automatic response feature.
-
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1123 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @konbini_payments = konbini_payments @mcc = mcc @script_statement_descriptor = script_statement_descriptor @smart_disputes = smart_disputes @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1101 1102 1103 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1101 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
1103 1104 1105 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1103 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
1105 1106 1107 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1105 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
1107 1108 1109 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1107 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
1109 1110 1111 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1109 def card_payments @card_payments end |
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
1111 1112 1113 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1111 def konbini_payments @konbini_payments end |
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
1113 1114 1115 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1113 def mcc @mcc end |
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
1115 1116 1117 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1115 def script_statement_descriptor @script_statement_descriptor end |
#smart_disputes ⇒ Object
Settings for Smart Disputes automatic response feature.
1117 1118 1119 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1117 def smart_disputes @smart_disputes end |
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
1119 1120 1121 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1119 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
1121 1122 1123 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1121 def support @support end |