Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, SmartDisputes, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
-
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant.
-
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
-
#smart_disputes ⇒ Object
Settings for Smart Disputes automatic response feature.
-
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1229 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, smart_disputes: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @konbini_payments = konbini_payments @mcc = mcc @script_statement_descriptor = script_statement_descriptor @smart_disputes = smart_disputes @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1207 1208 1209 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1207 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
1209 1210 1211 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1209 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
1211 1212 1213 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1211 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
1213 1214 1215 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1213 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
1215 1216 1217 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1215 def card_payments @card_payments end |
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
1217 1218 1219 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1217 def konbini_payments @konbini_payments end |
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
1219 1220 1221 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1219 def mcc @mcc end |
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
1221 1222 1223 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1221 def script_statement_descriptor @script_statement_descriptor end |
#smart_disputes ⇒ Object
Settings for Smart Disputes automatic response feature.
1223 1224 1225 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1223 def smart_disputes @smart_disputes end |
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
1225 1226 1227 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1225 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
1227 1228 1229 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1227 def support @support end |