Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, KonbiniPayments, ScriptStatementDescriptor, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
-
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant.
-
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
-
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 964 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, konbini_payments: nil, mcc: nil, script_statement_descriptor: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @konbini_payments = konbini_payments @mcc = mcc @script_statement_descriptor = script_statement_descriptor @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
944 945 946 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 944 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings for Bacs Direct Debit payments.
946 947 948 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 946 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
948 949 950 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 948 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
950 951 952 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 950 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
952 953 954 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 952 def card_payments @card_payments end |
#konbini_payments ⇒ Object
Settings specific to Konbini payments on the account.
954 955 956 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 954 def konbini_payments @konbini_payments end |
#mcc ⇒ Object
The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
956 957 958 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 956 def mcc @mcc end |
#script_statement_descriptor ⇒ Object
Settings for the default text that appears on statements for language variations.
958 959 960 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 958 def script_statement_descriptor @script_statement_descriptor end |
#statement_descriptor ⇒ Object
Settings for the default [statement descriptor](/connect/statement-descriptors) text.
960 961 962 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 960 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
962 963 964 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 962 def support @support end |