Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#mcc ⇒ Object
The merchant category code for the merchant.
-
#statement_descriptor ⇒ Object
Statement descriptor.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1031 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @mcc = mcc @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1015 1016 1017 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1015 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
1017 1018 1019 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1017 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
1019 1020 1021 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1019 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
1021 1022 1023 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1021 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
1023 1024 1025 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1023 def card_payments @card_payments end |
#mcc ⇒ Object
The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.
1025 1026 1027 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1025 def mcc @mcc end |
#statement_descriptor ⇒ Object
Statement descriptor.
1027 1028 1029 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1027 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
1029 1030 1031 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1029 def support @support end |