Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, StatementDescriptor, Support
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
-
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
-
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
-
#card_payments ⇒ Object
Card payments settings.
-
#mcc ⇒ Object
The merchant category code for the merchant.
-
#statement_descriptor ⇒ Object
Statement descriptor.
-
#support ⇒ Object
Publicly available contact information for sending support issues to.
Instance Method Summary collapse
-
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
constructor
A new instance of Merchant.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant
Returns a new instance of Merchant.
1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1011 def initialize( applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil ) @applied = applied @bacs_debit_payments = bacs_debit_payments @branding = branding @capabilities = capabilities @card_payments = card_payments @mcc = mcc @statement_descriptor = statement_descriptor @support = support end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
995 996 997 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 995 def applied @applied end |
#bacs_debit_payments ⇒ Object
Settings used for Bacs debit payments.
997 998 999 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 997 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.
999 1000 1001 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 999 def branding @branding end |
#capabilities ⇒ Object
Capabilities to request on the Merchant Configuration.
1001 1002 1003 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1001 def capabilities @capabilities end |
#card_payments ⇒ Object
Card payments settings.
1003 1004 1005 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1003 def card_payments @card_payments end |
#mcc ⇒ Object
The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.
1005 1006 1007 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1005 def mcc @mcc end |
#statement_descriptor ⇒ Object
Statement descriptor.
1007 1008 1009 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1007 def statement_descriptor @statement_descriptor end |
#support ⇒ Object
Publicly available contact information for sending support issues to.
1009 1010 1011 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1009 def support @support end |