Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, Capabilities, CardPayments, StatementDescriptor, Support

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applied: nil, bacs_debit_payments: nil, branding: nil, capabilities: nil, card_payments: nil, mcc: nil, statement_descriptor: nil, support: nil) ⇒ Merchant

Returns a new instance of Merchant.



891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 891

def initialize(
  applied: nil,
  bacs_debit_payments: nil,
  branding: nil,
  capabilities: nil,
  card_payments: nil,
  mcc: nil,
  statement_descriptor: nil,
  support: nil
)
  @applied = applied
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @capabilities = capabilities
  @card_payments = card_payments
  @mcc = mcc
  @statement_descriptor = statement_descriptor
  @support = support
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



875
876
877
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 875

def applied
  @applied
end

#bacs_debit_paymentsObject

Settings used for Bacs debit payments.



877
878
879
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 877

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the merchant’s branding to email receipts, invoices, Checkout, and other products.



879
880
881
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 879

def branding
  @branding
end

#capabilitiesObject

Capabilities to request on the Merchant Configuration.



881
882
883
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 881

def capabilities
  @capabilities
end

#card_paymentsObject

Card payments settings.



883
884
885
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 883

def card_payments
  @card_payments
end

#mccObject

The merchant category code for the merchant. MCCs are used to classify businesses based on the goods or services they provide.



885
886
887
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 885

def mcc
  @mcc
end

#statement_descriptorObject

Statement descriptor.



887
888
889
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 887

def statement_descriptor
  @statement_descriptor
end

#supportObject

Publicly available contact information for sending support issues to.



889
890
891
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 889

def support
  @support
end