Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Support
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Merchant::Support
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#email ⇒ Object
A publicly available email address for sending support issues to.
-
#phone ⇒ Object
A publicly available phone number to call with support issues.
-
#url ⇒ Object
A publicly available website for handling support issues.
Instance Method Summary collapse
-
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
constructor
A new instance of Support.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, email: nil, phone: nil, url: nil) ⇒ Support
Returns a new instance of Support.
1211 1212 1213 1214 1215 1216 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1211 def initialize(address: nil, email: nil, phone: nil, url: nil) @address = address @email = email @phone = phone @url = url end |
Instance Attribute Details
#address ⇒ Object
A publicly available mailing address for sending support issues to.
1203 1204 1205 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1203 def address @address end |
#email ⇒ Object
A publicly available email address for sending support issues to.
1205 1206 1207 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1205 def email @email end |
#phone ⇒ Object
A publicly available phone number to call with support issues.
1207 1208 1209 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1207 def phone @phone end |
#url ⇒ Object
A publicly available website for handling support issues.
1209 1210 1211 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1209 def url @url end |