Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BusinessStorage, InboundTransfers, OutboundPayments, OutboundTransfers, ReceivedCredits, ReceivedDebits
Instance Attribute Summary collapse
-
#business_storage ⇒ Object
Can send or receive business storage-type funds on Stripe.
-
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
-
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
-
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
-
#received_credits ⇒ Object
Can receive funds on a financial address to credit a FinancialAccount.
-
#received_debits ⇒ Object
Can receive debits to a FinancialAccount.
Instance Method Summary collapse
-
#initialize(business_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(business_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1299 def initialize( business_storage: nil, inbound_transfers: nil, outbound_payments: nil, outbound_transfers: nil, received_credits: nil, received_debits: nil ) @business_storage = business_storage @inbound_transfers = inbound_transfers @outbound_payments = outbound_payments @outbound_transfers = outbound_transfers @received_credits = received_credits @received_debits = received_debits end |
Instance Attribute Details
#business_storage ⇒ Object
Can send or receive business storage-type funds on Stripe.
1287 1288 1289 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1287 def business_storage @business_storage end |
#inbound_transfers ⇒ Object
Can pull funds from an external source, owned by yourself, to a FinancialAccount.
1289 1290 1291 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1289 def inbound_transfers @inbound_transfers end |
#outbound_payments ⇒ Object
Can send funds from a FinancialAccount to a destination owned by someone else.
1291 1292 1293 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1291 def outbound_payments @outbound_payments end |
#outbound_transfers ⇒ Object
Can send funds from a FinancialAccount to a destination owned by yourself.
1293 1294 1295 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1293 def outbound_transfers @outbound_transfers end |
#received_credits ⇒ Object
Can receive funds on a financial address to credit a FinancialAccount.
1295 1296 1297 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1295 def received_credits @received_credits end |
#received_debits ⇒ Object
Can receive debits to a FinancialAccount.
1297 1298 1299 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1297 def received_debits @received_debits end |