Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::OutboundPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::OutboundPayments
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, FinancialAccounts, PaperChecks
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Can send funds from a FinancialAccount to a bank account owned by someone else.
-
#cards ⇒ Object
Can send funds from a FinancialAccount to a debit card owned by someone else.
-
#crypto_wallets ⇒ Object
Can send funds from a FinancialAccount to a crypto wallet owned by someone else.
-
#financial_accounts ⇒ Object
Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
-
#paper_checks ⇒ Object
Can send funds from a FinancialAccount to someone else via paper check.
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, financial_accounts: nil, paper_checks: nil) ⇒ OutboundPayments
constructor
A new instance of OutboundPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, financial_accounts: nil, paper_checks: nil) ⇒ OutboundPayments
Returns a new instance of OutboundPayments.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3176 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, financial_accounts: nil, paper_checks: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @financial_accounts = financial_accounts @paper_checks = paper_checks end |
Instance Attribute Details
#bank_accounts ⇒ Object
Can send funds from a FinancialAccount to a bank account owned by someone else.
3166 3167 3168 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3166 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Can send funds from a FinancialAccount to a debit card owned by someone else.
3168 3169 3170 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3168 def cards @cards end |
#crypto_wallets ⇒ Object
Can send funds from a FinancialAccount to a crypto wallet owned by someone else.
3170 3171 3172 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3170 def crypto_wallets @crypto_wallets end |
#financial_accounts ⇒ Object
Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
3172 3173 3174 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3172 def financial_accounts @financial_accounts end |
#paper_checks ⇒ Object
Can send funds from a FinancialAccount to someone else via paper check.
3174 3175 3176 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3174 def paper_checks @paper_checks end |