Class: Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::OutboundPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::MoneyManager::Capabilities::OutboundPayments
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, FinancialAccounts
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Can send funds from a FinancialAccount to a bank account owned by someone else.
-
#cards ⇒ Object
Can send funds from a FinancialAccount to a debit card owned by someone else.
-
#financial_accounts ⇒ Object
Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, financial_accounts: nil) ⇒ OutboundPayments
constructor
A new instance of OutboundPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, financial_accounts: nil) ⇒ OutboundPayments
Returns a new instance of OutboundPayments.
1217 1218 1219 1220 1221 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1217 def initialize(bank_accounts: nil, cards: nil, financial_accounts: nil) @bank_accounts = bank_accounts @cards = cards @financial_accounts = financial_accounts end |
Instance Attribute Details
#bank_accounts ⇒ Object
Can send funds from a FinancialAccount to a bank account owned by someone else.
1211 1212 1213 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1211 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Can send funds from a FinancialAccount to a debit card owned by someone else.
1213 1214 1215 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1213 def cards @cards end |
#financial_accounts ⇒ Object
Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
1215 1216 1217 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1215 def financial_accounts @financial_accounts end |