Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1073 1074 1075 1076 1077 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1073 def initialize(bank_accounts: nil, cards: nil, stripe_balance: nil) @bank_accounts = bank_accounts @cards = cards @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1067 1068 1069 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1067 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
1069 1070 1071 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1069 def cards @cards end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1071 1072 1073 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1071 def stripe_balance @stripe_balance end |