Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, PaperChecks, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, paper_checks: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1353

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  paper_checks: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @paper_checks = paper_checks
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1343
1344
1345
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1343

def bank_accounts
  @bank_accounts
end

#cardsObject

Capability that enable OutboundPayments to a debit card linked to this Account.



1345
1346
1347
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1345

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



1347
1348
1349
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1347

def crypto_wallets
  @crypto_wallets
end

#paper_checksObject

Capabilities that enable OutboundPayments via paper check.



1349
1350
1351
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1349

def paper_checks
  @paper_checks
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1351
1352
1353
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1351

def stripe_balance
  @stripe_balance
end