Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1236 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1228 1229 1230 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1228 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
1230 1231 1232 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1230 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
1232 1233 1234 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1232 def crypto_wallets @crypto_wallets end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1234 1235 1236 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1234 def stripe_balance @stripe_balance end |