Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1126

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1118
1119
1120
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1118

def bank_accounts
  @bank_accounts
end

#cardsObject

Capability that enable OutboundPayments to a debit card linked to this Account.



1120
1121
1122
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1120

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



1122
1123
1124
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1122

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1124
1125
1126
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1124

def stripe_balance
  @stripe_balance
end