Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1203

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



1195
1196
1197
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1195

def bank_accounts
  @bank_accounts
end

#cardsObject

Capability that enable OutboundPayments to a debit card linked to this Account.



1197
1198
1199
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1197

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



1199
1200
1201
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1199

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



1201
1202
1203
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1201

def stripe_balance
  @stripe_balance
end