Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccounts, Cards, CryptoWallets, StripeBalance
Instance Attribute Summary collapse
-
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
-
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
-
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
-
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
Instance Method Summary collapse
-
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
constructor
A new instance of Capabilities.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities
Returns a new instance of Capabilities.
1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1106 def initialize( bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil ) @bank_accounts = bank_accounts @cards = cards @crypto_wallets = crypto_wallets @stripe_balance = stripe_balance end |
Instance Attribute Details
#bank_accounts ⇒ Object
Capabilities that enable OutboundPayments to a bank account linked to this Account.
1098 1099 1100 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1098 def bank_accounts @bank_accounts end |
#cards ⇒ Object
Capability that enable OutboundPayments to a debit card linked to this Account.
1100 1101 1102 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1100 def cards @cards end |
#crypto_wallets ⇒ Object
Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
1102 1103 1104 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1102 def crypto_wallets @crypto_wallets end |
#stripe_balance ⇒ Object
Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
1104 1105 1106 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1104 def stripe_balance @stripe_balance end |