Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BankAccounts, Cards, CryptoWallets, StripeBalance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_accounts: nil, cards: nil, crypto_wallets: nil, stripe_balance: nil) ⇒ Capabilities

Returns a new instance of Capabilities.



986
987
988
989
990
991
992
993
994
995
996
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 986

def initialize(
  bank_accounts: nil,
  cards: nil,
  crypto_wallets: nil,
  stripe_balance: nil
)
  @bank_accounts = bank_accounts
  @cards = cards
  @crypto_wallets = crypto_wallets
  @stripe_balance = stripe_balance
end

Instance Attribute Details

#bank_accountsObject

Capabilities that enable OutboundPayments to a bank account linked to this Account.



978
979
980
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 978

def bank_accounts
  @bank_accounts
end

#cardsObject

Capability that enable OutboundPayments to a debit card linked to this Account.



980
981
982
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 980

def cards
  @cards
end

#crypto_walletsObject

Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.



982
983
984
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 982

def crypto_wallets
  @crypto_wallets
end

#stripe_balanceObject

Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).



984
985
986
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 984

def stripe_balance
  @stripe_balance
end