Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::BankAccounts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::BankAccounts
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Ach, Becs, Eft, Fedwire, Fps, Instant, Local, Npp, Rtp, SepaCredit, SepaInstant, Swift, Wire
Instance Attribute Summary collapse
-
#ach ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over ACH rails.
-
#becs ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over BECS rails.
-
#eft ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over EFT rails.
-
#fedwire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over Fedwire or CHIPS.
-
#fps ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over FPS rails.
-
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
-
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
-
#npp ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over NPP (real time) rails.
-
#rtp ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over RTP rails.
-
#sepa_credit ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA credit rails.
-
#sepa_instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA instant (real time) rails.
-
#swift ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over SWIFT.
-
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
Instance Method Summary collapse
-
#initialize(ach: nil, becs: nil, eft: nil, fedwire: nil, fps: nil, instant: nil, local: nil, npp: nil, rtp: nil, sepa_credit: nil, sepa_instant: nil, swift: nil, wire: nil) ⇒ BankAccounts
constructor
A new instance of BankAccounts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(ach: nil, becs: nil, eft: nil, fedwire: nil, fps: nil, instant: nil, local: nil, npp: nil, rtp: nil, sepa_credit: nil, sepa_instant: nil, swift: nil, wire: nil) ⇒ BankAccounts
Returns a new instance of BankAccounts.
3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 3922 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3894 def initialize( ach: nil, becs: nil, eft: nil, fedwire: nil, fps: nil, instant: nil, local: nil, npp: nil, rtp: nil, sepa_credit: nil, sepa_instant: nil, swift: nil, wire: nil ) @ach = ach @becs = becs @eft = eft @fedwire = fedwire @fps = fps @instant = instant @local = local @npp = npp @rtp = rtp @sepa_credit = sepa_credit @sepa_instant = sepa_instant @swift = swift @wire = wire end |
Instance Attribute Details
#ach ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over ACH rails.
3868 3869 3870 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3868 def ach @ach end |
#becs ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over BECS rails.
3870 3871 3872 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3870 def becs @becs end |
#eft ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over EFT rails.
3872 3873 3874 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3872 def eft @eft end |
#fedwire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over Fedwire or CHIPS.
3874 3875 3876 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3874 def fedwire @fedwire end |
#fps ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over FPS rails.
3876 3877 3878 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3876 def fps @fps end |
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
3878 3879 3880 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3878 def instant @instant end |
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
3880 3881 3882 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3880 def local @local end |
#npp ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over NPP (real time) rails.
3882 3883 3884 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3882 def npp @npp end |
#rtp ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over RTP rails.
3884 3885 3886 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3884 def rtp @rtp end |
#sepa_credit ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA credit rails.
3886 3887 3888 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3886 def sepa_credit @sepa_credit end |
#sepa_instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over SEPA instant (real time) rails.
3888 3889 3890 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3888 def sepa_instant @sepa_instant end |
#swift ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over SWIFT.
3890 3891 3892 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3890 def swift @swift end |
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
3892 3893 3894 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3892 def wire @wire end |