Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::BankAccounts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Recipient::Capabilities::BankAccounts
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
-
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
-
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
Instance Method Summary collapse
-
#initialize(instant: nil, local: nil, wire: nil) ⇒ BankAccounts
constructor
A new instance of BankAccounts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(instant: nil, local: nil, wire: nil) ⇒ BankAccounts
Returns a new instance of BankAccounts.
1292 1293 1294 1295 1296 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1292 def initialize(instant: nil, local: nil, wire: nil) @instant = instant @local = local @wire = wire end |
Instance Attribute Details
#instant ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
1286 1287 1288 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1286 def instant @instant end |
#local ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
1288 1289 1290 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1288 def local @local end |
#wire ⇒ Object
Enables this Account to receive OutboundPayments to linked bank accounts over wire.
1290 1291 1292 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1290 def wire @wire end |