Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Capabilities
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
Instance Method Summary collapse
-
#initialize(applied: nil, capabilities: nil) ⇒ Storer
constructor
A new instance of Storer.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applied: nil, capabilities: nil) ⇒ Storer
Returns a new instance of Storer.
1269 1270 1271 1272 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1269 def initialize(applied: nil, capabilities: nil) @applied = applied @capabilities = capabilities end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1265 1266 1267 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1265 def applied @applied end |
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1267 1268 1269 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1267 def capabilities @capabilities end |