Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1669

def initialize(
  applied: nil,
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @applied = applied
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



1645
1646
1647
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1645

def applied
  @applied
end

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1647
1648
1649
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1647

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1649
1650
1651
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1649

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

Description of the high-risk activities the business offers.



1651
1652
1653
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1651

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1653
1654
1655
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1653

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Does the business operate in any prohibited countries.



1655
1656
1657
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1655

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Indicates whether the business participates in any regulated activity.



1657
1658
1659
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1657

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1659
1660
1661
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1659

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1661
1662
1663
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1661

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1663
1664
1665
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1663

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1665
1666
1667
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1665

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1667
1668
1669
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1667

def source_of_funds_description
  @source_of_funds_description
end