Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Capabilities, RegulatedActivity
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
-
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
-
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
-
#money_services_description ⇒ Object
Description of the money services offered by the business.
-
#operates_in_prohibited_countries ⇒ Object
Does the business operate in any prohibited countries.
-
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
-
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
-
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
-
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
-
#source_of_funds ⇒ Object
The source of funds for the business, e.g.
-
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer
Returns a new instance of Storer.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1695 def initialize( applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil ) @applied = applied @capabilities = capabilities @high_risk_activities = high_risk_activities @high_risk_activities_description = high_risk_activities_description @money_services_description = money_services_description @operates_in_prohibited_countries = operates_in_prohibited_countries @participates_in_regulated_activity = participates_in_regulated_activity @purpose_of_funds = purpose_of_funds @purpose_of_funds_description = purpose_of_funds_description @regulated_activity = regulated_activity @source_of_funds = source_of_funds @source_of_funds_description = source_of_funds_description end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1671 1672 1673 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1671 def applied @applied end |
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1673 1674 1675 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1673 def capabilities @capabilities end |
#high_risk_activities ⇒ Object
List of high-risk activities the business is involved in.
1675 1676 1677 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1675 def high_risk_activities @high_risk_activities end |
#high_risk_activities_description ⇒ Object
Description of the high-risk activities the business offers.
1677 1678 1679 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1677 def high_risk_activities_description @high_risk_activities_description end |
#money_services_description ⇒ Object
Description of the money services offered by the business.
1679 1680 1681 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1679 def money_services_description @money_services_description end |
#operates_in_prohibited_countries ⇒ Object
Does the business operate in any prohibited countries.
1681 1682 1683 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1681 def operates_in_prohibited_countries @operates_in_prohibited_countries end |
#participates_in_regulated_activity ⇒ Object
Indicates whether the business participates in any regulated activity.
1683 1684 1685 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1683 def participates_in_regulated_activity @participates_in_regulated_activity end |
#purpose_of_funds ⇒ Object
Primary purpose of the stored funds.
1685 1686 1687 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1685 def purpose_of_funds @purpose_of_funds end |
#purpose_of_funds_description ⇒ Object
Description of the purpose of the stored funds.
1687 1688 1689 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1687 def purpose_of_funds_description @purpose_of_funds_description end |
#regulated_activity ⇒ Object
Details of the regulated activity if the business participates in one.
1689 1690 1691 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1689 def regulated_activity @regulated_activity end |
#source_of_funds ⇒ Object
The source of funds for the business, e.g. profits, income, venture capital, etc.
1691 1692 1693 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1691 def source_of_funds @source_of_funds end |
#source_of_funds_description ⇒ Object
Description of the source of funds for the business’ account.
1693 1694 1695 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1693 def source_of_funds_description @source_of_funds_description end |