Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1501

def initialize(
  applied: nil,
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @applied = applied
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



1477
1478
1479
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1477

def applied
  @applied
end

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1479
1480
1481
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1479

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1481
1482
1483
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1481

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

An explanation of the high risk activities that the business performs.



1483
1484
1485
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1483

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1485
1486
1487
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1485

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Does the business operate in any prohibited countries.



1487
1488
1489
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1487

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Does the business participate in any regulated activity.



1489
1490
1491
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1489

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1491
1492
1493
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1491

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1493
1494
1495
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1493

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1495
1496
1497
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1495

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1497
1498
1499
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1497

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1499
1500
1501
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1499

def source_of_funds_description
  @source_of_funds_description
end