Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Capabilities, RegulatedActivity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applied: nil, capabilities: nil, high_risk_activities: nil, high_risk_activities_description: nil, money_services_description: nil, operates_in_prohibited_countries: nil, participates_in_regulated_activity: nil, purpose_of_funds: nil, purpose_of_funds_description: nil, regulated_activity: nil, source_of_funds: nil, source_of_funds_description: nil) ⇒ Storer

Returns a new instance of Storer.



1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1412

def initialize(
  applied: nil,
  capabilities: nil,
  high_risk_activities: nil,
  high_risk_activities_description: nil,
  money_services_description: nil,
  operates_in_prohibited_countries: nil,
  participates_in_regulated_activity: nil,
  purpose_of_funds: nil,
  purpose_of_funds_description: nil,
  regulated_activity: nil,
  source_of_funds: nil,
  source_of_funds_description: nil
)
  @applied = applied
  @capabilities = capabilities
  @high_risk_activities = high_risk_activities
  @high_risk_activities_description = high_risk_activities_description
  @money_services_description = money_services_description
  @operates_in_prohibited_countries = operates_in_prohibited_countries
  @participates_in_regulated_activity = participates_in_regulated_activity
  @purpose_of_funds = purpose_of_funds
  @purpose_of_funds_description = purpose_of_funds_description
  @regulated_activity = regulated_activity
  @source_of_funds = source_of_funds
  @source_of_funds_description = source_of_funds_description
end

Instance Attribute Details

#appliedObject

Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.



1388
1389
1390
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1388

def applied
  @applied
end

#capabilitiesObject

Capabilities to request on the Storer Configuration.



1390
1391
1392
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1390

def capabilities
  @capabilities
end

#high_risk_activitiesObject

List of high-risk activities the business is involved in.



1392
1393
1394
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1392

def high_risk_activities
  @high_risk_activities
end

#high_risk_activities_descriptionObject

An explanation of the high risk activities that the business performs.



1394
1395
1396
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1394

def high_risk_activities_description
  @high_risk_activities_description
end

#money_services_descriptionObject

Description of the money services offered by the business.



1396
1397
1398
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1396

def money_services_description
  @money_services_description
end

#operates_in_prohibited_countriesObject

Does the business operate in any prohibited countries.



1398
1399
1400
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1398

def operates_in_prohibited_countries
  @operates_in_prohibited_countries
end

#participates_in_regulated_activityObject

Does the business participate in any regulated activity.



1400
1401
1402
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1400

def participates_in_regulated_activity
  @participates_in_regulated_activity
end

#purpose_of_fundsObject

Primary purpose of the stored funds.



1402
1403
1404
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1402

def purpose_of_funds
  @purpose_of_funds
end

#purpose_of_funds_descriptionObject

Description of the purpose of the stored funds.



1404
1405
1406
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1404

def purpose_of_funds_description
  @purpose_of_funds_description
end

#regulated_activityObject

Details of the regulated activity if the business participates in one.



1406
1407
1408
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1406

def regulated_activity
  @regulated_activity
end

#source_of_fundsObject

The source of funds for the business, e.g. profits, income, venture capital, etc.



1408
1409
1410
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1408

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Description of the source of funds for the business’ account.



1410
1411
1412
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1410

def source_of_funds_description
  @source_of_funds_description
end