Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Capabilities
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
Instance Method Summary collapse
-
#initialize(applied: nil, capabilities: nil) ⇒ Storer
constructor
A new instance of Storer.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, capabilities: nil) ⇒ Storer
Returns a new instance of Storer.
1296 1297 1298 1299 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1296 def initialize(applied: nil, capabilities: nil) @applied = applied @capabilities = capabilities end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1292 1293 1294 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1292 def applied @applied end |
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1294 1295 1296 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1294 def capabilities @capabilities end |