Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Capabilities
Instance Attribute Summary collapse
-
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
-
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
Instance Method Summary collapse
-
#initialize(applied: nil, capabilities: nil) ⇒ Storer
constructor
A new instance of Storer.
Methods inherited from RequestParams
Constructor Details
#initialize(applied: nil, capabilities: nil) ⇒ Storer
Returns a new instance of Storer.
1164 1165 1166 1167 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1164 def initialize(applied: nil, capabilities: nil) @applied = applied @capabilities = capabilities end |
Instance Attribute Details
#applied ⇒ Object
Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
1160 1161 1162 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1160 def applied @applied end |
#capabilities ⇒ Object
Capabilities to request on the Storer Configuration.
1162 1163 1164 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1162 def capabilities @capabilities end |