Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1632

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



1624
1625
1626
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1624

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business’s primary regulator.



1626
1627
1628
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1626

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business’s regulated activities.



1628
1629
1630
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1628

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business’s regulated activities.



1630
1631
1632
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1630

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end