Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
-
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
-
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
-
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
Instance Method Summary collapse
-
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
constructor
A new instance of RegulatedActivity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
Returns a new instance of RegulatedActivity.
1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1658 def initialize( description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil ) @description = description @license_number = license_number @primary_regulatory_authority_country = @primary_regulatory_authority_name = end |
Instance Attribute Details
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
1650 1651 1652 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1650 def description @description end |
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
1652 1653 1654 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1652 def license_number @license_number end |
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
1654 1655 1656 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1654 def @primary_regulatory_authority_country end |
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
1656 1657 1658 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1656 def @primary_regulatory_authority_name end |