Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1476

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



1468
1469
1470
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1468

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business’s primary regulator.



1470
1471
1472
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1470

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business’s regulated activities.



1472
1473
1474
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1472

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business’s regulated activities.



1474
1475
1476
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1474

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end