Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1464

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



1456
1457
1458
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1456

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business’s primary regulator.



1458
1459
1460
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1458

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business’s regulated activities.



1460
1461
1462
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1460

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business’s regulated activities.



1462
1463
1464
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1462

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end