Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity

Returns a new instance of RegulatedActivity.



1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1375

def initialize(
  description: nil,
  license_number: nil,
  primary_regulatory_authority_country: nil,
  primary_regulatory_authority_name: nil
)
  @description = description
  @license_number = license_number
  @primary_regulatory_authority_country = primary_regulatory_authority_country
  @primary_regulatory_authority_name = primary_regulatory_authority_name
end

Instance Attribute Details

#descriptionObject

A detailed description of the regulated activities the business is licensed to conduct.



1367
1368
1369
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1367

def description
  @description
end

#license_numberObject

The license number or registration number assigned by the business’s primary regulator.



1369
1370
1371
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1369

def license_number
  @license_number
end

#primary_regulatory_authority_countryObject

The country of the primary regulatory authority that oversees the business’s regulated activities.



1371
1372
1373
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1371

def primary_regulatory_authority_country
  @primary_regulatory_authority_country
end

#primary_regulatory_authority_nameObject

The name of the primary regulatory authority that oversees the business’s regulated activities.



1373
1374
1375
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1373

def primary_regulatory_authority_name
  @primary_regulatory_authority_name
end