Class: Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Configuration::Storer::RegulatedActivity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
-
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
-
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
-
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
Instance Method Summary collapse
-
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
constructor
A new instance of RegulatedActivity.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil) ⇒ RegulatedActivity
Returns a new instance of RegulatedActivity.
1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1355 def initialize( description: nil, license_number: nil, primary_regulatory_authority_country: nil, primary_regulatory_authority_name: nil ) @description = description @license_number = license_number @primary_regulatory_authority_country = @primary_regulatory_authority_name = end |
Instance Attribute Details
#description ⇒ Object
A detailed description of the regulated activities the business is licensed to conduct.
1347 1348 1349 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1347 def description @description end |
#license_number ⇒ Object
The license number or registration number assigned by the business’s primary regulator.
1349 1350 1351 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1349 def license_number @license_number end |
#primary_regulatory_authority_country ⇒ Object
The country of the primary regulatory authority that oversees the business’s regulated activities.
1351 1352 1353 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1351 def @primary_regulatory_authority_country end |
#primary_regulatory_authority_name ⇒ Object
The name of the primary regulatory authority that oversees the business’s regulated activities.
1353 1354 1355 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1353 def @primary_regulatory_authority_name end |