Class: Stripe::V2::Core::AccountUpdateParams::Defaults::Profile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile

Returns a new instance of Profile.



1455
1456
1457
1458
1459
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1455

def initialize(business_url: nil, doing_business_as: nil, product_description: nil)
  @business_url = business_url
  @doing_business_as = doing_business_as
  @product_description = product_description
end

Instance Attribute Details

#business_urlObject

The business’s publicly-available website.



1449
1450
1451
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1449

def business_url
  @business_url
end

#doing_business_asObject

The name which is used by the business.



1451
1452
1453
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1451

def doing_business_as
  @doing_business_as
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1453
1454
1455
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1453

def product_description
  @product_description
end