Class: Stripe::V2::Core::AccountUpdateParams::Defaults::Profile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile

Returns a new instance of Profile.



1324
1325
1326
1327
1328
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1324

def initialize(business_url: nil, doing_business_as: nil, product_description: nil)
  @business_url = business_url
  @doing_business_as = doing_business_as
  @product_description = product_description
end

Instance Attribute Details

#business_urlObject

The business’s publicly-available website.



1318
1319
1320
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1318

def business_url
  @business_url
end

#doing_business_asObject

The name which is used by the business.



1320
1321
1322
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1320

def doing_business_as
  @doing_business_as
end

#product_descriptionObject

Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.



1322
1323
1324
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1322

def product_description
  @product_description
end