Class: Stripe::V2::Core::AccountUpdateParams::Defaults::Profile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Defaults::Profile
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#business_url ⇒ Object
The business’s publicly-available website.
-
#doing_business_as ⇒ Object
The name which is used by the business.
-
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business.
Instance Method Summary collapse
-
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
constructor
A new instance of Profile.
Methods inherited from RequestParams
Constructor Details
#initialize(business_url: nil, doing_business_as: nil, product_description: nil) ⇒ Profile
Returns a new instance of Profile.
1336 1337 1338 1339 1340 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1336 def initialize(business_url: nil, doing_business_as: nil, product_description: nil) @business_url = business_url @doing_business_as = doing_business_as @product_description = product_description end |
Instance Attribute Details
#business_url ⇒ Object
The business’s publicly-available website.
1330 1331 1332 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1330 def business_url @business_url end |
#doing_business_as ⇒ Object
The name which is used by the business.
1332 1333 1334 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1332 def doing_business_as @doing_business_as end |
#product_description ⇒ Object
Internal-only description of the product sold or service provided by the business. It’s used by Stripe for risk and underwriting purposes.
1334 1335 1336 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1334 def product_description @product_description end |