Class: Stripe::V2::Core::AccountUpdateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2545

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



2535
2536
2537
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2535

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



2537
2538
2539
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2537

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



2539
2540
2541
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2539

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



2541
2542
2543
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2541

def entity_type
  @entity_type
end

#individualObject

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



2543
2544
2545
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2543

def individual
  @individual
end

Class Method Details

.field_encodingsObject



2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2559

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end