Class: Stripe::V2::Core::AccountUpdateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
3809
3810
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3798

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



3788
3789
3790
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3788

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



3790
3791
3792
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3790

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



3792
3793
3794
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3792

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



3794
3795
3796
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3794

def entity_type
  @entity_type
end

#individualObject

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



3796
3797
3798
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3796

def individual
  @individual
end

Class Method Details

.field_encodingsObject



3812
3813
3814
3815
3816
3817
3818
3819
3820
3821
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3812

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end