Class: Stripe::V2::Core::AccountUpdateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2411

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



2401
2402
2403
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2401

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



2403
2404
2405
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2403

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



2405
2406
2407
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2405

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



2407
2408
2409
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2407

def entity_type
  @entity_type
end

#individualObject

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



2409
2410
2411
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2409

def individual
  @individual
end

Class Method Details

.field_encodingsObject



2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2425

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end