Class: Stripe::V2::Core::AccountUpdateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3702

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



3692
3693
3694
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3692

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



3694
3695
3696
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3694

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



3696
3697
3698
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3696

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



3698
3699
3700
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3698

def entity_type
  @entity_type
end

#individualObject

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



3700
3701
3702
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3700

def individual
  @individual
end

Class Method Details

.field_encodingsObject



3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3716

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end