Class: Stripe::V2::Core::AccountUpdateParams::Identity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Attestations, BusinessDetails, Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity

Returns a new instance of Identity.



3776
3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
3788
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3776

def initialize(
  attestations: nil,
  business_details: nil,
  country: nil,
  entity_type: nil,
  individual: nil
)
  @attestations = attestations
  @business_details = business_details
  @country = country
  @entity_type = entity_type
  @individual = individual
end

Instance Attribute Details

#attestationsObject

Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.



3766
3767
3768
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3766

def attestations
  @attestations
end

#business_detailsObject

Information about the company or business.



3768
3769
3770
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3768

def business_details
  @business_details
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.



3770
3771
3772
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3770

def country
  @country
end

#entity_typeObject

The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.



3772
3773
3774
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3772

def entity_type
  @entity_type
end

#individualObject

Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.



3774
3775
3776
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3774

def individual
  @individual
end

Class Method Details

.field_encodingsObject



3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3790

def self.field_encodings
  @field_encodings = {
    individual: {
      kind: :object,
      fields: {
        relationship: { kind: :object, fields: { percent_ownership: :decimal_string } },
      },
    },
  }
end