Class: Stripe::V2::Core::AccountUpdateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the individual represented by the Account.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2389 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
2379 2380 2381 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2379 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2381 2382 2383 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2381 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2383 2384 2385 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2383 def country @country end |
#entity_type ⇒ Object
The entity type.
2385 2386 2387 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2385 def entity_type @entity_type end |
#individual ⇒ Object
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
2387 2388 2389 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2387 def individual @individual end |
Class Method Details
.field_encodings ⇒ Object
2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2403 def self.field_encodings @field_encodings = { individual: { kind: :object, fields: { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, }, }, } end |