Class: Stripe::V2::Core::AccountUpdateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the individual represented by the Account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3636 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3626 3627 3628 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3626 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
3628 3629 3630 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3628 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3630 3631 3632 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3630 def country @country end |
#entity_type ⇒ Object
The entity type.
3632 3633 3634 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3632 def entity_type @entity_type end |
#individual ⇒ Object
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
3634 3635 3636 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3634 def individual @individual end |