Class: Stripe::V2::Core::AccountUpdateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the individual represented by the Account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2371 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
2361 2362 2363 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2361 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2363 2364 2365 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2363 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2365 2366 2367 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2365 def country @country end |
#entity_type ⇒ Object
The entity type.
2367 2368 2369 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2367 def entity_type @entity_type end |
#individual ⇒ Object
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
2369 2370 2371 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2369 def individual @individual end |