Class: Stripe::V2::Core::AccountUpdateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the individual represented by the Account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3033 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors, representatives.
3023 3024 3025 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3023 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
3025 3026 3027 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3025 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
3027 3028 3029 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3027 def country @country end |
#entity_type ⇒ Object
The entity type.
3029 3030 3031 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3029 def entity_type @entity_type end |
#individual ⇒ Object
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
3031 3032 3033 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3031 def individual @individual end |