Class: Stripe::V2::Core::AccountUpdateParams::Identity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Attestations, BusinessDetails, Individual
Instance Attribute Summary collapse
-
#attestations ⇒ Object
Attestations from the identity’s key people, e.g.
-
#business_details ⇒ Object
Information about the company or business.
-
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established.
-
#entity_type ⇒ Object
The entity type.
-
#individual ⇒ Object
Information about the individual represented by the Account.
Instance Method Summary collapse
-
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
constructor
A new instance of Identity.
Methods inherited from RequestParams
Constructor Details
#initialize(attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil) ⇒ Identity
Returns a new instance of Identity.
2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2209 def initialize( attestations: nil, business_details: nil, country: nil, entity_type: nil, individual: nil ) @attestations = attestations @business_details = business_details @country = country @entity_type = entity_type @individual = individual end |
Instance Attribute Details
#attestations ⇒ Object
Attestations from the identity’s key people, e.g. owners, executives, directors.
2199 2200 2201 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2199 def attestations @attestations end |
#business_details ⇒ Object
Information about the company or business.
2201 2202 2203 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2201 def business_details @business_details end |
#country ⇒ Object
The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
2203 2204 2205 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2203 def country @country end |
#entity_type ⇒ Object
The entity type.
2205 2206 2207 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2205 def entity_type @entity_type end |
#individual ⇒ Object
Information about the individual represented by the Account. This property is ‘null` unless `entity_type` is set to `individual`.
2207 2208 2209 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2207 def individual @individual end |