Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2869

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  representative_declaration: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @representative_declaration = representative_declaration
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



2859
2860
2861
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2859

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



2861
2862
2863
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2861

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



2863
2864
2865
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2863

def persons_provided
  @persons_provided
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



2865
2866
2867
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2865

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



2867
2868
2869
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2867

def terms_of_service
  @terms_of_service
end