Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1483

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  representative_declaration: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @representative_declaration = representative_declaration
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1473
1474
1475
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1473

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1475
1476
1477
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1475

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



1477
1478
1479
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1477

def persons_provided
  @persons_provided
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



1479
1480
1481
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1479

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



1481
1482
1483
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1481

def terms_of_service
  @terms_of_service
end