Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations

Returns a new instance of Attestations.



2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2041

def initialize(
  directorship_declaration: nil,
  ownership_declaration: nil,
  persons_provided: nil,
  representative_declaration: nil,
  terms_of_service: nil
)
  @directorship_declaration = directorship_declaration
  @ownership_declaration = ownership_declaration
  @persons_provided = persons_provided
  @representative_declaration = representative_declaration
  @terms_of_service = terms_of_service
end

Instance Attribute Details

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



2031
2032
2033
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2031

def directorship_declaration
  @directorship_declaration
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



2033
2034
2035
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2033

def ownership_declaration
  @ownership_declaration
end

#persons_providedObject

Attestation that all Persons with a specific Relationship value have been provided.



2035
2036
2037
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2035

def persons_provided
  @persons_provided
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



2037
2038
2039
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2037

def representative_declaration
  @representative_declaration
end

#terms_of_serviceObject

Attestations of accepted terms of service agreements.



2039
2040
2041
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2039

def terms_of_service
  @terms_of_service
end