Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2130 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @representative_declaration = representative_declaration @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
2120 2121 2122 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2120 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
2122 2123 2124 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2122 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
2124 2125 2126 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2124 def persons_provided @persons_provided end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
2126 2127 2128 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2126 def representative_declaration @representative_declaration end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
2128 2129 2130 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2128 def terms_of_service @terms_of_service end |