Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, RepresentativeDeclaration, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1927 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, representative_declaration: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @representative_declaration = representative_declaration @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1917 1918 1919 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1917 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1919 1920 1921 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1919 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
1921 1922 1923 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1921 def persons_provided @persons_provided end |
#representative_declaration ⇒ Object
This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
1923 1924 1925 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1923 def representative_declaration @representative_declaration end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
1925 1926 1927 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1925 def terms_of_service @terms_of_service end |