Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: DirectorshipDeclaration, OwnershipDeclaration, PersonsProvided, TermsOfService
Instance Attribute Summary collapse
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
-
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
Instance Method Summary collapse
-
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations
constructor
A new instance of Attestations.
Methods inherited from RequestParams
Constructor Details
#initialize(directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil) ⇒ Attestations
Returns a new instance of Attestations.
1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1334 def initialize( directorship_declaration: nil, ownership_declaration: nil, persons_provided: nil, terms_of_service: nil ) @directorship_declaration = directorship_declaration @ownership_declaration = ownership_declaration @persons_provided = persons_provided @terms_of_service = terms_of_service end |
Instance Attribute Details
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
1326 1327 1328 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1326 def directorship_declaration @directorship_declaration end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
1328 1329 1330 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1328 def ownership_declaration @ownership_declaration end |
#persons_provided ⇒ Object
Attestation that all Persons with a specific Relationship value have been provided.
1330 1331 1332 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1330 def persons_provided @persons_provided end |
#terms_of_service ⇒ Object
Attestations of accepted terms of service agreements.
1332 1333 1334 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1332 def terms_of_service @terms_of_service end |