Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1812
1813
1814
1815
1816
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1812

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1806
1807
1808
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1806

def date
  @date
end

#ipObject

The IP address from which the director attestation was made.



1808
1809
1810
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1808

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the director attestation was made.



1810
1811
1812
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1810

def user_agent
  @user_agent
end