Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1621
1622
1623
1624
1625
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1621

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1615
1616
1617
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1615

def date
  @date
end

#ipObject

The IP address from which the director attestation was made.



1617
1618
1619
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1617

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the director attestation was made.



1619
1620
1621
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1619

def user_agent
  @user_agent
end