Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the director attestation was made.
-
#ip ⇒ Object
The IP address from which the director attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the director attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1777 1778 1779 1780 1781 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1777 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1771 1772 1773 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1771 def date @date end |
#ip ⇒ Object
The IP address from which the director attestation was made.
1773 1774 1775 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1773 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the director attestation was made.
1775 1776 1777 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1775 def user_agent @user_agent end |