Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1535
1536
1537
1538
1539
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1535

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1529
1530
1531
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1529

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1531
1532
1533
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1531

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1533
1534
1535
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1533

def user_agent
  @user_agent
end