Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1255
1256
1257
1258
1259
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1255

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1249
1250
1251
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1249

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1251
1252
1253
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1251

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1253
1254
1255
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1253

def user_agent
  @user_agent
end