Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#directors ⇒ Object
Whether the company’s directors have been provided.
-
#executives ⇒ Object
Whether the company’s executives have been provided.
-
#owners ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
Instance Method Summary collapse
-
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
constructor
A new instance of PersonsProvided.
Methods inherited from RequestParams
Constructor Details
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
Returns a new instance of PersonsProvided.
1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1703 def initialize( directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil ) @directors = directors @executives = executives @owners = owners @ownership_exemption_reason = ownership_exemption_reason end |
Instance Attribute Details
#directors ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1695 1696 1697 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1695 def directors @directors end |
#executives ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1697 1698 1699 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1697 def executives @executives end |
#owners ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1699 1700 1701 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1699 def owners @owners end |
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
1701 1702 1703 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1701 def ownership_exemption_reason @ownership_exemption_reason end |