Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#directors ⇒ Object
Whether the company’s directors have been provided.
-
#executives ⇒ Object
Whether the company’s executives have been provided.
-
#owners ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
Instance Method Summary collapse
-
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
constructor
A new instance of PersonsProvided.
Methods inherited from RequestParams
Constructor Details
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
Returns a new instance of PersonsProvided.
1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1641 def initialize( directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil ) @directors = directors @executives = executives @owners = owners @ownership_exemption_reason = ownership_exemption_reason end |
Instance Attribute Details
#directors ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1633 1634 1635 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1633 def directors @directors end |
#executives ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1635 1636 1637 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1635 def executives @executives end |
#owners ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1637 1638 1639 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1637 def owners @owners end |
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
1639 1640 1641 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1639 def ownership_exemption_reason @ownership_exemption_reason end |