Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided

Returns a new instance of PersonsProvided.



1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1532

def initialize(
  directors: nil,
  executives: nil,
  owners: nil,
  ownership_exemption_reason: nil
)
  @directors = directors
  @executives = executives
  @owners = owners
  @ownership_exemption_reason = ownership_exemption_reason
end

Instance Attribute Details

#directorsObject

Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1524
1525
1526
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1524

def directors
  @directors
end

#executivesObject

Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1526
1527
1528
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1526

def executives
  @executives
end

#ownersObject

Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).



1528
1529
1530
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1528

def owners
  @owners
end

#ownership_exemption_reasonObject

Reason for why the company is exempt from providing ownership information.



1530
1531
1532
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1530

def ownership_exemption_reason
  @ownership_exemption_reason
end