Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::PersonsProvided
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#directors ⇒ Object
Whether the company’s directors have been provided.
-
#executives ⇒ Object
Whether the company’s executives have been provided.
-
#owners ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
Instance Method Summary collapse
-
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
constructor
A new instance of PersonsProvided.
Methods inherited from RequestParams
Constructor Details
#initialize(directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil) ⇒ PersonsProvided
Returns a new instance of PersonsProvided.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1401 def initialize( directors: nil, executives: nil, owners: nil, ownership_exemption_reason: nil ) @directors = directors @executives = executives @owners = owners @ownership_exemption_reason = ownership_exemption_reason end |
Instance Attribute Details
#directors ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1393 1394 1395 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1393 def directors @directors end |
#executives ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1395 1396 1397 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1395 def executives @executives end |
#owners ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the [Persons API](docs.stripe.com/api/v2/core/accounts/createperson).
1397 1398 1399 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1397 def owners @owners end |
#ownership_exemption_reason ⇒ Object
Reason for why the company is exempt from providing ownership information.
1399 1400 1401 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1399 def ownership_exemption_reason @ownership_exemption_reason end |