Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::RepresentativeDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::RepresentativeDeclaration
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time marking when the representative attestation was made.
-
#ip ⇒ Object
The IP address from which the representative attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the representative attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
constructor
A new instance of RepresentativeDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
Returns a new instance of RepresentativeDeclaration.
1407 1408 1409 1410 1411 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1407 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1401 1402 1403 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1401 def date @date end |
#ip ⇒ Object
The IP address from which the representative attestation was made.
1403 1404 1405 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1403 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the representative attestation was made.
1405 1406 1407 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1405 def user_agent @user_agent end |