Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1377
1378
1379
1380
1381
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1377

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1371
1372
1373
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1371

def date
  @date
end

#ipObject

The IP address from which the representative attestation was made.



1373
1374
1375
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1373

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative attestation was made.



1375
1376
1377
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1375

def user_agent
  @user_agent
end