Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1674
1675
1676
1677
1678
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1674

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



1668
1669
1670
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1668

def date
  @date
end

#ipObject

The IP address from which the representative attestation was made.



1670
1671
1672
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1670

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative attestation was made.



1672
1673
1674
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1672

def user_agent
  @user_agent
end