Class: Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Attestations::TermsOfService::Account
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The time when the Account’s representative accepted the terms of service.
-
#ip ⇒ Object
The IP address from which the Account’s representative accepted the terms of service.
-
#user_agent ⇒ Object
The user agent of the browser from which the Account’s representative accepted the terms of service.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
1294 1295 1296 1297 1298 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1294 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The time when the Account’s representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
1288 1289 1290 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1288 def date @date end |
#ip ⇒ Object
The IP address from which the Account’s representative accepted the terms of service.
1290 1291 1292 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1290 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the Account’s representative accepted the terms of service.
1292 1293 1294 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1292 def user_agent @user_agent end |