Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1702 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
1676 1677 1678 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1676 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
1678 1679 1680 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1678 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1680 1681 1682 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1680 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1682 1683 1684 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1682 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1684 1685 1686 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1684 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1686 1687 1688 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1686 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1688 1689 1690 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1688 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1690 1691 1692 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1690 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1692 1693 1694 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1692 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1694 1695 1696 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1694 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1696 1697 1698 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1696 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1698 1699 1700 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1698 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1700 1701 1702 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1700 def structure @structure end |