Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the business.
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2093 def initialize( additional_addresses: nil, address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @additional_addresses = additional_addresses @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the business.
2067 2068 2069 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2067 def additional_addresses @additional_addresses end |
#address ⇒ Object
The business registration address of the business entity.
2069 2070 2071 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2069 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
2071 2072 2073 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2071 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
2073 2074 2075 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2073 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
2075 2076 2077 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2075 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
2077 2078 2079 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2077 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
2079 2080 2081 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2079 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
2081 2082 2083 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2081 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
2083 2084 2085 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2083 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
2085 2086 2087 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2085 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
2087 2088 2089 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2087 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
2089 2090 2091 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2089 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
2091 2092 2093 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2091 def structure @structure end |