Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2052

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2028
2029
2030
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2028

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2030
2031
2032
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2030

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



2032
2033
2034
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2032

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



2034
2035
2036
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2034

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2036
2037
2038
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2036

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2038
2039
2040
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2038

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2040
2041
2042
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2040

def phone
  @phone
end

#registered_nameObject

The business legal name.



2042
2043
2044
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2042

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



2044
2045
2046
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2044

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2046
2047
2048
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2046

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2048
2049
2050
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2048

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2050
2051
2052
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2050

def structure
  @structure
end