Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3306
3307
3308
3309
3310
3311
3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3306

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3280
3281
3282
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3280

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3282
3283
3284
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3282

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



3284
3285
3286
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3284

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



3286
3287
3288
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3286

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3288
3289
3290
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3288

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3290
3291
3292
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3290

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3292
3293
3294
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3292

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3294
3295
3296
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3294

def phone
  @phone
end

#registered_nameObject

The business legal name.



3296
3297
3298
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3296

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



3298
3299
3300
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3298

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3300
3301
3302
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3300

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3302
3303
3304
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3302

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3304
3305
3306
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3304

def structure
  @structure
end