Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
1944
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1918

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



1894
1895
1896
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1894

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



1896
1897
1898
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1896

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



1898
1899
1900
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1898

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



1900
1901
1902
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1900

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



1902
1903
1904
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1902

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



1904
1905
1906
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1904

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



1906
1907
1908
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1906

def phone
  @phone
end

#registered_nameObject

The business legal name.



1908
1909
1910
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1908

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



1910
1911
1912
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1910

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



1912
1913
1914
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1912

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



1914
1915
1916
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1914

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



1916
1917
1918
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1916

def structure
  @structure
end