Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1648 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
1624 1625 1626 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1624 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1626 1627 1628 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1626 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1628 1629 1630 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1628 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1630 1631 1632 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1630 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1632 1633 1634 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1632 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1634 1635 1636 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1634 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1636 1637 1638 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1636 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1638 1639 1640 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1638 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1640 1641 1642 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1640 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1642 1643 1644 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1642 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1644 1645 1646 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1644 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1646 1647 1648 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1646 def structure @structure end |