Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
3296
3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3281

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



3255
3256
3257
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3255

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



3257
3258
3259
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3257

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



3259
3260
3261
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3259

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



3261
3262
3263
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3261

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



3263
3264
3265
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3263

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



3265
3266
3267
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3265

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



3267
3268
3269
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3267

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



3269
3270
3271
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3269

def phone
  @phone
end

#registered_nameObject

The business legal name.



3271
3272
3273
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3271

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



3273
3274
3275
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3273

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



3275
3276
3277
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3275

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



3277
3278
3279
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3277

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



3279
3280
3281
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3279

def structure
  @structure
end