Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1896 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
1872 1873 1874 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1872 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1874 1875 1876 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1874 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1876 1877 1878 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1876 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
1878 1879 1880 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1878 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1880 1881 1882 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1880 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1882 1883 1884 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1882 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1884 1885 1886 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1884 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1886 1887 1888 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1886 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
1888 1889 1890 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1888 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1890 1891 1892 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1890 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1892 1893 1894 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1892 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1894 1895 1896 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1894 def structure @structure end |