Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3207 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
3181 3182 3183 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3181 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
3183 3184 3185 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3183 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
3185 3186 3187 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3185 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
3187 3188 3189 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3187 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
3189 3190 3191 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3189 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
3191 3192 3193 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3191 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
3193 3194 3195 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3193 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
3195 3196 3197 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3195 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
3197 3198 3199 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3197 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
3199 3200 3201 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3199 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
3201 3202 3203 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3201 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
3203 3204 3205 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3203 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
3205 3206 3207 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3205 def structure @structure end |