Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2629

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  registration_date: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @registration_date = registration_date
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2603
2604
2605
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2603

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2605
2606
2607
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2605

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2607
2608
2609
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2607

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2609
2610
2611
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2609

def documents
  @documents
end

#estimated_worker_countObject

Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).



2611
2612
2613
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2611

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2613
2614
2615
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2613

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2615
2616
2617
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2615

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2617
2618
2619
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2617

def phone
  @phone
end

#registered_nameObject

The business legal name.



2619
2620
2621
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2619

def registered_name
  @registered_name
end

#registration_dateObject

When the business was incorporated or registered.



2621
2622
2623
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2621

def registration_date
  @registration_date
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2623
2624
2625
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2623

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2625
2626
2627
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2625

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2627
2628
2629
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2627

def structure
  @structure
end