Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3151 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
3125 3126 3127 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3125 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
3127 3128 3129 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3127 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
3129 3130 3131 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3129 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
3131 3132 3133 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3131 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
3133 3134 3135 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3133 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
3135 3136 3137 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3135 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
3137 3138 3139 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3137 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
3139 3140 3141 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3139 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
3141 3142 3143 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3141 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
3143 3144 3145 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3143 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
3145 3146 3147 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3145 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
3147 3148 3149 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3147 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
3149 3150 3151 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3149 def structure @structure end |