Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, RegistrationDate, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#registration_date ⇒ Object
When the business was incorporated or registered.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2579 def initialize( address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, registration_date: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @compliance_screening_description = compliance_screening_description @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @registration_date = registration_date @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
2553 2554 2555 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2553 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
2555 2556 2557 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2555 def annual_revenue @annual_revenue end |
#compliance_screening_description ⇒ Object
A detailed description of the business’s compliance and anti-money laundering controls and practices.
2557 2558 2559 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2557 def compliance_screening_description @compliance_screening_description end |
#documents ⇒ Object
A document verifying the business.
2559 2560 2561 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2559 def documents @documents end |
#estimated_worker_count ⇒ Object
Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
2561 2562 2563 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2561 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
2563 2564 2565 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2563 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
2565 2566 2567 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2565 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
2567 2568 2569 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2567 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
2569 2570 2571 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2569 def registered_name @registered_name end |
#registration_date ⇒ Object
When the business was incorporated or registered.
2571 2572 2573 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2571 def registration_date @registration_date end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
2573 2574 2575 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2573 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
2575 2576 2577 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2575 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
2577 2578 2579 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2577 def structure @structure end |