Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2550

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2526
2527
2528
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2526

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2528
2529
2530
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2528

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2530
2531
2532
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2530

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2532
2533
2534
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2532

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2534
2535
2536
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2534

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2536
2537
2538
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2536

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2538
2539
2540
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2538

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2540
2541
2542
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2540

def phone
  @phone
end

#registered_nameObject

The business legal name.



2542
2543
2544
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2542

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2544
2545
2546
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2544

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2546
2547
2548
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2546

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2548
2549
2550
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2548

def structure
  @structure
end