Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2325

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2301
2302
2303
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2301

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2303
2304
2305
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2303

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2305
2306
2307
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2305

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2307
2308
2309
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2307

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2309
2310
2311
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2309

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2311
2312
2313
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2311

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2313
2314
2315
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2313

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2315
2316
2317
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2315

def phone
  @phone
end

#registered_nameObject

The business legal name.



2317
2318
2319
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2317

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2319
2320
2321
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2319

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2321
2322
2323
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2321

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2323
2324
2325
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2323

def structure
  @structure
end