Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, compliance_screening_description: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2439

def initialize(
  address: nil,
  annual_revenue: nil,
  compliance_screening_description: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @compliance_screening_description = compliance_screening_description
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2415
2416
2417
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2415

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2417
2418
2419
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2417

def annual_revenue
  @annual_revenue
end

#compliance_screening_descriptionObject

A detailed description of the business’s compliance and anti-money laundering controls and practices.



2419
2420
2421
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2419

def compliance_screening_description
  @compliance_screening_description
end

#documentsObject

A document verifying the business.



2421
2422
2423
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2421

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2423
2424
2425
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2423

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2425
2426
2427
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2425

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2427
2428
2429
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2427

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2429
2430
2431
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2429

def phone
  @phone
end

#registered_nameObject

The business legal name.



2431
2432
2433
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2431

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2433
2434
2435
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2433

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2435
2436
2437
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2435

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2437
2438
2439
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2437

def structure
  @structure
end