Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails

Returns a new instance of BusinessDetails.



2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2186

def initialize(
  address: nil,
  annual_revenue: nil,
  documents: nil,
  estimated_worker_count: nil,
  id_numbers: nil,
  monthly_estimated_revenue: nil,
  phone: nil,
  registered_name: nil,
  script_addresses: nil,
  script_names: nil,
  structure: nil
)
  @address = address
  @annual_revenue = annual_revenue
  @documents = documents
  @estimated_worker_count = estimated_worker_count
  @id_numbers = id_numbers
  @monthly_estimated_revenue = monthly_estimated_revenue
  @phone = phone
  @registered_name = registered_name
  @script_addresses = script_addresses
  @script_names = script_names
  @structure = structure
end

Instance Attribute Details

#addressObject

The business registration address of the business entity.



2164
2165
2166
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2164

def address
  @address
end

#annual_revenueObject

The business gross annual revenue for its preceding fiscal year.



2166
2167
2168
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2166

def annual_revenue
  @annual_revenue
end

#documentsObject

A document verifying the business.



2168
2169
2170
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2168

def documents
  @documents
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2170
2171
2172
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2170

def estimated_worker_count
  @estimated_worker_count
end

#id_numbersObject

The ID numbers of a business entity.



2172
2173
2174
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2172

def id_numbers
  @id_numbers
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business.



2174
2175
2176
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2174

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#phoneObject

The phone number of the Business Entity.



2176
2177
2178
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2176

def phone
  @phone
end

#registered_nameObject

The business legal name.



2178
2179
2180
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2178

def registered_name
  @registered_name
end

#script_addressesObject

The business registration address of the business entity in non latin script.



2180
2181
2182
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2180

def script_addresses
  @script_addresses
end

#script_namesObject

The business legal name in non latin script.



2182
2183
2184
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2182

def script_names
  @script_names
end

#structureObject

The category identifying the legal structure of the business.



2184
2185
2186
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2184

def structure
  @structure
end