Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2155 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
2133 2134 2135 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2133 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
2135 2136 2137 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2135 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
2137 2138 2139 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2137 def documents @documents end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
2139 2140 2141 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2139 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
2141 2142 2143 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2141 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
2143 2144 2145 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2143 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
2145 2146 2147 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2145 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
2147 2148 2149 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2147 def registered_name @registered_name end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
2149 2150 2151 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2149 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
2151 2152 2153 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2151 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
2153 2154 2155 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2153 def structure @structure end |