Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Address, AnnualRevenue, Documents, IdNumber, MonthlyEstimatedRevenue, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#address ⇒ Object
The business registration address of the business entity.
-
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
-
#documents ⇒ Object
A document verifying the business.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#id_numbers ⇒ Object
The ID numbers of a business entity.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#phone ⇒ Object
The phone number of the Business Entity.
-
#registered_name ⇒ Object
The business legal name.
-
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
-
#script_names ⇒ Object
The business legal name in non latin script.
-
#structure ⇒ Object
The category identifying the legal structure of the business.
Instance Method Summary collapse
-
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
constructor
A new instance of BusinessDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil) ⇒ BusinessDetails
Returns a new instance of BusinessDetails.
1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1728 def initialize( address: nil, annual_revenue: nil, documents: nil, estimated_worker_count: nil, id_numbers: nil, monthly_estimated_revenue: nil, phone: nil, registered_name: nil, script_addresses: nil, script_names: nil, structure: nil ) @address = address @annual_revenue = annual_revenue @documents = documents @estimated_worker_count = estimated_worker_count @id_numbers = id_numbers @monthly_estimated_revenue = monthly_estimated_revenue @phone = phone @registered_name = registered_name @script_addresses = script_addresses @script_names = script_names @structure = structure end |
Instance Attribute Details
#address ⇒ Object
The business registration address of the business entity.
1706 1707 1708 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1706 def address @address end |
#annual_revenue ⇒ Object
The business gross annual revenue for its preceding fiscal year.
1708 1709 1710 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1708 def annual_revenue @annual_revenue end |
#documents ⇒ Object
A document verifying the business.
1710 1711 1712 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1710 def documents @documents end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
1712 1713 1714 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1712 def estimated_worker_count @estimated_worker_count end |
#id_numbers ⇒ Object
The ID numbers of a business entity.
1714 1715 1716 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1714 def id_numbers @id_numbers end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
1716 1717 1718 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1716 def monthly_estimated_revenue @monthly_estimated_revenue end |
#phone ⇒ Object
The phone number of the Business Entity.
1718 1719 1720 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1718 def phone @phone end |
#registered_name ⇒ Object
The business legal name.
1720 1721 1722 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1720 def registered_name @registered_name end |
#script_addresses ⇒ Object
The business registration address of the business entity in non latin script.
1722 1723 1724 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1722 def script_addresses @script_addresses end |
#script_names ⇒ Object
The business legal name in non latin script.
1724 1725 1726 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1724 def script_names @script_names end |
#structure ⇒ Object
The category identifying the legal structure of the business.
1726 1727 1728 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1726 def structure @structure end |