Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::AnnualRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::AnnualRevenue
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: Amount
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
-
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
constructor
A new instance of AnnualRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
Returns a new instance of AnnualRevenue.
1521 1522 1523 1524 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1521 def initialize(amount: nil, fiscal_year_end: nil) @amount = amount @fiscal_year_end = fiscal_year_end end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the smallest currency unit.
1517 1518 1519 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1517 def amount @amount end |
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
1519 1520 1521 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1519 def fiscal_year_end @fiscal_year_end end |