Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
A document verifying the business.
-
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
Returns a new instance of Documents.
1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1698 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @primary_verification = primary_verification @proof_of_address = proof_of_address @proof_of_registration = proof_of_registration @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
1678 1679 1680 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1678 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
1680 1681 1682 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1680 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
1682 1683 1684 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1682 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
1684 1685 1686 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1684 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
1686 1687 1688 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1686 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
1688 1689 1690 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1688 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object
A document verifying the business.
1690 1691 1692 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1690 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
1692 1693 1694 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1692 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
1694 1695 1696 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1694 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
1696 1697 1698 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1696 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |