Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#primary_verification ⇒ Object
A document verifying the business.
-
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
-
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
-
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents
Returns a new instance of Documents.
2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2940 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @primary_verification = primary_verification @proof_of_address = proof_of_address @proof_of_registration = proof_of_registration @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
2920 2921 2922 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2920 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
2922 2923 2924 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2922 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
2924 2925 2926 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2924 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.
2926 2927 2928 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2926 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
2928 2929 2930 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2928 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
2930 2931 2932 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2930 def company_tax_id_verification @company_tax_id_verification end |
#primary_verification ⇒ Object
A document verifying the business.
2932 2933 2934 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2932 def primary_verification @primary_verification end |
#proof_of_address ⇒ Object
One or more documents that demonstrate proof of address.
2934 2935 2936 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2934 def proof_of_address @proof_of_address end |
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
2936 2937 2938 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2936 def proof_of_registration @proof_of_registration end |
#proof_of_ultimate_beneficial_ownership ⇒ Object
One or more documents that demonstrate proof of ultimate beneficial ownership.
2938 2939 2940 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2938 def proof_of_ultimate_beneficial_ownership @proof_of_ultimate_beneficial_ownership end |