Class: Stripe::V2::Core::AccountUpdateParams::Identity::BusinessDetails::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, PrimaryVerification, ProofOfAddress, ProofOfRegistration, ProofOfUltimateBeneficialOwnership

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, primary_verification: nil, proof_of_address: nil, proof_of_registration: nil, proof_of_ultimate_beneficial_ownership: nil) ⇒ Documents

Returns a new instance of Documents.



2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2005

def initialize(
  bank_account_ownership_verification: nil,
  company_license: nil,
  company_memorandum_of_association: nil,
  company_ministerial_decree: nil,
  company_registration_verification: nil,
  company_tax_id_verification: nil,
  primary_verification: nil,
  proof_of_address: nil,
  proof_of_registration: nil,
  proof_of_ultimate_beneficial_ownership: nil
)
  @bank_account_ownership_verification = 
  @company_license = company_license
  @company_memorandum_of_association = company_memorandum_of_association
  @company_ministerial_decree = company_ministerial_decree
  @company_registration_verification = company_registration_verification
  @company_tax_id_verification = company_tax_id_verification
  @primary_verification = primary_verification
  @proof_of_address = proof_of_address
  @proof_of_registration = proof_of_registration
  @proof_of_ultimate_beneficial_ownership = proof_of_ultimate_beneficial_ownership
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.



1985
1986
1987
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1985

def 
  @bank_account_ownership_verification
end

#company_licenseObject

One or more documents that demonstrate proof of a company’s license to operate.



1987
1988
1989
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1987

def company_license
  @company_license
end

#company_memorandum_of_associationObject

One or more documents showing the company’s Memorandum of Association.



1989
1990
1991
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1989

def company_memorandum_of_association
  @company_memorandum_of_association
end

#company_ministerial_decreeObject

Certain countries only: One or more documents showing the ministerial decree legalizing the company’s establishment.



1991
1992
1993
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1991

def company_ministerial_decree
  @company_ministerial_decree
end

#company_registration_verificationObject

One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.



1993
1994
1995
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1993

def company_registration_verification
  @company_registration_verification
end

#company_tax_id_verificationObject

One or more documents that demonstrate proof of a company’s tax ID.



1995
1996
1997
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1995

def company_tax_id_verification
  @company_tax_id_verification
end

#primary_verificationObject

A document verifying the business.



1997
1998
1999
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1997

def primary_verification
  @primary_verification
end

#proof_of_addressObject

One or more documents that demonstrate proof of address.



1999
2000
2001
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1999

def proof_of_address
  @proof_of_address
end

#proof_of_registrationObject

One or more documents showing the company’s proof of registration with the national business registry.



2001
2002
2003
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2001

def proof_of_registration
  @proof_of_registration
end

#proof_of_ultimate_beneficial_ownershipObject

One or more documents that demonstrate proof of ultimate beneficial ownership.



2003
2004
2005
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2003

def proof_of_ultimate_beneficial_ownership
  @proof_of_ultimate_beneficial_ownership
end