Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual's residential address.
-
#date_of_birth ⇒ Object
The individual's date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual's email address.
-
#given_name ⇒ Object
The individual's first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual's phone number.
-
#political_exposure ⇒ Object
The individual's political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual's last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
6136 6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 6161 6162 6163 6164 6165 6166 6167 6168 6169 6170 6171 6172 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6136 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
6102 6103 6104 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6102 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
6104 6105 6106 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6104 def additional_names @additional_names end |
#address ⇒ Object
The individual's residential address.
6106 6107 6108 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6106 def address @address end |
#date_of_birth ⇒ Object
The individual's date of birth.
6108 6109 6110 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6108 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
6110 6111 6112 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6110 def documents @documents end |
#email ⇒ Object
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
6112 6113 6114 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6112 def email @email end |
#given_name ⇒ Object
The individual's first name.
6114 6115 6116 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6114 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
6116 6117 6118 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6116 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
6118 6119 6120 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6118 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
6120 6121 6122 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6120 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
6122 6123 6124 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6122 def nationalities @nationalities end |
#phone ⇒ Object
The individual's phone number.
6124 6125 6126 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6124 def phone @phone end |
#political_exposure ⇒ Object
The individual's political exposure.
6126 6127 6128 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6126 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
6128 6129 6130 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6128 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
6130 6131 6132 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6130 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
6132 6133 6134 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6132 def script_names @script_names end |
#surname ⇒ Object
The individual's last name.
6134 6135 6136 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6134 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
6174 6175 6176 6177 6178 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 6174 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |