Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual's residential address.
-
#date_of_birth ⇒ Object
The individual's date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual's email address.
-
#given_name ⇒ Object
The individual's first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual's phone number.
-
#political_exposure ⇒ Object
The individual's political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual's last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2142 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2108 2109 2110 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2108 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2110 2111 2112 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2110 def additional_names @additional_names end |
#address ⇒ Object
The individual's residential address.
2112 2113 2114 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2112 def address @address end |
#date_of_birth ⇒ Object
The individual's date of birth.
2114 2115 2116 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2114 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2116 2117 2118 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2116 def documents @documents end |
#email ⇒ Object
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
2118 2119 2120 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2118 def email @email end |
#given_name ⇒ Object
The individual's first name.
2120 2121 2122 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2120 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2122 2123 2124 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2122 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
2124 2125 2126 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2124 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2126 2127 2128 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2126 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
2128 2129 2130 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2128 def nationalities @nationalities end |
#phone ⇒ Object
The individual's phone number.
2130 2131 2132 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2130 def phone @phone end |
#political_exposure ⇒ Object
The individual's political exposure.
2132 2133 2134 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2132 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
2134 2135 2136 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2134 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2136 2137 2138 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2136 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2138 2139 2140 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2138 def script_names @script_names end |
#surname ⇒ Object
The individual's last name.
2140 2141 2142 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2140 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
2180 2181 2182 2183 2184 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2180 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |