Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual's residential address.
-
#date_of_birth ⇒ Object
The individual's date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual's email address.
-
#given_name ⇒ Object
The individual's first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual's phone number.
-
#political_exposure ⇒ Object
The individual's political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual's last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2533 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2499 2500 2501 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2499 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2501 2502 2503 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2501 def additional_names @additional_names end |
#address ⇒ Object
The individual's residential address.
2503 2504 2505 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2503 def address @address end |
#date_of_birth ⇒ Object
The individual's date of birth.
2505 2506 2507 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2505 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2507 2508 2509 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2507 def documents @documents end |
#email ⇒ Object
The individual's email address. You can only set this field when the Account is configured as a merchant or recipient. Use contact_email as the primary contact email for this Account.
2509 2510 2511 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2509 def email @email end |
#given_name ⇒ Object
The individual's first name.
2511 2512 2513 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2511 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2513 2514 2515 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2513 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual's gender (International regulations require either "male" or "female").
2515 2516 2517 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2515 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2517 2518 2519 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2517 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
2519 2520 2521 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2519 def nationalities @nationalities end |
#phone ⇒ Object
The individual's phone number.
2521 2522 2523 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2521 def phone @phone end |
#political_exposure ⇒ Object
The individual's political exposure.
2523 2524 2525 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2523 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account's identity.
2525 2526 2527 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2525 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2527 2528 2529 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2527 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2529 2530 2531 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2529 def script_names @script_names end |
#surname ⇒ Object
The individual's last name.
2531 2532 2533 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2531 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
2571 2572 2573 2574 2575 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2571 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |