Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2490 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2456 2457 2458 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2456 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2458 2459 2460 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2458 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2460 2461 2462 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2460 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2462 2463 2464 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2462 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2464 2465 2466 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2464 def documents @documents end |
#email ⇒ Object
The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
2466 2467 2468 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2466 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2468 2469 2470 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2468 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2470 2471 2472 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2470 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2472 2473 2474 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2472 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2474 2475 2476 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2474 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2476 2477 2478 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2476 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2478 2479 2480 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2478 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2480 2481 2482 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2480 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2482 2483 2484 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2482 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2484 2485 2486 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2484 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2486 2487 2488 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2486 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2488 2489 2490 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2488 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
2528 2529 2530 2531 2532 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2528 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |