Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 3778 3779 3780 3781 3782 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3746 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
3712 3713 3714 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3712 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
3714 3715 3716 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3714 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
3716 3717 3718 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3716 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
3718 3719 3720 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3718 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
3720 3721 3722 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3720 def documents @documents end |
#email ⇒ Object
The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
3722 3723 3724 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3722 def email @email end |
#given_name ⇒ Object
The individual’s first name.
3724 3725 3726 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3724 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
3726 3727 3728 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3726 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
3728 3729 3730 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3728 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3730 3731 3732 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3730 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3732 3733 3734 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3732 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
3734 3735 3736 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3734 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
3736 3737 3738 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3736 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
3738 3739 3740 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3738 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
3740 3741 3742 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3740 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
3742 3743 3744 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3742 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
3744 3745 3746 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3744 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
3784 3785 3786 3787 3788 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3784 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |