Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2356 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2322 2323 2324 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2322 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2324 2325 2326 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2324 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2326 2327 2328 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2326 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2328 2329 2330 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2328 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2330 2331 2332 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2330 def documents @documents end |
#email ⇒ Object
The individual’s email address. You can only set this field when the Account is configured as a ‘merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
2332 2333 2334 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2332 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2334 2335 2336 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2334 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2336 2337 2338 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2336 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2338 2339 2340 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2338 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2340 2341 2342 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2340 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2342 2343 2344 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2342 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2344 2345 2346 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2344 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2346 2347 2348 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2346 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2348 2349 2350 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2348 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2350 2351 2352 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2350 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2352 2353 2354 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2352 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2354 2355 2356 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2354 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
2394 2395 2396 2397 2398 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2394 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |