Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 3680 3681 3682 3683 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3647 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
3613 3614 3615 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3613 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
3615 3616 3617 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3615 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
3617 3618 3619 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3617 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
3619 3620 3621 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3619 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
3621 3622 3623 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3621 def documents @documents end |
#email ⇒ Object
The individual’s email address.
3623 3624 3625 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3623 def email @email end |
#given_name ⇒ Object
The individual’s first name.
3625 3626 3627 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3625 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
3627 3628 3629 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3627 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
3629 3630 3631 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3629 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3631 3632 3633 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3631 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3633 3634 3635 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3633 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
3635 3636 3637 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3635 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
3637 3638 3639 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3637 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
3639 3640 3641 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3639 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
3641 3642 3643 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3641 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
3643 3644 3645 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3643 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
3645 3646 3647 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3645 def surname @surname end |
Class Method Details
.field_encodings ⇒ Object
3685 3686 3687 3688 3689 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3685 def self.field_encodings @field_encodings = { relationship: { kind: :object, fields: { percent_ownership: :decimal_string } }, } end |