Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3065 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
3031 3032 3033 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3031 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
3033 3034 3035 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3033 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
3035 3036 3037 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3035 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
3037 3038 3039 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3037 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
3039 3040 3041 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3039 def documents @documents end |
#email ⇒ Object
The individual’s email address.
3041 3042 3043 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3041 def email @email end |
#given_name ⇒ Object
The individual’s first name.
3043 3044 3045 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3043 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
3045 3046 3047 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3045 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
3047 3048 3049 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3047 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3049 3050 3051 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3049 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3051 3052 3053 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3051 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
3053 3054 3055 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3053 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
3055 3056 3057 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3055 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
3057 3058 3059 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3057 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
3059 3060 3061 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3059 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
3061 3062 3063 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3061 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
3063 3064 3065 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3063 def surname @surname end |