Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2322 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2288 2289 2290 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2288 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2290 2291 2292 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2290 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2292 2293 2294 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2292 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2294 2295 2296 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2294 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2296 2297 2298 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2296 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2298 2299 2300 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2298 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2300 2301 2302 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2300 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2302 2303 2304 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2302 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2304 2305 2306 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2304 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2306 2307 2308 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2306 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2308 2309 2310 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2308 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2310 2311 2312 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2310 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2312 2313 2314 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2312 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2314 2315 2316 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2314 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2316 2317 2318 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2316 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2318 2319 2320 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2318 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2320 2321 2322 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2320 def surname @surname end |