Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3015 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2981 2982 2983 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2981 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2983 2984 2985 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2983 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2985 2986 2987 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2985 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2987 2988 2989 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2987 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2989 2990 2991 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2989 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2991 2992 2993 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2991 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2993 2994 2995 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2993 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2995 2996 2997 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2995 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2997 2998 2999 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2997 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2999 3000 3001 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2999 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3001 3002 3003 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3001 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
3003 3004 3005 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3003 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
3005 3006 3007 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3005 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
3007 3008 3009 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3007 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
3009 3010 3011 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3009 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
3011 3012 3013 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3011 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
3013 3014 3015 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3013 def surname @surname end |