Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2873 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2839 2840 2841 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2839 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2841 2842 2843 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2841 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2843 2844 2845 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2843 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2845 2846 2847 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2845 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2847 2848 2849 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2847 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2849 2850 2851 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2849 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2851 2852 2853 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2851 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2853 2854 2855 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2853 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2855 2856 2857 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2855 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2857 2858 2859 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2857 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2859 2860 2861 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2859 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2861 2862 2863 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2861 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2863 2864 2865 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2863 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2865 2866 2867 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2865 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2867 2868 2869 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2867 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2869 2870 2871 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2869 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2871 2872 2873 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2871 def surname @surname end |