Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2984 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2950 2951 2952 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2950 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2952 2953 2954 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2952 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2954 2955 2956 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2954 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2956 2957 2958 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2956 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2958 2959 2960 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2958 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2960 2961 2962 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2960 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2962 2963 2964 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2962 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2964 2965 2966 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2964 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2966 2967 2968 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2966 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2968 2969 2970 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2968 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2970 2971 2972 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2970 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2972 2973 2974 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2972 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2974 2975 2976 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2974 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2976 2977 2978 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2976 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2978 2979 2980 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2978 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2980 2981 2982 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2980 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2982 2983 2984 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2982 def surname @surname end |