Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2759 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2725 2726 2727 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2725 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2727 2728 2729 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2727 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2729 2730 2731 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2729 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2731 2732 2733 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2731 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2733 2734 2735 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2733 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2735 2736 2737 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2735 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2737 2738 2739 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2737 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2739 2740 2741 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2739 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2741 2742 2743 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2741 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2743 2744 2745 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2743 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2745 2746 2747 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2745 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2747 2748 2749 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2747 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2749 2750 2751 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2749 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2751 2752 2753 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2751 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2753 2754 2755 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2753 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2755 2756 2757 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2755 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2757 2758 2759 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2757 def surname @surname end |