Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2618 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2584 2585 2586 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2584 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2586 2587 2588 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2586 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2588 2589 2590 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2588 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2590 2591 2592 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2590 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2592 2593 2594 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2592 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2594 2595 2596 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2594 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2596 2597 2598 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2596 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2598 2599 2600 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2598 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2600 2601 2602 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2600 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2602 2603 2604 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2602 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2604 2605 2606 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2604 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2606 2607 2608 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2606 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2608 2609 2610 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2608 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2610 2611 2612 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2610 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2612 2613 2614 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2612 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2614 2615 2616 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2614 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2616 2617 2618 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2616 def surname @surname end |