Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2160 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender @metadata = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2126 2127 2128 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2126 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2128 2129 2130 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2128 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2130 2131 2132 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2130 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2132 2133 2134 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2132 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2134 2135 2136 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2134 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2136 2137 2138 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2136 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2138 2139 2140 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2138 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2140 2141 2142 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2140 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2142 2143 2144 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2142 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2144 2145 2146 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2144 def @metadata end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2146 2147 2148 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2146 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2148 2149 2150 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2148 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2150 2151 2152 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2150 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2152 2153 2154 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2152 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2154 2155 2156 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2154 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2156 2157 2158 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2156 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2158 2159 2160 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2158 def surname @surname end |