Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual

Returns a new instance of Individual.



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2082

def initialize(
  additional_addresses: nil,
  additional_names: nil,
  address: nil,
  date_of_birth: nil,
  documents: nil,
  email: nil,
  given_name: nil,
  id_numbers: nil,
  legal_gender: nil,
  metadata: nil,
  nationalities: nil,
  phone: nil,
  political_exposure: nil,
  relationship: nil,
  script_addresses: nil,
  script_names: nil,
  surname: nil
)
  @additional_addresses = additional_addresses
  @additional_names = additional_names
  @address = address
  @date_of_birth = date_of_birth
  @documents = documents
  @email = email
  @given_name = given_name
  @id_numbers = id_numbers
  @legal_gender = legal_gender
   = 
  @nationalities = nationalities
  @phone = phone
  @political_exposure = political_exposure
  @relationship = relationship
  @script_addresses = script_addresses
  @script_names = script_names
  @surname = surname
end

Instance Attribute Details

#additional_addressesObject

Additional addresses associated with the individual.



2048
2049
2050
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2048

def additional_addresses
  @additional_addresses
end

#additional_namesObject

Additional names (e.g. aliases) associated with the individual.



2050
2051
2052
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2050

def additional_names
  @additional_names
end

#addressObject

The individual’s residential address.



2052
2053
2054
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2052

def address
  @address
end

#date_of_birthObject

The individual’s date of birth.



2054
2055
2056
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2054

def date_of_birth
  @date_of_birth
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2056
2057
2058
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2056

def documents
  @documents
end

#emailObject

The individual’s email address.



2058
2059
2060
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2058

def email
  @email
end

#given_nameObject

The individual’s first name.



2060
2061
2062
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2060

def given_name
  @given_name
end

#id_numbersObject

The identification numbers (e.g., SSN) associated with the individual.



2062
2063
2064
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2062

def id_numbers
  @id_numbers
end

The individual’s gender (International regulations require either “male” or “female”).



2064
2065
2066
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2064

def legal_gender
  @legal_gender
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2066
2067
2068
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2066

def 
  
end

#nationalitiesObject

The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



2068
2069
2070
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2068

def nationalities
  @nationalities
end

#phoneObject

The individual’s phone number.



2070
2071
2072
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2070

def phone
  @phone
end

#political_exposureObject

The individual’s political exposure.



2072
2073
2074
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2072

def political_exposure
  @political_exposure
end

#relationshipObject

The relationship that this individual has with the account’s identity.



2074
2075
2076
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2074

def relationship
  @relationship
end

#script_addressesObject

The script addresses (e.g., non-Latin characters) associated with the individual.



2076
2077
2078
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2076

def script_addresses
  @script_addresses
end

#script_namesObject

The individuals primary name in non latin script.



2078
2079
2080
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2078

def script_names
  @script_names
end

#surnameObject

The individual’s last name.



2080
2081
2082
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2080

def surname
  @surname
end