Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: AdditionalAddress, AdditionalName, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames
Instance Attribute Summary collapse
-
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
-
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
-
#address ⇒ Object
The individual’s residential address.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The individual’s email address.
-
#given_name ⇒ Object
The individual’s first name.
-
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
-
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#nationalities ⇒ Object
The countries where the individual is a national.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
The individual’s political exposure.
-
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
-
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
-
#script_names ⇒ Object
The individuals primary name in non latin script.
-
#surname ⇒ Object
The individual’s last name.
Instance Method Summary collapse
-
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil) ⇒ Individual
Returns a new instance of Individual.
2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2082 def initialize( additional_addresses: nil, additional_names: nil, address: nil, date_of_birth: nil, documents: nil, email: nil, given_name: nil, id_numbers: nil, legal_gender: nil, metadata: nil, nationalities: nil, phone: nil, political_exposure: nil, relationship: nil, script_addresses: nil, script_names: nil, surname: nil ) @additional_addresses = additional_addresses @additional_names = additional_names @address = address @date_of_birth = date_of_birth @documents = documents @email = email @given_name = given_name @id_numbers = id_numbers @legal_gender = legal_gender = @nationalities = nationalities @phone = phone @political_exposure = political_exposure @relationship = relationship @script_addresses = script_addresses @script_names = script_names @surname = surname end |
Instance Attribute Details
#additional_addresses ⇒ Object
Additional addresses associated with the individual.
2048 2049 2050 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2048 def additional_addresses @additional_addresses end |
#additional_names ⇒ Object
Additional names (e.g. aliases) associated with the individual.
2050 2051 2052 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2050 def additional_names @additional_names end |
#address ⇒ Object
The individual’s residential address.
2052 2053 2054 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2052 def address @address end |
#date_of_birth ⇒ Object
The individual’s date of birth.
2054 2055 2056 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2054 def date_of_birth @date_of_birth end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2056 2057 2058 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2056 def documents @documents end |
#email ⇒ Object
The individual’s email address.
2058 2059 2060 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2058 def email @email end |
#given_name ⇒ Object
The individual’s first name.
2060 2061 2062 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2060 def given_name @given_name end |
#id_numbers ⇒ Object
The identification numbers (e.g., SSN) associated with the individual.
2062 2063 2064 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2062 def id_numbers @id_numbers end |
#legal_gender ⇒ Object
The individual’s gender (International regulations require either “male” or “female”).
2064 2065 2066 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2064 def legal_gender @legal_gender end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2066 2067 2068 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2066 def end |
#nationalities ⇒ Object
The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2068 2069 2070 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2068 def nationalities @nationalities end |
#phone ⇒ Object
The individual’s phone number.
2070 2071 2072 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2070 def phone @phone end |
#political_exposure ⇒ Object
The individual’s political exposure.
2072 2073 2074 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2072 def political_exposure @political_exposure end |
#relationship ⇒ Object
The relationship that this individual has with the account’s identity.
2074 2075 2076 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2074 def relationship @relationship end |
#script_addresses ⇒ Object
The script addresses (e.g., non-Latin characters) associated with the individual.
2076 2077 2078 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2076 def script_addresses @script_addresses end |
#script_names ⇒ Object
The individuals primary name in non latin script.
2078 2079 2080 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2078 def script_names @script_names end |
#surname ⇒ Object
The individual’s last name.
2080 2081 2082 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2080 def surname @surname end |