Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3538

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



3528
3529
3530
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3528

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



3530
3531
3532
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3530

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



3532
3533
3534
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3532

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



3534
3535
3536
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3534

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



3536
3537
3538
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3536

def visa
  @visa
end