Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2148 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
2138 2139 2140 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2138 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
2140 2141 2142 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2140 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
2142 2143 2144 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2142 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
2144 2145 2146 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2144 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
2146 2147 2148 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2146 def visa @visa end |