Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



3439
3440
3441
3442
3443
3444
3445
3446
3447
3448
3449
3450
3451
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3439

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



3429
3430
3431
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3429

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



3431
3432
3433
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3431

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



3433
3434
3435
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3433

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



3435
3436
3437
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3435

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



3437
3438
3439
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3437

def visa
  @visa
end