Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



3413
3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3413

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



3403
3404
3405
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3403

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



3405
3406
3407
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3405

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



3407
3408
3409
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3407

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



3409
3410
3411
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3409

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



3411
3412
3413
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3411

def visa
  @visa
end