Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2811 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
2801 2802 2803 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2801 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
2803 2804 2805 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2803 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
2805 2806 2807 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2805 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
2807 2808 2809 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2807 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
2809 2810 2811 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2809 def visa @visa end |