Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2780

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



2770
2771
2772
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2770

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



2772
2773
2774
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2772

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



2774
2775
2776
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2774

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



2776
2777
2778
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2776

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



2778
2779
2780
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2778

def visa
  @visa
end