Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account's identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
-
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1973 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1963 1964 1965 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1963 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1965 1966 1967 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1965 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
1967 1968 1969 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1967 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
1969 1970 1971 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1969 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
1971 1972 1973 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1971 def title @title end |
Class Method Details
.field_encodings ⇒ Object
1987 1988 1989 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1987 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |