Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account's identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
-
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2364 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2354 2355 2356 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2354 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2356 2357 2358 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2356 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2358 2359 2360 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2358 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account's legal entity.
2360 2361 2362 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2360 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person's title (e.g., CEO, Support Engineer).
2362 2363 2364 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2362 def title @title end |
Class Method Details
.field_encodings ⇒ Object
2378 2379 2380 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2378 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |