Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2321 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2311 2312 2313 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2311 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2313 2314 2315 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2313 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2315 2316 2317 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2315 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2317 2318 2319 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2317 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2319 2320 2321 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2319 def title @title end |
Class Method Details
.field_encodings ⇒ Object
2335 2336 2337 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2335 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |