Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3577

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3567
3568
3569
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3567

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3569
3570
3571
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3569

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



3571
3572
3573
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3571

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3573
3574
3575
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3573

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3575
3576
3577
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3575

def title
  @title
end

Class Method Details

.field_encodingsObject



3591
3592
3593
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3591

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end