Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1917 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1907 1908 1909 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1907 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1909 1910 1911 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1909 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
1911 1912 1913 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1911 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
1913 1914 1915 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1913 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
1915 1916 1917 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1915 def title @title end |
Class Method Details
.field_encodings ⇒ Object
1931 1932 1933 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1931 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |