Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 3489 3490 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3478 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
3468 3469 3470 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3468 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
3470 3471 3472 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3470 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
3472 3473 3474 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3472 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
3474 3475 3476 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3474 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
3476 3477 3478 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3476 def title @title end |
Class Method Details
.field_encodings ⇒ Object
3492 3493 3494 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3492 def self.field_encodings @field_encodings = { percent_ownership: :decimal_string } end |