Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3452

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3442
3443
3444
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3442

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3444
3445
3446
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3444

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



3446
3447
3448
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3446

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3448
3449
3450
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3448

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3450
3451
3452
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3450

def title
  @title
end

Class Method Details

.field_encodingsObject



3466
3467
3468
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 3466

def self.field_encodings
  @field_encodings = { percent_ownership: :decimal_string }
end