Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1917

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1907
1908
1909
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1907

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1909
1910
1911
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1909

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



1911
1912
1913
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1911

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1913
1914
1915
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1913

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1915
1916
1917
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1915

def title
  @title
end