Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship
- Defined in:
- lib/stripe/params/v2/core/account_update_params.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s identity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2831 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
2821 2822 2823 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2821 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
2823 2824 2825 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2823 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s identity.
2825 2826 2827 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2825 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
2827 2828 2829 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2827 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
2829 2830 2831 |
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2829 def title @title end |