Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2453

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



2443
2444
2445
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2443

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



2445
2446
2447
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2445

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



2447
2448
2449
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2447

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



2449
2450
2451
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2449

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



2451
2452
2453
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 2451

def title
  @title
end