Class: Stripe::V2::Core::AccountUpdateParams::Identity::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1995

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1985
1986
1987
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1985

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1987
1988
1989
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1987

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s identity.



1989
1990
1991
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1989

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1991
1992
1993
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1991

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1993
1994
1995
# File 'lib/stripe/params/v2/core/account_update_params.rb', line 1993

def title
  @title
end