Class: Stripe::V2::Core::Accounts::PersonService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/v2/core/accounts/person_service.rb

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(account_id, params = {}, opts = {}) ⇒ Object

Create a Person. Adds an individual to an Account’s identity. You can set relationship attributes and identity information at creation.

** raises RateLimitError



12
13
14
15
16
17
18
19
20
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 12

def create(, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/accounts/%<account_id>s/persons", { account_id: CGI.escape() }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#delete(account_id, id, params = {}, opts = {}) ⇒ Object

Delete a Person associated with an Account.

** raises RateLimitError



25
26
27
28
29
30
31
32
33
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 25

def delete(, id, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(), id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(account_id, params = {}, opts = {}) ⇒ Object

Returns a paginated list of Persons associated with an Account.

** raises RateLimitError



38
39
40
41
42
43
44
45
46
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 38

def list(, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/core/accounts/%<account_id>s/persons", { account_id: CGI.escape() }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(account_id, id, params = {}, opts = {}) ⇒ Object

Retrieves a Person associated with an Account.

** raises RateLimitError



51
52
53
54
55
56
57
58
59
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 51

def retrieve(, id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(), id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(account_id, id, params = {}, opts = {}) ⇒ Object

Updates a Person associated with an Account.

** raises RateLimitError



64
65
66
67
68
69
70
71
72
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 64

def update(, id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(), id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end