Class: Stripe::V2::Core::Accounts::PersonService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Core::Accounts::PersonService
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(account_id, params = {}, opts = {}) ⇒ Object
Create a Person associated with an Account.
-
#delete(account_id, id, params = {}, opts = {}) ⇒ Object
Delete a Person associated with an Account.
-
#list(account_id, params = {}, opts = {}) ⇒ Object
Returns a list of Persons associated with an Account.
-
#retrieve(account_id, id, params = {}, opts = {}) ⇒ Object
Retrieves a Person associated with an Account.
-
#update(account_id, id, params = {}, opts = {}) ⇒ Object
Updates a Person associated with an Account.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(account_id, params = {}, opts = {}) ⇒ Object
Create a Person associated with an Account.
989 990 991 992 993 994 995 996 997 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 989 def create(account_id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/accounts/%<account_id>s/persons", { account_id: CGI.escape(account_id) }), params: params, opts: opts, base_address: :api ) end |
#delete(account_id, id, params = {}, opts = {}) ⇒ Object
Delete a Person associated with an Account.
1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1000 def delete(account_id, id, params = {}, opts = {}) request( method: :delete, path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(account_id, params = {}, opts = {}) ⇒ Object
Returns a list of Persons associated with an Account.
1011 1012 1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1011 def list(account_id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/accounts/%<account_id>s/persons", { account_id: CGI.escape(account_id) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(account_id, id, params = {}, opts = {}) ⇒ Object
Retrieves a Person associated with an Account.
1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1022 def retrieve(account_id, id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(account_id, id, params = {}, opts = {}) ⇒ Object
Updates a Person associated with an Account.
1033 1034 1035 1036 1037 1038 1039 1040 1041 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1033 def update(account_id, id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |