Class: Stripe::V2::Core::Accounts::PersonService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Core::Accounts::PersonService
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(account_id, params = {}, opts = {}) ⇒ Object
Create a Person associated with an Account.
-
#delete(account_id, id, params = {}, opts = {}) ⇒ Object
Delete a Person associated with an Account.
-
#list(account_id, params = {}, opts = {}) ⇒ Object
Returns a list of Persons associated with an Account.
-
#retrieve(account_id, id, params = {}, opts = {}) ⇒ Object
Retrieves a Person associated with an Account.
-
#update(account_id, id, params = {}, opts = {}) ⇒ Object
Updates a Person associated with an Account.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(account_id, params = {}, opts = {}) ⇒ Object
Create a Person associated with an Account.
983 984 985 986 987 988 989 990 991 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 983 def create(account_id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/accounts/%<account_id>s/persons", { account_id: CGI.escape(account_id) }), params: params, opts: opts, base_address: :api ) end |
#delete(account_id, id, params = {}, opts = {}) ⇒ Object
Delete a Person associated with an Account.
994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 994 def delete(account_id, id, params = {}, opts = {}) request( method: :delete, path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(account_id, params = {}, opts = {}) ⇒ Object
Returns a list of Persons associated with an Account.
1005 1006 1007 1008 1009 1010 1011 1012 1013 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1005 def list(account_id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/accounts/%<account_id>s/persons", { account_id: CGI.escape(account_id) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(account_id, id, params = {}, opts = {}) ⇒ Object
Retrieves a Person associated with an Account.
1016 1017 1018 1019 1020 1021 1022 1023 1024 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1016 def retrieve(account_id, id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(account_id, id, params = {}, opts = {}) ⇒ Object
Updates a Person associated with an Account.
1027 1028 1029 1030 1031 1032 1033 1034 1035 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 1027 def update(account_id, id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/accounts/%<account_id>s/persons/%<id>s", { account_id: CGI.escape(account_id), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |