Class: Stripe::V2::Core::Accounts::PersonService::CreateParams::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Accounts::PersonService::CreateParams::Documents
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Defined Under Namespace
Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa
Instance Attribute Summary collapse
-
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
-
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
-
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
-
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
-
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
Instance Method Summary collapse
-
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents
Returns a new instance of Documents.
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 242 def initialize( company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil ) @company_authorization = @passport = passport @primary_verification = primary_verification @secondary_verification = secondary_verification @visa = visa end |
Instance Attribute Details
#company_authorization ⇒ Object
One or more documents that demonstrate proof that this person is authorized to represent the company.
232 233 234 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 232 def @company_authorization end |
#passport ⇒ Object
One or more documents showing the person’s passport page with photo and personal data.
234 235 236 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 234 def passport @passport end |
#primary_verification ⇒ Object
An identifying document showing the person’s name, either a passport or local ID card.
236 237 238 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 236 def primary_verification @primary_verification end |
#secondary_verification ⇒ Object
A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
238 239 240 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 238 def secondary_verification @secondary_verification end |
#visa ⇒ Object
One or more documents showing the person’s visa required for living in the country where they are residing.
240 241 242 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 240 def visa @visa end |