Class: Stripe::V2::Core::Accounts::PersonService::CreateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/accounts/person_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 233

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



223
224
225
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 223

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



225
226
227
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 225

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



227
228
229
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 227

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



229
230
231
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 229

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



231
232
233
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 231

def visa
  @visa
end