Class: Stripe::V2::Core::Accounts::PersonService::CreateParams::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Accounts::PersonService::CreateParams::Relationship
- Defined in:
- lib/stripe/services/v2/core/accounts/person_service.rb
Instance Attribute Summary collapse
-
#authorizer ⇒ Object
Whether the individual is an authorizer of the Account’s legal entity.
-
#director ⇒ Object
Indicates whether the person is a director of the associated legal entity.
-
#executive ⇒ Object
Indicates whether the person is an executive of the associated legal entity.
-
#legal_guardian ⇒ Object
Indicates whether the person is a legal guardian of the associated legal entity.
-
#owner ⇒ Object
Indicates whether the person is an owner of the associated legal entity.
-
#percent_ownership ⇒ Object
The percentage of ownership the person has in the associated legal entity.
-
#representative ⇒ Object
Indicates whether the person is a representative of the associated legal entity.
-
#title ⇒ Object
The title or position the person holds in the associated legal entity.
Instance Method Summary collapse
-
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 278 def initialize( authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil ) @authorizer = @director = director @executive = executive @legal_guardian = legal_guardian @owner = owner @percent_ownership = percent_ownership @representative = representative @title = title end |
Instance Attribute Details
#authorizer ⇒ Object
Whether the individual is an authorizer of the Account’s legal entity.
262 263 264 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 262 def @authorizer end |
#director ⇒ Object
Indicates whether the person is a director of the associated legal entity.
264 265 266 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 264 def director @director end |
#executive ⇒ Object
Indicates whether the person is an executive of the associated legal entity.
266 267 268 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 266 def executive @executive end |
#legal_guardian ⇒ Object
Indicates whether the person is a legal guardian of the associated legal entity.
268 269 270 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 268 def legal_guardian @legal_guardian end |
#owner ⇒ Object
Indicates whether the person is an owner of the associated legal entity.
270 271 272 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 270 def owner @owner end |
#percent_ownership ⇒ Object
The percentage of ownership the person has in the associated legal entity.
272 273 274 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 272 def percent_ownership @percent_ownership end |
#representative ⇒ Object
Indicates whether the person is a representative of the associated legal entity.
274 275 276 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 274 def representative @representative end |
#title ⇒ Object
The title or position the person holds in the associated legal entity.
276 277 278 |
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 276 def title @title end |