Class: Stripe::V2::Core::Accounts::PersonService::UpdateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/accounts/person_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, PrimaryVerification, SecondaryVerification, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, primary_verification: nil, secondary_verification: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



729
730
731
732
733
734
735
736
737
738
739
740
741
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 729

def initialize(
  company_authorization: nil,
  passport: nil,
  primary_verification: nil,
  secondary_verification: nil,
  visa: nil
)
  @company_authorization = company_authorization
  @passport = passport
  @primary_verification = primary_verification
  @secondary_verification = secondary_verification
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



719
720
721
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 719

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



721
722
723
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 721

def passport
  @passport
end

#primary_verificationObject

An identifying document showing the person’s name, either a passport or local ID card.



723
724
725
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 723

def primary_verification
  @primary_verification
end

#secondary_verificationObject

A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.



725
726
727
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 725

def secondary_verification
  @secondary_verification
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



727
728
729
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 727

def visa
  @visa
end