Class: Stripe::V2::Core::Accounts::PersonService::UpdateParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/accounts/person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 774

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the individual is an authorizer of the Account’s legal entity.



758
759
760
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 758

def authorizer
  @authorizer
end

#directorObject

Indicates whether the person is a director of the associated legal entity.



760
761
762
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 760

def director
  @director
end

#executiveObject

Indicates whether the person is an executive of the associated legal entity.



762
763
764
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 762

def executive
  @executive
end

Indicates whether the person is a legal guardian of the associated legal entity.



764
765
766
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 764

def legal_guardian
  @legal_guardian
end

#ownerObject

Indicates whether the person is an owner of the associated legal entity.



766
767
768
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 766

def owner
  @owner
end

#percent_ownershipObject

The percentage of ownership the person has in the associated legal entity.



768
769
770
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 768

def percent_ownership
  @percent_ownership
end

#representativeObject

Indicates whether the person is a representative of the associated legal entity.



770
771
772
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 770

def representative
  @representative
end

#titleObject

The title or position the person holds in the associated legal entity.



772
773
774
# File 'lib/stripe/services/v2/core/accounts/person_service.rb', line 772

def title
  @title
end