Class: Stripe::V2::Core::ApprovalRequest
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::ApprovalRequest
- Defined in:
- lib/stripe/resources/v2/core/approval_request.rb
Overview
An approval request represents a pending action that requires review before execution.
Defined Under Namespace
Classes: RequestedBy, Review, Rule, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.core.approval_request"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#action ⇒ Object
readonly
The action that was requested.
-
#created ⇒ Object
readonly
Time this ApprovalRequest was created.
-
#dashboard_url ⇒ Object
readonly
The URL to the dashboard for this ApprovalRequest.
-
#expires_at ⇒ Object
readonly
The timestamp at which this ApprovalRequest will expire.
-
#id ⇒ Object
readonly
The unique identifier for this ApprovalRequest.
-
#livemode ⇒ Object
readonly
Whether this ApprovalRequest is livemode.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#reason ⇒ Object
readonly
Context provided by the requester (e.g. an agent) to help reviewers evaluate the request.
-
#requested_by ⇒ Object
readonly
The requester of this ApprovalRequest.
-
#review ⇒ Object
readonly
The review of this ApprovalRequest if it has been reviewed.
-
#rule ⇒ Object
readonly
The rule associated with this ApprovalRequest.
-
#status ⇒ Object
readonly
The status of this ApprovalRequest.
-
#status_details ⇒ Object
readonly
The details of the status of this ApprovalRequest.
-
#status_transitions ⇒ Object
readonly
The transitions of the status of this ApprovalRequest.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#action ⇒ Object (readonly)
The action that was requested.
351 352 353 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 351 def action @action end |
#created ⇒ Object (readonly)
Time this ApprovalRequest was created.
353 354 355 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 353 def created @created end |
#dashboard_url ⇒ Object (readonly)
The URL to the dashboard for this ApprovalRequest.
355 356 357 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 355 def dashboard_url @dashboard_url end |
#expires_at ⇒ Object (readonly)
The timestamp at which this ApprovalRequest will expire.
357 358 359 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 357 def expires_at @expires_at end |
#id ⇒ Object (readonly)
The unique identifier for this ApprovalRequest.
359 360 361 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 359 def id @id end |
#livemode ⇒ Object (readonly)
Whether this ApprovalRequest is livemode.
361 362 363 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 361 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
363 364 365 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 363 def object @object end |
#reason ⇒ Object (readonly)
Context provided by the requester (e.g. an agent) to help reviewers evaluate the request.
365 366 367 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 365 def reason @reason end |
#requested_by ⇒ Object (readonly)
The requester of this ApprovalRequest.
367 368 369 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 367 def requested_by @requested_by end |
#review ⇒ Object (readonly)
The review of this ApprovalRequest if it has been reviewed.
369 370 371 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 369 def review @review end |
#rule ⇒ Object (readonly)
The rule associated with this ApprovalRequest.
371 372 373 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 371 def rule @rule end |
#status ⇒ Object (readonly)
The status of this ApprovalRequest.
373 374 375 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 373 def status @status end |
#status_details ⇒ Object (readonly)
The details of the status of this ApprovalRequest.
375 376 377 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 375 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The transitions of the status of this ApprovalRequest.
377 378 379 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 377 def status_transitions @status_transitions end |
Class Method Details
.field_remappings ⇒ Object
389 390 391 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 389 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
379 380 381 382 383 384 385 386 387 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 379 def self.inner_class_types @inner_class_types = { requested_by: RequestedBy, review: Review, rule: Rule, status_details: StatusDetails, status_transitions: StatusTransitions, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 10 def self.object_name "v2.core.approval_request" end |