Class: Stripe::V2::Core::ApprovalRequest
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::ApprovalRequest
- Defined in:
- lib/stripe/resources/v2/core/approval_request.rb
Overview
An approval request represents a pending action that requires review before execution.
Defined Under Namespace
Classes: RequestedBy, Review, Rule, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.core.approval_request"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#action ⇒ Object
readonly
The action that was requested.
-
#created ⇒ Object
readonly
Time this ApprovalRequest was created.
-
#dashboard_url ⇒ Object
readonly
The URL to the dashboard for this ApprovalRequest.
-
#description ⇒ Object
readonly
A description of the approval request.
-
#expires_at ⇒ Object
readonly
The timestamp at which this ApprovalRequest will expire.
-
#id ⇒ Object
readonly
The unique identifier for this ApprovalRequest.
-
#livemode ⇒ Object
readonly
Whether this ApprovalRequest is livemode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requested_by ⇒ Object
readonly
The requester of this ApprovalRequest.
-
#review ⇒ Object
readonly
The review of this ApprovalRequest if it has been reviewed.
-
#rule ⇒ Object
readonly
The rule associated with this ApprovalRequest.
-
#status ⇒ Object
readonly
The status of this ApprovalRequest.
-
#status_details ⇒ Object
readonly
The details of the status of this ApprovalRequest.
-
#status_transitions ⇒ Object
readonly
The transitions of the status of this ApprovalRequest.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#action ⇒ Object (readonly)
The action that was requested.
293 294 295 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 293 def action @action end |
#created ⇒ Object (readonly)
Time this ApprovalRequest was created.
295 296 297 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 295 def created @created end |
#dashboard_url ⇒ Object (readonly)
The URL to the dashboard for this ApprovalRequest.
297 298 299 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 297 def dashboard_url @dashboard_url end |
#description ⇒ Object (readonly)
A description of the approval request.
299 300 301 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 299 def description @description end |
#expires_at ⇒ Object (readonly)
The timestamp at which this ApprovalRequest will expire.
301 302 303 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 301 def expires_at @expires_at end |
#id ⇒ Object (readonly)
The unique identifier for this ApprovalRequest.
303 304 305 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 303 def id @id end |
#livemode ⇒ Object (readonly)
Whether this ApprovalRequest is livemode.
305 306 307 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 305 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
307 308 309 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 307 def object @object end |
#requested_by ⇒ Object (readonly)
The requester of this ApprovalRequest.
309 310 311 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 309 def requested_by @requested_by end |
#review ⇒ Object (readonly)
The review of this ApprovalRequest if it has been reviewed.
311 312 313 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 311 def review @review end |
#rule ⇒ Object (readonly)
The rule associated with this ApprovalRequest.
313 314 315 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 313 def rule @rule end |
#status ⇒ Object (readonly)
The status of this ApprovalRequest.
315 316 317 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 315 def status @status end |
#status_details ⇒ Object (readonly)
The details of the status of this ApprovalRequest.
317 318 319 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 317 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The transitions of the status of this ApprovalRequest.
319 320 321 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 319 def status_transitions @status_transitions end |
Class Method Details
.field_remappings ⇒ Object
331 332 333 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 331 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
321 322 323 324 325 326 327 328 329 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 321 def self.inner_class_types @inner_class_types = { requested_by: RequestedBy, review: Review, rule: Rule, status_details: StatusDetails, status_transitions: StatusTransitions, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/approval_request.rb', line 10 def self.object_name "v2.core.approval_request" end |