Class: Stripe::V2::Core::BatchJob::StatusDetails::ValidationFailed
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::BatchJob::StatusDetails::ValidationFailed
- Defined in:
- lib/stripe/resources/v2/core/batch_job.rb
Defined Under Namespace
Classes: OutputFile
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#failure_count ⇒ Object
readonly
The total number of records that failed processing.
-
#output_file ⇒ Object
readonly
The output file details.
-
#success_count ⇒ Object
readonly
The total number of records that were successfully processed.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#failure_count ⇒ Object (readonly)
The total number of records that failed processing.
305 306 307 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 305 def failure_count @failure_count end |
#output_file ⇒ Object (readonly)
The output file details. If BatchJob is cancelled it’s provided only if there is already output at this point.
307 308 309 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 307 def output_file @output_file end |
#success_count ⇒ Object (readonly)
The total number of records that were successfully processed.
309 310 311 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 309 def success_count @success_count end |
Class Method Details
.field_encodings ⇒ Object
319 320 321 322 323 324 325 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 319 def self.field_encodings @field_encodings = { failure_count: :int64_string, output_file: { kind: :object, fields: { size: :int64_string } }, success_count: :int64_string, } end |
.field_remappings ⇒ Object
315 316 317 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 315 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
311 312 313 |
# File 'lib/stripe/resources/v2/core/batch_job.rb', line 311 def self.inner_class_types @inner_class_types = { output_file: OutputFile } end |