Class: Stripe::V2::Core::BatchJobCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::BatchJobCreateParams
- Defined in:
- lib/stripe/params/v2/core/batch_job_create_params.rb
Defined Under Namespace
Classes: Endpoint, NotificationSuppression
Instance Attribute Summary collapse
-
#endpoint ⇒ Object
The endpoint configuration for the batch job.
-
#maximum_rps ⇒ Object
Optional field that allows the user to control how fast they want this batch job to run.
-
#metadata ⇒ Object
The metadata of the ‘BatchJob` object.
-
#notification_suppression ⇒ Object
Notification suppression settings for the batch job.
-
#skip_validation ⇒ Object
Allows the user to skip validation.
Instance Method Summary collapse
-
#initialize(endpoint: nil, maximum_rps: nil, metadata: nil, notification_suppression: nil, skip_validation: nil) ⇒ BatchJobCreateParams
constructor
A new instance of BatchJobCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(endpoint: nil, maximum_rps: nil, metadata: nil, notification_suppression: nil, skip_validation: nil) ⇒ BatchJobCreateParams
Returns a new instance of BatchJobCreateParams.
42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 42 def initialize( endpoint: nil, maximum_rps: nil, metadata: nil, notification_suppression: nil, skip_validation: nil ) @endpoint = endpoint @maximum_rps = maximum_rps @metadata = @notification_suppression = notification_suppression @skip_validation = skip_validation end |
Instance Attribute Details
#endpoint ⇒ Object
The endpoint configuration for the batch job.
31 32 33 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 31 def endpoint @endpoint end |
#maximum_rps ⇒ Object
Optional field that allows the user to control how fast they want this batch job to run. Gives them a control over the number of webhooks they receive.
34 35 36 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 34 def maximum_rps @maximum_rps end |
#metadata ⇒ Object
The metadata of the ‘BatchJob` object.
36 37 38 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 36 def @metadata end |
#notification_suppression ⇒ Object
Notification suppression settings for the batch job.
38 39 40 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 38 def notification_suppression @notification_suppression end |
#skip_validation ⇒ Object
Allows the user to skip validation.
40 41 42 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 40 def skip_validation @skip_validation end |