Class: Stripe::V2::Core::BatchJobCreateParams::Endpoint
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::BatchJobCreateParams::Endpoint
- Defined in:
- lib/stripe/params/v2/core/batch_job_create_params.rb
Instance Attribute Summary collapse
-
#http_method ⇒ Object
The HTTP method to use when calling the endpoint.
-
#path ⇒ Object
The path of the endpoint to run this batch job against.
Instance Method Summary collapse
-
#initialize(http_method: nil, path: nil) ⇒ Endpoint
constructor
A new instance of Endpoint.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(http_method: nil, path: nil) ⇒ Endpoint
Returns a new instance of Endpoint.
16 17 18 19 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 16 def initialize(http_method: nil, path: nil) @http_method = http_method @path = path end |
Instance Attribute Details
#http_method ⇒ Object
The HTTP method to use when calling the endpoint.
10 11 12 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 10 def http_method @http_method end |
#path ⇒ Object
The path of the endpoint to run this batch job against. In the form used in the documentation. For instance, for subscription migration this would be ‘/v1/subscriptions/:id/migrate`.
14 15 16 |
# File 'lib/stripe/params/v2/core/batch_job_create_params.rb', line 14 def path @path end |