Class: Stripe::V2::Core::ClaimableSandbox
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::ClaimableSandbox
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Overview
A claimable sandbox represents a Stripe sandbox that is anonymous. When it is created, it can be prefilled with specific metadata, such as email, name, or country. Claimable sandboxes can be claimed through a URL. When a user claims a sandbox through this URL, it will prompt them to create a new Stripe account. Or, it will allow them to claim this sandbox in their existing Stripe account. Claimable sandboxes have 60 days to be claimed. After this expiration time has passed, if the sandbox is not claimed, it will be deleted.
Defined Under Namespace
Classes: OnboardingLinkDetails, OwnerDetails, Prefill, SandboxDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.core.claimable_sandbox"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#app_channel ⇒ Object
readonly
The app channel that will be used when pre-installing your app on the claimable sandbox.
-
#claimed_at ⇒ Object
readonly
The timestamp the sandbox was claimed.
-
#created ⇒ Object
readonly
When the sandbox is created.
-
#expires_at ⇒ Object
readonly
The timestamp the sandbox will expire.
-
#id ⇒ Object
readonly
Unique identifier for the Claimable sandbox.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#onboarding_link_details ⇒ Object
readonly
Details about the onboarding link.
-
#owner_details ⇒ Object
readonly
Details about the livemode owner account of the sandbox.
-
#prefill ⇒ Object
readonly
Values prefilled during the creation of the sandbox.
-
#sandbox_details ⇒ Object
readonly
Data about the Stripe sandbox object.
-
#status ⇒ Object
readonly
Status of the sandbox.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#app_channel ⇒ Object (readonly)
The app channel that will be used when pre-installing your app on the claimable sandbox.
106 107 108 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 106 def app_channel @app_channel end |
#claimed_at ⇒ Object (readonly)
The timestamp the sandbox was claimed. The value will be null if the sandbox status is not ‘claimed`.
108 109 110 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 108 def claimed_at @claimed_at end |
#created ⇒ Object (readonly)
When the sandbox is created.
110 111 112 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 110 def created @created end |
#expires_at ⇒ Object (readonly)
The timestamp the sandbox will expire. The value will be null if the sandbox is ‘claimed`.
112 113 114 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 112 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the Claimable sandbox.
114 115 116 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 114 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
116 117 118 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 116 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
118 119 120 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 118 def object @object end |
#onboarding_link_details ⇒ Object (readonly)
Details about the onboarding link.
120 121 122 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 120 def onboarding_link_details @onboarding_link_details end |
#owner_details ⇒ Object (readonly)
Details about the livemode owner account of the sandbox. This will be null until the sandbox is claimed.
123 124 125 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 123 def owner_details @owner_details end |
#prefill ⇒ Object (readonly)
Values prefilled during the creation of the sandbox. When a user claims the sandbox, they will be able to update these values.
125 126 127 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 125 def prefill @prefill end |
#sandbox_details ⇒ Object (readonly)
Data about the Stripe sandbox object.
127 128 129 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 127 def sandbox_details @sandbox_details end |
#status ⇒ Object (readonly)
Status of the sandbox.
129 130 131 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 129 def status @status end |
Class Method Details
.field_remappings ⇒ Object
140 141 142 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 140 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
131 132 133 134 135 136 137 138 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 131 def self.inner_class_types @inner_class_types = { onboarding_link_details: OnboardingLinkDetails, owner_details: OwnerDetails, prefill: Prefill, sandbox_details: SandboxDetails, } end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 16 def self.object_name "v2.core.claimable_sandbox" end |