Class: Stripe::V2::Core::ClaimableSandbox

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/claimable_sandbox.rb

Overview

A claimable sandbox represents a Stripe sandbox that is anonymous. When it is created, it can be prefilled with specific metadata, such as email, name, or country. Claimable sandboxes can be claimed through a URL. When a user claims a sandbox through this URL, it will prompt them to create a new Stripe account. Or, it will allow them to claim this sandbox in their existing Stripe account. Claimable sandboxes have 60 days to be claimed. After this expiration time has passed, if the sandbox is not claimed, it will be deleted.

Defined Under Namespace

Classes: Prefill, SandboxDetails

Constant Summary collapse

OBJECT_NAME =
"v2.core.claimable_sandbox"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#claim_urlObject (readonly)

URL for user to claim sandbox into their existing Stripe account. The value will be null if the sandbox status is ‘claimed` or `expired`.



75
76
77
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 75

def claim_url
  @claim_url
end

#claimed_atObject (readonly)

The timestamp the sandbox was claimed. The value will be null if the sandbox status is not ‘claimed`.



77
78
79
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 77

def claimed_at
  @claimed_at
end

#createdObject (readonly)

When the sandbox is created.



79
80
81
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 79

def created
  @created
end

#expires_atObject (readonly)

The timestamp the sandbox will expire. The value will be null if the sandbox is ‘claimed`.



81
82
83
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 81

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the Claimable sandbox.



83
84
85
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 83

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



85
86
87
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 85

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



87
88
89
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 87

def object
  @object
end

#prefillObject (readonly)

Values prefilled during the creation of the sandbox. When a user claims the sandbox, they will be able to update these values.



89
90
91
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 89

def prefill
  @prefill
end

#sandbox_detailsObject (readonly)

Data about the Stripe sandbox object.



91
92
93
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 91

def sandbox_details
  @sandbox_details
end

#statusObject (readonly)

Status of the sandbox. One of ‘unclaimed`, `expired`, `claimed`.



93
94
95
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 93

def status
  @status
end

Class Method Details

.field_remappingsObject



99
100
101
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 99

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



95
96
97
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 95

def self.inner_class_types
  @inner_class_types = { prefill: Prefill, sandbox_details: SandboxDetails }
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 16

def self.object_name
  "v2.core.claimable_sandbox"
end