Class: Stripe::V2::Core::ClaimableSandbox
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::ClaimableSandbox
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Overview
A claimable sandbox represents a Stripe sandbox that is anonymous. When it is created, it can be prefilled with specific metadata, such as email, name, or country. Claimable sandboxes can be claimed through a URL. When a user claims a sandbox through this URL, it will prompt them to create a new Stripe account. Or, it will allow them to claim this sandbox in their existing Stripe account. Claimable sandboxes have 60 days to be claimed. After this expiration time has passed, if the sandbox is not claimed, it will be deleted.
Defined Under Namespace
Classes: Prefill, SandboxDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.core.claimable_sandbox"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#claim_url ⇒ Object
readonly
URL for user to claim sandbox into their existing Stripe account.
-
#claimed_at ⇒ Object
readonly
The timestamp the sandbox was claimed.
-
#created ⇒ Object
readonly
When the sandbox is created.
-
#expires_at ⇒ Object
readonly
The timestamp the sandbox will expire.
-
#id ⇒ Object
readonly
Unique identifier for the Claimable sandbox.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#prefill ⇒ Object
readonly
Values prefilled during the creation of the sandbox.
-
#sandbox_details ⇒ Object
readonly
Data about the Stripe sandbox object.
-
#status ⇒ Object
readonly
Status of the sandbox.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#claim_url ⇒ Object (readonly)
URL for user to claim sandbox into their existing Stripe account. The value will be null if the sandbox status is ‘claimed` or `expired`.
75 76 77 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 75 def claim_url @claim_url end |
#claimed_at ⇒ Object (readonly)
The timestamp the sandbox was claimed. The value will be null if the sandbox status is not ‘claimed`.
77 78 79 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 77 def claimed_at @claimed_at end |
#created ⇒ Object (readonly)
When the sandbox is created.
79 80 81 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 79 def created @created end |
#expires_at ⇒ Object (readonly)
The timestamp the sandbox will expire. The value will be null if the sandbox is ‘claimed`.
81 82 83 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 81 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the Claimable sandbox.
83 84 85 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 83 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
93 94 95 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 93 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
85 86 87 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 85 def object @object end |
#prefill ⇒ Object (readonly)
Values prefilled during the creation of the sandbox. When a user claims the sandbox, they will be able to update these values.
87 88 89 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 87 def prefill @prefill end |
#sandbox_details ⇒ Object (readonly)
Data about the Stripe sandbox object.
89 90 91 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 89 def sandbox_details @sandbox_details end |
#status ⇒ Object (readonly)
Status of the sandbox. One of ‘unclaimed`, `expired`, `claimed`.
91 92 93 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 91 def status @status end |
Class Method Details
.field_remappings ⇒ Object
99 100 101 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 99 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
95 96 97 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 95 def self.inner_class_types @inner_class_types = { prefill: Prefill, sandbox_details: SandboxDetails } end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 16 def self.object_name "v2.core.claimable_sandbox" end |