Class: Stripe::V2::Core::ClaimableSandbox

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/claimable_sandbox.rb

Overview

A claimable sandbox represents a Stripe sandbox that is anonymous. When it is created, it can be prefilled with specific metadata, such as email, name, or country. Claimable sandboxes can be claimed through a URL. When a user claims a sandbox through this URL, it will prompt them to create a new Stripe account. Or, it will allow them to claim this sandbox in their existing Stripe account. Claimable sandboxes have 60 days to be claimed. After this expiration time has passed, if the sandbox is not claimed, it will be deleted.

Defined Under Namespace

Classes: ApiKeys, Prefill

Constant Summary collapse

OBJECT_NAME =
"v2.core.claimable_sandbox"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#api_keysObject (readonly)

Keys that can be used to set up an integration for this sandbox and operate on the account.



41
42
43
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 41

def api_keys
  @api_keys
end

#claim_urlObject (readonly)

URL for user to claim sandbox into their existing Stripe account.



43
44
45
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 43

def claim_url
  @claim_url
end

#createdObject (readonly)

When the sandbox is created.



45
46
47
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 45

def created
  @created
end

#idObject (readonly)

Unique identifier for the Claimable sandbox.



47
48
49
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 47

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



53
54
55
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 53

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



49
50
51
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 49

def object
  @object
end

#prefillObject (readonly)

Values prefilled during the creation of the sandbox.



51
52
53
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 51

def prefill
  @prefill
end

Class Method Details

.object_nameObject



16
17
18
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 16

def self.object_name
  "v2.core.claimable_sandbox"
end