Class: Stripe::V2::Core::ClaimableSandbox

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/claimable_sandbox.rb

Overview

A claimable sandbox represents a Stripe sandbox that is anonymous. When it is created, it can be prefilled with specific metadata, such as email, name, or country. Claimable sandboxes can be claimed through a URL. When a user claims a sandbox through this URL, it will prompt them to create a new Stripe account. Or, it will allow them to claim this sandbox in their existing Stripe account. Claimable sandboxes have 60 days to be claimed. After this expiration time has passed, if the sandbox is not claimed, it will be deleted.

Defined Under Namespace

Classes: ApiKeys, Prefill

Constant Summary collapse

OBJECT_NAME =
"v2.core.claimable_sandbox"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#api_keysObject (readonly)

Keys that can be used to set up an integration for this sandbox and operate on the account.



57
58
59
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 57

def api_keys
  @api_keys
end

#claim_urlObject (readonly)

URL for user to claim sandbox into their existing Stripe account.



59
60
61
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 59

def claim_url
  @claim_url
end

#createdObject (readonly)

When the sandbox is created.



61
62
63
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 61

def created
  @created
end

#idObject (readonly)

Unique identifier for the Claimable sandbox.



63
64
65
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 63

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



69
70
71
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 69

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



65
66
67
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 65

def object
  @object
end

#prefillObject (readonly)

Values prefilled during the creation of the sandbox.



67
68
69
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 67

def prefill
  @prefill
end

Class Method Details

.field_remappingsObject



75
76
77
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 75

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



71
72
73
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 71

def self.inner_class_types
  @inner_class_types = { api_keys: ApiKeys, prefill: Prefill }
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 16

def self.object_name
  "v2.core.claimable_sandbox"
end