Class: Stripe::V2::Core::ClaimableSandbox::ApiKeys
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::ClaimableSandbox::ApiKeys
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#mcp ⇒ Object
readonly
Used to communicate with [Stripe’s MCP server](docs.stripe.com/mcp).
-
#publishable ⇒ Object
readonly
Publicly accessible in a web or mobile app client-side code.
-
#secret ⇒ Object
readonly
Should be stored securely in server-side code (such as an environment variable).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#mcp ⇒ Object (readonly)
Used to communicate with [Stripe’s MCP server](docs.stripe.com/mcp). This allows LLM agents to securely operate on a Stripe account.
23 24 25 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 23 def mcp @mcp end |
#publishable ⇒ Object (readonly)
Publicly accessible in a web or mobile app client-side code.
25 26 27 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 25 def publishable @publishable end |
#secret ⇒ Object (readonly)
Should be stored securely in server-side code (such as an environment variable).
27 28 29 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 27 def secret @secret end |
Class Method Details
.field_remappings ⇒ Object
33 34 35 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 33 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
29 30 31 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 29 def self.inner_class_types @inner_class_types = {} end |