Class: Stripe::V2::Core::ClaimableSandbox::Prefill

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/core/claimable_sandbox.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Country in which the account holder resides, or in which the business is legally established. Use two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



23
24
25
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 23

def country
  @country
end

#emailObject (readonly)

Email that this sandbox is meant to be claimed by. Stripe will send an email to this email address before the sandbox expires.



26
27
28
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 26

def email
  @email
end

#nameObject (readonly)

Name for the sandbox.



28
29
30
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 28

def name
  @name
end

Class Method Details

.field_remappingsObject



34
35
36
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 34

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



30
31
32
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 30

def self.inner_class_types
  @inner_class_types = {}
end