Class: Stripe::V2::Core::ClaimableSandbox::Prefill
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::ClaimableSandbox::Prefill
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Country in which the account holder resides, or in which the business is legally established.
-
#email ⇒ Object
readonly
Email that this sandbox is meant to be claimed by.
-
#name ⇒ Object
readonly
Name for the sandbox.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Country in which the account holder resides, or in which the business is legally established. Use two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
33 34 35 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 33 def country @country end |
#email ⇒ Object (readonly)
Email that this sandbox is meant to be claimed by. Stripe will send an email to this email address before the sandbox expires.
36 37 38 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 36 def email @email end |
#name ⇒ Object (readonly)
Name for the sandbox.
38 39 40 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 38 def name @name end |