Class: Stripe::V2::Core::ClaimableSandbox::SandboxDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::ClaimableSandbox::SandboxDetails
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Defined Under Namespace
Classes: ApiKeys
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The sandbox’s Stripe account ID.
-
#api_keys ⇒ Object
readonly
Keys that can be used to set up an integration for this sandbox and operate on the account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The sandbox’s Stripe account ID.
93 94 95 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 93 def account @account end |
#api_keys ⇒ Object (readonly)
Keys that can be used to set up an integration for this sandbox and operate on the account. This will be present only in the create response, and will be null in subsequent retrieve responses.
95 96 97 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 95 def api_keys @api_keys end |
Class Method Details
.field_remappings ⇒ Object
101 102 103 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 101 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
97 98 99 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 97 def self.inner_class_types @inner_class_types = { api_keys: ApiKeys } end |