Class: Stripe::V2::Core::ClaimableSandbox::SandboxDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::ClaimableSandbox::SandboxDetails
- Defined in:
- lib/stripe/resources/v2/core/claimable_sandbox.rb
Defined Under Namespace
Classes: ApiKeys
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The sandbox’s Stripe account ID.
-
#api_keys ⇒ Object
readonly
Keys that can be used to set up an integration for this sandbox and operate on the account.
-
#owner_account ⇒ Object
readonly
The livemode sandbox Stripe account ID.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The sandbox’s Stripe account ID.
58 59 60 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 58 def account @account end |
#api_keys ⇒ Object (readonly)
Keys that can be used to set up an integration for this sandbox and operate on the account. This will be present only in the create response, and will be null in subsequent retrieve responses.
60 61 62 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 60 def api_keys @api_keys end |
#owner_account ⇒ Object (readonly)
The livemode sandbox Stripe account ID. This field is only set if the user activates their sandbox and chooses to install your platform’s Stripe App in their live account.
63 64 65 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 63 def owner_account @owner_account end |
Class Method Details
.field_remappings ⇒ Object
69 70 71 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 69 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
65 66 67 |
# File 'lib/stripe/resources/v2/core/claimable_sandbox.rb', line 65 def self.inner_class_types @inner_class_types = { api_keys: ApiKeys } end |