Class: Stripe::V2::Core::ClaimableSandboxCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::ClaimableSandboxCreateParams
- Defined in:
- lib/stripe/params/v2/core/claimable_sandbox_create_params.rb
Defined Under Namespace
Classes: Prefill
Instance Attribute Summary collapse
-
#enable_mcp_access ⇒ Object
If true, returns a key that can be used with [Stripe’s MCP server](docs.stripe.com/mcp).
-
#prefill ⇒ Object
Values that are prefilled when a user claims the sandbox.
Instance Method Summary collapse
-
#initialize(enable_mcp_access: nil, prefill: nil) ⇒ ClaimableSandboxCreateParams
constructor
A new instance of ClaimableSandboxCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(enable_mcp_access: nil, prefill: nil) ⇒ ClaimableSandboxCreateParams
Returns a new instance of ClaimableSandboxCreateParams.
29 30 31 32 |
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 29 def initialize(enable_mcp_access: nil, prefill: nil) @enable_mcp_access = enable_mcp_access @prefill = prefill end |
Instance Attribute Details
#enable_mcp_access ⇒ Object
If true, returns a key that can be used with [Stripe’s MCP server](docs.stripe.com/mcp).
25 26 27 |
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 25 def enable_mcp_access @enable_mcp_access end |
#prefill ⇒ Object
Values that are prefilled when a user claims the sandbox. When a user claims the sandbox, they will be able to update these values.
27 28 29 |
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 27 def prefill @prefill end |