Class: Stripe::V2::Core::ClaimableSandboxCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/core/claimable_sandbox_create_params.rb

Defined Under Namespace

Classes: Prefill

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enable_mcp_access: nil, prefill: nil) ⇒ ClaimableSandboxCreateParams

Returns a new instance of ClaimableSandboxCreateParams.



29
30
31
32
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 29

def initialize(enable_mcp_access: nil, prefill: nil)
  @enable_mcp_access = enable_mcp_access
  @prefill = prefill
end

Instance Attribute Details

#enable_mcp_accessObject

If true, returns a key that can be used with [Stripe’s MCP server](docs.stripe.com/mcp).



25
26
27
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 25

def enable_mcp_access
  @enable_mcp_access
end

#prefillObject

Values that are prefilled when a user claims the sandbox. When a user claims the sandbox, they will be able to update these values.



27
28
29
# File 'lib/stripe/params/v2/core/claimable_sandbox_create_params.rb', line 27

def prefill
  @prefill
end