Class: Stripe::V2::Core::ClaimableSandboxService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/v2/core/claimable_sandbox_service.rb

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Create an anonymous, claimable sandbox. This sandbox can be prefilled with data. The response will include a claim URL that allow a user to claim the account.



10
11
12
13
14
15
16
17
18
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 10

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v2/core/claimable_sandboxes",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieves the details of a claimable sandbox that was previously been created. Supply the unique claimable sandbox ID that was returned from your creation request, and Stripe will return the corresponding sandbox information.



23
24
25
26
27
28
29
30
31
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 23

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/core/claimable_sandboxes/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end