Class: Stripe::V2::Core::ClaimableSandboxService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Core::ClaimableSandboxService
- Defined in:
- lib/stripe/services/v2/core/claimable_sandbox_service.rb
Defined Under Namespace
Classes: CreateParams, RetrieveParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create an anonymous, claimable sandbox.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a claimable sandbox that was previously been created.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create an anonymous, claimable sandbox. This sandbox can be prefilled with data. The response will include a claim URL that allow a user to claim the account.
40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 40 def create(params = {}, opts = {}) request( method: :post, path: "/v2/core/claimable_sandboxes", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a claimable sandbox that was previously been created. Supply the unique claimable sandbox ID that was returned from your creation request, and Stripe will return the corresponding sandbox information.
53 54 55 56 57 58 59 60 61 |
# File 'lib/stripe/services/v2/core/claimable_sandbox_service.rb', line 53 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/claimable_sandboxes/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |