Class: Stripe::V2::Core::ConnectionSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::ConnectionSession
- Defined in:
- lib/stripe/resources/v2/core/connection_session.rb
Overview
The ConnectionSession resource.
Defined Under Namespace
Classes: Connection
Constant Summary collapse
- OBJECT_NAME =
"v2.core.connection_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The Account this Connection Session was created for.
-
#allowed_connection_types ⇒ Object
readonly
The Connection types that the Connection Session is allowed to establish.
-
#client_secret ⇒ Object
readonly
The client secret of this Connection Session.
-
#connection ⇒ Object
readonly
The Connection created by the ConnectionSession.
-
#created ⇒ Object
readonly
Time at which the ConnectionSession was created.
-
#id ⇒ Object
readonly
The unique identifier for this ConnectionSession.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#requested_access ⇒ Object
readonly
The access that is collected with the Connection Session.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The Account this Connection Session was created for.
29 30 31 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 29 def account @account end |
#allowed_connection_types ⇒ Object (readonly)
The Connection types that the Connection Session is allowed to establish.
31 32 33 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 31 def allowed_connection_types @allowed_connection_types end |
#client_secret ⇒ Object (readonly)
The client secret of this Connection Session. Used on the client to set up secure access to the given Account.
33 34 35 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 33 def client_secret @client_secret end |
#connection ⇒ Object (readonly)
The Connection created by the ConnectionSession.
35 36 37 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 35 def connection @connection end |
#created ⇒ Object (readonly)
Time at which the ConnectionSession was created.
37 38 39 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 37 def created @created end |
#id ⇒ Object (readonly)
The unique identifier for this ConnectionSession.
39 40 41 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 39 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
45 46 47 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 45 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
41 42 43 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 41 def object @object end |
#requested_access ⇒ Object (readonly)
The access that is collected with the Connection Session.
43 44 45 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 43 def requested_access @requested_access end |
Class Method Details
.field_remappings ⇒ Object
51 52 53 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 51 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
47 48 49 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 47 def self.inner_class_types @inner_class_types = { connection: Connection } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/connection_session.rb', line 10 def self.object_name "v2.core.connection_session" end |