Class: Stripe::V2::Core::Event
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Event
- Defined in:
- lib/stripe/resources/v2/core/event.rb
Overview
Events are generated to keep you informed of activity in your business account. APIs in the /v2 namespace generate thin events which have small, unversioned payloads that include a reference to the ID of the object that has changed. The Events v2 API returns these new thin events. Retrieve the event object for additional data about the event. Use the related object ID in the event payload to fetch the API resource of the object associated with the event. Comparatively, events generated by most API v1 include a versioned snapshot of an API object in their payload. You can access events through the Retrieve Event API for 30 days.
Direct Known Subclasses
Events::V1BillingMeterErrorReportTriggeredEvent, Events::V1BillingMeterNoMeterFoundEvent, Events::V2CommerceProductCatalogImportsFailedEvent, Events::V2CommerceProductCatalogImportsProcessingEvent, Events::V2CommerceProductCatalogImportsSucceededEvent, Events::V2CommerceProductCatalogImportsSucceededWithErrorsEvent, Events::V2CoreAccountClosedEvent, Events::V2CoreAccountCreatedEvent, Events::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationCustomerUpdatedEvent, Events::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationMerchantUpdatedEvent, Events::V2CoreAccountIncludingConfigurationMoneyManagerCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationMoneyManagerUpdatedEvent, Events::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationRecipientUpdatedEvent, Events::V2CoreAccountIncludingDefaultsUpdatedEvent, Events::V2CoreAccountIncludingFutureRequirementsUpdatedEvent, Events::V2CoreAccountIncludingIdentityUpdatedEvent, Events::V2CoreAccountIncludingRequirementsUpdatedEvent, Events::V2CoreAccountLinkReturnedEvent, Events::V2CoreAccountPersonCreatedEvent, Events::V2CoreAccountPersonDeletedEvent, Events::V2CoreAccountPersonUpdatedEvent, Events::V2CoreAccountUpdatedEvent, Events::V2CoreBatchJobBatchFailedEvent, Events::V2CoreBatchJobCanceledEvent, Events::V2CoreBatchJobCompletedEvent, Events::V2CoreBatchJobCreatedEvent, Events::V2CoreBatchJobReadyForUploadEvent, Events::V2CoreBatchJobTimeoutEvent, Events::V2CoreBatchJobUpdatedEvent, Events::V2CoreBatchJobUploadTimeoutEvent, Events::V2CoreBatchJobValidatingEvent, Events::V2CoreBatchJobValidationFailedEvent, Events::V2CoreEventDestinationPingEvent, Events::V2CoreHealthEventGenerationFailureResolvedEvent, Events::V2DataReportingQueryRunCreatedEvent, Events::V2DataReportingQueryRunFailedEvent, Events::V2DataReportingQueryRunSucceededEvent, Events::V2DataReportingQueryRunUpdatedEvent, Events::V2ExtendWorkflowRunFailedEvent, Events::V2ExtendWorkflowRunStartedEvent, Events::V2ExtendWorkflowRunSucceededEvent, Events::V2MoneyManagementAdjustmentCreatedEvent, Events::V2MoneyManagementFinancialAccountCreatedEvent, Events::V2MoneyManagementFinancialAccountUpdatedEvent, Events::V2MoneyManagementFinancialAddressActivatedEvent, Events::V2MoneyManagementFinancialAddressFailedEvent, Events::V2MoneyManagementInboundTransferAvailableEvent, Events::V2MoneyManagementInboundTransferBankDebitFailedEvent, Events::V2MoneyManagementInboundTransferBankDebitProcessingEvent, Events::V2MoneyManagementInboundTransferBankDebitQueuedEvent, Events::V2MoneyManagementInboundTransferBankDebitReturnedEvent, Events::V2MoneyManagementInboundTransferBankDebitSucceededEvent, Events::V2MoneyManagementOutboundPaymentCanceledEvent, Events::V2MoneyManagementOutboundPaymentCreatedEvent, Events::V2MoneyManagementOutboundPaymentFailedEvent, Events::V2MoneyManagementOutboundPaymentPostedEvent, Events::V2MoneyManagementOutboundPaymentReturnedEvent, Events::V2MoneyManagementOutboundPaymentUnderReviewEvent, Events::V2MoneyManagementOutboundPaymentUpdatedEvent, Events::V2MoneyManagementOutboundTransferCanceledEvent, Events::V2MoneyManagementOutboundTransferCreatedEvent, Events::V2MoneyManagementOutboundTransferFailedEvent, Events::V2MoneyManagementOutboundTransferPostedEvent, Events::V2MoneyManagementOutboundTransferReturnedEvent, Events::V2MoneyManagementOutboundTransferUnderReviewEvent, Events::V2MoneyManagementOutboundTransferUpdatedEvent, Events::V2MoneyManagementPayoutMethodCreatedEvent, Events::V2MoneyManagementPayoutMethodUpdatedEvent, Events::V2MoneyManagementReceivedCreditAvailableEvent, Events::V2MoneyManagementReceivedCreditFailedEvent, Events::V2MoneyManagementReceivedCreditReturnedEvent, Events::V2MoneyManagementReceivedCreditSucceededEvent, Events::V2MoneyManagementReceivedDebitCanceledEvent, Events::V2MoneyManagementReceivedDebitFailedEvent, Events::V2MoneyManagementReceivedDebitPendingEvent, Events::V2MoneyManagementReceivedDebitSucceededEvent, Events::V2MoneyManagementReceivedDebitUpdatedEvent, Events::V2MoneyManagementTransactionCreatedEvent, Events::V2MoneyManagementTransactionUpdatedEvent, Events::V2OrchestratedCommerceAgreementConfirmedEvent, Events::V2OrchestratedCommerceAgreementCreatedEvent, Events::V2OrchestratedCommerceAgreementPartiallyConfirmedEvent, Events::V2OrchestratedCommerceAgreementTerminatedEvent
Defined Under Namespace
Classes: Reason
Constant Summary collapse
- OBJECT_NAME =
"v2.core.event"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#changes ⇒ Object
readonly
Before and after changes for the primary related object.
-
#context ⇒ Object
readonly
Authentication context needed to fetch the event or related object.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the event.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#object ⇒ Object
readonly
String representing the object's type.
-
#reason ⇒ Object
readonly
Reason for the event.
-
#type ⇒ Object
readonly
The type of the event.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#changes ⇒ Object (readonly)
Before and after changes for the primary related object.
44 45 46 |
# File 'lib/stripe/resources/v2/core/event.rb', line 44 def changes @changes end |
#context ⇒ Object (readonly)
Authentication context needed to fetch the event or related object.
46 47 48 |
# File 'lib/stripe/resources/v2/core/event.rb', line 46 def context @context end |
#created ⇒ Object (readonly)
Time at which the object was created.
48 49 50 |
# File 'lib/stripe/resources/v2/core/event.rb', line 48 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the event.
50 51 52 |
# File 'lib/stripe/resources/v2/core/event.rb', line 50 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
52 53 54 |
# File 'lib/stripe/resources/v2/core/event.rb', line 52 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
54 55 56 |
# File 'lib/stripe/resources/v2/core/event.rb', line 54 def object @object end |
#reason ⇒ Object (readonly)
Reason for the event.
56 57 58 |
# File 'lib/stripe/resources/v2/core/event.rb', line 56 def reason @reason end |
#type ⇒ Object (readonly)
The type of the event.
58 59 60 |
# File 'lib/stripe/resources/v2/core/event.rb', line 58 def type @type end |
Class Method Details
.field_remappings ⇒ Object
64 65 66 |
# File 'lib/stripe/resources/v2/core/event.rb', line 64 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
60 61 62 |
# File 'lib/stripe/resources/v2/core/event.rb', line 60 def self.inner_class_types @inner_class_types = { reason: Reason } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/event.rb', line 11 def self.object_name "v2.core.event" end |