Class: Stripe::V2::Core::Event

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/event.rb

Overview

Events are generated to keep you informed of activity in your business account. APIs in the /v2 namespace generate [thin events](docs.stripe.com/event-destinations#benefits-of-thin-events) which have small, unversioned payloads that include a reference to the ID of the object that has changed. The Events v2 API returns these new thin events. [Retrieve the event object](docs.stripe.com/event-destinations#fetch-data) for additional data about the event. Use the related object ID in the event payload to [fetch the API resource](docs.stripe.com/event-destinations#retrieve-the-object-associated-with-thin-events) of the object associated with the event. Comparatively, events generated by most API v1 include a versioned snapshot of an API object in their payload. You can access events through the [Retrieve Event API](docs.stripe.com/api/v2/core/events/retrieve) for 30 days.

Defined Under Namespace

Classes: Reason

Constant Summary collapse

OBJECT_NAME =
"v2.core.event"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#changesObject (readonly)

Before and after changes for the primary related object.



44
45
46
# File 'lib/stripe/resources/v2/core/event.rb', line 44

def changes
  @changes
end

#contextObject (readonly)

Authentication context needed to fetch the event or related object.



46
47
48
# File 'lib/stripe/resources/v2/core/event.rb', line 46

def context
  @context
end

#createdObject (readonly)

Time at which the object was created.



48
49
50
# File 'lib/stripe/resources/v2/core/event.rb', line 48

def created
  @created
end

#idObject (readonly)

Unique identifier for the event.



50
51
52
# File 'lib/stripe/resources/v2/core/event.rb', line 50

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



52
53
54
# File 'lib/stripe/resources/v2/core/event.rb', line 52

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



54
55
56
# File 'lib/stripe/resources/v2/core/event.rb', line 54

def object
  @object
end

#reasonObject (readonly)

Reason for the event.



56
57
58
# File 'lib/stripe/resources/v2/core/event.rb', line 56

def reason
  @reason
end

#typeObject (readonly)

The type of the event.



58
59
60
# File 'lib/stripe/resources/v2/core/event.rb', line 58

def type
  @type
end

Class Method Details

.field_remappingsObject



64
65
66
# File 'lib/stripe/resources/v2/core/event.rb', line 64

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



60
61
62
# File 'lib/stripe/resources/v2/core/event.rb', line 60

def self.inner_class_types
  @inner_class_types = { reason: Reason }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/event.rb', line 11

def self.object_name
  "v2.core.event"
end