Class: Stripe::V2::Core::Event
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Event
- Defined in:
- lib/stripe/resources/v2/core/event.rb
Overview
Events are generated to keep you informed of activity in your business account. APIs in the /v2 namespace generate [thin events](docs.stripe.com/event-destinations#benefits-of-thin-events) which have small, unversioned payloads that include a reference to the ID of the object that has changed. The Events v2 API returns these new thin events. [Retrieve the event object](docs.stripe.com/event-destinations#fetch-data) for additional data about the event. Use the related object ID in the event payload to [fetch the API resource](docs.stripe.com/event-destinations#retrieve-the-object-associated-with-thin-events) of the object associated with the event. Comparatively, events generated by most API v1 include a versioned snapshot of an API object in their payload.
Direct Known Subclasses
Events::V1BillingMeterErrorReportTriggeredEvent, Events::V1BillingMeterNoMeterFoundEvent, Events::V2BillingCadenceBilledEvent, Events::V2BillingCadenceCanceledEvent, Events::V2BillingCadenceCreatedEvent, Events::V2BillingLicenseFeeCreatedEvent, Events::V2BillingLicenseFeeUpdatedEvent, Events::V2BillingLicenseFeeVersionCreatedEvent, Events::V2BillingLicensedItemCreatedEvent, Events::V2BillingLicensedItemUpdatedEvent, Events::V2BillingMeteredItemCreatedEvent, Events::V2BillingMeteredItemUpdatedEvent, Events::V2BillingPricingPlanComponentCreatedEvent, Events::V2BillingPricingPlanComponentUpdatedEvent, Events::V2BillingPricingPlanCreatedEvent, Events::V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent, Events::V2BillingPricingPlanSubscriptionCollectionCurrentEvent, Events::V2BillingPricingPlanSubscriptionCollectionPastDueEvent, Events::V2BillingPricingPlanSubscriptionCollectionPausedEvent, Events::V2BillingPricingPlanSubscriptionCollectionUnpaidEvent, Events::V2BillingPricingPlanSubscriptionServicingActivatedEvent, Events::V2BillingPricingPlanSubscriptionServicingCanceledEvent, Events::V2BillingPricingPlanSubscriptionServicingPausedEvent, Events::V2BillingPricingPlanUpdatedEvent, Events::V2BillingPricingPlanVersionCreatedEvent, Events::V2BillingRateCardCreatedEvent, Events::V2BillingRateCardRateCreatedEvent, Events::V2BillingRateCardSubscriptionActivatedEvent, Events::V2BillingRateCardSubscriptionCanceledEvent, Events::V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent, Events::V2BillingRateCardSubscriptionCollectionCurrentEvent, Events::V2BillingRateCardSubscriptionCollectionPastDueEvent, Events::V2BillingRateCardSubscriptionCollectionPausedEvent, Events::V2BillingRateCardSubscriptionCollectionUnpaidEvent, Events::V2BillingRateCardSubscriptionServicingActivatedEvent, Events::V2BillingRateCardSubscriptionServicingCanceledEvent, Events::V2BillingRateCardSubscriptionServicingPausedEvent, Events::V2BillingRateCardUpdatedEvent, Events::V2BillingRateCardVersionCreatedEvent, Events::V2CoreAccountClosedEvent, Events::V2CoreAccountCreatedEvent, Events::V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationCardCreatorUpdatedEvent, Events::V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationCustomerUpdatedEvent, Events::V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationMerchantUpdatedEvent, Events::V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationRecipientUpdatedEvent, Events::V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent, Events::V2CoreAccountIncludingConfigurationStorerUpdatedEvent, Events::V2CoreAccountIncludingDefaultsUpdatedEvent, Events::V2CoreAccountIncludingIdentityUpdatedEvent, Events::V2CoreAccountIncludingRequirementsUpdatedEvent, Events::V2CoreAccountLinkReturnedEvent, Events::V2CoreAccountPersonCreatedEvent, Events::V2CoreAccountPersonDeletedEvent, Events::V2CoreAccountPersonUpdatedEvent, Events::V2CoreAccountUpdatedEvent, Events::V2CoreClaimableSandboxClaimedEvent, Events::V2CoreClaimableSandboxCreatedEvent, Events::V2CoreClaimableSandboxExpiredEvent, Events::V2CoreClaimableSandboxExpiringEvent, Events::V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEvent, Events::V2CoreEventDestinationPingEvent, Events::V2CoreHealthApiErrorFiringEvent, Events::V2CoreHealthApiErrorResolvedEvent, Events::V2CoreHealthApiLatencyFiringEvent, Events::V2CoreHealthApiLatencyResolvedEvent, Events::V2CoreHealthAuthorizationRateDropFiringEvent, Events::V2CoreHealthAuthorizationRateDropResolvedEvent, Events::V2CoreHealthEventGenerationFailureResolvedEvent, Events::V2CoreHealthFraudRateIncreasedEvent, Events::V2CoreHealthIssuingAuthorizationRequestErrorsFiringEvent, Events::V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEvent, Events::V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent, Events::V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent, Events::V2CoreHealthPaymentMethodErrorFiringEvent, Events::V2CoreHealthPaymentMethodErrorResolvedEvent, Events::V2CoreHealthTrafficVolumeDropFiringEvent, Events::V2CoreHealthTrafficVolumeDropResolvedEvent, Events::V2CoreHealthWebhookLatencyFiringEvent, Events::V2CoreHealthWebhookLatencyResolvedEvent, Events::V2IamApiKeyCreatedEvent, Events::V2IamApiKeyDefaultSecretRevealedEvent, Events::V2IamApiKeyExpiredEvent, Events::V2IamApiKeyPermissionsUpdatedEvent, Events::V2IamApiKeyRotatedEvent, Events::V2IamApiKeyUpdatedEvent, Events::V2MoneyManagementAdjustmentCreatedEvent, Events::V2MoneyManagementFinancialAccountCreatedEvent, Events::V2MoneyManagementFinancialAccountUpdatedEvent, Events::V2MoneyManagementFinancialAddressActivatedEvent, Events::V2MoneyManagementFinancialAddressFailedEvent, Events::V2MoneyManagementInboundTransferAvailableEvent, Events::V2MoneyManagementInboundTransferBankDebitFailedEvent, Events::V2MoneyManagementInboundTransferBankDebitProcessingEvent, Events::V2MoneyManagementInboundTransferBankDebitQueuedEvent, Events::V2MoneyManagementInboundTransferBankDebitReturnedEvent, Events::V2MoneyManagementInboundTransferBankDebitSucceededEvent, Events::V2MoneyManagementOutboundPaymentCanceledEvent, Events::V2MoneyManagementOutboundPaymentCreatedEvent, Events::V2MoneyManagementOutboundPaymentFailedEvent, Events::V2MoneyManagementOutboundPaymentPostedEvent, Events::V2MoneyManagementOutboundPaymentReturnedEvent, Events::V2MoneyManagementOutboundPaymentUpdatedEvent, Events::V2MoneyManagementOutboundTransferCanceledEvent, Events::V2MoneyManagementOutboundTransferCreatedEvent, Events::V2MoneyManagementOutboundTransferFailedEvent, Events::V2MoneyManagementOutboundTransferPostedEvent, Events::V2MoneyManagementOutboundTransferReturnedEvent, Events::V2MoneyManagementOutboundTransferUpdatedEvent, Events::V2MoneyManagementPayoutMethodUpdatedEvent, Events::V2MoneyManagementReceivedCreditAvailableEvent, Events::V2MoneyManagementReceivedCreditFailedEvent, Events::V2MoneyManagementReceivedCreditReturnedEvent, Events::V2MoneyManagementReceivedCreditSucceededEvent, Events::V2MoneyManagementReceivedDebitCanceledEvent, Events::V2MoneyManagementReceivedDebitFailedEvent, Events::V2MoneyManagementReceivedDebitPendingEvent, Events::V2MoneyManagementReceivedDebitSucceededEvent, Events::V2MoneyManagementReceivedDebitUpdatedEvent, Events::V2MoneyManagementRecipientVerificationCreatedEvent, Events::V2MoneyManagementRecipientVerificationUpdatedEvent, Events::V2MoneyManagementTransactionCreatedEvent, Events::V2MoneyManagementTransactionUpdatedEvent, Events::V2PaymentsOffSessionPaymentAttemptFailedEvent, Events::V2PaymentsOffSessionPaymentAttemptStartedEvent, Events::V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent, Events::V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent, Events::V2PaymentsOffSessionPaymentCanceledEvent, Events::V2PaymentsOffSessionPaymentCreatedEvent, Events::V2PaymentsOffSessionPaymentFailedEvent, Events::V2PaymentsOffSessionPaymentRequiresCaptureEvent, Events::V2PaymentsOffSessionPaymentSucceededEvent, Events::V2ReportingReportRunCreatedEvent, Events::V2ReportingReportRunFailedEvent, Events::V2ReportingReportRunSucceededEvent, Events::V2ReportingReportRunUpdatedEvent
Defined Under Namespace
Classes: Reason
Constant Summary collapse
- OBJECT_NAME =
"v2.core.event"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#changes ⇒ Object
readonly
Before and after changes for the primary related object.
-
#context ⇒ Object
readonly
Authentication context needed to fetch the event or related object.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the event.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#reason ⇒ Object
readonly
Reason for the event.
-
#type ⇒ Object
readonly
The type of the event.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#changes ⇒ Object (readonly)
Before and after changes for the primary related object.
92 93 94 |
# File 'lib/stripe/resources/v2/core/event.rb', line 92 def changes @changes end |
#context ⇒ Object (readonly)
Authentication context needed to fetch the event or related object.
94 95 96 |
# File 'lib/stripe/resources/v2/core/event.rb', line 94 def context @context end |
#created ⇒ Object (readonly)
Time at which the object was created.
96 97 98 |
# File 'lib/stripe/resources/v2/core/event.rb', line 96 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the event.
98 99 100 |
# File 'lib/stripe/resources/v2/core/event.rb', line 98 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
100 101 102 |
# File 'lib/stripe/resources/v2/core/event.rb', line 100 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
102 103 104 |
# File 'lib/stripe/resources/v2/core/event.rb', line 102 def object @object end |
#reason ⇒ Object (readonly)
Reason for the event.
104 105 106 |
# File 'lib/stripe/resources/v2/core/event.rb', line 104 def reason @reason end |
#type ⇒ Object (readonly)
The type of the event.
106 107 108 |
# File 'lib/stripe/resources/v2/core/event.rb', line 106 def type @type end |
Class Method Details
.field_remappings ⇒ Object
112 113 114 |
# File 'lib/stripe/resources/v2/core/event.rb', line 112 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
108 109 110 |
# File 'lib/stripe/resources/v2/core/event.rb', line 108 def self.inner_class_types @inner_class_types = { reason: Reason } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/event.rb', line 10 def self.object_name "v2.core.event" end |