Class: Stripe::V2::Core::EventDestination

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/event_destination.rb

Overview

Set up an event destination to receive events from Stripe across multiple destination types, including [webhook endpoints](docs.stripe.com/webhooks) and [Amazon EventBridge](docs.stripe.com/event-destinations/eventbridge). Event destinations support receiving [thin events](docs.stripe.com/api/v2/events) and [snapshot events](docs.stripe.com/api/events).

Defined Under Namespace

Classes: AmazonEventbridge, AzureEventGrid, StatusDetails, WebhookEndpoint

Constant Summary collapse

OBJECT_NAME =
"v2.core.event_destination"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amazon_eventbridgeObject (readonly)

Amazon EventBridge configuration.



92
93
94
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 92

def amazon_eventbridge
  @amazon_eventbridge
end

#azure_event_gridObject (readonly)

Azure Event Grid configuration.



94
95
96
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 94

def azure_event_grid
  @azure_event_grid
end

#createdObject (readonly)

Time at which the object was created.



96
97
98
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 96

def created
  @created
end

#descriptionObject (readonly)

An optional description of what the event destination is used for.



98
99
100
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 98

def description
  @description
end

#enabled_eventsObject (readonly)

The list of events to enable for this endpoint.



100
101
102
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 100

def enabled_events
  @enabled_events
end

#event_payloadObject (readonly)

Payload type of events being subscribed to.



102
103
104
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 102

def event_payload
  @event_payload
end

#events_fromObject (readonly)

Specifies which accounts’ events route to this destination. ‘@self`: Receive events from the account that owns the event destination. `@accounts`: Receive events emitted from other accounts you manage which includes your v1 and v2 accounts. `@organization_members`: Receive events from accounts directly linked to the organization. `@organization_members/@accounts`: Receive events from all accounts connected to any platform accounts in the organization.



108
109
110
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 108

def events_from
  @events_from
end

#idObject (readonly)

Unique identifier for the object.



110
111
112
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 110

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



112
113
114
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 112

def livemode
  @livemode
end

#metadataObject (readonly)

Metadata.



114
115
116
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 114

def 
  @metadata
end

#nameObject (readonly)

Event destination name.



116
117
118
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 116

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



118
119
120
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 118

def object
  @object
end

#snapshot_api_versionObject (readonly)

If using the snapshot event payload, the API version events are rendered as.



120
121
122
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 120

def snapshot_api_version
  @snapshot_api_version
end

#statusObject (readonly)

Status. It can be set to either enabled or disabled.



122
123
124
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 122

def status
  @status
end

#status_detailsObject (readonly)

Additional information about event destination status.



124
125
126
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 124

def status_details
  @status_details
end

#typeObject (readonly)

Event destination type.



126
127
128
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 126

def type
  @type
end

#updatedObject (readonly)

Time at which the object was last updated.



128
129
130
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 128

def updated
  @updated
end

#webhook_endpointObject (readonly)

Webhook endpoint configuration.



130
131
132
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 130

def webhook_endpoint
  @webhook_endpoint
end

Class Method Details

.field_remappingsObject



141
142
143
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 141

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



132
133
134
135
136
137
138
139
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 132

def self.inner_class_types
  @inner_class_types = {
    amazon_eventbridge: AmazonEventbridge,
    azure_event_grid: AzureEventGrid,
    status_details: StatusDetails,
    webhook_endpoint: WebhookEndpoint,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/event_destination.rb', line 10

def self.object_name
  "v2.core.event_destination"
end