Class: Stripe::V2::Core::EventDestinationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/event_destination_service.rb

Defined Under Namespace

Classes: WebhookEndpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, enabled_events: nil, include: nil, metadata: nil, name: nil, webhook_endpoint: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 137

def initialize(
  description: nil,
  enabled_events: nil,
  include: nil,
  metadata: nil,
  name: nil,
  webhook_endpoint: nil
)
  @description = description
  @enabled_events = enabled_events
  @include = include
  @metadata = 
  @name = name
  @webhook_endpoint = webhook_endpoint
end

Instance Attribute Details

#descriptionObject

An optional description of what the event destination is used for.



125
126
127
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 125

def description
  @description
end

#enabled_eventsObject

The list of events to enable for this endpoint.



127
128
129
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 127

def enabled_events
  @enabled_events
end

#includeObject

Additional fields to include in the response. Currently supports ‘webhook_endpoint.url`.



129
130
131
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 129

def include
  @include
end

#metadataObject

Metadata.



131
132
133
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 131

def 
  @metadata
end

#nameObject

Event destination name.



133
134
135
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 133

def name
  @name
end

#webhook_endpointObject

Webhook endpoint configuration.



135
136
137
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 135

def webhook_endpoint
  @webhook_endpoint
end