Class: Stripe::V2::Core::EventDestinationService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/core/event_destination_service.rb

Defined Under Namespace

Classes: WebhookEndpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, enabled_events: nil, include: nil, metadata: nil, name: nil, webhook_endpoint: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 155

def initialize(
  description: nil,
  enabled_events: nil,
  include: nil,
  metadata: nil,
  name: nil,
  webhook_endpoint: nil
)
  @description = description
  @enabled_events = enabled_events
  @include = include
  @metadata = 
  @name = name
  @webhook_endpoint = webhook_endpoint
end

Instance Attribute Details

#descriptionObject

An optional description of what the event destination is used for.



138
139
140
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 138

def description
  @description
end

#enabled_eventsObject

The list of events to enable for this endpoint.



141
142
143
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 141

def enabled_events
  @enabled_events
end

#includeObject

Additional fields to include in the response. Currently supports ‘webhook_endpoint.url`.



144
145
146
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 144

def include
  @include
end

#metadataObject

Metadata.



147
148
149
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 147

def 
  @metadata
end

#nameObject

Event destination name.



150
151
152
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 150

def name
  @name
end

#webhook_endpointObject

Webhook endpoint configuration.



153
154
155
# File 'lib/stripe/services/v2/core/event_destination_service.rb', line 153

def webhook_endpoint
  @webhook_endpoint
end