Class: Stripe::V2::Core::EventService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Core::EventService
- Defined in:
- lib/stripe/services/v2/core/event_service.rb
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
List events, going back up to 30 days.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an event if it was created in the last 30 days.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
List events, going back up to 30 days.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/v2/core/event_service.rb', line 9 def list(params = {}, opts = {}) request( method: :get, path: "/v2/core/events", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an event if it was created in the last 30 days. Supply the unique identifier of the event, which might have been delivered to your event destination.
21 22 23 24 25 26 27 28 29 |
# File 'lib/stripe/services/v2/core/event_service.rb', line 21 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/events/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |