Class: Stripe::V2::Core::FeeBatch

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/fee_batch.rb

Overview

A FeeBatch represents a settlement grouping of fees. It bridges the fee domain with actual money movement, tracking what was settled and how.

Defined Under Namespace

Classes: Adjustments, CollectedBy, CollectionRecord, StatusTransitions, Tax

Constant Summary collapse

OBJECT_NAME =
"v2.core.fee_batch"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adjustmentsObject (readonly)

Adjustments applied to this batch.



104
105
106
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 104

def adjustments
  @adjustments
end

#amountObject (readonly)

The total fee amount billed in this batch.



106
107
108
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 106

def amount
  @amount
end

#collected_byObject (readonly)

The entity that collected this batch.



108
109
110
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 108

def collected_by
  @collected_by
end

#collection_recordsObject (readonly)

The money movement records associated with collecting this batch.



110
111
112
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 110

def collection_records
  @collection_records
end

#createdObject (readonly)

Timestamp of when this batch was created.



112
113
114
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 112

def created
  @created
end

#idObject (readonly)

Unique identifier for the FeeBatch.



114
115
116
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 114

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode, or `false` if in test mode.



116
117
118
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 116

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



118
119
120
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 118

def object
  @object
end

#statusObject (readonly)

The current state of this batch.



120
121
122
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 120

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for each status transition.



122
123
124
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 122

def status_transitions
  @status_transitions
end

#taxObject (readonly)

The tax amount included in this batch.



124
125
126
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 124

def tax
  @tax
end

Class Method Details

.field_remappingsObject



136
137
138
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 136

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



126
127
128
129
130
131
132
133
134
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 126

def self.inner_class_types
  @inner_class_types = {
    adjustments: Adjustments,
    collected_by: CollectedBy,
    collection_records: CollectionRecord,
    status_transitions: StatusTransitions,
    tax: Tax,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/fee_batch.rb', line 11

def self.object_name
  "v2.core.fee_batch"
end