Class: Stripe::V2::Core::FeeEntry

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/fee_entry.rb

Overview

A FeeEntry is the atomic, append-only record of an assessed fee.

Defined Under Namespace

Classes: ChargedBy, IncurredBy, Tax

Constant Summary collapse

OBJECT_NAME =
"v2.core.fee_entry"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The fee amount.



103
104
105
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 103

def amount
  @amount
end

#charged_byObject (readonly)

The entity that assessed this fee.



105
106
107
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 105

def charged_by
  @charged_by
end

#createdObject (readonly)

Timestamp of when this fee entry was created.



107
108
109
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 107

def created
  @created
end

#fee_batchObject (readonly)

The ID of the FeeBatch that collected this fee, if any.



109
110
111
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 109

def fee_batch
  @fee_batch
end

#idObject (readonly)

Unique identifier for the FeeEntry.



111
112
113
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 111

def id
  @id
end

#incurred_byObject (readonly)

The usage event that caused this fee to be assessed.



113
114
115
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 113

def incurred_by
  @incurred_by
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode, or `false` if in test mode.



115
116
117
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 115

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



117
118
119
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 117

def object
  @object
end

#reasonObject (readonly)

The reason this fee entry was created.



119
120
121
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 119

def reason
  @reason
end

#taxObject (readonly)

The tax portion of the fee, if applicable.



121
122
123
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 121

def tax
  @tax
end

#typeObject (readonly)

The category of this fee.



123
124
125
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 123

def type
  @type
end

Class Method Details

.field_remappingsObject



129
130
131
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 129

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



125
126
127
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 125

def self.inner_class_types
  @inner_class_types = { charged_by: ChargedBy, incurred_by: IncurredBy, tax: Tax }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 10

def self.object_name
  "v2.core.fee_entry"
end