Class: Stripe::V2::Core::FeeEntry
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::FeeEntry
- Defined in:
- lib/stripe/resources/v2/core/fee_entry.rb
Overview
A FeeEntry is the atomic, append-only record of an assessed fee.
Defined Under Namespace
Classes: ChargedBy, IncurredBy, Tax
Constant Summary collapse
- OBJECT_NAME =
"v2.core.fee_entry"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The fee amount.
-
#charged_by ⇒ Object
readonly
The entity that assessed this fee.
-
#created ⇒ Object
readonly
Timestamp of when this fee entry was created.
-
#fee_batch ⇒ Object
readonly
The ID of the FeeBatch that collected this fee, if any.
-
#id ⇒ Object
readonly
Unique identifier for the FeeEntry.
-
#incurred_by ⇒ Object
readonly
The usage event that caused this fee to be assessed.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode, or `false` if in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#reason ⇒ Object
readonly
The reason this fee entry was created.
-
#tax ⇒ Object
readonly
The tax portion of the fee, if applicable.
-
#type ⇒ Object
readonly
The category of this fee.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The fee amount.
103 104 105 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 103 def amount @amount end |
#charged_by ⇒ Object (readonly)
The entity that assessed this fee.
105 106 107 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 105 def charged_by @charged_by end |
#created ⇒ Object (readonly)
Timestamp of when this fee entry was created.
107 108 109 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 107 def created @created end |
#fee_batch ⇒ Object (readonly)
The ID of the FeeBatch that collected this fee, if any.
109 110 111 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 109 def fee_batch @fee_batch end |
#id ⇒ Object (readonly)
Unique identifier for the FeeEntry.
111 112 113 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 111 def id @id end |
#incurred_by ⇒ Object (readonly)
The usage event that caused this fee to be assessed.
113 114 115 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 113 def incurred_by @incurred_by end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode, or `false` if in test mode.
115 116 117 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 115 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
117 118 119 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 117 def object @object end |
#reason ⇒ Object (readonly)
The reason this fee entry was created.
119 120 121 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 119 def reason @reason end |
#tax ⇒ Object (readonly)
The tax portion of the fee, if applicable.
121 122 123 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 121 def tax @tax end |
#type ⇒ Object (readonly)
The category of this fee.
123 124 125 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 123 def type @type end |
Class Method Details
.field_remappings ⇒ Object
129 130 131 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 129 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
125 126 127 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 125 def self.inner_class_types @inner_class_types = { charged_by: ChargedBy, incurred_by: IncurredBy, tax: Tax } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 10 def self.object_name "v2.core.fee_entry" end |