Class: Stripe::V2::Core::FeeEntry::ChargedBy
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::FeeEntry::ChargedBy
- Defined in:
- lib/stripe/resources/v2/core/fee_entry.rb
Defined Under Namespace
Classes: Application, Network, Stripe
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#application ⇒ Object
readonly
Details for a fee charged by a Connect application.
-
#network ⇒ Object
readonly
Details for a fee charged by the payment network.
-
#stripe ⇒ Object
readonly
Details for a fee charged by Stripe.
-
#type ⇒ Object
readonly
The type of entity that charged this fee.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#application ⇒ Object (readonly)
Details for a fee charged by a Connect application.
54 55 56 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 54 def application @application end |
#network ⇒ Object (readonly)
Details for a fee charged by the payment network.
56 57 58 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 56 def network @network end |
#stripe ⇒ Object (readonly)
Details for a fee charged by Stripe.
58 59 60 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 58 def stripe @stripe end |
#type ⇒ Object (readonly)
The type of entity that charged this fee.
60 61 62 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 60 def type @type end |
Class Method Details
.field_remappings ⇒ Object
66 67 68 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 66 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
62 63 64 |
# File 'lib/stripe/resources/v2/core/fee_entry.rb', line 62 def self.inner_class_types @inner_class_types = { application: Application, network: Network, stripe: Stripe } end |