Class: Stripe::V2::Core::FeeEntryListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::FeeEntryListParams
- Defined in:
- lib/stripe/params/v2/core/fee_entry_list_params.rb
Instance Attribute Summary collapse
-
#collection_record ⇒ Object
Filter by money movement id (e.g. txn_xxx, bt_xxx).
-
#created ⇒ Object
Filter for FeeEntries created at the exact specified timestamp.
-
#created_gt ⇒ Object
Filter for FeeEntries created after the specified timestamp (exclusive).
-
#created_gte ⇒ Object
Filter for FeeEntries created at or after the specified timestamp (inclusive).
-
#created_lt ⇒ Object
Filter for FeeEntries created before the specified timestamp (exclusive).
-
#created_lte ⇒ Object
Filter for FeeEntries created at or before the specified timestamp (inclusive).
-
#fee_batch ⇒ Object
Filter by fee batch id (fb_xxx).
-
#incurred_by ⇒ Object
Filter by usage object id (e.g. ch_xxx, py_xxx).
-
#limit ⇒ Object
Maximum number of results to return per page.
Instance Method Summary collapse
-
#initialize(collection_record: nil, created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, fee_batch: nil, incurred_by: nil, limit: nil) ⇒ FeeEntryListParams
constructor
A new instance of FeeEntryListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(collection_record: nil, created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, fee_batch: nil, incurred_by: nil, limit: nil) ⇒ FeeEntryListParams
Returns a new instance of FeeEntryListParams.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 27 def initialize( collection_record: nil, created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, fee_batch: nil, incurred_by: nil, limit: nil ) @collection_record = collection_record @created = created @created_gt = created_gt @created_gte = created_gte @created_lt = created_lt @created_lte = created_lte @fee_batch = fee_batch @incurred_by = incurred_by @limit = limit end |
Instance Attribute Details
#collection_record ⇒ Object
Filter by money movement id (e.g. txn_xxx, bt_xxx).
9 10 11 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 9 def collection_record @collection_record end |
#created ⇒ Object
Filter for FeeEntries created at the exact specified timestamp.
11 12 13 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 11 def created @created end |
#created_gt ⇒ Object
Filter for FeeEntries created after the specified timestamp (exclusive).
13 14 15 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 13 def created_gt @created_gt end |
#created_gte ⇒ Object
Filter for FeeEntries created at or after the specified timestamp (inclusive).
15 16 17 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 15 def created_gte @created_gte end |
#created_lt ⇒ Object
Filter for FeeEntries created before the specified timestamp (exclusive).
17 18 19 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 17 def created_lt @created_lt end |
#created_lte ⇒ Object
Filter for FeeEntries created at or before the specified timestamp (inclusive).
19 20 21 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 19 def created_lte @created_lte end |
#fee_batch ⇒ Object
Filter by fee batch id (fb_xxx).
21 22 23 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 21 def fee_batch @fee_batch end |
#incurred_by ⇒ Object
Filter by usage object id (e.g. ch_xxx, py_xxx).
23 24 25 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 23 def incurred_by @incurred_by end |
#limit ⇒ Object
Maximum number of results to return per page. Defaults to 20.
25 26 27 |
# File 'lib/stripe/params/v2/core/fee_entry_list_params.rb', line 25 def limit @limit end |