Class: Stripe::V2::Core::Health::Alert
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Health::Alert
- Defined in:
- lib/stripe/resources/v2/core/health/alert.rb
Overview
A health alert represents a detected problem affecting a merchant's Stripe integration.
Defined Under Namespace
Classes: ApiError, ApiLatency, AuthorizationRateDrop, DocumentationLink, ElementsError, EventGenerationFailure, FraudRate, InvoiceCountDropped, IssuingAuthorizationRequestErrors, IssuingAuthorizationRequestTimeout, MeterEventSummariesDelayed, MetronomeNotificationLatency, PaymentMethodError, SepaDebitDelayed, TrafficVolumeDrop, WebhookLatency
Constant Summary collapse
- OBJECT_NAME =
"v2.core.health.alert"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#api_error ⇒ Object
readonly
Populated when type is api_error.
-
#api_latency ⇒ Object
readonly
Populated when type is api_latency.
-
#authorization_rate_drop ⇒ Object
readonly
Populated when type is authorization_rate_drop.
-
#created ⇒ Object
readonly
Time at which the health alert was created.
-
#documentation_links ⇒ Object
readonly
Links to relevant documentation for diagnosing and resolving the alert.
-
#elements_error ⇒ Object
readonly
Populated when type is elements_error.
-
#event_generation_failure ⇒ Object
readonly
Populated when type is event_generation_failure.
-
#fraud_rate ⇒ Object
readonly
Populated when type is fraud_rate.
-
#grouping_key ⇒ Object
readonly
The grouping key for the alert.
-
#grouping_type ⇒ Object
readonly
Whether the alert is linked to an incident or is a self-contained problem.
-
#id ⇒ Object
readonly
Unique identifier for the health alert.
-
#invoice_count_dropped ⇒ Object
readonly
Populated when type is invoice_count_dropped.
-
#issuing_authorization_request_errors ⇒ Object
readonly
Populated when type is issuing_authorization_request_errors.
-
#issuing_authorization_request_timeout ⇒ Object
readonly
Populated when type is issuing_authorization_request_timeout.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#meter_event_summaries_delayed ⇒ Object
readonly
Populated when type is meter_event_summaries_delayed.
-
#metronome_notification_latency ⇒ Object
readonly
Populated when type is metronome_notification_latency.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#payment_method_error ⇒ Object
readonly
Populated when type is payment_method_error.
-
#resolved_at ⇒ Object
readonly
The time when the user experience has returned to expected levels.
-
#sepa_debit_delayed ⇒ Object
readonly
Populated when type is sepa_debit_delayed.
-
#severity ⇒ Object
readonly
The severity of the alert.
-
#started_at ⇒ Object
readonly
The time when impact on the user experience was first detected.
-
#status ⇒ Object
readonly
The current status of the alert.
-
#summary ⇒ Object
readonly
A short description of the alert.
-
#traffic_volume_drop ⇒ Object
readonly
Populated when type is traffic_volume_drop.
-
#type ⇒ Object
readonly
The type of the alert.
-
#webhook_latency ⇒ Object
readonly
Populated when type is webhook_latency.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#api_error ⇒ Object (readonly)
Populated when type is api_error.
434 435 436 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 434 def api_error @api_error end |
#api_latency ⇒ Object (readonly)
Populated when type is api_latency.
436 437 438 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 436 def api_latency @api_latency end |
#authorization_rate_drop ⇒ Object (readonly)
Populated when type is authorization_rate_drop.
438 439 440 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 438 def @authorization_rate_drop end |
#created ⇒ Object (readonly)
Time at which the health alert was created.
440 441 442 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 440 def created @created end |
#documentation_links ⇒ Object (readonly)
Links to relevant documentation for diagnosing and resolving the alert.
442 443 444 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 442 def documentation_links @documentation_links end |
#elements_error ⇒ Object (readonly)
Populated when type is elements_error.
444 445 446 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 444 def elements_error @elements_error end |
#event_generation_failure ⇒ Object (readonly)
Populated when type is event_generation_failure.
446 447 448 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 446 def event_generation_failure @event_generation_failure end |
#fraud_rate ⇒ Object (readonly)
Populated when type is fraud_rate.
448 449 450 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 448 def fraud_rate @fraud_rate end |
#grouping_key ⇒ Object (readonly)
The grouping key for the alert.
450 451 452 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 450 def grouping_key @grouping_key end |
#grouping_type ⇒ Object (readonly)
Whether the alert is linked to an incident or is a self-contained problem.
452 453 454 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 452 def grouping_type @grouping_type end |
#id ⇒ Object (readonly)
Unique identifier for the health alert.
454 455 456 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 454 def id @id end |
#invoice_count_dropped ⇒ Object (readonly)
Populated when type is invoice_count_dropped.
456 457 458 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 456 def invoice_count_dropped @invoice_count_dropped end |
#issuing_authorization_request_errors ⇒ Object (readonly)
Populated when type is issuing_authorization_request_errors.
458 459 460 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 458 def @issuing_authorization_request_errors end |
#issuing_authorization_request_timeout ⇒ Object (readonly)
Populated when type is issuing_authorization_request_timeout.
460 461 462 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 460 def @issuing_authorization_request_timeout end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
462 463 464 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 462 def livemode @livemode end |
#meter_event_summaries_delayed ⇒ Object (readonly)
Populated when type is meter_event_summaries_delayed.
464 465 466 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 464 def meter_event_summaries_delayed @meter_event_summaries_delayed end |
#metronome_notification_latency ⇒ Object (readonly)
Populated when type is metronome_notification_latency.
466 467 468 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 466 def metronome_notification_latency @metronome_notification_latency end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
468 469 470 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 468 def object @object end |
#payment_method_error ⇒ Object (readonly)
Populated when type is payment_method_error.
470 471 472 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 470 def payment_method_error @payment_method_error end |
#resolved_at ⇒ Object (readonly)
The time when the user experience has returned to expected levels. Null if the alert is still open.
472 473 474 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 472 def resolved_at @resolved_at end |
#sepa_debit_delayed ⇒ Object (readonly)
Populated when type is sepa_debit_delayed.
474 475 476 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 474 def sepa_debit_delayed @sepa_debit_delayed end |
#severity ⇒ Object (readonly)
The severity of the alert.
476 477 478 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 476 def severity @severity end |
#started_at ⇒ Object (readonly)
The time when impact on the user experience was first detected.
478 479 480 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 478 def started_at @started_at end |
#status ⇒ Object (readonly)
The current status of the alert.
480 481 482 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 480 def status @status end |
#summary ⇒ Object (readonly)
A short description of the alert.
482 483 484 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 482 def summary @summary end |
#traffic_volume_drop ⇒ Object (readonly)
Populated when type is traffic_volume_drop.
484 485 486 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 484 def traffic_volume_drop @traffic_volume_drop end |
#type ⇒ Object (readonly)
The type of the alert. Determines which sub-hash field is populated.
486 487 488 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 486 def type @type end |
#webhook_latency ⇒ Object (readonly)
Populated when type is webhook_latency.
488 489 490 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 488 def webhook_latency @webhook_latency end |
Class Method Details
.field_encodings ⇒ Object
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 515 def self.field_encodings @field_encodings = { api_error: { kind: :object, fields: { impacted_requests_percentage: :decimal_string, top_impacted_accounts: { kind: :array, element: { kind: :object, fields: { impacted_requests_percentage: :decimal_string }, }, }, }, }, api_latency: { kind: :object, fields: { impacted_requests_percentage: :decimal_string, top_impacted_accounts: { kind: :array, element: { kind: :object, fields: { impacted_requests_percentage: :decimal_string }, }, }, }, }, authorization_rate_drop: { kind: :object, fields: { current_percentage: :decimal_string, previous_percentage: :decimal_string }, }, invoice_count_dropped: { kind: :object, fields: { observed_count: :decimal_string, threshold_count: :decimal_string }, }, payment_method_error: { kind: :object, fields: { impacted_requests_percentage: :decimal_string, top_impacted_accounts: { kind: :array, element: { kind: :object, fields: { impacted_requests_percentage: :decimal_string }, }, }, }, }, sepa_debit_delayed: { kind: :object, fields: { impacted_payments_percentage: :decimal_string }, }, } end |
.field_remappings ⇒ Object
511 512 513 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 511 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 490 def self.inner_class_types @inner_class_types = { api_error: ApiError, api_latency: ApiLatency, authorization_rate_drop: AuthorizationRateDrop, documentation_links: DocumentationLink, elements_error: ElementsError, event_generation_failure: EventGenerationFailure, fraud_rate: FraudRate, invoice_count_dropped: InvoiceCountDropped, issuing_authorization_request_errors: IssuingAuthorizationRequestErrors, issuing_authorization_request_timeout: IssuingAuthorizationRequestTimeout, meter_event_summaries_delayed: MeterEventSummariesDelayed, metronome_notification_latency: MetronomeNotificationLatency, payment_method_error: PaymentMethodError, sepa_debit_delayed: SepaDebitDelayed, traffic_volume_drop: TrafficVolumeDrop, webhook_latency: WebhookLatency, } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 11 def self.object_name "v2.core.health.alert" end |