Class: Stripe::V2::Core::Health::Alert::TrafficVolumeDrop
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Health::Alert::TrafficVolumeDrop
- Defined in:
- lib/stripe/resources/v2/core/health/alert.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#actual_traffic ⇒ Object
readonly
The total volume of payment requests within the latest observation time window.
-
#canonical_path ⇒ Object
readonly
The canonical path.
-
#expected_traffic ⇒ Object
readonly
The expected volume of payment requests within the latest observation time window.
-
#time_window ⇒ Object
readonly
The size of the observation time window.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#actual_traffic ⇒ Object (readonly)
The total volume of payment requests within the latest observation time window.
404 405 406 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 404 def actual_traffic @actual_traffic end |
#canonical_path ⇒ Object (readonly)
The canonical path.
406 407 408 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 406 def canonical_path @canonical_path end |
#expected_traffic ⇒ Object (readonly)
The expected volume of payment requests within the latest observation time window.
408 409 410 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 408 def expected_traffic @expected_traffic end |
#time_window ⇒ Object (readonly)
The size of the observation time window.
410 411 412 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 410 def time_window @time_window end |
Class Method Details
.field_remappings ⇒ Object
416 417 418 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 416 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
412 413 414 |
# File 'lib/stripe/resources/v2/core/health/alert.rb', line 412 def self.inner_class_types @inner_class_types = {} end |