Class: Stripe::V2::Core::Health::AlertHistoryEntry::EventGenerationFailure
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Health::AlertHistoryEntry::EventGenerationFailure
- Defined in:
- lib/stripe/resources/v2/core/health/alert_history_entry.rb
Defined Under Namespace
Classes: RelatedObject
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
The context the event should have been generated for.
-
#event_type ⇒ Object
readonly
The type of event that Stripe failed to generate.
-
#related_object ⇒ Object
readonly
The related object details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#context ⇒ Object (readonly)
The context the event should have been generated for. Only present when the account is a connected account.
200 201 202 |
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 200 def context @context end |
#event_type ⇒ Object (readonly)
The type of event that Stripe failed to generate.
202 203 204 |
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 202 def event_type @event_type end |
#related_object ⇒ Object (readonly)
The related object details.
204 205 206 |
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 204 def @related_object end |
Class Method Details
.field_remappings ⇒ Object
210 211 212 |
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 210 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
206 207 208 |
# File 'lib/stripe/resources/v2/core/health/alert_history_entry.rb', line 206 def self.inner_class_types @inner_class_types = { related_object: RelatedObject } end |