Class: Stripe::V2::Core::Person

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/person.rb

Overview

Person retrieval response schema.

Defined Under Namespace

Classes: AdditionalAddress, AdditionalName, AdditionalTermsOfService, Address, DateOfBirth, Documents, IdNumber, Relationship, ScriptAddresses, ScriptNames

Constant Summary collapse

OBJECT_NAME =
"v2.core.account_person"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account ID which the individual belongs to.



226
227
228
# File 'lib/stripe/resources/v2/core/person.rb', line 226

def 
  @account
end

#additional_addressesObject (readonly)

Additional addresses associated with the person.



228
229
230
# File 'lib/stripe/resources/v2/core/person.rb', line 228

def additional_addresses
  @additional_addresses
end

#additional_namesObject (readonly)

Additional names (e.g. aliases) associated with the person.



230
231
232
# File 'lib/stripe/resources/v2/core/person.rb', line 230

def additional_names
  @additional_names
end

#additional_terms_of_serviceObject (readonly)

Attestations of accepted terms of service agreements.



232
233
234
# File 'lib/stripe/resources/v2/core/person.rb', line 232

def additional_terms_of_service
  @additional_terms_of_service
end

#addressObject (readonly)

The person’s residential address.



234
235
236
# File 'lib/stripe/resources/v2/core/person.rb', line 234

def address
  @address
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



236
237
238
# File 'lib/stripe/resources/v2/core/person.rb', line 236

def created
  @created
end

#date_of_birthObject (readonly)

The person’s date of birth.



238
239
240
# File 'lib/stripe/resources/v2/core/person.rb', line 238

def date_of_birth
  @date_of_birth
end

#documentsObject (readonly)

Documents that may be submitted to satisfy various informational requests.



240
241
242
# File 'lib/stripe/resources/v2/core/person.rb', line 240

def documents
  @documents
end

#emailObject (readonly)

The person’s email address.



242
243
244
# File 'lib/stripe/resources/v2/core/person.rb', line 242

def email
  @email
end

#given_nameObject (readonly)

The person’s first name.



244
245
246
# File 'lib/stripe/resources/v2/core/person.rb', line 244

def given_name
  @given_name
end

#idObject (readonly)

Unique identifier for the Person.



246
247
248
# File 'lib/stripe/resources/v2/core/person.rb', line 246

def id
  @id
end

#id_numbersObject (readonly)

The identification numbers (e.g., SSN) associated with the person.



248
249
250
# File 'lib/stripe/resources/v2/core/person.rb', line 248

def id_numbers
  @id_numbers
end

The person’s gender (International regulations require either “male” or “female”).



250
251
252
# File 'lib/stripe/resources/v2/core/person.rb', line 250

def legal_gender
  @legal_gender
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



272
273
274
# File 'lib/stripe/resources/v2/core/person.rb', line 272

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



252
253
254
# File 'lib/stripe/resources/v2/core/person.rb', line 252

def 
  @metadata
end

#nationalitiesObject (readonly)

The countries where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



254
255
256
# File 'lib/stripe/resources/v2/core/person.rb', line 254

def nationalities
  @nationalities
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



256
257
258
# File 'lib/stripe/resources/v2/core/person.rb', line 256

def object
  @object
end

#phoneObject (readonly)

The person’s phone number.



258
259
260
# File 'lib/stripe/resources/v2/core/person.rb', line 258

def phone
  @phone
end

#political_exposureObject (readonly)

The person’s political exposure.



260
261
262
# File 'lib/stripe/resources/v2/core/person.rb', line 260

def political_exposure
  @political_exposure
end

#relationshipObject (readonly)

The relationship that this person has with the Account’s business or legal entity.



262
263
264
# File 'lib/stripe/resources/v2/core/person.rb', line 262

def relationship
  @relationship
end

#script_addressesObject (readonly)

The script addresses (e.g., non-Latin characters) associated with the person.



264
265
266
# File 'lib/stripe/resources/v2/core/person.rb', line 264

def script_addresses
  @script_addresses
end

#script_namesObject (readonly)

The script names (e.g. non-Latin characters) associated with the person.



266
267
268
# File 'lib/stripe/resources/v2/core/person.rb', line 266

def script_names
  @script_names
end

#surnameObject (readonly)

The person’s last name.



268
269
270
# File 'lib/stripe/resources/v2/core/person.rb', line 268

def surname
  @surname
end

#updatedObject (readonly)

Time at which the object was last updated. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



270
271
272
# File 'lib/stripe/resources/v2/core/person.rb', line 270

def updated
  @updated
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/core/person.rb', line 10

def self.object_name
  "v2.core.account_person"
end