Class: Stripe::V2::Core::Vault::GbBankAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/vault/gb_bank_account.rb

Overview

Use the GBBankAccounts API to create and manage GB bank account objects

Defined Under Namespace

Classes: ConfirmationOfPayee

Constant Summary collapse

OBJECT_NAME =
"v2.core.vault.gb_bank_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#archivedObject (readonly)

Whether this bank account object was archived. Bank account objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived bank account objects cannot be used as outbound destinations and will not appear in the outbound destination list.



50
51
52
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 50

def archived
  @archived
end

#bank_account_typeObject (readonly)

Closed Enum. The type of the bank account (checking or savings).



52
53
54
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 52

def 
  @bank_account_type
end

#bank_nameObject (readonly)

The name of the bank.



54
55
56
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 54

def bank_name
  @bank_name
end

#confirmation_of_payeeObject (readonly)

Information around the status of Confirmation of Payee matching done on this bank account. Confirmation of Payee is a name matching service that must be done before making OutboundPayments in the UK.



57
58
59
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 57

def confirmation_of_payee
  @confirmation_of_payee
end

#createdObject (readonly)

Creation time.



59
60
61
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 59

def created
  @created
end

#idObject (readonly)

The ID of the GBBankAccount object.



61
62
63
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 61

def id
  @id
end

#last4Object (readonly)

The last 4 digits of the account number or IBAN.



63
64
65
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 63

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



69
70
71
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 69

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



65
66
67
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 65

def object
  @object
end

#sort_codeObject (readonly)

The Sort Code of the bank account.



67
68
69
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 67

def sort_code
  @sort_code
end

Class Method Details

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 11

def self.object_name
  "v2.core.vault.gb_bank_account"
end