Class: Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result
- Defined in:
- lib/stripe/resources/v2/core/vault/gb_bank_account.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
When the CoP result was created.
-
#match_result ⇒ Object
readonly
Whether or not the information of the bank account matches what you have provided.
-
#matched ⇒ Object
readonly
The fields that CoP service matched against.
-
#message ⇒ Object
readonly
Human-readable message describing the match result.
-
#provided ⇒ Object
readonly
The fields that are matched against what the network has on file.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
When the CoP result was created.
63 64 65 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 63 def created @created end |
#match_result ⇒ Object (readonly)
Whether or not the information of the bank account matches what you have provided. Closed enum.
65 66 67 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 65 def match_result @match_result end |
#matched ⇒ Object (readonly)
The fields that CoP service matched against. Only has value if MATCH or PARTIAL_MATCH, empty otherwise.
67 68 69 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 67 def matched @matched end |
#message ⇒ Object (readonly)
Human-readable message describing the match result.
69 70 71 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 69 def @message end |
#provided ⇒ Object (readonly)
The fields that are matched against what the network has on file.
71 72 73 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 71 def provided @provided end |
Class Method Details
.field_remappings ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 77 def self.field_remappings @field_remappings = {} end |