Class: Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result
- Defined in:
- lib/stripe/resources/v2/core/vault/gb_bank_account.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
When the CoP result was created.
-
#match_result ⇒ Object
readonly
Whether or not the information of the bank account matches what you have provided.
-
#matched ⇒ Object
readonly
The fields that CoP service matched against.
-
#message ⇒ Object
readonly
Human-readable message describing the match result.
-
#provided ⇒ Object
readonly
The fields that are matched against what the network has on file.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
When the CoP result was created.
48 49 50 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 48 def created @created end |
#match_result ⇒ Object (readonly)
Whether or not the information of the bank account matches what you have provided. Closed enum.
50 51 52 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 50 def match_result @match_result end |
#matched ⇒ Object (readonly)
The fields that CoP service matched against. Only has value if MATCH or PARTIAL_MATCH, empty otherwise.
52 53 54 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 52 def matched @matched end |
#message ⇒ Object (readonly)
Human-readable message describing the match result.
54 55 56 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 54 def @message end |
#provided ⇒ Object (readonly)
The fields that are matched against what the network has on file.
56 57 58 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 56 def provided @provided end |
Class Method Details
.field_remappings ⇒ Object
62 63 64 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 62 def self.field_remappings @field_remappings = {} end |