Class: Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Core::Vault::GbBankAccount::ConfirmationOfPayee::Result
- Defined in:
- lib/stripe/resources/v2/core/vault/gb_bank_account.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
When the CoP result was created.
-
#match_result ⇒ Object
readonly
Whether or not the information of the bank account matches what you have provided.
-
#matched ⇒ Object
readonly
The fields that CoP service matched against.
-
#message ⇒ Object
readonly
Human-readable message describing the match result.
-
#provided ⇒ Object
readonly
The fields that are matched against what the network has on file.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
When the CoP result was created.
32 33 34 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 32 def created @created end |
#match_result ⇒ Object (readonly)
Whether or not the information of the bank account matches what you have provided. Closed enum.
34 35 36 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 34 def match_result @match_result end |
#matched ⇒ Object (readonly)
The fields that CoP service matched against. Only has value if MATCH or PARTIAL_MATCH, empty otherwise.
36 37 38 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 36 def matched @matched end |
#message ⇒ Object (readonly)
Human-readable message describing the match result.
38 39 40 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 38 def @message end |
#provided ⇒ Object (readonly)
The fields that are matched against what the network has on file.
40 41 42 |
# File 'lib/stripe/resources/v2/core/vault/gb_bank_account.rb', line 40 def provided @provided end |