Class: Stripe::V2::Core::Vault::GbBankAccountCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountCreateParams
- Defined in:
- lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb
Defined Under Namespace
Classes: ConfirmationOfPayee
Instance Attribute Summary collapse
-
#account_number ⇒ Object
The Account Number of the bank account.
-
#bank_account_type ⇒ Object
Closed Enum.
-
#confirmation_of_payee ⇒ Object
Whether or not to automatically perform Confirmation of Payee to verify the users information against what was provided by the bank.
-
#currency ⇒ Object
The currency of the bank account.
-
#iban ⇒ Object
The IBAN of the bank account.
-
#sort_code ⇒ Object
The Sort Code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, bank_account_type: nil, confirmation_of_payee: nil, currency: nil, iban: nil, sort_code: nil) ⇒ GbBankAccountCreateParams
constructor
A new instance of GbBankAccountCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_number: nil, bank_account_type: nil, confirmation_of_payee: nil, currency: nil, iban: nil, sort_code: nil) ⇒ GbBankAccountCreateParams
Returns a new instance of GbBankAccountCreateParams.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 39 def initialize( account_number: nil, bank_account_type: nil, confirmation_of_payee: nil, currency: nil, iban: nil, sort_code: nil ) @account_number = account_number @bank_account_type = bank_account_type @confirmation_of_payee = confirmation_of_payee @currency = currency @iban = iban @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
The Account Number of the bank account.
25 26 27 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 25 def account_number @account_number end |
#bank_account_type ⇒ Object
Closed Enum. The type of the bank account (checking or savings).
27 28 29 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 27 def bank_account_type @bank_account_type end |
#confirmation_of_payee ⇒ Object
Whether or not to automatically perform Confirmation of Payee to verify the users information against what was provided by the bank. Doing so is required for all bank accounts not owned by you before making domestic UK OutboundPayments.
31 32 33 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 31 def confirmation_of_payee @confirmation_of_payee end |
#currency ⇒ Object
The currency of the bank account.
33 34 35 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 33 def currency @currency end |
#iban ⇒ Object
The IBAN of the bank account.
35 36 37 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 35 def iban @iban end |
#sort_code ⇒ Object
The Sort Code of the bank account.
37 38 39 |
# File 'lib/stripe/params/v2/core/vault/gb_bank_account_create_params.rb', line 37 def sort_code @sort_code end |