Class: Stripe::V2::Core::Vault::GbBankAccountService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::Core::Vault::GbBankAccountService
- Defined in:
- lib/stripe/services/v2/core/vault/gb_bank_account_service.rb
Instance Method Summary collapse
-
#acknowledge_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object
Confirm that you have received the result of the Confirmation of Payee request, and that you are okay with proceeding to pay out to this bank account despite the account not matching, partially matching, or the service being unavailable.
-
#archive(id, params = {}, opts = {}) ⇒ Object
Archive a GBBankAccount object.
-
#create(params = {}, opts = {}) ⇒ Object
Create a GB bank account.
-
#initiate_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object
Initiate Confirmation of Payee (CoP) in order to verify that the owner of a UK bank account matches who you expect.
-
#list(params = {}, opts = {}) ⇒ Object
List objects that can be used as destinations for outbound money movement via OutboundPayment.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a GB bank account.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#acknowledge_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object
Confirm that you have received the result of the Confirmation of Payee request, and that you are okay with proceeding to pay out to this bank account despite the account not matching, partially matching, or the service being unavailable. Once you confirm this, you will be able to send OutboundPayments, but this may lead to funds being sent to the wrong account, which we might not be able to recover.
13 14 15 16 17 18 19 20 21 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 13 def acknowledge_confirmation_of_payee(id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/vault/gb_bank_accounts/%<id>s/acknowledge_confirmation_of_payee", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#archive(id, params = {}, opts = {}) ⇒ Object
Archive a GBBankAccount object. Archived GBBankAccount objects cannot be used as outbound destinations and will not appear in the outbound destination list.
25 26 27 28 29 30 31 32 33 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 25 def archive(id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/vault/gb_bank_accounts/%<id>s/archive", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Create a GB bank account.
36 37 38 39 40 41 42 43 44 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 36 def create(params = {}, opts = {}) request( method: :post, path: "/v2/core/vault/gb_bank_accounts", params: params, opts: opts, base_address: :api ) end |
#initiate_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object
Initiate Confirmation of Payee (CoP) in order to verify that the owner of a UK bank account matches who you expect. This must be done on all UK bank accounts before sending domestic OutboundPayments. If the result is a partial match or a non match, explicit acknowledgement using AcknowledgeConfirmationOfPayee is required before sending funds.
50 51 52 53 54 55 56 57 58 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 50 def initiate_confirmation_of_payee(id, params = {}, opts = {}) request( method: :post, path: format("/v2/core/vault/gb_bank_accounts/%<id>s/initiate_confirmation_of_payee", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List objects that can be used as destinations for outbound money movement via OutboundPayment.
61 62 63 64 65 66 67 68 69 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 61 def list(params = {}, opts = {}) request( method: :get, path: "/v2/core/vault/gb_bank_accounts", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a GB bank account.
72 73 74 75 76 77 78 79 80 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 72 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/core/vault/gb_bank_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |