Class: Stripe::V2::Core::Vault::GbBankAccountService

Inherits:
StripeService
  • Object
show all
Defined in:
lib/stripe/services/v2/core/vault/gb_bank_account_service.rb

Defined Under Namespace

Classes: AcknowledgeConfirmationOfPayeeParams, ArchiveParams, CreateParams, InitiateConfirmationOfPayeeParams, RetrieveParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#acknowledge_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object

Confirm that you have received the result of the Confirmation of Payee request, and that you are okay with proceeding to pay out to this bank account despite the account not matching, partially matching, or the service being unavailable. Once you confirm this, you will be able to send OutboundPayments, but this may lead to funds being sent to the wrong account, which we might not be able to recover.



69
70
71
72
73
74
75
76
77
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 69

def acknowledge_confirmation_of_payee(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s/acknowledge_confirmation_of_payee", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#archive(id, params = {}, opts = {}) ⇒ Object

Archive a GBBankAccount object. Archived GBBankAccount objects cannot be used as outbound destinations and will not appear in the outbound destination list.



81
82
83
84
85
86
87
88
89
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 81

def archive(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s/archive", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

Create a GB bank account.



92
93
94
95
96
97
98
99
100
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 92

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v2/core/vault/gb_bank_accounts",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#initiate_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object

Initiate Confirmation of Payee (CoP) in order to verify that the owner of a UK bank account matches who you expect. This must be done on all UK bank accounts before sending domestic OutboundPayments. If the result is a partial match or a non match, explicit acknowledgement using AcknowledgeConfirmationOfPayee is required before sending funds.



106
107
108
109
110
111
112
113
114
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 106

def initiate_confirmation_of_payee(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s/initiate_confirmation_of_payee", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieve a GB bank account.



117
118
119
120
121
122
123
124
125
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 117

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end