Class: Stripe::V2::Core::Vault::GbBankAccountService

Inherits:
StripeService
  • Object
show all
Defined in:
lib/stripe/services/v2/core/vault/gb_bank_account_service.rb

Defined Under Namespace

Classes: AcknowledgeConfirmationOfPayeeParams, ArchiveParams, CreateParams, InitiateConfirmationOfPayeeParams, RetrieveParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#acknowledge_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object

Confirm that you have received the result of the Confirmation of Payee request, and that you are okay with proceeding to pay out to this bank account despite the account not matching, partially matching, or the service being unavailable. Once you confirm this, you will be able to send OutboundPayments, but this may lead to funds being sent to the wrong account, which we might not be able to recover.



74
75
76
77
78
79
80
81
82
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 74

def acknowledge_confirmation_of_payee(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s/acknowledge_confirmation_of_payee", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#archive(id, params = {}, opts = {}) ⇒ Object

Archive a GbBankAccount object. Archived GbBankAccount objects cannot be used as outbound destinations and will not appear in the outbound destination list.



86
87
88
89
90
91
92
93
94
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 86

def archive(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s/archive", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

Create a GB bank account.



97
98
99
100
101
102
103
104
105
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 97

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v2/core/vault/gb_bank_accounts",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#initiate_confirmation_of_payee(id, params = {}, opts = {}) ⇒ Object

Initiate Confirmation of Payee (CoP) in order to verify that the owner of a UK bank account matches who you expect. This must be done on all UK bank accounts before sending domestic OutboundPayments. If the result is a partial match or a non match, explicit acknowledgement using AcknowledgeConfirmationOfPayee is required before sending funds.



111
112
113
114
115
116
117
118
119
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 111

def initiate_confirmation_of_payee(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s/initiate_confirmation_of_payee", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieve a GB bank account.



122
123
124
125
126
127
128
129
130
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 122

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/core/vault/gb_bank_accounts/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end