Class: Stripe::V2::Core::Vault::GbBankAccountService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountService::CreateParams
- Defined in:
- lib/stripe/services/v2/core/vault/gb_bank_account_service.rb
Defined Under Namespace
Classes: ConfirmationOfPayee
Instance Attribute Summary collapse
-
#account_number ⇒ Object
The Account Number of the bank account.
-
#bank_account_type ⇒ Object
Closed Enum.
-
#confirmation_of_payee ⇒ Object
Whether or not to automatically perform Confirmation of Payee to verify the users information against what was provided by the bank.
-
#sort_code ⇒ Object
The Sort Code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, bank_account_type: nil, confirmation_of_payee: nil, sort_code: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_number: nil, bank_account_type: nil, confirmation_of_payee: nil, sort_code: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 36 def initialize( account_number: nil, bank_account_type: nil, confirmation_of_payee: nil, sort_code: nil ) @account_number = account_number @bank_account_type = bank_account_type @confirmation_of_payee = confirmation_of_payee @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
The Account Number of the bank account.
26 27 28 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 26 def account_number @account_number end |
#bank_account_type ⇒ Object
Closed Enum. The type of the bank account (checking or savings).
28 29 30 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 28 def bank_account_type @bank_account_type end |
#confirmation_of_payee ⇒ Object
Whether or not to automatically perform Confirmation of Payee to verify the users information against what was provided by the bank. Doing so is required for all bank accounts not owned by you before making domestic UK OutboundPayments.
32 33 34 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 32 def confirmation_of_payee @confirmation_of_payee end |
#sort_code ⇒ Object
The Sort Code of the bank account.
34 35 36 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 34 def sort_code @sort_code end |