Class: Stripe::V2::Core::Vault::GbBankAccountService::CreateParams::ConfirmationOfPayee
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Core::Vault::GbBankAccountService::CreateParams::ConfirmationOfPayee
- Defined in:
- lib/stripe/services/v2/core/vault/gb_bank_account_service.rb
Instance Attribute Summary collapse
-
#business_type ⇒ Object
The business type to be checked against.
-
#initiate ⇒ Object
User specifies whether Confirmation of Payee is automatically initiated when creating the bank account.
-
#name ⇒ Object
The name to be checked against.
Instance Method Summary collapse
-
#initialize(business_type: nil, initiate: nil, name: nil) ⇒ ConfirmationOfPayee
constructor
A new instance of ConfirmationOfPayee.
Methods inherited from RequestParams
Constructor Details
#initialize(business_type: nil, initiate: nil, name: nil) ⇒ ConfirmationOfPayee
Returns a new instance of ConfirmationOfPayee.
25 26 27 28 29 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 25 def initialize(business_type: nil, initiate: nil, name: nil) @business_type = business_type @initiate = initiate @name = name end |
Instance Attribute Details
#business_type ⇒ Object
The business type to be checked against. Legal entity information will be used if unspecified. Closed enum.
19 20 21 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 19 def business_type @business_type end |
#initiate ⇒ Object
User specifies whether Confirmation of Payee is automatically initiated when creating the bank account.
21 22 23 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 21 def initiate @initiate end |
#name ⇒ Object
The name to be checked against. Legal entity information will be used if unspecified.
23 24 25 |
# File 'lib/stripe/services/v2/core/vault/gb_bank_account_service.rb', line 23 def name @name end |