Class: Stripe::V2::Core::Vault::UsBankAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Vault::UsBankAccount
- Defined in:
- lib/stripe/resources/v2/core/vault/us_bank_account.rb
Overview
Use the USBankAccounts API to create and manage US bank accounts objects that you can use to receive funds. Note that these are not interchangeable with v1 Tokens.
Defined Under Namespace
Classes: AlternativeReference, Verification
Constant Summary collapse
- OBJECT_NAME =
"v2.core.vault.us_bank_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternative_reference ⇒ Object
readonly
The alternative reference for this payout method, if it’s a projected payout method.
-
#archived ⇒ Object
readonly
Whether this USBankAccount object was archived.
-
#bank_account_type ⇒ Object
readonly
Closed Enum.
-
#bank_name ⇒ Object
readonly
The name of the bank this bank account belongs to.
-
#created ⇒ Object
readonly
Creation time of the object.
-
#fedwire_routing_number ⇒ Object
readonly
The fedwire routing number of the bank account.
-
#financial_connections_account ⇒ Object
readonly
The ID of the Financial Connections Account used to create the bank account.
-
#id ⇒ Object
readonly
The ID of the USBankAccount object.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#routing_number ⇒ Object
readonly
The ACH routing number of the bank account.
-
#supported_currencies ⇒ Object
readonly
The list of currencies supported by this bank account.
-
#verification ⇒ Object
readonly
The bank account verification details.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternative_reference ⇒ Object (readonly)
The alternative reference for this payout method, if it’s a projected payout method.
63 64 65 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 63 def alternative_reference @alternative_reference end |
#archived ⇒ Object (readonly)
Whether this USBankAccount object was archived.
65 66 67 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 65 def archived @archived end |
#bank_account_type ⇒ Object (readonly)
Closed Enum. The type of bank account (checking or savings).
67 68 69 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 67 def bank_account_type @bank_account_type end |
#bank_name ⇒ Object (readonly)
The name of the bank this bank account belongs to. This field is populated automatically by Stripe based on the routing number.
69 70 71 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 69 def bank_name @bank_name end |
#created ⇒ Object (readonly)
Creation time of the object.
71 72 73 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 71 def created @created end |
#fedwire_routing_number ⇒ Object (readonly)
The fedwire routing number of the bank account.
73 74 75 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 73 def fedwire_routing_number @fedwire_routing_number end |
#financial_connections_account ⇒ Object (readonly)
The ID of the Financial Connections Account used to create the bank account.
75 76 77 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 75 def financial_connections_account @financial_connections_account end |
#id ⇒ Object (readonly)
The ID of the USBankAccount object.
77 78 79 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 77 def id @id end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number.
79 80 81 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 79 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
81 82 83 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 81 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
83 84 85 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 83 def object @object end |
#routing_number ⇒ Object (readonly)
The ACH routing number of the bank account.
85 86 87 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 85 def routing_number @routing_number end |
#supported_currencies ⇒ Object (readonly)
The list of currencies supported by this bank account.
87 88 89 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 87 def supported_currencies @supported_currencies end |
#verification ⇒ Object (readonly)
The bank account verification details.
89 90 91 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 89 def verification @verification end |
Class Method Details
.field_remappings ⇒ Object
98 99 100 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 98 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
91 92 93 94 95 96 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 91 def self.inner_class_types @inner_class_types = { alternative_reference: AlternativeReference, verification: Verification, } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 11 def self.object_name "v2.core.vault.us_bank_account" end |