Class: Stripe::V2::Core::Vault::UsBankAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/core/vault/us_bank_account.rb

Overview

Use the USBankAccounts API to create and manage US bank accounts objects that you can use to receive funds. Note that these are not interchangeable with v1 Tokens.

Defined Under Namespace

Classes: Verification

Constant Summary collapse

OBJECT_NAME =
"v2.core.vault.us_bank_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#archivedObject (readonly)

Whether this USBankAccount object was archived.



48
49
50
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 48

def archived
  @archived
end

#bank_account_typeObject (readonly)

Closed Enum. The type of bank account (checking or savings).



50
51
52
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 50

def 
  @bank_account_type
end

#bank_nameObject (readonly)

The name of the bank this bank account belongs to. This field is populated automatically by Stripe based on the routing number.



52
53
54
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 52

def bank_name
  @bank_name
end

#createdObject (readonly)

Creation time of the object.



54
55
56
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 54

def created
  @created
end

#fedwire_routing_numberObject (readonly)

The fedwire routing number of the bank account.



56
57
58
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 56

def fedwire_routing_number
  @fedwire_routing_number
end

#idObject (readonly)

The ID of the USBankAccount object.



58
59
60
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 58

def id
  @id
end

#last4Object (readonly)

The last 4 digits of the account number.



60
61
62
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 60

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



68
69
70
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 68

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



62
63
64
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 62

def object
  @object
end

#routing_numberObject (readonly)

The ACH routing number of the bank account.



64
65
66
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 64

def routing_number
  @routing_number
end

#verificationObject (readonly)

The bank account verification details.



66
67
68
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 66

def verification
  @verification
end

Class Method Details

.field_remappingsObject



74
75
76
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 74

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



70
71
72
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 70

def self.inner_class_types
  @inner_class_types = { verification: Verification }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 11

def self.object_name
  "v2.core.vault.us_bank_account"
end