Class: Stripe::V2::Core::Vault::UsBankAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Core::Vault::UsBankAccount
- Defined in:
- lib/stripe/resources/v2/core/vault/us_bank_account.rb
Overview
Use the USBankAccounts API to create and manage US bank accounts objects that you can use to receive funds. Note that these are not interchangeable with v1 Tokens.
Constant Summary collapse
- OBJECT_NAME =
"v2.core.vault.us_bank_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#archived ⇒ Object
readonly
Whether this USBankAccount object was archived.
-
#bank_account_type ⇒ Object
readonly
Closed Enum.
-
#bank_name ⇒ Object
readonly
The name of the bank this bank account belongs to.
-
#created ⇒ Object
readonly
Creation time of the object.
-
#fedwire_routing_number ⇒ Object
readonly
The fedwire routing number of the bank account.
-
#id ⇒ Object
readonly
The ID of the USBankAccount object.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#routing_number ⇒ Object
readonly
The ACH routing number of the bank account.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#archived ⇒ Object (readonly)
Whether this USBankAccount object was archived.
16 17 18 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 16 def archived @archived end |
#bank_account_type ⇒ Object (readonly)
Closed Enum. The type of bank account (checking or savings).
18 19 20 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 18 def bank_account_type @bank_account_type end |
#bank_name ⇒ Object (readonly)
The name of the bank this bank account belongs to. This field is populated automatically by Stripe based on the routing number.
20 21 22 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 20 def bank_name @bank_name end |
#created ⇒ Object (readonly)
Creation time of the object.
22 23 24 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 22 def created @created end |
#fedwire_routing_number ⇒ Object (readonly)
The fedwire routing number of the bank account.
24 25 26 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 24 def fedwire_routing_number @fedwire_routing_number end |
#id ⇒ Object (readonly)
The ID of the USBankAccount object.
26 27 28 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 26 def id @id end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number.
28 29 30 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 28 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
34 35 36 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 34 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
30 31 32 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 30 def object @object end |
#routing_number ⇒ Object (readonly)
The ACH routing number of the bank account.
32 33 34 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 32 def routing_number @routing_number end |
Class Method Details
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/core/vault/us_bank_account.rb', line 11 def self.object_name "v2.core.vault.us_bank_account" end |