Class: Stripe::V2::Data::Analytics::MetricQueryResult
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Data::Analytics::MetricQueryResult
- Defined in:
- lib/stripe/resources/v2/data/analytics/metric_query_result.rb
Overview
The result of a metric query.
Defined Under Namespace
Classes: Data
Constant Summary collapse
- OBJECT_NAME =
"v2.data.analytics.metric_query_result"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The timestamp at which this metric query result was created.
-
#data ⇒ Object
readonly
An array of timeseries data rows.
-
#id ⇒ Object
readonly
The unique identifier of this metric query result.
-
#livemode ⇒ Object
readonly
Whether this query was run in live mode.
-
#next_page_url ⇒ Object
readonly
Pagination future-proofing: URL to fetch the next page; always null for now.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#previous_page_url ⇒ Object
readonly
Pagination future-proofing: URL to fetch the previous page; always null for now.
-
#refreshed_at ⇒ Object
readonly
A timestamp representing the freshness of the data this metric is aggregated from.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The timestamp at which this metric query result was created.
62 63 64 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 62 def created @created end |
#data ⇒ Object (readonly)
An array of timeseries data rows.
64 65 66 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 64 def data @data end |
#id ⇒ Object (readonly)
The unique identifier of this metric query result.
66 67 68 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 66 def id @id end |
#livemode ⇒ Object (readonly)
Whether this query was run in live mode.
68 69 70 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 68 def livemode @livemode end |
#next_page_url ⇒ Object (readonly)
Pagination future-proofing: URL to fetch the next page; always null for now.
70 71 72 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 70 def next_page_url @next_page_url end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
72 73 74 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 72 def object @object end |
#previous_page_url ⇒ Object (readonly)
Pagination future-proofing: URL to fetch the previous page; always null for now.
74 75 76 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 74 def previous_page_url @previous_page_url end |
#refreshed_at ⇒ Object (readonly)
A timestamp representing the freshness of the data this metric is aggregated from.
76 77 78 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 76 def refreshed_at @refreshed_at end |
Class Method Details
.field_encodings ⇒ Object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 86 def self.field_encodings @field_encodings = { data: { kind: :array, element: { kind: :object, fields: { results: { kind: :array, element: { kind: :object, fields: { value: :int64_string } }, }, }, }, }, } end |
.field_remappings ⇒ Object
82 83 84 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 82 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
78 79 80 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 78 def self.inner_class_types @inner_class_types = { data: Data } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/data/analytics/metric_query_result.rb', line 11 def self.object_name "v2.data.analytics.metric_query_result" end |