Class: Stripe::V2::Event
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Event
- Defined in:
- lib/stripe/resources/v2/event.rb
Direct Known Subclasses
Stripe::V1BillingMeterErrorReportTriggeredEvent, Stripe::V1BillingMeterNoMeterFoundEvent
Defined Under Namespace
Classes: Reason
Constant Summary collapse
- OBJECT_NAME =
"v2.core.event"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
Authentication context needed to fetch the event or related object.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the event.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#reason ⇒ Object
readonly
Reason for the event.
-
#type ⇒ Object
readonly
The type of the event.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#context ⇒ Object (readonly)
Authentication context needed to fetch the event or related object.
19 20 21 |
# File 'lib/stripe/resources/v2/event.rb', line 19 def context @context end |
#created ⇒ Object (readonly)
Time at which the object was created.
21 22 23 |
# File 'lib/stripe/resources/v2/event.rb', line 21 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the event.
23 24 25 |
# File 'lib/stripe/resources/v2/event.rb', line 23 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
25 26 27 |
# File 'lib/stripe/resources/v2/event.rb', line 25 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
27 28 29 |
# File 'lib/stripe/resources/v2/event.rb', line 27 def object @object end |
#reason ⇒ Object (readonly)
Reason for the event.
29 30 31 |
# File 'lib/stripe/resources/v2/event.rb', line 29 def reason @reason end |
#type ⇒ Object (readonly)
The type of the event.
31 32 33 |
# File 'lib/stripe/resources/v2/event.rb', line 31 def type @type end |
Class Method Details
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/v2/event.rb', line 8 def self.object_name "v2.core.event" end |