Class: Stripe::V2::EventDestination

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/event_destination.rb

Defined Under Namespace

Classes: AmazonEventbridge, StatusDetails, WebhookEndpoint

Constant Summary collapse

OBJECT_NAME =
"v2.core.event_destination"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amazon_eventbridgeObject (readonly)

Amazon EventBridge configuration.



57
58
59
# File 'lib/stripe/resources/v2/event_destination.rb', line 57

def amazon_eventbridge
  @amazon_eventbridge
end

#createdObject (readonly)

Time at which the object was created.



27
28
29
# File 'lib/stripe/resources/v2/event_destination.rb', line 27

def created
  @created
end

#descriptionObject (readonly)

An optional description of what the event destination is used for.



29
30
31
# File 'lib/stripe/resources/v2/event_destination.rb', line 29

def description
  @description
end

#enabled_eventsObject (readonly)

The list of events to enable for this endpoint.



31
32
33
# File 'lib/stripe/resources/v2/event_destination.rb', line 31

def enabled_events
  @enabled_events
end

#event_payloadObject (readonly)

Payload type of events being subscribed to.



33
34
35
# File 'lib/stripe/resources/v2/event_destination.rb', line 33

def event_payload
  @event_payload
end

#events_fromObject (readonly)

Where events should be routed from.



35
36
37
# File 'lib/stripe/resources/v2/event_destination.rb', line 35

def events_from
  @events_from
end

#idObject (readonly)

Unique identifier for the object.



37
38
39
# File 'lib/stripe/resources/v2/event_destination.rb', line 37

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



39
40
41
# File 'lib/stripe/resources/v2/event_destination.rb', line 39

def livemode
  @livemode
end

#metadataObject (readonly)

Metadata.



41
42
43
# File 'lib/stripe/resources/v2/event_destination.rb', line 41

def 
  @metadata
end

#nameObject (readonly)

Event destination name.



43
44
45
# File 'lib/stripe/resources/v2/event_destination.rb', line 43

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



45
46
47
# File 'lib/stripe/resources/v2/event_destination.rb', line 45

def object
  @object
end

#snapshot_api_versionObject (readonly)

If using the snapshot event payload, the API version events are rendered as.



47
48
49
# File 'lib/stripe/resources/v2/event_destination.rb', line 47

def snapshot_api_version
  @snapshot_api_version
end

#statusObject (readonly)

Status. It can be set to either enabled or disabled.



49
50
51
# File 'lib/stripe/resources/v2/event_destination.rb', line 49

def status
  @status
end

#status_detailsObject (readonly)

Additional information about event destination status.



51
52
53
# File 'lib/stripe/resources/v2/event_destination.rb', line 51

def status_details
  @status_details
end

#typeObject (readonly)

Event destination type.



53
54
55
# File 'lib/stripe/resources/v2/event_destination.rb', line 53

def type
  @type
end

#updatedObject (readonly)

Time at which the object was last updated.



55
56
57
# File 'lib/stripe/resources/v2/event_destination.rb', line 55

def updated
  @updated
end

#webhook_endpointObject (readonly)

Webhook endpoint configuration.



59
60
61
# File 'lib/stripe/resources/v2/event_destination.rb', line 59

def webhook_endpoint
  @webhook_endpoint
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/v2/event_destination.rb', line 8

def self.object_name
  "v2.core.event_destination"
end