Class: Stripe::V2::Extend::WorkflowListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Extend::WorkflowListParams
- Defined in:
- lib/stripe/params/v2/extend/workflow_list_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Restrict page size to no more than this number.
-
#status ⇒ Object
When retrieving Workflows, include only those with the specified status values.
Instance Method Summary collapse
-
#initialize(limit: nil, status: nil) ⇒ WorkflowListParams
constructor
A new instance of WorkflowListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil, status: nil) ⇒ WorkflowListParams
Returns a new instance of WorkflowListParams.
14 15 16 17 |
# File 'lib/stripe/params/v2/extend/workflow_list_params.rb', line 14 def initialize(limit: nil, status: nil) @limit = limit @status = status end |
Instance Attribute Details
#limit ⇒ Object
Restrict page size to no more than this number.
9 10 11 |
# File 'lib/stripe/params/v2/extend/workflow_list_params.rb', line 9 def limit @limit end |
#status ⇒ Object
When retrieving Workflows, include only those with the specified status values. If not specified, all Workflows in active and inactive status are returned.
12 13 14 |
# File 'lib/stripe/params/v2/extend/workflow_list_params.rb', line 12 def status @status end |