Class: Stripe::V2::Extend::WorkflowRunListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Extend::WorkflowRunListParams
- Defined in:
- lib/stripe/params/v2/extend/workflow_run_list_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
Restrict page size to no more than this number.
-
#status ⇒ Object
When retrieving Workflow Runs, include only those with the specified status values.
-
#workflow ⇒ Object
When retrieving Workflow Runs, include only those associated with the Workflows specified.
Instance Method Summary collapse
-
#initialize(limit: nil, status: nil, workflow: nil) ⇒ WorkflowRunListParams
constructor
A new instance of WorkflowRunListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil, status: nil, workflow: nil) ⇒ WorkflowRunListParams
Returns a new instance of WorkflowRunListParams.
15 16 17 18 19 |
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 15 def initialize(limit: nil, status: nil, workflow: nil) @limit = limit @status = status @workflow = workflow end |
Instance Attribute Details
#limit ⇒ Object
Restrict page size to no more than this number.
9 10 11 |
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 9 def limit @limit end |
#status ⇒ Object
When retrieving Workflow Runs, include only those with the specified status values. If not specified, all Runs are returned.
11 12 13 |
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 11 def status @status end |
#workflow ⇒ Object
When retrieving Workflow Runs, include only those associated with the Workflows specified. If not specified, all Runs are returned.
13 14 15 |
# File 'lib/stripe/params/v2/extend/workflow_run_list_params.rb', line 13 def workflow @workflow end |