Class: Stripe::V2::FinancialAddressCreditSimulation

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/financial_address_credit_simulation.rb

Constant Summary collapse

OBJECT_NAME =
"financial_address_credit_simulation"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



17
18
19
# File 'lib/stripe/resources/v2/financial_address_credit_simulation.rb', line 17

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



13
14
15
# File 'lib/stripe/resources/v2/financial_address_credit_simulation.rb', line 13

def object
  @object
end

#statusObject (readonly)

The status of the request, signifying whether a simulated credit was initiated.



15
16
17
# File 'lib/stripe/resources/v2/financial_address_credit_simulation.rb', line 15

def status
  @status
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/v2/financial_address_credit_simulation.rb', line 8

def self.object_name
  "financial_address_credit_simulation"
end