Class: Stripe::V2::FinancialAddressGeneratedMicrodeposits
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::FinancialAddressGeneratedMicrodeposits
- Defined in:
- lib/stripe/resources/v2/financial_address_generated_microdeposits.rb
Constant Summary collapse
- OBJECT_NAME =
"financial_address_generated_microdeposits"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amounts ⇒ Object
readonly
The amounts of the microdeposits that were generated.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Closed Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amounts ⇒ Object (readonly)
The amounts of the microdeposits that were generated.
13 14 15 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 13 def amounts @amounts end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
19 20 21 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 19 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
15 16 17 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 15 def object @object end |
#status ⇒ Object (readonly)
Closed Enum. The status of the request.
17 18 19 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 17 def status @status end |
Class Method Details
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/v2/financial_address_generated_microdeposits.rb', line 8 def self.object_name "financial_address_generated_microdeposits" end |