Class: Stripe::V2::Iam::ApiKeyCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/iam/api_key_create_params.rb

Defined Under Namespace

Classes: PublicKey

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(name: nil, note: nil, public_key: nil, type: nil) ⇒ ApiKeyCreateParams

Returns a new instance of ApiKeyCreateParams.



42
43
44
45
46
47
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 42

def initialize(name: nil, note: nil, public_key: nil, type: nil)
  @name = name
  @note = note
  @public_key = public_key
  @type = type
end

Instance Attribute Details

#nameObject

Name for the API key.



31
32
33
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 31

def name
  @name
end

#noteObject

Note or description for the API key.



33
34
35
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 33

def note
  @note
end

#public_keyObject

Public key for encrypting the API key secret. This must a PEM-formatted RSA key suitable for encryption, >= 2048 bits. A public key is required when creating secret keys. Publishable keys are not encrypted and a public key should not be included.



38
39
40
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 38

def public_key
  @public_key
end

#typeObject

Type of the API key to create (secret or publishable).



40
41
42
# File 'lib/stripe/params/v2/iam/api_key_create_params.rb', line 40

def type
  @type
end