Class: Stripe::V2::Iam::ApiKeyRotateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/v2/iam/api_key_rotate_params.rb

Defined Under Namespace

Classes: PublicKey

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(expire_current_key_in_minutes: nil, public_key: nil) ⇒ ApiKeyRotateParams

Returns a new instance of ApiKeyRotateParams.



39
40
41
42
# File 'lib/stripe/params/v2/iam/api_key_rotate_params.rb', line 39

def initialize(expire_current_key_in_minutes: nil, public_key: nil)
  @expire_current_key_in_minutes = expire_current_key_in_minutes
  @public_key = public_key
end

Instance Attribute Details

#expire_current_key_in_minutesObject

Duration in minutes before the current key expires, with a maximum of 7 days (10080 minutes). If not provided, the current key expires immediately.



32
33
34
# File 'lib/stripe/params/v2/iam/api_key_rotate_params.rb', line 32

def expire_current_key_in_minutes
  @expire_current_key_in_minutes
end

#public_keyObject

Public key for encrypting the new API key secret. This must a PEM-formatted RSA key suitable for encryption, >= 2048 bits. A public key is required when rotating secret keys. Publishable keys are not encrypted and a public key should not be included.



37
38
39
# File 'lib/stripe/params/v2/iam/api_key_rotate_params.rb', line 37

def public_key
  @public_key
end