Method: Stripe::V2::ListObject#fetch_next_page
- Defined in:
- lib/stripe/v2_list_object.rb
#fetch_next_page(opts = {}) ⇒ Object
Fetches the next page in the resource list (if there is one).
This method will try to respect the limit of the current page. If none was given, the default limit will be fetched again.
73 74 75 76 77 78 79 80 81 |
# File 'lib/stripe/v2_list_object.rb', line 73 def fetch_next_page(opts = {}) return self.class.empty_list(opts) if next_page_url.nil? _request( method: :get, path: next_page_url, base_address: :api ) end |