Class: Stripe::V2::MoneyManagement::Adjustment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::Adjustment
- Defined in:
- lib/stripe/resources/v2/money_management/adjustment.rb
Overview
Adjustments represent Stripe-initiated credits or debits to a user balance. They might be used to amend balances due to technical or operational error.
Defined Under Namespace
Classes: AdjustedFlow
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.adjustment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjusted_flow ⇒ Object
readonly
If applicable, contains information about the original flow linked to this Adjustment.
-
#amount ⇒ Object
readonly
The amount of the Adjustment.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#description ⇒ Object
readonly
Description of the Adjustment and what it was used for.
-
#financial_account ⇒ Object
readonly
The FinancialAccount that this adjustment is for.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjusted_flow ⇒ Object (readonly)
If applicable, contains information about the original flow linked to this Adjustment.
39 40 41 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 39 def adjusted_flow @adjusted_flow end |
#amount ⇒ Object (readonly)
The amount of the Adjustment.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 41 def amount @amount end |
#created ⇒ Object (readonly)
Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 43 def created @created end |
#description ⇒ Object (readonly)
Description of the Adjustment and what it was used for.
45 46 47 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 45 def description @description end |
#financial_account ⇒ Object (readonly)
The FinancialAccount that this adjustment is for.
47 48 49 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 47 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the object.
49 50 51 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 49 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
51 52 53 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 51 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
53 54 55 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 53 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt that is provided when money movement is considered regulated under Stripe’s money transmission licenses. The receipt link remains active for 60 days from the Adjustment creation date. After this period, the link will expire and the receipt url value will be null.
55 56 57 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 55 def receipt_url @receipt_url end |
Class Method Details
.field_remappings ⇒ Object
61 62 63 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 61 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
57 58 59 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 57 def self.inner_class_types @inner_class_types = { adjusted_flow: AdjustedFlow } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 10 def self.object_name "v2.money_management.adjustment" end |