Class: Stripe::V2::MoneyManagement::Adjustment::AdjustedFlow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::Adjustment::AdjustedFlow
- Defined in:
- lib/stripe/resources/v2/money_management/adjustment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
readonly
If applicable, the ID of the Adjustment linked to this Adjustment.
-
#inbound_transfer ⇒ Object
readonly
If applicable, the ID of the InboundTransfer linked to this Adjustment.
-
#outbound_payment ⇒ Object
readonly
If applicable, the ID of the OutboundPayment linked to this Adjustment.
-
#outbound_transfer ⇒ Object
readonly
If applicable, the ID of the OutboundTransfer linked to this Adjustment.
-
#received_credit ⇒ Object
readonly
If applicable, the ID of the ReceivedCredit linked to this Adjustment.
-
#received_debit ⇒ Object
readonly
If applicable, the ID of the ReceivedDebit linked to this Adjustment.
-
#type ⇒ Object
readonly
Closed Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjustment ⇒ Object (readonly)
If applicable, the ID of the Adjustment linked to this Adjustment.
16 17 18 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 16 def adjustment @adjustment end |
#inbound_transfer ⇒ Object (readonly)
If applicable, the ID of the InboundTransfer linked to this Adjustment.
18 19 20 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 18 def inbound_transfer @inbound_transfer end |
#outbound_payment ⇒ Object (readonly)
If applicable, the ID of the OutboundPayment linked to this Adjustment.
20 21 22 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 20 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
If applicable, the ID of the OutboundTransfer linked to this Adjustment.
22 23 24 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 22 def outbound_transfer @outbound_transfer end |
#received_credit ⇒ Object (readonly)
If applicable, the ID of the ReceivedCredit linked to this Adjustment.
24 25 26 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 24 def received_credit @received_credit end |
#received_debit ⇒ Object (readonly)
If applicable, the ID of the ReceivedDebit linked to this Adjustment.
26 27 28 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 26 def received_debit @received_debit end |
#type ⇒ Object (readonly)
Closed Enum. If applicable, the type of flow linked to this Adjustment. The field matching this value will contain the ID of the flow.
28 29 30 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 28 def type @type end |
Class Method Details
.field_remappings ⇒ Object
34 35 36 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 34 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
30 31 32 |
# File 'lib/stripe/resources/v2/money_management/adjustment.rb', line 30 def self.inner_class_types @inner_class_types = {} end |