Class: Stripe::V2::MoneyManagement::CurrencyConversion
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::CurrencyConversion
- Defined in:
- lib/stripe/resources/v2/money_management/currency_conversion.rb
Overview
The CurrencyConversion object. Contains details such as the amount debited and credited and the FinancialAccount the CurrencyConversion was performed on.
Defined Under Namespace
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.currency_conversion"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The time the CurrencyConversion was created at.
-
#exchange_rate ⇒ Object
readonly
The exchange rate used when processing the CurrencyConversion.
-
#financial_account ⇒ Object
readonly
The FinancialAccount the CurrencyConversion was performed on.
-
#from ⇒ Object
readonly
The from block containing what was debited.
-
#id ⇒ Object
readonly
The id of the CurrencyConversion.
-
#livemode ⇒ Object
readonly
If the CurrencyConversion was performed in livemode or not.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#to ⇒ Object
readonly
The to block containing what was credited.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The time the CurrencyConversion was created at.
40 41 42 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 40 def created @created end |
#exchange_rate ⇒ Object (readonly)
The exchange rate used when processing the CurrencyConversion.
42 43 44 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 42 def exchange_rate @exchange_rate end |
#financial_account ⇒ Object (readonly)
The FinancialAccount the CurrencyConversion was performed on.
44 45 46 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 44 def financial_account @financial_account end |
#from ⇒ Object (readonly)
The from block containing what was debited.
46 47 48 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 46 def from @from end |
#id ⇒ Object (readonly)
The id of the CurrencyConversion.
48 49 50 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 48 def id @id end |
#livemode ⇒ Object (readonly)
If the CurrencyConversion was performed in livemode or not.
50 51 52 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 50 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
52 53 54 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 52 def object @object end |
#to ⇒ Object (readonly)
The to block containing what was credited.
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 54 def to @to end |
Class Method Details
.field_remappings ⇒ Object
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 60 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
56 57 58 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 56 def self.inner_class_types @inner_class_types = { from: From, to: To } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 10 def self.object_name "v2.money_management.currency_conversion" end |