Class: Stripe::V2::MoneyManagement::CurrencyConversion

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/currency_conversion.rb

Overview

The CurrencyConversion object. Contains details such as the amount debited and credited and the FinancialAccount the CurrencyConversion was performed on.

Defined Under Namespace

Classes: From, To

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.currency_conversion"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The time the CurrencyConversion was created at.



68
69
70
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 68

def created
  @created
end

#exchange_rateObject (readonly)

The exchange rate used when processing the CurrencyConversion.



70
71
72
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 70

def exchange_rate
  @exchange_rate
end

#financial_accountObject (readonly)

The FinancialAccount the CurrencyConversion was performed on.



72
73
74
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 72

def 
  @financial_account
end

#fromObject (readonly)

The from block containing what was debited.



74
75
76
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 74

def from
  @from
end

#idObject (readonly)

The id of the CurrencyConversion.



76
77
78
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 76

def id
  @id
end

#livemodeObject (readonly)

If the CurrencyConversion was performed in livemode or not.



78
79
80
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 78

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



80
81
82
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 80

def object
  @object
end

#toObject (readonly)

The to block containing what was credited.



82
83
84
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 82

def to
  @to
end

Class Method Details

.field_remappingsObject



88
89
90
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 88

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



84
85
86
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 84

def self.inner_class_types
  @inner_class_types = { from: From, to: To }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/currency_conversion.rb', line 10

def self.object_name
  "v2.money_management.currency_conversion"
end