Class: Stripe::V2::MoneyManagement::CurrencyConversionCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/currency_conversion_create_params.rb

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_account: nil, from: nil, to: nil) ⇒ CurrencyConversionCreateParams

Returns a new instance of CurrencyConversionCreateParams.



38
39
40
41
42
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 38

def initialize(financial_account: nil, from: nil, to: nil)
  @financial_account = 
  @from = from
  @to = to
end

Instance Attribute Details

#financial_accountObject

The FinancialAccount id to create the CurrencyConversion on.



32
33
34
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 32

def 
  @financial_account
end

#fromObject

From amount object indicating the from currency or optional amount.



34
35
36
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 34

def from
  @from
end

#toObject

To amount object indicating the to currency or optional amount.



36
37
38
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 36

def to
  @to
end