Class: Stripe::V2::MoneyManagement::CurrencyConversionCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/currency_conversion_create_params.rb

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_account: nil, from: nil, to: nil) ⇒ CurrencyConversionCreateParams

Returns a new instance of CurrencyConversionCreateParams.



60
61
62
63
64
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 60

def initialize(financial_account: nil, from: nil, to: nil)
  @financial_account = 
  @from = from
  @to = to
end

Instance Attribute Details

#financial_accountObject

The FinancialAccount id to create the CurrencyConversion on.



54
55
56
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 54

def 
  @financial_account
end

#fromObject

From amount object indicating the from currency or optional amount.



56
57
58
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 56

def from
  @from
end

#toObject

To amount object indicating the to currency or optional amount.



58
59
60
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 58

def to
  @to
end