Class: Stripe::V2::MoneyManagement::CurrencyConversionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::CurrencyConversionCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/currency_conversion_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#financial_account ⇒ Object
The FinancialAccount id to create the CurrencyConversion on.
-
#from ⇒ Object
From amount object indicating the from currency or optional amount.
-
#to ⇒ Object
To amount object indicating the to currency or optional amount.
Instance Method Summary collapse
-
#initialize(financial_account: nil, from: nil, to: nil) ⇒ CurrencyConversionCreateParams
constructor
A new instance of CurrencyConversionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_account: nil, from: nil, to: nil) ⇒ CurrencyConversionCreateParams
Returns a new instance of CurrencyConversionCreateParams.
60 61 62 63 64 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 60 def initialize(financial_account: nil, from: nil, to: nil) @financial_account = financial_account @from = from @to = to end |
Instance Attribute Details
#financial_account ⇒ Object
The FinancialAccount id to create the CurrencyConversion on.
54 55 56 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 54 def financial_account @financial_account end |
#from ⇒ Object
From amount object indicating the from currency or optional amount.
56 57 58 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 56 def from @from end |
#to ⇒ Object
To amount object indicating the to currency or optional amount.
58 59 60 |
# File 'lib/stripe/params/v2/money_management/currency_conversion_create_params.rb', line 58 def to @to end |