Class: Stripe::V2::MoneyManagement::DebitDispute
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::DebitDispute
- Defined in:
- lib/stripe/resources/v2/money_management/debit_dispute.rb
Overview
A DebitDispute represents a dispute raised against a received debit.
Defined Under Namespace
Classes: BankTransfer, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.debit_dispute"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the DebitDispute.
-
#bank_transfer ⇒ Object
readonly
Details about the bank transfer dispute.
-
#created ⇒ Object
readonly
Time at which the DebitDispute was created.
-
#financial_account ⇒ Object
readonly
The Financial Account associated with the DebitDispute.
-
#id ⇒ Object
readonly
The ID of a DebitDispute.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#received_debit ⇒ Object
readonly
The ID of the ReceivedDebit that was disputed.
-
#status ⇒ Object
readonly
The status of the DebitDispute.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the DebitDispute.
-
#status_transitions ⇒ Object
readonly
The time at which the DebitDispute transitioned to a particular status.
-
#type ⇒ Object
readonly
The type of the DebitDispute.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the DebitDispute.
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 74 def amount @amount end |
#bank_transfer ⇒ Object (readonly)
Details about the bank transfer dispute. Present if ‘type` field value is `bank_transfer`.
76 77 78 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 76 def bank_transfer @bank_transfer end |
#created ⇒ Object (readonly)
Time at which the DebitDispute was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2026-03-23T13:22:18.123Z`.
79 80 81 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 79 def created @created end |
#financial_account ⇒ Object (readonly)
The Financial Account associated with the DebitDispute.
81 82 83 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 81 def financial_account @financial_account end |
#id ⇒ Object (readonly)
The ID of a DebitDispute.
83 84 85 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 83 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
85 86 87 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 85 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
87 88 89 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 87 def object @object end |
#received_debit ⇒ Object (readonly)
The ID of the ReceivedDebit that was disputed.
89 90 91 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 89 def received_debit @received_debit end |
#status ⇒ Object (readonly)
The status of the DebitDispute.
91 92 93 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 91 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the DebitDispute.
93 94 95 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 93 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the DebitDispute transitioned to a particular status.
95 96 97 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 95 def status_transitions @status_transitions end |
#type ⇒ Object (readonly)
The type of the DebitDispute.
97 98 99 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 97 def type @type end |
Class Method Details
.field_remappings ⇒ Object
107 108 109 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 107 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
99 100 101 102 103 104 105 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 99 def self.inner_class_types @inner_class_types = { bank_transfer: BankTransfer, status_details: StatusDetails, status_transitions: StatusTransitions, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/debit_dispute.rb', line 10 def self.object_name "v2.money_management.debit_dispute" end |