Class: Stripe::V2::MoneyManagement::FinancialAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::FinancialAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_account.rb
Overview
A FinancialAccount represents a balance and can be used as the source or destination for the money management (/v2/money_management) APIs.
Defined Under Namespace
Classes: AccruedFees, Balance, Credit, MultiprocessorSettlement, Other, Payments, StatusDetails, Storage
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.financial_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accrued_fees ⇒ Object
readonly
If this is a
accrued_feesFinancialAccount, this hash include details specific toaccrued_feesFinancialAccount. -
#balance ⇒ Object
readonly
Multi-currency balance of this FinancialAccount, split by availability state.
-
#country ⇒ Object
readonly
Open Enum.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#credit ⇒ Object
readonly
If this is a
creditFinancialAccount, this hash includes details specific tocreditFinancialAccounts. -
#display_name ⇒ Object
readonly
A descriptive name for the FinancialAccount, up to 50 characters long.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#metadata ⇒ Object
readonly
Metadata associated with the FinancialAccount.
-
#multiprocessor_settlement ⇒ Object
readonly
If this is a
multiprocessor_settlementFinancialAccount, this hash includes details specific tomultiprocessor_settlementFinancialAccounts. -
#object ⇒ Object
readonly
String representing the object's type.
-
#other ⇒ Object
readonly
If this is a
otherFinancialAccount, this hash indicates what the actual type is. -
#payments ⇒ Object
readonly
If this is a
paymentsFinancialAccount, this hash include details specific topaymentsFinancialAccount. -
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Additional details related to the status of the FinancialAccount.
-
#storage ⇒ Object
readonly
If this is a
storageFinancialAccount, this hash includes details specific tostorageFinancialAccounts. -
#type ⇒ Object
readonly
Type of the FinancialAccount.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accrued_fees ⇒ Object (readonly)
If this is a accrued_fees FinancialAccount, this hash include details specific to accrued_fees FinancialAccount.
257 258 259 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 257 def accrued_fees @accrued_fees end |
#balance ⇒ Object (readonly)
Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.
259 260 261 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 259 def balance @balance end |
#country ⇒ Object (readonly)
Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.
261 262 263 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 261 def country @country end |
#created ⇒ Object (readonly)
Time at which the object was created.
263 264 265 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 263 def created @created end |
#credit ⇒ Object (readonly)
If this is a credit FinancialAccount, this hash includes details specific to credit FinancialAccounts.
265 266 267 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 265 def credit @credit end |
#display_name ⇒ Object (readonly)
A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.
267 268 269 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 267 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
269 270 271 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 269 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
271 272 273 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 271 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Metadata associated with the FinancialAccount.
273 274 275 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 273 def @metadata end |
#multiprocessor_settlement ⇒ Object (readonly)
If this is a multiprocessor_settlement FinancialAccount, this hash includes details specific to multiprocessor_settlement FinancialAccounts.
275 276 277 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 275 def multiprocessor_settlement @multiprocessor_settlement end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
277 278 279 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 277 def object @object end |
#other ⇒ Object (readonly)
If this is a other FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in type.
279 280 281 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 279 def other @other end |
#payments ⇒ Object (readonly)
If this is a payments FinancialAccount, this hash include details specific to payments FinancialAccount.
281 282 283 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 281 def payments @payments end |
#status ⇒ Object (readonly)
Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.
283 284 285 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 283 def status @status end |
#status_details ⇒ Object (readonly)
Additional details related to the status of the FinancialAccount.
285 286 287 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 285 def status_details @status_details end |
#storage ⇒ Object (readonly)
If this is a storage FinancialAccount, this hash includes details specific to storage FinancialAccounts.
287 288 289 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 287 def storage @storage end |
#type ⇒ Object (readonly)
Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.
290 291 292 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 290 def type @type end |
Class Method Details
.field_remappings ⇒ Object
305 306 307 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 305 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 292 def self.inner_class_types @inner_class_types = { accrued_fees: AccruedFees, balance: Balance, credit: Credit, multiprocessor_settlement: MultiprocessorSettlement, other: Other, payments: Payments, status_details: StatusDetails, storage: Storage, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10 def self.object_name "v2.money_management.financial_account" end |