Class: Stripe::V2::MoneyManagement::FinancialAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::FinancialAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_account.rb
Overview
A FinancialAccount represents a balance and can be used as the source or destination for the money management (‘/v2/money_management`) APIs.
Defined Under Namespace
Classes: AccruedFees, Balance, ManagedBy, MultiprocessorSettlement, Other, Payments, StatusDetails, Storage
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.financial_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#accrued_fees ⇒ Object
readonly
If this is a ‘accrued_fees` FinancialAccount, this hash include details specific to `accrued_fees` FinancialAccount.
-
#balance ⇒ Object
readonly
Multi-currency balance of this FinancialAccount, split by availability state.
-
#country ⇒ Object
readonly
Open Enum.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A descriptive name for the FinancialAccount, up to 50 characters long.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#managed_by ⇒ Object
readonly
If this is a managed FinancialAccount, ‘managed_by` indicates the product that created and manages this FinancialAccount.
-
#metadata ⇒ Object
readonly
Metadata associated with the FinancialAccount.
-
#multiprocessor_settlement ⇒ Object
readonly
If this is a ‘multiprocessor_settlement` FinancialAccount, this hash includes details specific to `multiprocessor_settlement` FinancialAccounts.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#other ⇒ Object
readonly
If this is a ‘other` FinancialAccount, this hash indicates what the actual type is.
-
#payments ⇒ Object
readonly
If this is a ‘payments` FinancialAccount, this hash include details specific to `payments` FinancialAccount.
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Additional details related to the status of the FinancialAccount.
-
#storage ⇒ Object
readonly
If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.
-
#type ⇒ Object
readonly
Type of the FinancialAccount.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#accrued_fees ⇒ Object (readonly)
If this is a ‘accrued_fees` FinancialAccount, this hash include details specific to `accrued_fees` FinancialAccount.
229 230 231 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 229 def accrued_fees @accrued_fees end |
#balance ⇒ Object (readonly)
Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.
231 232 233 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 231 def balance @balance end |
#country ⇒ Object (readonly)
Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.
233 234 235 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 233 def country @country end |
#created ⇒ Object (readonly)
Time at which the object was created.
235 236 237 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 235 def created @created end |
#display_name ⇒ Object (readonly)
A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.
237 238 239 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 237 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
239 240 241 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 239 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
241 242 243 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 241 def livemode @livemode end |
#managed_by ⇒ Object (readonly)
If this is a managed FinancialAccount, ‘managed_by` indicates the product that created and manages this FinancialAccount. For managed FinancialAccounts, creation of money management resources can only be orchestrated by the managing product.
244 245 246 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 244 def managed_by @managed_by end |
#metadata ⇒ Object (readonly)
Metadata associated with the FinancialAccount.
246 247 248 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 246 def @metadata end |
#multiprocessor_settlement ⇒ Object (readonly)
If this is a ‘multiprocessor_settlement` FinancialAccount, this hash includes details specific to `multiprocessor_settlement` FinancialAccounts.
248 249 250 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 248 def multiprocessor_settlement @multiprocessor_settlement end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
250 251 252 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 250 def object @object end |
#other ⇒ Object (readonly)
If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.
252 253 254 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 252 def other @other end |
#payments ⇒ Object (readonly)
If this is a ‘payments` FinancialAccount, this hash include details specific to `payments` FinancialAccount.
254 255 256 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 254 def payments @payments end |
#status ⇒ Object (readonly)
Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.
256 257 258 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 256 def status @status end |
#status_details ⇒ Object (readonly)
Additional details related to the status of the FinancialAccount.
258 259 260 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 258 def status_details @status_details end |
#storage ⇒ Object (readonly)
If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.
260 261 262 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 260 def storage @storage end |
#type ⇒ Object (readonly)
Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.
263 264 265 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 263 def type @type end |
Class Method Details
.field_remappings ⇒ Object
278 279 280 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 278 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 265 def self.inner_class_types @inner_class_types = { accrued_fees: AccruedFees, balance: Balance, managed_by: ManagedBy, multiprocessor_settlement: MultiprocessorSettlement, other: Other, payments: Payments, status_details: StatusDetails, storage: Storage, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10 def self.object_name "v2.money_management.financial_account" end |