Class: Stripe::V2::MoneyManagement::FinancialAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Overview

A FinancialAccount represents a balance and can be used as the source or destination for the money management (‘/v2/money_management`) APIs.

Defined Under Namespace

Classes: Balance, Other, StatusDetails, Storage

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.



98
99
100
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 98

def balance
  @balance
end

#countryObject (readonly)

Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.



100
101
102
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 100

def country
  @country
end

#createdObject (readonly)

Time at which the object was created.



102
103
104
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 102

def created
  @created
end

#display_nameObject (readonly)

A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.



104
105
106
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 104

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



106
107
108
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 106

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



108
109
110
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 108

def livemode
  @livemode
end

#metadataObject (readonly)

Metadata associated with the FinancialAccount.



110
111
112
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 110

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



112
113
114
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 112

def object
  @object
end

#otherObject (readonly)

If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.



114
115
116
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 114

def other
  @other
end

#statusObject (readonly)

Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.



116
117
118
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 116

def status
  @status
end

#status_detailsObject (readonly)

Additional details related to the status of the FinancialAccount.



118
119
120
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 118

def status_details
  @status_details
end

#storageObject (readonly)

If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.



120
121
122
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 120

def storage
  @storage
end

#typeObject (readonly)

Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.



123
124
125
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 123

def type
  @type
end

Class Method Details

.field_remappingsObject



134
135
136
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 134

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



125
126
127
128
129
130
131
132
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 125

def self.inner_class_types
  @inner_class_types = {
    balance: Balance,
    other: Other,
    status_details: StatusDetails,
    storage: Storage,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10

def self.object_name
  "v2.money_management.financial_account"
end