Class: Stripe::V2::MoneyManagement::FinancialAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Overview

A FinancialAccount represents a balance and can be used as the source or destination for the money management (‘/v2/money_management`) APIs.

Defined Under Namespace

Classes: AccruedFees, Balance, ManagedBy, Other, Payments, StatusDetails, Storage

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accrued_feesObject (readonly)

If this is a ‘accrued_fees` FinancialAccount, this hash include details specific to `accrued_fees` FinancialAccount.



219
220
221
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 219

def accrued_fees
  @accrued_fees
end

#balanceObject (readonly)

Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.



221
222
223
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 221

def balance
  @balance
end

#countryObject (readonly)

Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.



223
224
225
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 223

def country
  @country
end

#createdObject (readonly)

Time at which the object was created.



225
226
227
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 225

def created
  @created
end

#display_nameObject (readonly)

A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.



227
228
229
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 227

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



229
230
231
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 229

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



251
252
253
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 251

def livemode
  @livemode
end

#managed_byObject (readonly)

If this is a managed FinancialAccount, ‘managed_by` indicates the product that created and manages this FinancialAccount. For managed FinancialAccounts, creation of money management resources can only be orchestrated by the managing product.



232
233
234
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 232

def managed_by
  @managed_by
end

#metadataObject (readonly)

Metadata associated with the FinancialAccount.



234
235
236
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 234

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



236
237
238
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 236

def object
  @object
end

#otherObject (readonly)

If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.



238
239
240
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 238

def other
  @other
end

#paymentsObject (readonly)

If this is a ‘payments` FinancialAccount, this hash include details specific to `payments` FinancialAccount.



240
241
242
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 240

def payments
  @payments
end

#statusObject (readonly)

Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.



242
243
244
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 242

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



244
245
246
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 244

def status_details
  @status_details
end

#storageObject (readonly)

If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.



246
247
248
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 246

def storage
  @storage
end

#typeObject (readonly)

Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.



249
250
251
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 249

def type
  @type
end

Class Method Details

.field_remappingsObject



265
266
267
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 265

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



253
254
255
256
257
258
259
260
261
262
263
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 253

def self.inner_class_types
  @inner_class_types = {
    accrued_fees: AccruedFees,
    balance: Balance,
    managed_by: ManagedBy,
    other: Other,
    payments: Payments,
    status_details: StatusDetails,
    storage: Storage,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10

def self.object_name
  "v2.money_management.financial_account"
end