Class: Stripe::V2::MoneyManagement::FinancialAccount
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::FinancialAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_account.rb
Overview
A FinancialAccount represents a balance and can be used as the source or destination for the money management (‘/v2/money_management`) APIs.
Defined Under Namespace
Classes: Balance, Other, StatusDetails, Storage
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.financial_account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance ⇒ Object
readonly
Multi-currency balance of this FinancialAccount, split by availability state.
-
#country ⇒ Object
readonly
Open Enum.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A descriptive name for the FinancialAccount, up to 50 characters long.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Metadata associated with the FinancialAccount.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#other ⇒ Object
readonly
If this is a ‘other` FinancialAccount, this hash indicates what the actual type is.
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
-
#storage ⇒ Object
readonly
If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.
-
#type ⇒ Object
readonly
Type of the FinancialAccount.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance ⇒ Object (readonly)
Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.
146 147 148 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 146 def balance @balance end |
#country ⇒ Object (readonly)
Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.
148 149 150 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 148 def country @country end |
#created ⇒ Object (readonly)
Time at which the object was created.
150 151 152 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 150 def created @created end |
#display_name ⇒ Object (readonly)
A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.
152 153 154 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 152 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
154 155 156 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 154 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
171 172 173 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 171 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Metadata associated with the FinancialAccount.
156 157 158 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 156 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
158 159 160 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 158 def object @object end |
#other ⇒ Object (readonly)
If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.
160 161 162 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 160 def other @other end |
#status ⇒ Object (readonly)
Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.
162 163 164 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 162 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
164 165 166 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 164 def status_details @status_details end |
#storage ⇒ Object (readonly)
If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.
166 167 168 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 166 def storage @storage end |
#type ⇒ Object (readonly)
Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.
169 170 171 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 169 def type @type end |
Class Method Details
.field_remappings ⇒ Object
182 183 184 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 182 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
173 174 175 176 177 178 179 180 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 173 def self.inner_class_types @inner_class_types = { balance: Balance, other: Other, status_details: StatusDetails, storage: Storage, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10 def self.object_name "v2.money_management.financial_account" end |