Class: Stripe::V2::MoneyManagement::FinancialAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Overview

A FinancialAccount represents a balance and can be used as the source or destination for the money management (‘/v2/money_management`) APIs.

Defined Under Namespace

Classes: Balance, ManagedBy, Other, Payments, StatusDetails, Storage

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.



174
175
176
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 174

def balance
  @balance
end

#countryObject (readonly)

Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.



176
177
178
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 176

def country
  @country
end

#createdObject (readonly)

Time at which the object was created.



178
179
180
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 178

def created
  @created
end

#display_nameObject (readonly)

A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.



180
181
182
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 180

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



182
183
184
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 182

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



204
205
206
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 204

def livemode
  @livemode
end

#managed_byObject (readonly)

If this is a managed FinancialAccount, ‘managed_by` indicates the product that created and manages this FinancialAccount. For managed FinancialAccounts, creation of money management resources can only be orchestrated by the managing product.



185
186
187
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 185

def managed_by
  @managed_by
end

#metadataObject (readonly)

Metadata associated with the FinancialAccount.



187
188
189
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 187

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



189
190
191
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 189

def object
  @object
end

#otherObject (readonly)

If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.



191
192
193
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 191

def other
  @other
end

#paymentsObject (readonly)

If this is a ‘payments` FinancialAccount, this hash include details specific to `payments` FinancialAccount.



193
194
195
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 193

def payments
  @payments
end

#statusObject (readonly)

Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.



195
196
197
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 195

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



197
198
199
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 197

def status_details
  @status_details
end

#storageObject (readonly)

If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.



199
200
201
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 199

def storage
  @storage
end

#typeObject (readonly)

Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.



202
203
204
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 202

def type
  @type
end

Class Method Details

.field_remappingsObject



217
218
219
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 217

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



206
207
208
209
210
211
212
213
214
215
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 206

def self.inner_class_types
  @inner_class_types = {
    balance: Balance,
    managed_by: ManagedBy,
    other: Other,
    payments: Payments,
    status_details: StatusDetails,
    storage: Storage,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10

def self.object_name
  "v2.money_management.financial_account"
end