Class: Stripe::V2::MoneyManagement::FinancialAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Overview

A FinancialAccount represents a balance and can be used as the source or destination for the money management (‘/v2/money_management`) APIs.

Defined Under Namespace

Classes: Balance, Other, StatusDetails, Storage

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.



50
51
52
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 50

def balance
  @balance
end

#countryObject (readonly)

Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.



52
53
54
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 52

def country
  @country
end

#createdObject (readonly)

Time at which the object was created.



54
55
56
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 54

def created
  @created
end

#display_nameObject (readonly)

A descriptive name for the FinancialAccount, up to 50 characters long. This name will be used in the Stripe Dashboard and embedded components.



56
57
58
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 56

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



58
59
60
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 58

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



75
76
77
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 75

def livemode
  @livemode
end

#metadataObject (readonly)

Metadata associated with the FinancialAccount.



60
61
62
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 60

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



62
63
64
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 62

def object
  @object
end

#otherObject (readonly)

If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.



64
65
66
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 64

def other
  @other
end

#statusObject (readonly)

Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.



66
67
68
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 66

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



68
69
70
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 68

def status_details
  @status_details
end

#storageObject (readonly)

If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.



70
71
72
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 70

def storage
  @storage
end

#typeObject (readonly)

Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.



73
74
75
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 73

def type
  @type
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10

def self.object_name
  "v2.money_management.financial_account"
end