Class: Stripe::V2::MoneyManagement::FinancialAccount

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_account.rb

Overview

The Financial Account is the container that allows for the configuration of money movement.

Defined Under Namespace

Classes: Balance, Other, Storage

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Multi-currency balance of this FinancialAccount, split by availability state. Each balance is represented as a hash where the key is the three-letter ISO currency code, in lowercase, and the value is the amount for that currency.



33
34
35
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 33

def balance
  @balance
end

#countryObject (readonly)

Open Enum. Two-letter country code that represents the country where the LegalEntity associated with the FinancialAccount is based in.



35
36
37
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 35

def country
  @country
end

#createdObject (readonly)

Time at which the object was created.



37
38
39
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 37

def created
  @created
end

#descriptionObject (readonly)

Attribute for field description



39
40
41
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 39

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



41
42
43
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 41

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



54
55
56
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 54

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



43
44
45
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 43

def object
  @object
end

#otherObject (readonly)

If this is a ‘other` FinancialAccount, this hash indicates what the actual type is. Upgrade your API version to see it reflected in `type`.



45
46
47
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 45

def other
  @other
end

#statusObject (readonly)

Closed Enum. An enum representing the status of the FinancialAccount. This indicates whether or not the FinancialAccount can be used for any money movement flows.



47
48
49
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 47

def status
  @status
end

#storageObject (readonly)

If this is a ‘storage` FinancialAccount, this hash includes details specific to `storage` FinancialAccounts.



49
50
51
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 49

def storage
  @storage
end

#typeObject (readonly)

Type of the FinancialAccount. An additional hash is included on the FinancialAccount with a name matching this value. It contains additional information specific to the FinancialAccount type.



52
53
54
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 52

def type
  @type
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 10

def self.object_name
  "v2.money_management.financial_account"
end