Class: Stripe::V2::MoneyManagement::FinancialAccount::Balance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAccount::Balance
- Defined in:
- lib/stripe/resources/v2/money_management/financial_account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#available ⇒ Object
readonly
Balance that can be used for money movement.
-
#inbound_pending ⇒ Object
readonly
Balance of inbound funds that will later transition to the ‘available` balance.
-
#outbound_pending ⇒ Object
readonly
Balance of funds that are being used for a pending outbound money movement.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#available ⇒ Object (readonly)
Balance that can be used for money movement.
16 17 18 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 16 def available @available end |
#inbound_pending ⇒ Object (readonly)
Balance of inbound funds that will later transition to the ‘available` balance.
18 19 20 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 18 def inbound_pending @inbound_pending end |
#outbound_pending ⇒ Object (readonly)
Balance of funds that are being used for a pending outbound money movement.
20 21 22 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 20 def outbound_pending @outbound_pending end |