Class: Stripe::V2::MoneyManagement::FinancialAccount::Payments
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAccount::Payments
- Defined in:
- lib/stripe/resources/v2/money_management/financial_account.rb
Defined Under Namespace
Classes: BalanceByFundsType, StartingBalance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance_by_funds_type ⇒ Object
readonly
The balance of the ‘payments` FinancialAccount is a mix of payment processing and stored value funds, and this field describes the breakdown between the two.
-
#default_currency ⇒ Object
readonly
The currency that non-settlement currency payments will be converted to.
-
#settlement_currencies ⇒ Object
readonly
Settlement currencies enabled for this FinancialAccount.
-
#starting_balance ⇒ Object
readonly
Describes the available balance when it was projected.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance_by_funds_type ⇒ Object (readonly)
The balance of the ‘payments` FinancialAccount is a mix of payment processing and stored value funds, and this field describes the breakdown between the two. The sum will match the balance of the FinancialAccount.
153 154 155 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 153 def balance_by_funds_type @balance_by_funds_type end |
#default_currency ⇒ Object (readonly)
The currency that non-settlement currency payments will be converted to.
155 156 157 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 155 def default_currency @default_currency end |
#settlement_currencies ⇒ Object (readonly)
Settlement currencies enabled for this FinancialAccount. Payments in other currencies will be automatically converted to ‘default_currency`.
157 158 159 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 157 def settlement_currencies @settlement_currencies end |
#starting_balance ⇒ Object (readonly)
Describes the available balance when it was projected.
159 160 161 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 159 def starting_balance @starting_balance end |
Class Method Details
.field_remappings ⇒ Object
168 169 170 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 168 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
161 162 163 164 165 166 |
# File 'lib/stripe/resources/v2/money_management/financial_account.rb', line 161 def self.inner_class_types @inner_class_types = { balance_by_funds_type: BalanceByFundsType, starting_balance: StartingBalance, } end |