Class: Stripe::V2::MoneyManagement::FinancialAddress

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address.rb

Overview

A Financial Address contains information needed to transfer money to a Financial Account. A Financial Account can have more than one Financial Address.

Defined Under Namespace

Classes: Credentials

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.financial_address"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The creation timestamp of the FinancialAddress.



157
158
159
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 157

def created
  @created
end

#credentialsObject (readonly)

Object indicates the type of credentials that have been allocated and attached to the FinancialAddress. It contains all necessary banking details with which to perform money movements with the FinancialAddress. This field is only available for FinancialAddresses with an active status.



161
162
163
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 161

def credentials
  @credentials
end

#currencyObject (readonly)

Open Enum. The currency the FinancialAddress supports.



163
164
165
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 163

def currency
  @currency
end

#financial_accountObject (readonly)

A ID of the FinancialAccount this FinancialAddress corresponds to.



165
166
167
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 165

def 
  @financial_account
end

#idObject (readonly)

The ID of a FinancialAddress.



167
168
169
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 167

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



169
170
171
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 169

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



171
172
173
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 171

def object
  @object
end

#settlement_currencyObject (readonly)

Open Enum. The currency the FinancialAddress settles into the FinancialAccount.



173
174
175
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 173

def settlement_currency
  @settlement_currency
end

#statusObject (readonly)

Closed Enum. An enum representing the status of the FinancialAddress. This indicates whether or not the FinancialAddress can be used for any money movement flows.



175
176
177
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 175

def status
  @status
end

Class Method Details

.field_remappingsObject



181
182
183
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 181

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



177
178
179
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 177

def self.inner_class_types
  @inner_class_types = { credentials: Credentials }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 10

def self.object_name
  "v2.money_management.financial_address"
end