Class: Stripe::V2::MoneyManagement::FinancialAddress
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::FinancialAddress
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Overview
A Financial Address contains information needed to transfer money to a Financial Account. A Financial Account can have more than one Financial Address.
Defined Under Namespace
Classes: Credentials
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.financial_address"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The creation timestamp of the FinancialAddress.
-
#credentials ⇒ Object
readonly
Object indicates the type of credentials that have been allocated and attached to the FinancialAddress.
-
#currency ⇒ Object
readonly
Open Enum.
-
#financial_account ⇒ Object
readonly
A ID of the FinancialAccount this FinancialAddress corresponds to.
-
#id ⇒ Object
readonly
The ID of a FinancialAddress.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#settlement_currency ⇒ Object
readonly
Open Enum.
-
#status ⇒ Object
readonly
Closed Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The creation timestamp of the FinancialAddress.
195 196 197 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 195 def created @created end |
#credentials ⇒ Object (readonly)
Object indicates the type of credentials that have been allocated and attached to the FinancialAddress. It contains all necessary banking details with which to perform money movements with the FinancialAddress. This field is only available for FinancialAddresses with an active status.
199 200 201 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 199 def credentials @credentials end |
#currency ⇒ Object (readonly)
Open Enum. The currency the FinancialAddress supports.
201 202 203 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 201 def currency @currency end |
#financial_account ⇒ Object (readonly)
A ID of the FinancialAccount this FinancialAddress corresponds to.
203 204 205 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 203 def financial_account @financial_account end |
#id ⇒ Object (readonly)
The ID of a FinancialAddress.
205 206 207 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 205 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
207 208 209 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 207 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
209 210 211 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 209 def object @object end |
#settlement_currency ⇒ Object (readonly)
Open Enum. The currency the FinancialAddress settles into the FinancialAccount.
211 212 213 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 211 def settlement_currency @settlement_currency end |
#status ⇒ Object (readonly)
Closed Enum. An enum representing the status of the FinancialAddress. This indicates whether or not the FinancialAddress can be used for any money movement flows.
213 214 215 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 213 def status @status end |
Class Method Details
.field_remappings ⇒ Object
219 220 221 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 219 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
215 216 217 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 215 def self.inner_class_types @inner_class_types = { credentials: Credentials } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 10 def self.object_name "v2.money_management.financial_address" end |