Class: Stripe::V2::MoneyManagement::FinancialAddress
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::FinancialAddress
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Overview
A FinancialAddress contains information needed to transfer money to a Financial Account. A Financial Account can have more than one Financial Address.
Defined Under Namespace
Classes: Credentials
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.financial_address"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The creation timestamp of the FinancialAddress.
-
#credentials ⇒ Object
readonly
Object indicates the type of credentials that have been allocated and attached to the FinancialAddress.
-
#currency ⇒ Object
readonly
Open Enum.
-
#financial_account ⇒ Object
readonly
A ID of the FinancialAccount this FinancialAddress corresponds to.
-
#id ⇒ Object
readonly
The ID of a FinancialAddress.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Closed Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The creation timestamp of the FinancialAddress.
48 49 50 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 48 def created @created end |
#credentials ⇒ Object (readonly)
Object indicates the type of credentials that have been allocated and attached to the FinancialAddress. It contains all necessary banking details with which to perform money movements with the FinancialAddress. This field is only available for FinancialAddresses with an active status.
52 53 54 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 52 def credentials @credentials end |
#currency ⇒ Object (readonly)
Open Enum. The currency the FinancialAddress supports.
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 54 def currency @currency end |
#financial_account ⇒ Object (readonly)
A ID of the FinancialAccount this FinancialAddress corresponds to.
56 57 58 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 56 def financial_account @financial_account end |
#id ⇒ Object (readonly)
The ID of a FinancialAddress.
58 59 60 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 58 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
64 65 66 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 64 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 60 def object @object end |
#status ⇒ Object (readonly)
Closed Enum. An enum representing the status of the FinancialAddress. This indicates whether or not the FinancialAddress can be used for any money movement flows.
62 63 64 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 62 def status @status end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 10 def self.object_name "v2.money_management.financial_address" end |