Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAddress::Credentials
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Defined Under Namespace
Classes: CaBankAccount, CryptoWallet, GbBankAccount, MxBankAccount, SepaBankAccount, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ca_bank_account ⇒ Object
readonly
The credentials of the Canadian Bank Account for the FinancialAddress.
-
#crypto_wallet ⇒ Object
readonly
The credentials of the crypto wallet for the Financial Address.
-
#gb_bank_account ⇒ Object
readonly
The credentials of the UK Bank Account for the FinancialAddress.
-
#mx_bank_account ⇒ Object
readonly
The credentials of the Mexican Bank Account for the FinancialAddress.
-
#sepa_bank_account ⇒ Object
readonly
The credentials of the SEPA Bank Account for the FinancialAddress.
-
#type ⇒ Object
readonly
Open Enum.
-
#us_bank_account ⇒ Object
readonly
The credentials of the US Bank Account for the FinancialAddress.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ca_bank_account ⇒ Object (readonly)
The credentials of the Canadian Bank Account for the FinancialAddress. This contains unique banking details such as the account number, institution number, etc. of a Canadian bank account.
165 166 167 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 165 def ca_bank_account @ca_bank_account end |
#crypto_wallet ⇒ Object (readonly)
The credentials of the crypto wallet for the Financial Address. This contains unique details such as the blockchain network, wallet address, and memo of a crypto wallet.
167 168 169 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 167 def crypto_wallet @crypto_wallet end |
#gb_bank_account ⇒ Object (readonly)
The credentials of the UK Bank Account for the FinancialAddress. This contains unique banking details such as the sort code, account number, etc. of a UK bank account.
169 170 171 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 169 def gb_bank_account @gb_bank_account end |
#mx_bank_account ⇒ Object (readonly)
The credentials of the Mexican Bank Account for the FinancialAddress. This contains unique banking details such as the CLABE and account holder name of a Mexican bank account.
171 172 173 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 171 def mx_bank_account @mx_bank_account end |
#sepa_bank_account ⇒ Object (readonly)
The credentials of the SEPA Bank Account for the FinancialAddress. This contains unique banking details such as the IBAN, BIC, etc. of a SEPA bank account.
173 174 175 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 173 def sepa_bank_account @sepa_bank_account end |
#type ⇒ Object (readonly)
Open Enum. The type of Credentials that are provisioned for the FinancialAddress.
175 176 177 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 175 def type @type end |
#us_bank_account ⇒ Object (readonly)
The credentials of the US Bank Account for the FinancialAddress. This contains unique banking details such as the routing number, account number, etc. of a US bank account.
177 178 179 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 177 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
190 191 192 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 190 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 179 def self.inner_class_types @inner_class_types = { ca_bank_account: CaBankAccount, crypto_wallet: CryptoWallet, gb_bank_account: GbBankAccount, mx_bank_account: MxBankAccount, sepa_bank_account: SepaBankAccount, us_bank_account: UsBankAccount, } end |