Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address.rb

Defined Under Namespace

Classes: GbBankAccount, SepaBankAccount, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#gb_bank_accountObject (readonly)

The credentials of the UK Bank Account for the FinancialAddress. This contains unique banking details such as the sort code, account number, etc. of a UK bank account.



109
110
111
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 109

def 
  @gb_bank_account
end

#sepa_bank_accountObject (readonly)

The credentials of the SEPA Bank Account for the FinancialAddress. This contains unique banking details such as the IBAN, BIC, etc. of a SEPA bank account.



111
112
113
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 111

def 
  @sepa_bank_account
end

#typeObject (readonly)

Open Enum. The type of Credentials that are provisioned for the FinancialAddress.



113
114
115
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 113

def type
  @type
end

#us_bank_accountObject (readonly)

The credentials of the US Bank Account for the FinancialAddress. This contains unique banking details such as the routing number, account number, etc. of a US bank account.



115
116
117
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 115

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



125
126
127
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 125

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



117
118
119
120
121
122
123
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 117

def self.inner_class_types
  @inner_class_types = {
    gb_bank_account: GbBankAccount,
    sepa_bank_account: SepaBankAccount,
    us_bank_account: UsBankAccount,
  }
end