Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address.rb

Defined Under Namespace

Classes: GbBankAccount, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#gb_bank_accountObject (readonly)

The credentials of the UK Bank Account for the FinancialAddress. This contains unique banking details such as the sort code, account number, etc. of a UK bank account.



43
44
45
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 43

def 
  @gb_bank_account
end

#typeObject (readonly)

Open Enum. The type of Credentials that are provisioned for the FinancialAddress.



41
42
43
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 41

def type
  @type
end

#us_bank_accountObject (readonly)

The credentials of the US Bank Account for the FinancialAddress. This contains unique banking details such as the routing number, account number, etc. of a US bank account.



45
46
47
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 45

def 
  @us_bank_account
end