Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::GbBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAddress::Credentials::GbBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The account holder name to be used during bank transference.
-
#account_number ⇒ Object
readonly
The account number of the UK Bank Account.
-
#last4 ⇒ Object
readonly
The last four digits of the UK Bank Account number.
-
#sort_code ⇒ Object
readonly
The sort code of the UK Bank Account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The account holder name to be used during bank transference.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 41 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number of the UK Bank Account.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 43 def account_number @account_number end |
#last4 ⇒ Object (readonly)
The last four digits of the UK Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.
46 47 48 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 46 def last4 @last4 end |
#sort_code ⇒ Object (readonly)
The sort code of the UK Bank Account.
48 49 50 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 48 def sort_code @sort_code end |
Class Method Details
.field_remappings ⇒ Object
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 54 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
50 51 52 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 50 def self.inner_class_types @inner_class_types = {} end |