Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::GbBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAddress::Credentials::GbBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The account holder name to be used during bank transference.
-
#account_number ⇒ Object
readonly
The account number of the UK Bank Account.
-
#last4 ⇒ Object
readonly
The last four digits of the UK Bank Account number.
-
#sort_code ⇒ Object
readonly
The sort code of the UK Bank Account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The account holder name to be used during bank transference.
17 18 19 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 17 def account_holder_name @account_holder_name end |
#account_number ⇒ Object (readonly)
The account number of the UK Bank Account.
19 20 21 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 19 def account_number @account_number end |
#last4 ⇒ Object (readonly)
The last four digits of the UK Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.
22 23 24 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 22 def last4 @last4 end |
#sort_code ⇒ Object (readonly)
The sort code of the UK Bank Account.
24 25 26 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 24 def sort_code @sort_code end |
Class Method Details
.field_remappings ⇒ Object
30 31 32 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 30 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
26 27 28 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 26 def self.inner_class_types @inner_class_types = {} end |