Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address.rb

Defined Under Namespace

Classes: AccountHolderAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_addressObject (readonly)

The address of the account holder.



85
86
87
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 85

def 
  @account_holder_address
end

#account_holder_nameObject (readonly)

The name of the account holder.



87
88
89
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 87

def 
  @account_holder_name
end

#account_numberObject (readonly)

The account number of the US Bank Account.



89
90
91
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 89

def 
  @account_number
end

#bank_nameObject (readonly)

The name of the Bank.



91
92
93
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 91

def bank_name
  @bank_name
end

#last4Object (readonly)

The last four digits of the US Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.



94
95
96
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 94

def last4
  @last4
end

#routing_numberObject (readonly)

The routing number of the US Bank Account.



96
97
98
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 96

def routing_number
  @routing_number
end

#swift_codeObject (readonly)

The swift code of the bank or financial institution.



98
99
100
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 98

def swift_code
  @swift_code
end

Class Method Details

.field_remappingsObject



104
105
106
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 104

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



100
101
102
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 100

def self.inner_class_types
  @inner_class_types = { account_holder_address: AccountHolderAddress }
end