Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/financial_address.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_numberObject (readonly)

The account number of the US Bank Account.



61
62
63
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 61

def 
  @account_number
end

#bank_nameObject (readonly)

The name of the Bank.



63
64
65
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 63

def bank_name
  @bank_name
end

#last4Object (readonly)

The last four digits of the US Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.



66
67
68
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 66

def last4
  @last4
end

#routing_numberObject (readonly)

The routing number of the US Bank Account.



68
69
70
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 68

def routing_number
  @routing_number
end

#swift_codeObject (readonly)

The swift code of the bank or financial institution.



70
71
72
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 70

def swift_code
  @swift_code
end

Class Method Details

.field_remappingsObject



76
77
78
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 76

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



72
73
74
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 72

def self.inner_class_types
  @inner_class_types = {}
end