Class: Stripe::V2::MoneyManagement::FinancialAddress::Credentials::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::FinancialAddress::Credentials::UsBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/financial_address.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
The account number of the US Bank Account.
-
#bank_name ⇒ Object
readonly
The name of the Bank.
-
#last4 ⇒ Object
readonly
The last four digits of the US Bank Account number.
-
#routing_number ⇒ Object
readonly
The routing number of the US Bank Account.
-
#swift_code ⇒ Object
readonly
The swift code of the bank or financial institution.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
The account number of the US Bank Account.
29 30 31 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 29 def account_number @account_number end |
#bank_name ⇒ Object (readonly)
The name of the Bank.
31 32 33 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 31 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last four digits of the US Bank Account number. This will always be returned. To view the full account number when retrieving or listing FinancialAddresses, use the ‘include` request parameter.
34 35 36 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 34 def last4 @last4 end |
#routing_number ⇒ Object (readonly)
The routing number of the US Bank Account.
36 37 38 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 36 def routing_number @routing_number end |
#swift_code ⇒ Object (readonly)
The swift code of the bank or financial institution.
38 39 40 |
# File 'lib/stripe/resources/v2/money_management/financial_address.rb', line 38 def swift_code @swift_code end |