Class: Stripe::V2::MoneyManagement::FinancialAddressCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/financial_address_create_params.rb

Defined Under Namespace

Classes: SepaBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_account: nil, sepa_bank_account: nil, type: nil) ⇒ FinancialAddressCreateParams

Returns a new instance of FinancialAddressCreateParams.



23
24
25
26
27
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 23

def initialize(financial_account: nil, sepa_bank_account: nil, type: nil)
  @financial_account = 
  @sepa_bank_account = 
  @type = type
end

Instance Attribute Details

#financial_accountObject

The ID of the FinancialAccount the new FinancialAddress should be associated with.



17
18
19
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 17

def 
  @financial_account
end

#sepa_bank_accountObject

Optional SEPA Bank account options, used to configure the type of SEPA Bank account to create, such as the originating country.



19
20
21
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 19

def 
  @sepa_bank_account
end

#typeObject

The type of FinancialAddress details to provision.



21
22
23
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 21

def type
  @type
end