Class: Stripe::V2::MoneyManagement::FinancialAddressCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::FinancialAddressCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/financial_address_create_params.rb
Defined Under Namespace
Classes: SepaBankAccount
Instance Attribute Summary collapse
-
#financial_account ⇒ Object
The ID of the FinancialAccount the new FinancialAddress should be associated with.
-
#sepa_bank_account ⇒ Object
Optional SEPA Bank account options, used to configure the type of SEPA Bank account to create, such as the originating country.
-
#type ⇒ Object
The type of FinancialAddress details to provision.
Instance Method Summary collapse
-
#initialize(financial_account: nil, sepa_bank_account: nil, type: nil) ⇒ FinancialAddressCreateParams
constructor
A new instance of FinancialAddressCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_account: nil, sepa_bank_account: nil, type: nil) ⇒ FinancialAddressCreateParams
Returns a new instance of FinancialAddressCreateParams.
23 24 25 26 27 |
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 23 def initialize(financial_account: nil, sepa_bank_account: nil, type: nil) @financial_account = financial_account @sepa_bank_account = sepa_bank_account @type = type end |
Instance Attribute Details
#financial_account ⇒ Object
The ID of the FinancialAccount the new FinancialAddress should be associated with.
17 18 19 |
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 17 def financial_account @financial_account end |
#sepa_bank_account ⇒ Object
Optional SEPA Bank account options, used to configure the type of SEPA Bank account to create, such as the originating country.
19 20 21 |
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 19 def sepa_bank_account @sepa_bank_account end |
#type ⇒ Object
The type of FinancialAddress details to provision.
21 22 23 |
# File 'lib/stripe/params/v2/money_management/financial_address_create_params.rb', line 21 def type @type end |