Class: Stripe::V2::MoneyManagement::InboundTransfer

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/inbound_transfer.rb

Overview

An InboundTransfer object, representing a money movement from a user owned PaymentMethod to a FinancialAccount belonging to the same user.

Defined Under Namespace

Classes: Amount, From, To, TransferHistory

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.inbound_transfer"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount in specified currency that will land in the FinancialAccount balance.



162
163
164
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 162

def amount
  @amount
end

#createdObject (readonly)

Creation time of the InboundTransfer. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



164
165
166
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 164

def created
  @created
end

#descriptionObject (readonly)

A freeform text field provided by user, containing metadata.



166
167
168
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 166

def description
  @description
end

#fromObject (readonly)

A nested object containing information about the origin of the InboundTransfer.



168
169
170
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 168

def from
  @from
end

#idObject (readonly)

Unique identifier for the InboundTransfer.



170
171
172
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 170

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



180
181
182
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 180

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



172
173
174
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 172

def object
  @object
end

#receipt_urlObject (readonly)

A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.



174
175
176
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 174

def receipt_url
  @receipt_url
end

#toObject (readonly)

A nested object containing information about the destination of the InboundTransfer.



176
177
178
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 176

def to
  @to
end

#transfer_historyObject (readonly)

A list of history objects, representing changes in the state of the InboundTransfer.



178
179
180
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 178

def transfer_history
  @transfer_history
end

Class Method Details

.field_remappingsObject



191
192
193
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 191

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



182
183
184
185
186
187
188
189
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 182

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    from: From,
    to: To,
    transfer_history: TransferHistory,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 11

def self.object_name
  "v2.money_management.inbound_transfer"
end