Class: Stripe::V2::MoneyManagement::InboundTransfer
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::InboundTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/inbound_transfer.rb
Overview
An InboundTransfer object, representing a money movement from a user owned PaymentMethod to a FinancialAccount belonging to the same user.
Defined Under Namespace
Classes: From, To, TransferHistory
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.inbound_transfer"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount in specified currency that will land in the FinancialAccount balance.
-
#created ⇒ Object
readonly
Creation time of the InboundTransfer.
-
#description ⇒ Object
readonly
A freeform text field provided by user, containing metadata.
-
#from ⇒ Object
readonly
A nested object containing information about the origin of the InboundTransfer.
-
#id ⇒ Object
readonly
Unique identifier for the InboundTransfer.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#to ⇒ Object
readonly
A nested object containing information about the destination of the InboundTransfer.
-
#transfer_history ⇒ Object
readonly
A list of history objects, representing changes in the state of the InboundTransfer.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount in specified currency that will land in the FinancialAccount balance.
72 73 74 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 72 def amount @amount end |
#created ⇒ Object (readonly)
Creation time of the InboundTransfer. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 74 def created @created end |
#description ⇒ Object (readonly)
A freeform text field provided by user, containing metadata.
76 77 78 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 76 def description @description end |
#from ⇒ Object (readonly)
A nested object containing information about the origin of the InboundTransfer.
78 79 80 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 78 def from @from end |
#id ⇒ Object (readonly)
Unique identifier for the InboundTransfer.
80 81 82 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 80 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
82 83 84 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 82 def object @object end |
#receipt_url ⇒ Object (readonly)
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
84 85 86 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 84 def receipt_url @receipt_url end |
#to ⇒ Object (readonly)
A nested object containing information about the destination of the InboundTransfer.
86 87 88 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 86 def to @to end |
#transfer_history ⇒ Object (readonly)
A list of history objects, representing changes in the state of the InboundTransfer.
88 89 90 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 88 def transfer_history @transfer_history end |
Class Method Details
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 11 def self.object_name "v2.money_management.inbound_transfer" end |