Class: Stripe::V2::MoneyManagement::InboundTransfer::From

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/inbound_transfer.rb

Defined Under Namespace

Classes: PaymentMethod

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#debitedObject (readonly)

The amount in specified currency that was debited from the Payment Method.



23
24
25
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 23

def debited
  @debited
end

#payment_methodObject (readonly)

The Payment Method object used to create the InboundTransfer.



25
26
27
# File 'lib/stripe/resources/v2/money_management/inbound_transfer.rb', line 25

def payment_method
  @payment_method
end