Class: Stripe::V2::MoneyManagement::InboundTransferCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb

Defined Under Namespace

Classes: Amount, From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, from: nil, to: nil) ⇒ InboundTransferCreateParams

Returns a new instance of InboundTransferCreateParams.



53
54
55
56
57
58
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 53

def initialize(amount: nil, description: nil, from: nil, to: nil)
  @amount = amount
  @description = description
  @from = from
  @to = to
end

Instance Attribute Details

#amountObject

The amount, in specified currency, by which the FinancialAccount balance will increase due to the InboundTransfer.



45
46
47
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 45

def amount
  @amount
end

#descriptionObject

An optional, freeform description field intended to store metadata.



47
48
49
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 47

def description
  @description
end

#fromObject

Object containing details about where the funds will originate from.



49
50
51
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 49

def from
  @from
end

#toObject

Object containing details about where the funds will land.



51
52
53
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 51

def to
  @to
end