Class: Stripe::V2::MoneyManagement::InboundTransferCreateParams::From
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::InboundTransferCreateParams::From
- Defined in:
- lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
An optional currency field used to specify which currency is debited from the Payment Method.
-
#payment_method ⇒ Object
ID of the Payment Method using which IBT will be made.
Instance Method Summary collapse
-
#initialize(currency: nil, payment_method: nil) ⇒ From
constructor
A new instance of From.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, payment_method: nil) ⇒ From
Returns a new instance of From.
15 16 17 18 |
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 15 def initialize(currency: nil, payment_method: nil) @currency = currency @payment_method = payment_method end |
Instance Attribute Details
#currency ⇒ Object
An optional currency field used to specify which currency is debited from the Payment Method. Since many Payment Methods support only one currency, this field is optional.
11 12 13 |
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 11 def currency @currency end |
#payment_method ⇒ Object
ID of the Payment Method using which IBT will be made.
13 14 15 |
# File 'lib/stripe/params/v2/money_management/inbound_transfer_create_params.rb', line 13 def payment_method @payment_method end |