Class: Stripe::V2::MoneyManagement::InboundTransferService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::InboundTransferService::CreateParams
- Defined in:
- lib/stripe/services/v2/money_management/inbound_transfer_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in specified currency, by which the FinancialAccount balance will increase due to the InboundTransfer.
-
#description ⇒ Object
An optional, freeform description field intended to store metadata.
-
#from ⇒ Object
Object containing details about where the funds will originate from.
-
#to ⇒ Object
Object containing details about where the funds will land.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, from: nil, to: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, from: nil, to: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
42 43 44 45 46 47 |
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 42 def initialize(amount: nil, description: nil, from: nil, to: nil) @amount = amount @description = description @from = from @to = to end |
Instance Attribute Details
#amount ⇒ Object
The amount, in specified currency, by which the FinancialAccount balance will increase due to the InboundTransfer.
34 35 36 |
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 34 def amount @amount end |
#description ⇒ Object
An optional, freeform description field intended to store metadata.
36 37 38 |
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 36 def description @description end |
#from ⇒ Object
Object containing details about where the funds will originate from.
38 39 40 |
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 38 def from @from end |
#to ⇒ Object
Object containing details about where the funds will land.
40 41 42 |
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 40 def to @to end |