Class: Stripe::V2::MoneyManagement::InboundTransferService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/inbound_transfer_service.rb

Defined Under Namespace

Classes: From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, from: nil, to: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



42
43
44
45
46
47
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 42

def initialize(amount: nil, description: nil, from: nil, to: nil)
  @amount = amount
  @description = description
  @from = from
  @to = to
end

Instance Attribute Details

#amountObject

The amount, in specified currency, by which the FinancialAccount balance will increase due to the InboundTransfer.



34
35
36
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 34

def amount
  @amount
end

#descriptionObject

An optional, freeform description field intended to store metadata.



36
37
38
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 36

def description
  @description
end

#fromObject

Object containing details about where the funds will originate from.



38
39
40
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 38

def from
  @from
end

#toObject

Object containing details about where the funds will land.



40
41
42
# File 'lib/stripe/services/v2/money_management/inbound_transfer_service.rb', line 40

def to
  @to
end