Class: Stripe::V2::MoneyManagement::OutboundPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::OutboundPayment
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment.rb
Overview
OutboundPayment represents a single money movement from one FinancialAccount you own to a payout method someone else owns.
Defined Under Namespace
Classes: DeliveryOptions, From, RecipientNotification, StatusDetails, StatusTransitions, To, TraceId
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.outbound_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The “presentment amount” for the OutboundPayment.
-
#cancelable ⇒ Object
readonly
Returns true if the OutboundPayment can be canceled, and false otherwise.
-
#created ⇒ Object
readonly
Time at which the OutboundPayment was created.
-
#delivery_options ⇒ Object
readonly
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the OutboundPayment.
-
#expected_arrival_date ⇒ Object
readonly
The date when funds are expected to arrive in the payout method.
-
#from ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#id ⇒ Object
readonly
Unique identifier for the OutboundPayment.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#outbound_payment_quote ⇒ Object
readonly
The quote for this OutboundPayment.
-
#purpose ⇒ Object
readonly
The purpose of the OutboundPayment.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this OutboundPayment.
-
#recipient_notification ⇒ Object
readonly
Details about the OutboundPayment notification settings for recipient.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Status details for an OutboundPayment in a ‘processing`, `failed`, or `returned` state.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#to ⇒ Object
readonly
To which payout method the OutboundPayment was sent.
-
#trace_id ⇒ Object
readonly
A unique identifier that can be used to track this OutboundPayment with recipient bank.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The “presentment amount” for the OutboundPayment.
169 170 171 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 169 def amount @amount end |
#cancelable ⇒ Object (readonly)
Returns true if the OutboundPayment can be canceled, and false otherwise.
171 172 173 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 171 def cancelable @cancelable end |
#created ⇒ Object (readonly)
Time at which the OutboundPayment was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
174 175 176 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 174 def created @created end |
#delivery_options ⇒ Object (readonly)
Delivery options to be used to send the OutboundPayment.
176 177 178 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 176 def @delivery_options end |
#description ⇒ Object (readonly)
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
178 179 180 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 178 def description @description end |
#expected_arrival_date ⇒ Object (readonly)
The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
181 182 183 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 181 def expected_arrival_date @expected_arrival_date end |
#from ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
183 184 185 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 183 def from @from end |
#id ⇒ Object (readonly)
Unique identifier for the OutboundPayment.
185 186 187 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 185 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
187 188 189 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 187 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
189 190 191 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 189 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
191 192 193 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 191 def object @object end |
#outbound_payment_quote ⇒ Object (readonly)
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
193 194 195 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 193 def outbound_payment_quote @outbound_payment_quote end |
#purpose ⇒ Object (readonly)
The purpose of the OutboundPayment.
195 196 197 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 195 def purpose @purpose end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this OutboundPayment. The receipt link remains active for 60 days from the OutboundPayment creation date. After this period, the link will expire and the receipt url value will be null.
197 198 199 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 197 def receipt_url @receipt_url end |
#recipient_notification ⇒ Object (readonly)
Details about the OutboundPayment notification settings for recipient.
199 200 201 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 199 def recipient_notification @recipient_notification end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.
201 202 203 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 201 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Closed Enum. Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its payout method, its status will change to `returned`.
206 207 208 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 206 def status @status end |
#status_details ⇒ Object (readonly)
Status details for an OutboundPayment in a ‘processing`, `failed`, or `returned` state.
208 209 210 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 208 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
210 211 212 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 210 def status_transitions @status_transitions end |
#to ⇒ Object (readonly)
To which payout method the OutboundPayment was sent.
212 213 214 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 212 def to @to end |
#trace_id ⇒ Object (readonly)
A unique identifier that can be used to track this OutboundPayment with recipient bank. Banks might call this a “reference number” or something similar.
214 215 216 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 214 def trace_id @trace_id end |
Class Method Details
.field_remappings ⇒ Object
228 229 230 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 228 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 216 def self.inner_class_types @inner_class_types = { delivery_options: DeliveryOptions, from: From, recipient_notification: RecipientNotification, status_details: StatusDetails, status_transitions: StatusTransitions, to: To, trace_id: TraceId, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 10 def self.object_name "v2.money_management.outbound_payment" end |