Class: Stripe::V2::MoneyManagement::OutboundPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::OutboundPayment
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment.rb
Overview
OutboundPayment represents a single money movement from one FinancialAccount you own to a payout method someone else owns.
Defined Under Namespace
Classes: DeliveryOptions, From, RecipientNotification, StatusDetails, StatusTransitions, To, TraceId, TrackingDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.outbound_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The “presentment amount” for the OutboundPayment.
-
#cancelable ⇒ Object
readonly
Returns true if the OutboundPayment can be canceled, and false otherwise.
-
#created ⇒ Object
readonly
Time at which the OutboundPayment was created.
-
#delivery_options ⇒ Object
readonly
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the OutboundPayment.
-
#expected_arrival_date ⇒ Object
readonly
The date when funds are expected to arrive in the payout method.
-
#from ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#id ⇒ Object
readonly
Unique identifier for the OutboundPayment.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#outbound_payment_quote ⇒ Object
readonly
The quote for this OutboundPayment.
-
#purpose ⇒ Object
readonly
The purpose of the OutboundPayment.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this OutboundPayment.
-
#recipient_notification ⇒ Object
readonly
Details about the OutboundPayment notification settings for recipient.
-
#recipient_verification ⇒ Object
readonly
The recipient verification id for this OutboundPayment.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Status details for an OutboundPayment in a ‘failed` or `returned` state.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#to ⇒ Object
readonly
To which payout method the OutboundPayment was sent.
-
#trace_id ⇒ Object
readonly
A unique identifier that can be used to track this OutboundPayment with recipient bank.
-
#tracking_details ⇒ Object
readonly
Information to track this OutboundPayment with the recipient bank.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The “presentment amount” for the OutboundPayment.
233 234 235 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 233 def amount @amount end |
#cancelable ⇒ Object (readonly)
Returns true if the OutboundPayment can be canceled, and false otherwise.
235 236 237 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 235 def cancelable @cancelable end |
#created ⇒ Object (readonly)
Time at which the OutboundPayment was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
238 239 240 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 238 def created @created end |
#delivery_options ⇒ Object (readonly)
Delivery options to be used to send the OutboundPayment.
240 241 242 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 240 def @delivery_options end |
#description ⇒ Object (readonly)
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
242 243 244 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 242 def description @description end |
#expected_arrival_date ⇒ Object (readonly)
The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
245 246 247 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 245 def expected_arrival_date @expected_arrival_date end |
#from ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
247 248 249 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 247 def from @from end |
#id ⇒ Object (readonly)
Unique identifier for the OutboundPayment.
249 250 251 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 249 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
251 252 253 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 251 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
253 254 255 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 253 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
255 256 257 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 255 def object @object end |
#outbound_payment_quote ⇒ Object (readonly)
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
257 258 259 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 257 def outbound_payment_quote @outbound_payment_quote end |
#purpose ⇒ Object (readonly)
The purpose of the OutboundPayment.
259 260 261 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 259 def purpose @purpose end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this OutboundPayment. The receipt link remains active for 60 days from the OutboundPayment creation date. After this period, the link will expire and the receipt url value will be null.
261 262 263 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 261 def receipt_url @receipt_url end |
#recipient_notification ⇒ Object (readonly)
Details about the OutboundPayment notification settings for recipient.
263 264 265 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 263 def recipient_notification @recipient_notification end |
#recipient_verification ⇒ Object (readonly)
The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.
265 266 267 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 265 def recipient_verification @recipient_verification end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.
267 268 269 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 267 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Closed Enum. Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its payout method, its status will change to `returned`.
272 273 274 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 272 def status @status end |
#status_details ⇒ Object (readonly)
Status details for an OutboundPayment in a ‘failed` or `returned` state.
274 275 276 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 274 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
276 277 278 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 276 def status_transitions @status_transitions end |
#to ⇒ Object (readonly)
To which payout method the OutboundPayment was sent.
278 279 280 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 278 def to @to end |
#trace_id ⇒ Object (readonly)
A unique identifier that can be used to track this OutboundPayment with recipient bank. Banks might call this a “reference number” or something similar.
280 281 282 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 280 def trace_id @trace_id end |
#tracking_details ⇒ Object (readonly)
Information to track this OutboundPayment with the recipient bank.
282 283 284 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 282 def tracking_details @tracking_details end |
Class Method Details
.field_remappings ⇒ Object
297 298 299 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 297 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 284 def self.inner_class_types @inner_class_types = { delivery_options: DeliveryOptions, from: From, recipient_notification: RecipientNotification, status_details: StatusDetails, status_transitions: StatusTransitions, to: To, trace_id: TraceId, tracking_details: TrackingDetails, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 10 def self.object_name "v2.money_management.outbound_payment" end |