Class: Stripe::V2::MoneyManagement::OutboundPayment

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment.rb

Overview

OutboundPayment represents a single money movement from one FinancialAccount you own to a payout method someone else owns.

Defined Under Namespace

Classes: Amount, DeliveryOptions, From, RecipientNotification, StatusDetails, StatusTransitions, To, TraceId, TrackingDetails

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundPayment.



278
279
280
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 278

def amount
  @amount
end

#cancelableObject (readonly)

Returns true if the OutboundPayment can be canceled, and false otherwise.



280
281
282
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 280

def cancelable
  @cancelable
end

#createdObject (readonly)

Time at which the OutboundPayment was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



283
284
285
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 283

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



285
286
287
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 285

def delivery_options
  @delivery_options
end

#descriptionObject (readonly)

An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.



287
288
289
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 287

def description
  @description
end

#expected_arrival_dateObject (readonly)

The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



290
291
292
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 290

def expected_arrival_date
  @expected_arrival_date
end

#fromObject (readonly)

The FinancialAccount that funds were pulled from.



292
293
294
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 292

def from
  @from
end

#idObject (readonly)

Unique identifier for the OutboundPayment.



294
295
296
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 294

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



327
328
329
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 327

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



296
297
298
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 296

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



298
299
300
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 298

def object
  @object
end

#outbound_payment_quoteObject (readonly)

The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.



300
301
302
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 300

def outbound_payment_quote
  @outbound_payment_quote
end

#purposeObject (readonly)

The purpose of the OutboundPayment.



302
303
304
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 302

def purpose
  @purpose
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this OutboundPayment. The receipt link remains active for 60 days from the OutboundPayment creation date. After this period, the link will expire and the receipt url value will be null.



304
305
306
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 304

def receipt_url
  @receipt_url
end

#recipient_notificationObject (readonly)

Details about the OutboundPayment notification settings for recipient.



306
307
308
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 306

def recipient_notification
  @recipient_notification
end

#recipient_verificationObject (readonly)

The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.



308
309
310
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 308

def recipient_verification
  @recipient_verification
end

#statement_descriptorObject (readonly)

The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.



310
311
312
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 310

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Closed Enum. Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its payout method, its status will change to `returned`.



315
316
317
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 315

def status
  @status
end

#status_detailsObject (readonly)

Status details for an OutboundPayment in a ‘failed` or `returned` state.



317
318
319
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 317

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



319
320
321
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 319

def status_transitions
  @status_transitions
end

#toObject (readonly)

To which payout method the OutboundPayment was sent.



321
322
323
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 321

def to
  @to
end

#trace_idObject (readonly)

A unique identifier that can be used to track this OutboundPayment with recipient bank. Banks might call this a “reference number” or something similar.



323
324
325
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 323

def trace_id
  @trace_id
end

#tracking_detailsObject (readonly)

Information to track this OutboundPayment with the recipient bank.



325
326
327
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 325

def tracking_details
  @tracking_details
end

Class Method Details

.field_remappingsObject



343
344
345
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 343

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 329

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    delivery_options: DeliveryOptions,
    from: From,
    recipient_notification: RecipientNotification,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    to: To,
    trace_id: TraceId,
    tracking_details: TrackingDetails,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment"
end