Class: Stripe::V2::MoneyManagement::OutboundPayment

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment.rb

Overview

OutboundPayment represents a single money movement from one FinancialAccount you own to a payout method someone else owns.

Defined Under Namespace

Classes: Amount, DeliveryOptions, From, RecipientNotification, StatusDetails, StatusTransitions, To, TraceId

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundPayment.



197
198
199
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 197

def amount
  @amount
end

#cancelableObject (readonly)

Returns true if the OutboundPayment can be canceled, and false otherwise.



199
200
201
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 199

def cancelable
  @cancelable
end

#createdObject (readonly)

Time at which the OutboundPayment was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



202
203
204
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 202

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



204
205
206
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 204

def delivery_options
  @delivery_options
end

#descriptionObject (readonly)

An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.



206
207
208
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 206

def description
  @description
end

#expected_arrival_dateObject (readonly)

The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



209
210
211
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 209

def expected_arrival_date
  @expected_arrival_date
end

#fromObject (readonly)

The FinancialAccount that funds were pulled from.



211
212
213
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 211

def from
  @from
end

#idObject (readonly)

Unique identifier for the OutboundPayment.



213
214
215
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 213

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



240
241
242
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 240

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



215
216
217
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 215

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



217
218
219
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 217

def object
  @object
end

#outbound_payment_quoteObject (readonly)

The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.



219
220
221
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 219

def outbound_payment_quote
  @outbound_payment_quote
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this OutboundPayment. The receipt link remains active for 60 days from the OutboundPayment creation date. After this period, the link will expire and the receipt url value will be null.



221
222
223
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 221

def receipt_url
  @receipt_url
end

#recipient_notificationObject (readonly)

Details about the OutboundPayment notification settings for recipient.



223
224
225
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 223

def recipient_notification
  @recipient_notification
end

#statement_descriptorObject (readonly)

The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.



225
226
227
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 225

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Closed Enum. Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its payout method, its status will change to `returned`.



230
231
232
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 230

def status
  @status
end

#status_detailsObject (readonly)

Status details for an OutboundPayment in a ‘failed` or `returned` state.



232
233
234
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 232

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



234
235
236
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 234

def status_transitions
  @status_transitions
end

#toObject (readonly)

To which payout method the OutboundPayment was sent.



236
237
238
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 236

def to
  @to
end

#trace_idObject (readonly)

A unique identifier that can be used to track this OutboundPayment with recipient bank. Banks might call this a “reference number” or something similar.



238
239
240
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 238

def trace_id
  @trace_id
end

Class Method Details

.field_remappingsObject



255
256
257
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 255

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 242

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    delivery_options: DeliveryOptions,
    from: From,
    recipient_notification: RecipientNotification,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    to: To,
    trace_id: TraceId,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment"
end