Class: Stripe::V2::MoneyManagement::OutboundPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::OutboundPayment
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment.rb
Overview
OutboundPayment represents a single money movement from one FinancialAccount you own to a payout method someone else owns.
Defined Under Namespace
Classes: Amount, DeliveryOptions, From, RecipientNotification, StatusDetails, StatusTransitions, To, TraceId, TrackingDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.outbound_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The “presentment amount” for the OutboundPayment.
-
#cancelable ⇒ Object
readonly
Returns true if the OutboundPayment can be canceled, and false otherwise.
-
#created ⇒ Object
readonly
Time at which the OutboundPayment was created.
-
#delivery_options ⇒ Object
readonly
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the OutboundPayment.
-
#expected_arrival_date ⇒ Object
readonly
The date when funds are expected to arrive in the payout method.
-
#from ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#id ⇒ Object
readonly
Unique identifier for the OutboundPayment.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#outbound_payment_quote ⇒ Object
readonly
The quote for this OutboundPayment.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this OutboundPayment.
-
#recipient_notification ⇒ Object
readonly
Details about the OutboundPayment notification settings for recipient.
-
#recipient_verification ⇒ Object
readonly
The recipient verification id for this OutboundPayment.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Status details for an OutboundPayment in a ‘failed` or `returned` state.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#to ⇒ Object
readonly
To which payout method the OutboundPayment was sent.
-
#trace_id ⇒ Object
readonly
A unique identifier that can be used to track this OutboundPayment with recipient bank.
-
#tracking_details ⇒ Object
readonly
Information to track this OutboundPayment with the recipient bank.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The “presentment amount” for the OutboundPayment.
278 279 280 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 278 def amount @amount end |
#cancelable ⇒ Object (readonly)
Returns true if the OutboundPayment can be canceled, and false otherwise.
280 281 282 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 280 def cancelable @cancelable end |
#created ⇒ Object (readonly)
Time at which the OutboundPayment was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
283 284 285 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 283 def created @created end |
#delivery_options ⇒ Object (readonly)
Delivery options to be used to send the OutboundPayment.
285 286 287 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 285 def @delivery_options end |
#description ⇒ Object (readonly)
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
287 288 289 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 287 def description @description end |
#expected_arrival_date ⇒ Object (readonly)
The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
290 291 292 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 290 def expected_arrival_date @expected_arrival_date end |
#from ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
292 293 294 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 292 def from @from end |
#id ⇒ Object (readonly)
Unique identifier for the OutboundPayment.
294 295 296 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 294 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
325 326 327 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 325 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
296 297 298 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 296 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
298 299 300 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 298 def object @object end |
#outbound_payment_quote ⇒ Object (readonly)
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
300 301 302 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 300 def outbound_payment_quote @outbound_payment_quote end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this OutboundPayment. The receipt link remains active for 60 days from the OutboundPayment creation date. After this period, the link will expire and the receipt url value will be null.
302 303 304 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 302 def receipt_url @receipt_url end |
#recipient_notification ⇒ Object (readonly)
Details about the OutboundPayment notification settings for recipient.
304 305 306 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 304 def recipient_notification @recipient_notification end |
#recipient_verification ⇒ Object (readonly)
The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.
306 307 308 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 306 def recipient_verification @recipient_verification end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.
308 309 310 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 308 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Closed Enum. Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its payout method, its status will change to `returned`.
313 314 315 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 313 def status @status end |
#status_details ⇒ Object (readonly)
Status details for an OutboundPayment in a ‘failed` or `returned` state.
315 316 317 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 315 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
317 318 319 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 317 def status_transitions @status_transitions end |
#to ⇒ Object (readonly)
To which payout method the OutboundPayment was sent.
319 320 321 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 319 def to @to end |
#trace_id ⇒ Object (readonly)
A unique identifier that can be used to track this OutboundPayment with recipient bank. Banks might call this a “reference number” or something similar.
321 322 323 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 321 def trace_id @trace_id end |
#tracking_details ⇒ Object (readonly)
Information to track this OutboundPayment with the recipient bank.
323 324 325 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 323 def tracking_details @tracking_details end |
Class Method Details
.field_remappings ⇒ Object
341 342 343 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 341 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 327 def self.inner_class_types @inner_class_types = { amount: Amount, delivery_options: DeliveryOptions, from: From, recipient_notification: RecipientNotification, status_details: StatusDetails, status_transitions: StatusTransitions, to: To, trace_id: TraceId, tracking_details: TrackingDetails, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 10 def self.object_name "v2.money_management.outbound_payment" end |