Class: Stripe::V2::MoneyManagement::OutboundPayment

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment.rb

Overview

OutboundPayment represents a single money movement from one FinancialAccount you own to a payout method someone else owns.

Defined Under Namespace

Classes: DeliveryOptions, From, RecipientNotification, StatusDetails, StatusTransitions, To, TraceId

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundPayment.



82
83
84
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 82

def amount
  @amount
end

#cancelableObject (readonly)

Returns true if the OutboundPayment can be canceled, and false otherwise.



84
85
86
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 84

def cancelable
  @cancelable
end

#createdObject (readonly)

Time at which the OutboundPayment was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



87
88
89
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 87

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



89
90
91
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 89

def delivery_options
  @delivery_options
end

#descriptionObject (readonly)

An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.



91
92
93
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 91

def description
  @description
end

#expected_arrival_dateObject (readonly)

The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



94
95
96
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 94

def expected_arrival_date
  @expected_arrival_date
end

#fromObject (readonly)

The FinancialAccount that funds were pulled from.



96
97
98
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 96

def from
  @from
end

#idObject (readonly)

Unique identifier for the OutboundPayment.



98
99
100
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 98

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



125
126
127
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 125

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



100
101
102
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 100

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



102
103
104
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 102

def object
  @object
end

#outbound_payment_quoteObject (readonly)

The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.



104
105
106
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 104

def outbound_payment_quote
  @outbound_payment_quote
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this OutboundPayment. The receipt link remains active for 60 days from the OutboundPayment creation date. After this period, the link will expire and the receipt url value will be null.



106
107
108
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 106

def receipt_url
  @receipt_url
end

#recipient_notificationObject (readonly)

Details about the OutboundPayment notification settings for recipient.



108
109
110
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 108

def recipient_notification
  @recipient_notification
end

#statement_descriptorObject (readonly)

The description that appears on the receiving end for an OutboundPayment (for example, bank statement for external bank transfer).



110
111
112
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 110

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Closed Enum. Current status of the OutboundPayment: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundPayment is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundPayment has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundPayment fails to arrive at its payout method, its status will change to `returned`.



115
116
117
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 115

def status
  @status
end

#status_detailsObject (readonly)

Status details for an OutboundPayment in a ‘failed` or `returned` state.



117
118
119
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 117

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



119
120
121
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 119

def status_transitions
  @status_transitions
end

#toObject (readonly)

To which payout method the OutboundPayment was sent.



121
122
123
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 121

def to
  @to
end

#trace_idObject (readonly)

A unique identifier that can be used to track this OutboundPayment with recipient bank. Banks might call this a “reference number” or something similar.



123
124
125
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 123

def trace_id
  @trace_id
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment"
end