Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Defined Under Namespace
Classes: DeliveryOptions, From, RecipientNotification, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The "presentment amount" to be sent to the recipient.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
An arbitrary string attached to the OutboundPayment.
-
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment.
-
#purpose ⇒ Object
The purpose of the OutboundPayment.
-
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
-
#recipient_verification ⇒ Object
The recipient verification id for this OutboundPayment.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for an OutboundPayment (for example, on a bank statement).
-
#to ⇒ Object
To which payout method to send the OutboundPayment.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, purpose: nil, recipient_notification: nil, recipient_verification: nil, statement_descriptor: nil, to: nil) ⇒ OutboundPaymentCreateParams
constructor
A new instance of OutboundPaymentCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, purpose: nil, recipient_notification: nil, recipient_verification: nil, statement_descriptor: nil, to: nil) ⇒ OutboundPaymentCreateParams
Returns a new instance of OutboundPaymentCreateParams.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 151 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, purpose: nil, recipient_notification: nil, recipient_verification: nil, statement_descriptor: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @outbound_payment_quote = outbound_payment_quote @purpose = purpose @recipient_notification = recipient_notification @recipient_verification = recipient_verification @statement_descriptor = statement_descriptor @to = to end |
Instance Attribute Details
#amount ⇒ Object
The "presentment amount" to be sent to the recipient.
129 130 131 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 129 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
131 132 133 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 131 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
133 134 135 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 133 def description @description end |
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
135 136 137 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 135 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
137 138 139 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 137 def @metadata end |
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
139 140 141 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 139 def outbound_payment_quote @outbound_payment_quote end |
#purpose ⇒ Object
The purpose of the OutboundPayment.
141 142 143 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 141 def purpose @purpose end |
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
143 144 145 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 143 def recipient_notification @recipient_notification end |
#recipient_verification ⇒ Object
The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.
145 146 147 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 145 def recipient_verification @recipient_verification end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for an OutboundPayment (for example, on a bank statement). Must be between 3 and 22 characters long for most destinations (500 for FinancialAccount destinations), and not contain profanity.
147 148 149 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 147 def statement_descriptor @statement_descriptor end |
#to ⇒ Object
To which payout method to send the OutboundPayment.
149 150 151 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 149 def to @to end |