Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_payment_create_params.rb

Defined Under Namespace

Classes: DeliveryOptions, From, RecipientNotification, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, purpose: nil, recipient_notification: nil, recipient_verification: nil, statement_descriptor: nil, to: nil) ⇒ OutboundPaymentCreateParams

Returns a new instance of OutboundPaymentCreateParams.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 102

def initialize(
  amount: nil,
  delivery_options: nil,
  description: nil,
  from: nil,
  metadata: nil,
  outbound_payment_quote: nil,
  purpose: nil,
  recipient_notification: nil,
  recipient_verification: nil,
  statement_descriptor: nil,
  to: nil
)
  @amount = amount
  @delivery_options = delivery_options
  @description = description
  @from = from
  @metadata = 
  @outbound_payment_quote = outbound_payment_quote
  @purpose = purpose
  @recipient_notification = recipient_notification
  @recipient_verification = recipient_verification
  @statement_descriptor = statement_descriptor
  @to = to
end

Instance Attribute Details

#amountObject

The “presentment amount” to be sent to the recipient.



80
81
82
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 80

def amount
  @amount
end

#delivery_optionsObject

Delivery options to be used to send the OutboundPayment.



82
83
84
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 82

def delivery_options
  @delivery_options
end

#descriptionObject

An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.



84
85
86
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 84

def description
  @description
end

#fromObject

From which FinancialAccount and BalanceType to pull funds from.



86
87
88
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 86

def from
  @from
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



88
89
90
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 88

def 
  @metadata
end

#outbound_payment_quoteObject

The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.



90
91
92
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 90

def outbound_payment_quote
  @outbound_payment_quote
end

#purposeObject

The purpose of the OutboundPayment.



92
93
94
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 92

def purpose
  @purpose
end

#recipient_notificationObject

Details about the notification settings for the OutboundPayment recipient.



94
95
96
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 94

def recipient_notification
  @recipient_notification
end

#recipient_verificationObject

The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.



96
97
98
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 96

def recipient_verification
  @recipient_verification
end

#statement_descriptorObject

The description that appears on the receiving end for an OutboundPayment (for example, on a bank statement). Must be between 3 and 22 characters long for most destinations (500 for FinancialAccount destinations), and not contain profanity.



98
99
100
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 98

def statement_descriptor
  @statement_descriptor
end

#toObject

To which payout method to send the OutboundPayment.



100
101
102
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 100

def to
  @to
end