Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_payment_create_params.rb

Defined Under Namespace

Classes: DeliveryOptions, From, RecipientNotification, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, purpose: nil, recipient_notification: nil, to: nil) ⇒ OutboundPaymentCreateParams

Returns a new instance of OutboundPaymentCreateParams.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 78

def initialize(
  amount: nil,
  delivery_options: nil,
  description: nil,
  from: nil,
  metadata: nil,
  outbound_payment_quote: nil,
  purpose: nil,
  recipient_notification: nil,
  to: nil
)
  @amount = amount
  @delivery_options = delivery_options
  @description = description
  @from = from
  @metadata = 
  @outbound_payment_quote = outbound_payment_quote
  @purpose = purpose
  @recipient_notification = recipient_notification
  @to = to
end

Instance Attribute Details

#amountObject

The “presentment amount” to be sent to the recipient.



60
61
62
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 60

def amount
  @amount
end

#delivery_optionsObject

Delivery options to be used to send the OutboundPayment.



62
63
64
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 62

def delivery_options
  @delivery_options
end

#descriptionObject

An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.



64
65
66
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 64

def description
  @description
end

#fromObject

From which FinancialAccount and BalanceType to pull funds from.



66
67
68
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 66

def from
  @from
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



68
69
70
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 68

def 
  @metadata
end

#outbound_payment_quoteObject

The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.



70
71
72
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 70

def outbound_payment_quote
  @outbound_payment_quote
end

#purposeObject

The purpose of the OutboundPayment.



72
73
74
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 72

def purpose
  @purpose
end

#recipient_notificationObject

Details about the notification settings for the OutboundPayment recipient.



74
75
76
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 74

def recipient_notification
  @recipient_notification
end

#toObject

To which payout method to send the OutboundPayment.



76
77
78
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 76

def to
  @to
end