Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Defined Under Namespace
Classes: Amount, DeliveryOptions, From, RecipientNotification, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
An arbitrary string attached to the OutboundPayment.
-
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment.
-
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
-
#recipient_verification ⇒ Object
The recipient verification id for this OutboundPayment.
-
#to ⇒ Object
To which payout method to send the OutboundPayment.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, recipient_verification: nil, to: nil) ⇒ OutboundPaymentCreateParams
constructor
A new instance of OutboundPaymentCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, recipient_verification: nil, to: nil) ⇒ OutboundPaymentCreateParams
Returns a new instance of OutboundPaymentCreateParams.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 110 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, recipient_verification: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @outbound_payment_quote = outbound_payment_quote @recipient_notification = recipient_notification @recipient_verification = recipient_verification @to = to end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
92 93 94 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 92 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
94 95 96 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 94 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
96 97 98 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 96 def description @description end |
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
98 99 100 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 98 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
100 101 102 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 100 def @metadata end |
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
102 103 104 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 102 def outbound_payment_quote @outbound_payment_quote end |
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
104 105 106 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 104 def recipient_notification @recipient_notification end |
#recipient_verification ⇒ Object
The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.
106 107 108 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 106 def recipient_verification @recipient_verification end |
#to ⇒ Object
To which payout method to send the OutboundPayment.
108 109 110 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 108 def to @to end |