Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Defined Under Namespace
Classes: Amount, DeliveryOptions, From, RecipientNotification, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
An arbitrary string attached to the OutboundPayment.
-
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment.
-
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
-
#recipient_verification ⇒ Object
The recipient verification id for this OutboundPayment.
-
#to ⇒ Object
To which payout method to send the OutboundPayment.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, recipient_verification: nil, to: nil) ⇒ OutboundPaymentCreateParams
constructor
A new instance of OutboundPaymentCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, recipient_verification: nil, to: nil) ⇒ OutboundPaymentCreateParams
Returns a new instance of OutboundPaymentCreateParams.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 93 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, recipient_verification: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @outbound_payment_quote = outbound_payment_quote @recipient_notification = recipient_notification @recipient_verification = recipient_verification @to = to end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
75 76 77 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 75 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
77 78 79 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 77 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
79 80 81 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 79 def description @description end |
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
81 82 83 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 81 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
83 84 85 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 83 def @metadata end |
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
85 86 87 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 85 def outbound_payment_quote @outbound_payment_quote end |
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
87 88 89 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 87 def recipient_notification @recipient_notification end |
#recipient_verification ⇒ Object
The recipient verification id for this OutboundPayment. Only required for countries with regulatory mandates to verify recipient names before OutboundPayment creation.
89 90 91 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 89 def recipient_verification @recipient_verification end |
#to ⇒ Object
To which payout method to send the OutboundPayment.
91 92 93 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 91 def to @to end |