Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::DeliveryOptions::PaperCheck
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::DeliveryOptions::PaperCheck
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Instance Attribute Summary collapse
-
#memo ⇒ Object
Memo printed on the memo field of the check.
-
#shipping_speed ⇒ Object
Open Enum.
-
#signature ⇒ Object
Signature for the paper check.
Instance Method Summary collapse
-
#initialize(memo: nil, shipping_speed: nil, signature: nil) ⇒ PaperCheck
constructor
A new instance of PaperCheck.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(memo: nil, shipping_speed: nil, signature: nil) ⇒ PaperCheck
Returns a new instance of PaperCheck.
17 18 19 20 21 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 17 def initialize(memo: nil, shipping_speed: nil, signature: nil) @memo = memo @shipping_speed = shipping_speed @signature = signature end |
Instance Attribute Details
#memo ⇒ Object
Memo printed on the memo field of the check.
11 12 13 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 11 def memo @memo end |
#shipping_speed ⇒ Object
Open Enum. Shipping speed of the paper check. Defaults to standard.
13 14 15 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 13 def shipping_speed @shipping_speed end |
#signature ⇒ Object
Signature for the paper check.
15 16 17 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 15 def signature @signature end |