Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::DeliveryOptions::PaperCheck
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::DeliveryOptions::PaperCheck
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Instance Attribute Summary collapse
-
#memo ⇒ Object
Memo printed on the memo field of the check.
-
#shipping_speed ⇒ Object
Open Enum.
-
#signature ⇒ Object
Signature for the paper check.
Instance Method Summary collapse
-
#initialize(memo: nil, shipping_speed: nil, signature: nil) ⇒ PaperCheck
constructor
A new instance of PaperCheck.
Methods inherited from RequestParams
Constructor Details
#initialize(memo: nil, shipping_speed: nil, signature: nil) ⇒ PaperCheck
Returns a new instance of PaperCheck.
29 30 31 32 33 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 29 def initialize(memo: nil, shipping_speed: nil, signature: nil) @memo = memo @shipping_speed = shipping_speed @signature = signature end |
Instance Attribute Details
#memo ⇒ Object
Memo printed on the memo field of the check.
23 24 25 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 23 def memo @memo end |
#shipping_speed ⇒ Object
Open Enum. Shipping speed of the paper check. Defaults to standard.
25 26 27 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 25 def shipping_speed @shipping_speed end |
#signature ⇒ Object
Signature for the paper check.
27 28 29 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 27 def signature @signature end |