Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::To
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::To
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Defined Under Namespace
Classes: PayoutMethodOptions
Instance Attribute Summary collapse
-
#currency ⇒ Object
Describes the currency to send to the recipient.
-
#payout_method ⇒ Object
The payout method which the OutboundPayment uses to send payout.
-
#payout_method_options ⇒ Object
Payout method options for the OutboundPayment.
-
#recipient ⇒ Object
To which account the OutboundPayment is sent.
Instance Method Summary collapse
-
#initialize(currency: nil, payout_method: nil, payout_method_options: nil, recipient: nil) ⇒ To
constructor
A new instance of To.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, payout_method: nil, payout_method_options: nil, recipient: nil) ⇒ To
Returns a new instance of To.
116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 116 def initialize( currency: nil, payout_method: nil, payout_method_options: nil, recipient: nil ) @currency = currency @payout_method = payout_method @payout_method_options = @recipient = recipient end |
Instance Attribute Details
#currency ⇒ Object
Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:
- destination only supports one currency
- destination supports multiple currencies and one of the currencies matches the FA currency
- destination supports multiple currencies and one of the currencies matches the presentment currency Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.
108 109 110 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 108 def currency @currency end |
#payout_method ⇒ Object
The payout method which the OutboundPayment uses to send payout.
110 111 112 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 110 def payout_method @payout_method end |
#payout_method_options ⇒ Object
Payout method options for the OutboundPayment.
112 113 114 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 112 def @payout_method_options end |
#recipient ⇒ Object
To which account the OutboundPayment is sent.
114 115 116 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 114 def recipient @recipient end |