Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::To

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_payment_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(currency: nil, payout_method: nil, recipient: nil) ⇒ To

Returns a new instance of To.



73
74
75
76
77
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 73

def initialize(currency: nil, payout_method: nil, recipient: nil)
  @currency = currency
  @payout_method = payout_method
  @recipient = recipient
end

Instance Attribute Details

#currencyObject

Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:

  • destination only supports one currency

  • destination supports multiple currencies and one of the currencies matches the FA currency

  • destination supports multiple currencies and one of the currencies matches the presentment currency

Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.



67
68
69
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 67

def currency
  @currency
end

#payout_methodObject

The payout method which the OutboundPayment uses to send payout.



69
70
71
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 69

def payout_method
  @payout_method
end

#recipientObject

To which account the OutboundPayment is sent.



71
72
73
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 71

def recipient
  @recipient
end