Class: Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::To
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentCreateParams::To
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_create_params.rb
Instance Attribute Summary collapse
-
#currency ⇒ Object
Describes the currency to send to the recipient.
-
#payout_method ⇒ Object
The payout method which the OutboundPayment uses to send payout.
-
#recipient ⇒ Object
To which account the OutboundPayment is sent.
Instance Method Summary collapse
-
#initialize(currency: nil, payout_method: nil, recipient: nil) ⇒ To
constructor
A new instance of To.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, payout_method: nil, recipient: nil) ⇒ To
Returns a new instance of To.
85 86 87 88 89 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 85 def initialize(currency: nil, payout_method: nil, recipient: nil) @currency = currency @payout_method = payout_method @recipient = recipient end |
Instance Attribute Details
#currency ⇒ Object
Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:
-
destination only supports one currency
-
destination supports multiple currencies and one of the currencies matches the FA currency
-
destination supports multiple currencies and one of the currencies matches the presentment currency
Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.
79 80 81 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 79 def currency @currency end |
#payout_method ⇒ Object
The payout method which the OutboundPayment uses to send payout.
81 82 83 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 81 def payout_method @payout_method end |
#recipient ⇒ Object
To which account the OutboundPayment is sent.
83 84 85 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_create_params.rb', line 83 def recipient @recipient end |