Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment_quote.rb

Overview

OutboundPaymentQuote represents a quote that provides fee and amount estimates for OutboundPayment.

Defined Under Namespace

Classes: DeliveryOptions, EstimatedFee, From, FxQuote, To

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment_quote"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundPaymentQuote.



107
108
109
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 107

def amount
  @amount
end

#createdObject (readonly)

Time at which the OutboundPaymentQuote was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



110
111
112
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 110

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



112
113
114
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 112

def delivery_options
  @delivery_options
end

#estimated_feesObject (readonly)

The estimated fees for the OutboundPaymentQuote.



114
115
116
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 114

def estimated_fees
  @estimated_fees
end

#fromObject (readonly)

Details about the sender of an OutboundPaymentQuote.



116
117
118
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 116

def from
  @from
end

#fx_quoteObject (readonly)

The underlying FXQuote details for the OutboundPaymentQuote.



118
119
120
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 118

def fx_quote
  @fx_quote
end

#idObject (readonly)

Unique identifier for the OutboundPaymentQuote.



120
121
122
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 120

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



122
123
124
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 122

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



124
125
126
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 124

def object
  @object
end

#toObject (readonly)

Details about the recipient of an OutboundPaymentQuote.



126
127
128
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 126

def to
  @to
end

Class Method Details

.field_remappingsObject



138
139
140
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 138

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



128
129
130
131
132
133
134
135
136
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 128

def self.inner_class_types
  @inner_class_types = {
    delivery_options: DeliveryOptions,
    estimated_fees: EstimatedFee,
    from: From,
    fx_quote: FxQuote,
    to: To,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment_quote"
end