Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::OutboundPaymentQuote
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment_quote.rb
Overview
OutboundPaymentQuote represents a quote that provides fee and amount estimates for OutboundPayment.
Defined Under Namespace
Classes: DeliveryOptions, EstimatedFee, From, FxQuote, To
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.outbound_payment_quote"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The “presentment amount” for the OutboundPaymentQuote.
-
#created ⇒ Object
readonly
Time at which the OutboundPaymentQuote was created.
-
#delivery_options ⇒ Object
readonly
Delivery options to be used to send the OutboundPayment.
-
#estimated_fees ⇒ Object
readonly
The estimated fees for the OutboundPaymentQuote.
-
#from ⇒ Object
readonly
Details about the sender of an OutboundPaymentQuote.
-
#fx_quote ⇒ Object
readonly
The underlying FXQuote details for the OutboundPaymentQuote.
-
#id ⇒ Object
readonly
Unique identifier for the OutboundPaymentQuote.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#to ⇒ Object
readonly
Details about the recipient of an OutboundPaymentQuote.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The “presentment amount” for the OutboundPaymentQuote.
107 108 109 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 107 def amount @amount end |
#created ⇒ Object (readonly)
Time at which the OutboundPaymentQuote was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
110 111 112 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 110 def created @created end |
#delivery_options ⇒ Object (readonly)
Delivery options to be used to send the OutboundPayment.
112 113 114 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 112 def @delivery_options end |
#estimated_fees ⇒ Object (readonly)
The estimated fees for the OutboundPaymentQuote.
114 115 116 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 114 def estimated_fees @estimated_fees end |
#from ⇒ Object (readonly)
Details about the sender of an OutboundPaymentQuote.
116 117 118 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 116 def from @from end |
#fx_quote ⇒ Object (readonly)
The underlying FXQuote details for the OutboundPaymentQuote.
118 119 120 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 118 def fx_quote @fx_quote end |
#id ⇒ Object (readonly)
Unique identifier for the OutboundPaymentQuote.
120 121 122 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 120 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
122 123 124 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 122 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
124 125 126 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 124 def object @object end |
#to ⇒ Object (readonly)
Details about the recipient of an OutboundPaymentQuote.
126 127 128 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 126 def to @to end |
Class Method Details
.field_remappings ⇒ Object
138 139 140 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 138 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
128 129 130 131 132 133 134 135 136 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 128 def self.inner_class_types @inner_class_types = { delivery_options: DeliveryOptions, estimated_fees: EstimatedFee, from: From, fx_quote: FxQuote, to: To, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 10 def self.object_name "v2.money_management.outbound_payment_quote" end |