Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment_quote.rb

Overview

OutboundPaymentQuote represents a quote that provides fee and amount estimates for OutboundPayment.

Defined Under Namespace

Classes: Amount, DeliveryOptions, EstimatedFee, From, FxQuote, To

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment_quote"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundPaymentQuote.



164
165
166
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 164

def amount
  @amount
end

#createdObject (readonly)

Time at which the OutboundPaymentQuote was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



167
168
169
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 167

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



169
170
171
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 169

def delivery_options
  @delivery_options
end

#estimated_feesObject (readonly)

The estimated fees for the OutboundPaymentQuote.



171
172
173
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 171

def estimated_fees
  @estimated_fees
end

#fromObject (readonly)

Details about the sender of an OutboundPaymentQuote.



173
174
175
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 173

def from
  @from
end

#fx_quoteObject (readonly)

The underlying FXQuote details for the OutboundPaymentQuote.



175
176
177
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 175

def fx_quote
  @fx_quote
end

#idObject (readonly)

Unique identifier for the OutboundPaymentQuote.



177
178
179
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 177

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



183
184
185
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 183

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



179
180
181
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 179

def object
  @object
end

#toObject (readonly)

Details about the recipient of an OutboundPaymentQuote.



181
182
183
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 181

def to
  @to
end

Class Method Details

.field_remappingsObject



196
197
198
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 196

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



185
186
187
188
189
190
191
192
193
194
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 185

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    delivery_options: DeliveryOptions,
    estimated_fees: EstimatedFee,
    from: From,
    fx_quote: FxQuote,
    to: To,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment_quote"
end