Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment_quote.rb

Overview

OutboundPaymentQuote represents a quote

Defined Under Namespace

Classes: DeliveryOptions, EstimatedFee, From, FxQuote, To

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_payment_quote"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundPaymentQuote.



59
60
61
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 59

def amount
  @amount
end

#createdObject (readonly)

Time at which the OutboundPaymentQuote was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



62
63
64
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 62

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundPayment.



64
65
66
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 64

def delivery_options
  @delivery_options
end

#estimated_feesObject (readonly)

The estimated fees for the OutboundPaymentQuote.



66
67
68
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 66

def estimated_fees
  @estimated_fees
end

#fromObject (readonly)

Details about the sender of an OutboundPaymentQuote.



68
69
70
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 68

def from
  @from
end

#fx_quoteObject (readonly)

The underlying FXQuote details for the OutboundPaymentQuote.



70
71
72
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 70

def fx_quote
  @fx_quote
end

#idObject (readonly)

Unique identifier for the OutboundPaymentQuote.



72
73
74
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 72

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



78
79
80
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 78

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



74
75
76
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 74

def object
  @object
end

#toObject (readonly)

Details about the recipient of an OutboundPaymentQuote.



76
77
78
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 76

def to
  @to
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 10

def self.object_name
  "v2.money_management.outbound_payment_quote"
end