Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote::FxQuote

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_payment_quote.rb

Defined Under Namespace

Classes: Rates

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#lock_durationObject (readonly)

The duration the exchange rate lock remains valid from creation time. Allowed value is five_minutes or none.



116
117
118
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 116

def lock_duration
  @lock_duration
end

#lock_expires_atObject (readonly)

Time at which the rate lock will expire, measured in seconds since the Unix epoch. Null when rate locking is not supported.



118
119
120
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 118

def lock_expires_at
  @lock_expires_at
end

#lock_statusObject (readonly)

Lock status of the quote. Transitions from active to expired once past the lock_expires_at timestamp. Value can be active, expired or none.



120
121
122
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 120

def lock_status
  @lock_status
end

#ratesObject (readonly)

Key pair: from currency Value: exchange rate going from_currency -> to_currency.



122
123
124
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 122

def rates
  @rates
end

#to_currencyObject (readonly)

The currency that the transaction is exchanging to.



124
125
126
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 124

def to_currency
  @to_currency
end

Class Method Details

.field_remappingsObject



130
131
132
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 130

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



126
127
128
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 126

def self.inner_class_types
  @inner_class_types = { rates: Rates }
end