Class: Stripe::V2::MoneyManagement::OutboundPaymentQuote::FxQuote
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::OutboundPaymentQuote::FxQuote
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_payment_quote.rb
Defined Under Namespace
Classes: Rates
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#lock_duration ⇒ Object
readonly
The duration the exchange rate lock remains valid from creation time.
-
#lock_expires_at ⇒ Object
readonly
Time at which the rate lock will expire, measured in seconds since the Unix epoch.
-
#lock_status ⇒ Object
readonly
Lock status of the quote.
-
#rates ⇒ Object
readonly
Key pair: from currency Value: exchange rate going from_currency -> to_currency.
-
#to_currency ⇒ Object
readonly
The currency that the transaction is exchanging to.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#lock_duration ⇒ Object (readonly)
The duration the exchange rate lock remains valid from creation time. Allowed value is five_minutes.
39 40 41 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 39 def lock_duration @lock_duration end |
#lock_expires_at ⇒ Object (readonly)
Time at which the rate lock will expire, measured in seconds since the Unix epoch.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 41 def lock_expires_at @lock_expires_at end |
#lock_status ⇒ Object (readonly)
Lock status of the quote. Transitions from active to expired once past the lock_expires_at timestamp. Value can be active or expired.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 43 def lock_status @lock_status end |
#rates ⇒ Object (readonly)
Key pair: from currency Value: exchange rate going from_currency -> to_currency.
45 46 47 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 45 def rates @rates end |
#to_currency ⇒ Object (readonly)
The currency that the transaction is exchanging to.
47 48 49 |
# File 'lib/stripe/resources/v2/money_management/outbound_payment_quote.rb', line 47 def to_currency @to_currency end |