Class: Stripe::V2::MoneyManagement::OutboundPaymentQuoteCreateParams::To
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentQuoteCreateParams::To
- Defined in:
- lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb
Defined Under Namespace
Classes: PayoutMethodOptions
Instance Attribute Summary collapse
-
#currency ⇒ Object
Describes the currency to send to the recipient.
-
#payout_method ⇒ Object
The payout method which the OutboundPayment uses to send payout.
-
#payout_method_options ⇒ Object
Payout method options for the OutboundPaymentQuote.
-
#recipient ⇒ Object
To which account the OutboundPayment is sent.
Instance Method Summary collapse
-
#initialize(currency: nil, payout_method: nil, payout_method_options: nil, recipient: nil) ⇒ To
constructor
A new instance of To.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(currency: nil, payout_method: nil, payout_method_options: nil, recipient: nil) ⇒ To
Returns a new instance of To.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 86 def initialize( currency: nil, payout_method: nil, payout_method_options: nil, recipient: nil ) @currency = currency @payout_method = payout_method @payout_method_options = @recipient = recipient end |
Instance Attribute Details
#currency ⇒ Object
Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:
- destination only supports one currency
- destination supports multiple currencies and one of the currencies matches the FA currency
- destination supports multiple currencies and one of the currencies matches the presentment currency Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.
78 79 80 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 78 def currency @currency end |
#payout_method ⇒ Object
The payout method which the OutboundPayment uses to send payout.
80 81 82 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 80 def payout_method @payout_method end |
#payout_method_options ⇒ Object
Payout method options for the OutboundPaymentQuote.
82 83 84 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 82 def @payout_method_options end |
#recipient ⇒ Object
To which account the OutboundPayment is sent.
84 85 86 |
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 84 def recipient @recipient end |