Class: Stripe::V2::MoneyManagement::OutboundPaymentQuoteCreateParams::To

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, payout_method: nil, recipient: nil) ⇒ To

Returns a new instance of To.



58
59
60
61
62
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 58

def initialize(currency: nil, payout_method: nil, recipient: nil)
  @currency = currency
  @payout_method = payout_method
  @recipient = recipient
end

Instance Attribute Details

#currencyObject

Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:

  • destination only supports one currency

  • destination supports multiple currencies and one of the currencies matches the FA currency

  • destination supports multiple currencies and one of the currencies matches the presentment currency

Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.



52
53
54
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 52

def currency
  @currency
end

#payout_methodObject

The payout method which the OutboundPayment uses to send payout.



54
55
56
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 54

def payout_method
  @payout_method
end

#recipientObject

To which account the OutboundPayment is sent.



56
57
58
# File 'lib/stripe/params/v2/money_management/outbound_payment_quote_create_params.rb', line 56

def recipient
  @recipient
end