Class: Stripe::V2::MoneyManagement::OutboundPaymentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentService::CreateParams
- Defined in:
- lib/stripe/services/v2/money_management/outbound_payment_service.rb
Defined Under Namespace
Classes: DeliveryOptions, From, RecipientNotification, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
An arbitrary string attached to the OutboundPayment.
-
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment.
-
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
-
#to ⇒ Object
To which payout method to send the OutboundPayment.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 121 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @outbound_payment_quote = outbound_payment_quote @recipient_notification = recipient_notification @to = to end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
105 106 107 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 105 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
107 108 109 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 107 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
109 110 111 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 109 def description @description end |
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
111 112 113 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 111 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
113 114 115 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 113 def @metadata end |
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
115 116 117 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 115 def outbound_payment_quote @outbound_payment_quote end |
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
117 118 119 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 117 def recipient_notification @recipient_notification end |
#to ⇒ Object
To which payout method to send the OutboundPayment.
119 120 121 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 119 def to @to end |