Class: Stripe::V2::MoneyManagement::OutboundPaymentService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_payment_service.rb

Defined Under Namespace

Classes: DeliveryOptions, From, RecipientNotification, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 79

def initialize(
  amount: nil,
  delivery_options: nil,
  description: nil,
  from: nil,
  metadata: nil,
  outbound_payment_quote: nil,
  recipient_notification: nil,
  to: nil
)
  @amount = amount
  @delivery_options = delivery_options
  @description = description
  @from = from
  @metadata = 
  @outbound_payment_quote = outbound_payment_quote
  @recipient_notification = recipient_notification
  @to = to
end

Instance Attribute Details

#amountObject

The “presentment amount” to be sent to the recipient.



63
64
65
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 63

def amount
  @amount
end

#delivery_optionsObject

Delivery options to be used to send the OutboundPayment.



65
66
67
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 65

def delivery_options
  @delivery_options
end

#descriptionObject

An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.



67
68
69
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 67

def description
  @description
end

#fromObject

From which FinancialAccount and BalanceType to pull funds from.



69
70
71
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 69

def from
  @from
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



71
72
73
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 71

def 
  @metadata
end

#outbound_payment_quoteObject

The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.



73
74
75
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 73

def outbound_payment_quote
  @outbound_payment_quote
end

#recipient_notificationObject

Details about the notification settings for the OutboundPayment recipient.



75
76
77
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 75

def recipient_notification
  @recipient_notification
end

#toObject

To which payout method to send the OutboundPayment.



77
78
79
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 77

def to
  @to
end