Class: Stripe::V2::MoneyManagement::OutboundPaymentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentService::CreateParams
- Defined in:
- lib/stripe/services/v2/money_management/outbound_payment_service.rb
Defined Under Namespace
Classes: DeliveryOptions, From, RecipientNotification, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
-
#description ⇒ Object
An arbitrary string attached to the OutboundPayment.
-
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment.
-
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
-
#to ⇒ Object
To which payout method to send the OutboundPayment.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 80 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, outbound_payment_quote: nil, recipient_notification: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @outbound_payment_quote = outbound_payment_quote @recipient_notification = recipient_notification @to = to end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” to be sent to the recipient.
64 65 66 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 64 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundPayment.
66 67 68 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 66 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundPayment. Often useful for displaying to users.
68 69 70 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 68 def description @description end |
#from ⇒ Object
From which FinancialAccount and BalanceType to pull funds from.
70 71 72 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 70 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
72 73 74 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 72 def @metadata end |
#outbound_payment_quote ⇒ Object
The quote for this OutboundPayment. Only required for countries with regulatory mandates to display fee estimates before OutboundPayment creation.
74 75 76 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 74 def outbound_payment_quote @outbound_payment_quote end |
#recipient_notification ⇒ Object
Details about the notification settings for the OutboundPayment recipient.
76 77 78 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 76 def recipient_notification @recipient_notification end |
#to ⇒ Object
To which payout method to send the OutboundPayment.
78 79 80 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 78 def to @to end |