Class: Stripe::V2::MoneyManagement::OutboundPaymentService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundPaymentService::ListParams
- Defined in:
- lib/stripe/services/v2/money_management/outbound_payment_service.rb
Instance Attribute Summary collapse
-
#created ⇒ Object
Filter for objects created at the specified timestamp.
-
#created_gt ⇒ Object
Filter for objects created after the specified timestamp.
-
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp.
-
#created_lt ⇒ Object
Filter for objects created before the specified timestamp.
-
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp.
-
#limit ⇒ Object
The maximum number of results to return.
-
#recipient ⇒ Object
Only return OutboundPayments sent to this recipient.
-
#status ⇒ Object
Closed Enum.
Instance Method Summary collapse
-
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, recipient: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, recipient: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 124 def initialize( created: nil, created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, limit: nil, recipient: nil, status: nil ) @created = created @created_gt = created_gt @created_gte = created_gte @created_lt = created_lt @created_lte = created_lte @limit = limit @recipient = recipient @status = status end |
Instance Attribute Details
#created ⇒ Object
Filter for objects created at the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
104 105 106 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 104 def created @created end |
#created_gt ⇒ Object
Filter for objects created after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
107 108 109 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 107 def created_gt @created_gt end |
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
110 111 112 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 110 def created_gte @created_gte end |
#created_lt ⇒ Object
Filter for objects created before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
113 114 115 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 113 def created_lt @created_lt end |
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2022-09-18T13:22:00Z.
116 117 118 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 116 def created_lte @created_lte end |
#limit ⇒ Object
The maximum number of results to return.
118 119 120 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 118 def limit @limit end |
#recipient ⇒ Object
Only return OutboundPayments sent to this recipient.
120 121 122 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 120 def recipient @recipient end |
#status ⇒ Object
Closed Enum. Only return OutboundPayments with this status.
122 123 124 |
# File 'lib/stripe/services/v2/money_management/outbound_payment_service.rb', line 122 def status @status end |