Class: Stripe::V2::MoneyManagement::OutboundSetupIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::OutboundSetupIntent
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_setup_intent.rb
Overview
Use the OutboundSetupIntent API to create and setup usable payout methods.
Defined Under Namespace
Classes: NextAction
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.outbound_setup_intent"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Created timestamp.
-
#id ⇒ Object
readonly
ID of the outbound setup intent.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#next_action ⇒ Object
readonly
Specifies which actions needs to be taken next to continue setup of the credential.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payout_method ⇒ Object
readonly
Information about the payout method that’s created and linked to this outbound setup intent.
-
#status ⇒ Object
readonly
Closed Enum.
-
#usage_intent ⇒ Object
readonly
The intended money movement flow this payout method should be set up for, specified in params.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Created timestamp.
27 28 29 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 27 def created @created end |
#id ⇒ Object (readonly)
ID of the outbound setup intent.
29 30 31 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 29 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 41 def livemode @livemode end |
#next_action ⇒ Object (readonly)
Specifies which actions needs to be taken next to continue setup of the credential.
31 32 33 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 31 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
33 34 35 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 33 def object @object end |
#payout_method ⇒ Object (readonly)
Information about the payout method that’s created and linked to this outbound setup intent.
35 36 37 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 35 def payout_method @payout_method end |
#status ⇒ Object (readonly)
Closed Enum. Status of the outbound setup intent.
37 38 39 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 37 def status @status end |
#usage_intent ⇒ Object (readonly)
The intended money movement flow this payout method should be set up for, specified in params.
39 40 41 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 39 def usage_intent @usage_intent end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/outbound_setup_intent.rb', line 10 def self.object_name "v2.money_management.outbound_setup_intent" end |