Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb

Defined Under Namespace

Classes: PayoutMethodData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil) ⇒ OutboundSetupIntentCreateParams

Returns a new instance of OutboundSetupIntentCreateParams.



77
78
79
80
81
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 77

def initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil)
  @payout_method = payout_method
  @payout_method_data = payout_method_data
  @usage_intent = usage_intent
end

Instance Attribute Details

#payout_methodObject

If provided, the existing payout method resource to link to this setup intent. Any payout_method_data provided is used to update information on this linked payout method resource.



69
70
71
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 69

def payout_method
  @payout_method
end

#payout_method_dataObject

If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.



72
73
74
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 72

def payout_method_data
  @payout_method_data
end

#usage_intentObject

Specify which type of outbound money movement this credential should be set up for (payment | transfer). If not provided, defaults to payment.



75
76
77
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 75

def usage_intent
  @usage_intent
end