Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb
Defined Under Namespace
Classes: PayoutMethodData
Instance Attribute Summary collapse
-
#payout_method ⇒ Object
If provided, the existing payout method resource to link to this setup intent.
-
#payout_method_data ⇒ Object
If no payout_method provided, used to create the underlying credential that is set up for outbound money movement.
-
#usage_intent ⇒ Object
Specify which type of outbound money movement this credential should be set up for (payment | transfer).
Instance Method Summary collapse
-
#initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil) ⇒ OutboundSetupIntentCreateParams
constructor
A new instance of OutboundSetupIntentCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil) ⇒ OutboundSetupIntentCreateParams
Returns a new instance of OutboundSetupIntentCreateParams.
95 96 97 98 99 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 95 def initialize(payout_method: nil, payout_method_data: nil, usage_intent: nil) @payout_method = payout_method @payout_method_data = payout_method_data @usage_intent = usage_intent end |
Instance Attribute Details
#payout_method ⇒ Object
If provided, the existing payout method resource to link to this setup intent. Any payout_method_data provided is used to update information on this linked payout method resource.
87 88 89 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 87 def payout_method @payout_method end |
#payout_method_data ⇒ Object
If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.
90 91 92 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 90 def payout_method_data @payout_method_data end |
#usage_intent ⇒ Object
Specify which type of outbound money movement this credential should be set up for (payment | transfer). If not provided, defaults to payment.
93 94 95 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 93 def usage_intent @usage_intent end |