Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb

Defined Under Namespace

Classes: BankAccount, Card, CryptoWallet

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(type: nil, bank_account: nil, card: nil, crypto_wallet: nil) ⇒ PayoutMethodData

Returns a new instance of PayoutMethodData.



85
86
87
88
89
90
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 85

def initialize(type: nil, bank_account: nil, card: nil, crypto_wallet: nil)
  @type = type
  @bank_account = 
  @card = card
  @crypto_wallet = crypto_wallet
end

Instance Attribute Details

#bank_accountObject

The type specific details of the bank account payout method.



79
80
81
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 79

def 
  @bank_account
end

#cardObject

The type specific details of the card payout method.



81
82
83
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 81

def card
  @card
end

#crypto_walletObject

The type specific details of the crypto wallet payout method.



83
84
85
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 83

def crypto_wallet
  @crypto_wallet
end

#typeObject

Closed Enum. The type of payout method to be created.



77
78
79
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 77

def type
  @type
end