Class: Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData::CryptoWallet
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentCreateParams::PayoutMethodData::CryptoWallet
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Crypto wallet address.
-
#memo ⇒ Object
Optional field, required if network supports memos (only “stellar” currently).
-
#network ⇒ Object
Which rail we should use to make an Outbound money movement to this wallet.
Instance Method Summary collapse
-
#initialize(address: nil, memo: nil, network: nil) ⇒ CryptoWallet
constructor
A new instance of CryptoWallet.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, memo: nil, network: nil) ⇒ CryptoWallet
Returns a new instance of CryptoWallet.
63 64 65 66 67 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 63 def initialize(address: nil, memo: nil, network: nil) @address = address @memo = memo @network = network end |
Instance Attribute Details
#address ⇒ Object
Crypto wallet address.
57 58 59 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 57 def address @address end |
#memo ⇒ Object
Optional field, required if network supports memos (only “stellar” currently).
59 60 61 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 59 def memo @memo end |
#network ⇒ Object
Which rail we should use to make an Outbound money movement to this wallet.
61 62 63 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_create_params.rb', line 61 def network @network end |