Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Defined Under Namespace

Classes: PayoutMethodData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payout_method: nil, payout_method_data: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



164
165
166
167
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 164

def initialize(payout_method: nil, payout_method_data: nil)
  @payout_method = payout_method
  @payout_method_data = payout_method_data
end

Instance Attribute Details

#payout_methodObject

If provided, the existing payout method resource to link to this outbound setup intent.



159
160
161
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 159

def payout_method
  @payout_method
end

#payout_method_dataObject

If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.



162
163
164
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 162

def payout_method_data
  @payout_method_data
end