Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Defined Under Namespace

Classes: BankAccount, Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(type: nil, bank_account: nil, card: nil) ⇒ PayoutMethodData

Returns a new instance of PayoutMethodData.



154
155
156
157
158
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 154

def initialize(type: nil, bank_account: nil, card: nil)
  @type = type
  @bank_account = 
  @card = card
end

Instance Attribute Details

#bank_accountObject

The type specific details of the bank account payout method.



150
151
152
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 150

def 
  @bank_account
end

#cardObject

The type specific details of the card payout method.



152
153
154
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 152

def card
  @card
end

#typeObject

Closed Enum. The type of payout method to be created/updated.



148
149
150
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 148

def type
  @type
end