Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_number: nil, bank_account_type: nil, branch_number: nil, country: nil, routing_number: nil, swift_code: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 116

def initialize(
  account_number: nil,
  bank_account_type: nil,
  branch_number: nil,
  country: nil,
  routing_number: nil,
  swift_code: nil
)
  @account_number = 
  @bank_account_type = 
  @branch_number = branch_number
  @country = country
  @routing_number = routing_number
  @swift_code = swift_code
end

Instance Attribute Details

#account_numberObject

The account number or IBAN of the bank account.



104
105
106
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 104

def 
  @account_number
end

#bank_account_typeObject

Closed Enum. The type of the bank account (checking or savings).



106
107
108
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 106

def 
  @bank_account_type
end

#branch_numberObject

The branch number of the bank account, if present.



108
109
110
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 108

def branch_number
  @branch_number
end

#countryObject

The country code of the bank account.



110
111
112
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 110

def country
  @country
end

#routing_numberObject

The routing number of the bank account, if present.



112
113
114
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 112

def routing_number
  @routing_number
end

#swift_codeObject

The swift code of the bank account, if present.



114
115
116
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 114

def swift_code
  @swift_code
end