Class: Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentService::UpdateParams::PayoutMethodData::Card
- Defined in:
- lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb
Instance Attribute Summary collapse
-
#exp_month ⇒ Object
The expiration month of the card.
-
#exp_year ⇒ Object
The expiration year of the card.
-
#number ⇒ Object
The card number.
Instance Method Summary collapse
-
#initialize(exp_month: nil, exp_year: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(exp_month: nil, exp_year: nil, number: nil) ⇒ Card
Returns a new instance of Card.
137 138 139 140 141 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 137 def initialize(exp_month: nil, exp_year: nil, number: nil) @exp_month = exp_month @exp_year = exp_year @number = number end |
Instance Attribute Details
#exp_month ⇒ Object
The expiration month of the card.
131 132 133 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 131 def exp_month @exp_month end |
#exp_year ⇒ Object
The expiration year of the card.
133 134 135 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 133 def exp_year @exp_year end |
#number ⇒ Object
The card number. This can only be passed when creating a new credential on an outbound setup intent in the requires_payout_method state.
135 136 137 |
# File 'lib/stripe/services/v2/money_management/outbound_setup_intent_service.rb', line 135 def number @number end |