Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb
Defined Under Namespace
Classes: PayoutMethodData
Instance Attribute Summary collapse
-
#payout_method ⇒ Object
If provided, the existing payout method resource to link to this outbound setup intent.
-
#payout_method_data ⇒ Object
If no payout_method provided, used to create the underlying credential that is set up for outbound money movement.
Instance Method Summary collapse
-
#initialize(payout_method: nil, payout_method_data: nil) ⇒ OutboundSetupIntentUpdateParams
constructor
A new instance of OutboundSetupIntentUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payout_method: nil, payout_method_data: nil) ⇒ OutboundSetupIntentUpdateParams
Returns a new instance of OutboundSetupIntentUpdateParams.
80 81 82 83 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 80 def initialize(payout_method: nil, payout_method_data: nil) @payout_method = payout_method @payout_method_data = payout_method_data end |
Instance Attribute Details
#payout_method ⇒ Object
If provided, the existing payout method resource to link to this outbound setup intent.
75 76 77 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 75 def payout_method @payout_method end |
#payout_method_data ⇒ Object
If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.
78 79 80 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 78 def payout_method_data @payout_method_data end |