Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb

Defined Under Namespace

Classes: PayoutMethodData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payout_method: nil, payout_method_data: nil) ⇒ OutboundSetupIntentUpdateParams

Returns a new instance of OutboundSetupIntentUpdateParams.



73
74
75
76
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 73

def initialize(payout_method: nil, payout_method_data: nil)
  @payout_method = payout_method
  @payout_method_data = payout_method_data
end

Instance Attribute Details

#payout_methodObject

If provided, the existing payout method resource to link to this outbound setup intent.



68
69
70
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 68

def payout_method
  @payout_method
end

#payout_method_dataObject

If no payout_method provided, used to create the underlying credential that is set up for outbound money movement. If a payout_method provided, used to update data on the credential linked to this setup intent.



71
72
73
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 71

def payout_method_data
  @payout_method_data
end