Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb

Defined Under Namespace

Classes: BankAccount, Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(type: nil, bank_account: nil, card: nil) ⇒ PayoutMethodData

Returns a new instance of PayoutMethodData.



61
62
63
64
65
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 61

def initialize(type: nil, bank_account: nil, card: nil)
  @type = type
  @bank_account = 
  @card = card
end

Instance Attribute Details

#bank_accountObject

The type specific details of the bank account payout method.



57
58
59
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 57

def 
  @bank_account
end

#cardObject

The type specific details of the card payout method.



59
60
61
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 59

def card
  @card
end

#typeObject

Closed Enum. The type of payout method to be created/updated.



55
56
57
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 55

def type
  @type
end