Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(exp_month: nil, exp_year: nil, number: nil) ⇒ Card

Returns a new instance of Card.



48
49
50
51
52
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 48

def initialize(exp_month: nil, exp_year: nil, number: nil)
  @exp_month = exp_month
  @exp_year = exp_year
  @number = number
end

Instance Attribute Details

#exp_monthObject

The expiration month of the card.



42
43
44
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 42

def exp_month
  @exp_month
end

#exp_yearObject

The expiration year of the card.



44
45
46
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 44

def exp_year
  @exp_year
end

#numberObject

The card number. This can only be passed when creating a new credential on an outbound setup intent in the requires_payout_method state.



46
47
48
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 46

def number
  @number
end