Class: Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundSetupIntentUpdateParams::PayoutMethodData::Card
- Defined in:
- lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb
Instance Attribute Summary collapse
-
#exp_month ⇒ Object
The expiration month of the card.
-
#exp_year ⇒ Object
The expiration year of the card.
-
#number ⇒ Object
The card number.
Instance Method Summary collapse
-
#initialize(exp_month: nil, exp_year: nil, number: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
Constructor Details
#initialize(exp_month: nil, exp_year: nil, number: nil) ⇒ Card
Returns a new instance of Card.
48 49 50 51 52 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 48 def initialize(exp_month: nil, exp_year: nil, number: nil) @exp_month = exp_month @exp_year = exp_year @number = number end |
Instance Attribute Details
#exp_month ⇒ Object
The expiration month of the card.
42 43 44 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 42 def exp_month @exp_month end |
#exp_year ⇒ Object
The expiration year of the card.
44 45 46 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 44 def exp_year @exp_year end |
#number ⇒ Object
The card number. This can only be passed when creating a new credential on an outbound setup intent in the requires_payout_method state.
46 47 48 |
# File 'lib/stripe/params/v2/money_management/outbound_setup_intent_update_params.rb', line 46 def number @number end |