Class: Stripe::V2::MoneyManagement::OutboundTransfer

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_transfer.rb

Overview

OutboundTransfer represents a single money movement from one FinancialAccount you own to a payout method you also own.

Defined Under Namespace

Classes: DeliveryOptions, From, StatusDetails, StatusTransitions, To, TraceId

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_transfer"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundTransfer.



138
139
140
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 138

def amount
  @amount
end

#cancelableObject (readonly)

Returns true if the OutboundTransfer can be canceled, and false otherwise.



140
141
142
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 140

def cancelable
  @cancelable
end

#createdObject (readonly)

Time at which the OutboundTransfer was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



143
144
145
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 143

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundTransfer.



145
146
147
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 145

def delivery_options
  @delivery_options
end

#descriptionObject (readonly)

An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.



147
148
149
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 147

def description
  @description
end

#expected_arrival_dateObject (readonly)

The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



150
151
152
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 150

def expected_arrival_date
  @expected_arrival_date
end

#fromObject (readonly)

The FinancialAccount that funds were pulled from.



152
153
154
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 152

def from
  @from
end

#idObject (readonly)

Unique identifier for the OutboundTransfer.



154
155
156
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 154

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



156
157
158
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 156

def livemode
  @livemode
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



158
159
160
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 158

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



160
161
162
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 160

def object
  @object
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this OutboundTransfer. The receipt link remains active for 60 days from the OutboundTransfer creation date. After this period, the link will expire and the receipt url value will be null.



162
163
164
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 162

def receipt_url
  @receipt_url
end

#statement_descriptorObject (readonly)

The description that appears on the receiving end for an OutboundTransfer (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.



164
165
166
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 164

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Closed Enum. Current status of the OutboundTransfer: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundTransfer is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundTransfer has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundTransfer fails to arrive at its payout method, its status will change to `returned`.



169
170
171
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 169

def status
  @status
end

#status_detailsObject (readonly)

Status details for an OutboundTransfer in a ‘failed` or `returned` state.



171
172
173
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 171

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



173
174
175
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 173

def status_transitions
  @status_transitions
end

#toObject (readonly)

To which payout method the OutboundTransfer was sent.



175
176
177
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 175

def to
  @to
end

#trace_idObject (readonly)

A unique identifier that can be used to track this OutboundTransfer with recipient bank. Banks might call this a “reference number” or something similar.



177
178
179
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 177

def trace_id
  @trace_id
end

Class Method Details

.field_remappingsObject



190
191
192
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 190

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



179
180
181
182
183
184
185
186
187
188
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 179

def self.inner_class_types
  @inner_class_types = {
    delivery_options: DeliveryOptions,
    from: From,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    to: To,
    trace_id: TraceId,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 10

def self.object_name
  "v2.money_management.outbound_transfer"
end