Class: Stripe::V2::MoneyManagement::OutboundTransfer
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::OutboundTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_transfer.rb
Overview
OutboundTransfer represents a single money movement from one FinancialAccount you own to a payout method you also own.
Defined Under Namespace
Classes: Amount, DeliveryOptions, From, StatusDetails, StatusTransitions, To, TraceId
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.outbound_transfer"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The “presentment amount” for the OutboundTransfer.
-
#cancelable ⇒ Object
readonly
Returns true if the OutboundTransfer can be canceled, and false otherwise.
-
#created ⇒ Object
readonly
Time at which the OutboundTransfer was created.
-
#delivery_options ⇒ Object
readonly
Delivery options to be used to send the OutboundTransfer.
-
#description ⇒ Object
readonly
An arbitrary string attached to the OutboundTransfer.
-
#expected_arrival_date ⇒ Object
readonly
The date when funds are expected to arrive in the payout method.
-
#from ⇒ Object
readonly
The FinancialAccount that funds were pulled from.
-
#id ⇒ Object
readonly
Unique identifier for the OutboundTransfer.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this OutboundTransfer.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for an OutboundTransfer (for example, bank statement for external bank transfer).
-
#status ⇒ Object
readonly
Closed Enum.
-
#status_details ⇒ Object
readonly
Status details for an OutboundTransfer in a ‘failed` or `returned` state.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#to ⇒ Object
readonly
To which payout method the OutboundTransfer was sent.
-
#trace_id ⇒ Object
readonly
A unique identifier that can be used to track this OutboundTransfer with recipient bank.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The “presentment amount” for the OutboundTransfer.
181 182 183 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 181 def amount @amount end |
#cancelable ⇒ Object (readonly)
Returns true if the OutboundTransfer can be canceled, and false otherwise.
183 184 185 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 183 def cancelable @cancelable end |
#created ⇒ Object (readonly)
Time at which the OutboundTransfer was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
186 187 188 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 186 def created @created end |
#delivery_options ⇒ Object (readonly)
Delivery options to be used to send the OutboundTransfer.
188 189 190 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 188 def @delivery_options end |
#description ⇒ Object (readonly)
An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.
190 191 192 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 190 def description @description end |
#expected_arrival_date ⇒ Object (readonly)
The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
193 194 195 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 193 def expected_arrival_date @expected_arrival_date end |
#from ⇒ Object (readonly)
The FinancialAccount that funds were pulled from.
195 196 197 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 195 def from @from end |
#id ⇒ Object (readonly)
Unique identifier for the OutboundTransfer.
197 198 199 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 197 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
220 221 222 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 220 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
199 200 201 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 199 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
201 202 203 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 201 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this OutboundTransfer. The receipt link remains active for 60 days from the OutboundTransfer creation date. After this period, the link will expire and the receipt url value will be null.
203 204 205 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 203 def receipt_url @receipt_url end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for an OutboundTransfer (for example, bank statement for external bank transfer). It will default to ‘STRIPE` if not set on the account settings.
205 206 207 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 205 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Closed Enum. Current status of the OutboundTransfer: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundTransfer is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundTransfer has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundTransfer fails to arrive at its payout method, its status will change to `returned`.
210 211 212 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 210 def status @status end |
#status_details ⇒ Object (readonly)
Status details for an OutboundTransfer in a ‘failed` or `returned` state.
212 213 214 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 212 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
214 215 216 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 214 def status_transitions @status_transitions end |
#to ⇒ Object (readonly)
To which payout method the OutboundTransfer was sent.
216 217 218 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 216 def to @to end |
#trace_id ⇒ Object (readonly)
A unique identifier that can be used to track this OutboundTransfer with recipient bank. Banks might call this a “reference number” or something similar.
218 219 220 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 218 def trace_id @trace_id end |
Class Method Details
.field_remappings ⇒ Object
234 235 236 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 234 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 222 def self.inner_class_types @inner_class_types = { amount: Amount, delivery_options: DeliveryOptions, from: From, status_details: StatusDetails, status_transitions: StatusTransitions, to: To, trace_id: TraceId, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 10 def self.object_name "v2.money_management.outbound_transfer" end |