Class: Stripe::V2::MoneyManagement::OutboundTransfer

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/outbound_transfer.rb

Overview

OutboundTransfer represents a single money movement from one FinancialAccount you own to a payout method you also own.

Defined Under Namespace

Classes: DeliveryOptions, From, StatusDetails, StatusTransitions, To, TraceId

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.outbound_transfer"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The “presentment amount” for the OutboundTransfer.



74
75
76
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 74

def amount
  @amount
end

#cancelableObject (readonly)

Returns true if the OutboundTransfer can be canceled, and false otherwise.



76
77
78
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 76

def cancelable
  @cancelable
end

#createdObject (readonly)

Time at which the OutboundTransfer was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



79
80
81
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 79

def created
  @created
end

#delivery_optionsObject (readonly)

Delivery options to be used to send the OutboundTransfer.



81
82
83
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 81

def delivery_options
  @delivery_options
end

#descriptionObject (readonly)

An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.



83
84
85
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 83

def description
  @description
end

#expected_arrival_dateObject (readonly)

The date when funds are expected to arrive in the payout method. This field is not set if the payout method is in a ‘failed`, `canceled`, or `returned` state. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



86
87
88
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 86

def expected_arrival_date
  @expected_arrival_date
end

#fromObject (readonly)

The FinancialAccount that funds were pulled from.



88
89
90
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 88

def from
  @from
end

#idObject (readonly)

Unique identifier for the OutboundTransfer.



90
91
92
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 90

def id
  @id
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



92
93
94
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 92

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



94
95
96
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 94

def object
  @object
end

#receipt_urlObject (readonly)

A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.



96
97
98
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 96

def receipt_url
  @receipt_url
end

#statement_descriptorObject (readonly)

The description that appears on the receiving end for an OutboundTransfer (for example, bank statement for external bank transfer).



98
99
100
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 98

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

Closed Enum. Current status of the OutboundTransfer: ‘processing`, `failed`, `posted`, `returned`, `canceled`. An OutboundTransfer is `processing` if it has been created and is processing. The status changes to `posted` once the OutboundTransfer has been “confirmed” and funds have left the account, or to `failed` or `canceled`. If an OutboundTransfer fails to arrive at its payout method, its status will change to `returned`.



103
104
105
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 103

def status
  @status
end

#status_detailsObject (readonly)

Status details for an OutboundTransfer in a ‘failed` or `returned` state.



105
106
107
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 105

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



107
108
109
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 107

def status_transitions
  @status_transitions
end

#toObject (readonly)

To which payout method the OutboundTransfer was sent.



109
110
111
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 109

def to
  @to
end

#trace_idObject (readonly)

A unique identifier that can be used to track this OutboundTransfer with recipient bank. Banks might call this a “reference number” or something similar.



111
112
113
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 111

def trace_id
  @trace_id
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 10

def self.object_name
  "v2.money_management.outbound_transfer"
end