Class: Stripe::V2::MoneyManagement::OutboundTransfer::TraceId
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::OutboundTransfer::TraceId
- Defined in:
- lib/stripe/resources/v2/money_management/outbound_transfer.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#status ⇒ Object
readonly
Possible values are
pending,supported, andunsupported. -
#value ⇒ Object
readonly
The trace ID value if
trace_id.statusissupported, otherwise empty.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#status ⇒ Object (readonly)
Possible values are pending, supported, and unsupported. Initially set to pending, it changes to
supported when the recipient bank provides a trace ID, or unsupported if the recipient bank doesn't support it.
Note that this status may not align with the OutboundPayment or OutboundTransfer status and can remain pending
even after the payment or transfer is posted.
166 167 168 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 166 def status @status end |
#value ⇒ Object (readonly)
The trace ID value if trace_id.status is supported, otherwise empty.
168 169 170 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 168 def value @value end |
Class Method Details
.field_remappings ⇒ Object
174 175 176 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 174 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
170 171 172 |
# File 'lib/stripe/resources/v2/money_management/outbound_transfer.rb', line 170 def self.inner_class_types @inner_class_types = {} end |