Class: Stripe::V2::MoneyManagement::OutboundTransferCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundTransferCreateParams
- Defined in:
- lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb
Defined Under Namespace
Classes: DeliveryOptions, From, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” for the OutboundPayment.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundTransfer.
-
#description ⇒ Object
An arbitrary string attached to the OutboundTransfer.
-
#from ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#to ⇒ Object
To which payout method to send the OutboundTransfer.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil) ⇒ OutboundTransferCreateParams
constructor
A new instance of OutboundTransferCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil) ⇒ OutboundTransferCreateParams
Returns a new instance of OutboundTransferCreateParams.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 59 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @to = to end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” for the OutboundPayment.
47 48 49 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 47 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundTransfer.
49 50 51 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 49 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.
51 52 53 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 51 def description @description end |
#from ⇒ Object
The FinancialAccount to pull funds from.
53 54 55 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 53 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
55 56 57 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 55 def @metadata end |
#to ⇒ Object
To which payout method to send the OutboundTransfer.
57 58 59 |
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 57 def to @to end |