Class: Stripe::V2::MoneyManagement::OutboundTransferCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb

Defined Under Namespace

Classes: Amount, DeliveryOptions, From, To

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, recipient_verification: nil, to: nil) ⇒ OutboundTransferCreateParams

Returns a new instance of OutboundTransferCreateParams.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 73

def initialize(
  amount: nil,
  delivery_options: nil,
  description: nil,
  from: nil,
  metadata: nil,
  recipient_verification: nil,
  to: nil
)
  @amount = amount
  @delivery_options = delivery_options
  @description = description
  @from = from
  @metadata = 
  @recipient_verification = recipient_verification
  @to = to
end

Instance Attribute Details

#amountObject

The “presentment amount” for the OutboundPayment.



59
60
61
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 59

def amount
  @amount
end

#delivery_optionsObject

Delivery options to be used to send the OutboundTransfer.



61
62
63
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 61

def delivery_options
  @delivery_options
end

#descriptionObject

An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.



63
64
65
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 63

def description
  @description
end

#fromObject

The FinancialAccount to pull funds from.



65
66
67
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 65

def from
  @from
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



67
68
69
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 67

def 
  @metadata
end

#recipient_verificationObject

The recipient verification id for this OutboundTransfer. Only required for countries with regulatory mandates to verify recipient names before OutboundTransfer creation.



69
70
71
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 69

def recipient_verification
  @recipient_verification
end

#toObject

To which payout method to send the OutboundTransfer.



71
72
73
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 71

def to
  @to
end