Class: Stripe::V2::MoneyManagement::OutboundTransferCreateParams::To

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(currency: nil, payout_method: nil) ⇒ To

Returns a new instance of To.



41
42
43
44
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 41

def initialize(currency: nil, payout_method: nil)
  @currency = currency
  @payout_method = payout_method
end

Instance Attribute Details

#currencyObject

Describes the currency to send to the recipient. If included, this currency must match a currency supported by the destination. Can be omitted in the following cases:

  • destination only supports one currency

  • destination supports multiple currencies and one of the currencies matches the FA currency

  • destination supports multiple currencies and one of the currencies matches the presentment currency

Note - when both FA currency and presentment currency are supported, we pick the FA currency to minimize FX.



37
38
39
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 37

def currency
  @currency
end

#payout_methodObject

The payout method which the OutboundTransfer uses to send payout.



39
40
41
# File 'lib/stripe/params/v2/money_management/outbound_transfer_create_params.rb', line 39

def payout_method
  @payout_method
end