Class: Stripe::V2::MoneyManagement::OutboundTransferService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::OutboundTransferService::CreateParams
- Defined in:
- lib/stripe/services/v2/money_management/outbound_transfer_service.rb
Defined Under Namespace
Classes: DeliveryOptions, From, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” for the OutboundPayment.
-
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundTransfer.
-
#description ⇒ Object
An arbitrary string attached to the OutboundTransfer.
-
#from ⇒ Object
The FinancialAccount to pull funds from.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#to ⇒ Object
To which payout method to send the OutboundTransfer.
Instance Method Summary collapse
-
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 62 def initialize( amount: nil, delivery_options: nil, description: nil, from: nil, metadata: nil, to: nil ) @amount = amount @delivery_options = @description = description @from = from @metadata = @to = to end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” for the OutboundPayment.
50 51 52 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 50 def amount @amount end |
#delivery_options ⇒ Object
Delivery options to be used to send the OutboundTransfer.
52 53 54 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 52 def @delivery_options end |
#description ⇒ Object
An arbitrary string attached to the OutboundTransfer. Often useful for displaying to users.
54 55 56 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 54 def description @description end |
#from ⇒ Object
The FinancialAccount to pull funds from.
56 57 58 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 56 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
58 59 60 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 58 def @metadata end |
#to ⇒ Object
To which payout method to send the OutboundTransfer.
60 61 62 |
# File 'lib/stripe/services/v2/money_management/outbound_transfer_service.rb', line 60 def to @to end |