Class: Stripe::V2::MoneyManagement::PayoutIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::PayoutIntent
- Defined in:
- lib/stripe/resources/v2/money_management/payout_intent.rb
Overview
PayoutIntent represents an intent to send funds from a Financial Account to a payout method.
Defined Under Namespace
Classes: EstimatedFee, From, FxQuote, LatestPayout, NextAction, RecipientNotification, ScheduleOptions, StatusTransitions, To
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.payout_intent"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The monetary amount to be sent.
-
#confirmation_method ⇒ Object
readonly
Controls whether the intent requires explicit confirmation before transitioning to pending.
-
#created ⇒ Object
readonly
Time at which the PayoutIntent was created.
-
#description ⇒ Object
readonly
An arbitrary string attached to the PayoutIntent.
-
#estimated_fees ⇒ Object
readonly
Estimated fees and taxes.
-
#from ⇒ Object
readonly
The FinancialAccount that funds are pulled from.
-
#fx_quote ⇒ Object
readonly
FX rate information for fee transparency.
-
#id ⇒ Object
readonly
Unique identifier for the PayoutIntent.
-
#latest_payout ⇒ Object
readonly
Details about the latest payout associated with this PayoutIntent.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#next_action ⇒ Object
readonly
Next action required for a PayoutIntent in the requires_action state.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#recipient_notification ⇒ Object
readonly
Details about the OutboundPayment notification settings for recipient.
-
#schedule_options ⇒ Object
readonly
Scheduling options for the payout.
-
#statement_descriptor ⇒ Object
readonly
The description that appears on the receiving end for the payout (for example, on a bank statement).
-
#status ⇒ Object
readonly
Open Enum.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when transitioned to a particular status.
-
#to ⇒ Object
readonly
To which payout method the payout is sent.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The monetary amount to be sent.
278 279 280 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 278 def amount @amount end |
#confirmation_method ⇒ Object (readonly)
Controls whether the intent requires explicit confirmation before transitioning to pending.
280 281 282 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 280 def confirmation_method @confirmation_method end |
#created ⇒ Object (readonly)
Time at which the PayoutIntent was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
283 284 285 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 283 def created @created end |
#description ⇒ Object (readonly)
An arbitrary string attached to the PayoutIntent. Often useful for displaying to users.
285 286 287 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 285 def description @description end |
#estimated_fees ⇒ Object (readonly)
Estimated fees and taxes.
287 288 289 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 287 def estimated_fees @estimated_fees end |
#from ⇒ Object (readonly)
The FinancialAccount that funds are pulled from.
289 290 291 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 289 def from @from end |
#fx_quote ⇒ Object (readonly)
FX rate information for fee transparency.
291 292 293 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 291 def fx_quote @fx_quote end |
#id ⇒ Object (readonly)
Unique identifier for the PayoutIntent.
293 294 295 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 293 def id @id end |
#latest_payout ⇒ Object (readonly)
Details about the latest payout associated with this PayoutIntent.
295 296 297 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 295 def latest_payout @latest_payout end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
297 298 299 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 297 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
299 300 301 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 299 def @metadata end |
#next_action ⇒ Object (readonly)
Next action required for a PayoutIntent in the requires_action state. Populated when status is requires_action.
301 302 303 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 301 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
303 304 305 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 303 def object @object end |
#recipient_notification ⇒ Object (readonly)
Details about the OutboundPayment notification settings for recipient. Only applicable to OutboundPayment.
305 306 307 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 305 def recipient_notification @recipient_notification end |
#schedule_options ⇒ Object (readonly)
Scheduling options for the payout. If this is nil, we assume immediate execution.
307 308 309 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 307 def @schedule_options end |
#statement_descriptor ⇒ Object (readonly)
The description that appears on the receiving end for the payout (for example, on a bank statement).
309 310 311 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 309 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Open Enum. Current status of the PayoutIntent: pending, processing, posted, canceled, requires_action.
311 312 313 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 311 def status @status end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when transitioned to a particular status.
313 314 315 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 313 def status_transitions @status_transitions end |
#to ⇒ Object (readonly)
To which payout method the payout is sent.
315 316 317 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 315 def to @to end |
Class Method Details
.field_remappings ⇒ Object
331 332 333 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 331 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 317 def self.inner_class_types @inner_class_types = { estimated_fees: EstimatedFee, from: From, fx_quote: FxQuote, latest_payout: LatestPayout, next_action: NextAction, recipient_notification: RecipientNotification, schedule_options: ScheduleOptions, status_transitions: StatusTransitions, to: To, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/payout_intent.rb', line 10 def self.object_name "v2.money_management.payout_intent" end |