Class: Stripe::V2::MoneyManagement::PayoutIntentUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::MoneyManagement::PayoutIntentUpdateParams
- Defined in:
- lib/stripe/params/v2/money_management/payout_intent_update_params.rb
Defined Under Namespace
Classes: From, RecipientNotification, ScheduleOptions, To
Instance Attribute Summary collapse
-
#amount ⇒ Object
The monetary amount to be sent.
-
#description ⇒ Object
An arbitrary string attached to the PayoutIntent.
-
#from ⇒ Object
From which FinancialAccount to pull funds.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#recipient_notification ⇒ Object
Details about the OutboundPayment notification settings for recipient.
-
#schedule_options ⇒ Object
Scheduling options for the payout.
-
#statement_descriptor ⇒ Object
The description that appears on the receiving end for the payout (for example, on a bank statement).
-
#to ⇒ Object
To which payout method the payout is sent.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, from: nil, metadata: nil, recipient_notification: nil, schedule_options: nil, statement_descriptor: nil, to: nil) ⇒ PayoutIntentUpdateParams
constructor
A new instance of PayoutIntentUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, description: nil, from: nil, metadata: nil, recipient_notification: nil, schedule_options: nil, statement_descriptor: nil, to: nil) ⇒ PayoutIntentUpdateParams
Returns a new instance of PayoutIntentUpdateParams.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 116 def initialize( amount: nil, description: nil, from: nil, metadata: nil, recipient_notification: nil, schedule_options: nil, statement_descriptor: nil, to: nil ) @amount = amount @description = description @from = from @metadata = @recipient_notification = recipient_notification @schedule_options = @statement_descriptor = statement_descriptor @to = to end |
Instance Attribute Details
#amount ⇒ Object
The monetary amount to be sent.
100 101 102 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 100 def amount @amount end |
#description ⇒ Object
An arbitrary string attached to the PayoutIntent. Often useful for displaying to users.
102 103 104 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 102 def description @description end |
#from ⇒ Object
From which FinancialAccount to pull funds.
104 105 106 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 104 def from @from end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
106 107 108 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 106 def @metadata end |
#recipient_notification ⇒ Object
Details about the OutboundPayment notification settings for recipient. Only applicable to OutboundPayment.
108 109 110 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 108 def recipient_notification @recipient_notification end |
#schedule_options ⇒ Object
Scheduling options for the payout. If this is nil, we assume immediate execution.
110 111 112 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 110 def @schedule_options end |
#statement_descriptor ⇒ Object
The description that appears on the receiving end for the payout (for example, on a bank statement).
112 113 114 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 112 def statement_descriptor @statement_descriptor end |
#to ⇒ Object
To which payout method the payout is sent.
114 115 116 |
# File 'lib/stripe/params/v2/money_management/payout_intent_update_params.rb', line 114 def to @to end |