Class: Stripe::V2::MoneyManagement::PayoutMethod
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::PayoutMethod
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Overview
Use the PayoutMethods API to list and interact with PayoutMethod objects.
Defined Under Namespace
Classes: AlternativeReference, BankAccount, Card, CryptoWallet, NetworkBusinessProfileWallet, UsageStatus
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.payout_method"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternative_reference ⇒ Object
readonly
The alternative reference for this payout method, if it's a projected payout method.
-
#available_payout_speeds ⇒ Object
readonly
A set of available payout speeds for this payout method.
-
#bank_account ⇒ Object
readonly
The PayoutMethodBankAccount object details.
-
#card ⇒ Object
readonly
The PayoutMethodCard object details.
-
#created ⇒ Object
readonly
Created timestamp.
-
#crypto_wallet ⇒ Object
readonly
The PayoutMethodCryptoWallet object details.
-
#id ⇒ Object
readonly
ID of the PayoutMethod object.
-
#latest_outbound_setup_intent ⇒ Object
readonly
ID of the underlying active OutboundSetupIntent object, if any.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#network_business_profile_wallet ⇒ Object
readonly
The PayoutMethodNetworkBusinessProfileWallet object details.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#restricted ⇒ Object
readonly
Whether the Payout Method is currently unusable for money movement, despite potentially being correctly set up.
-
#type ⇒ Object
readonly
Closed Enum.
-
#usage_status ⇒ Object
readonly
Indicates whether the payout method has met the necessary requirements for outbound money movement.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternative_reference ⇒ Object (readonly)
The alternative reference for this payout method, if it's a projected payout method.
139 140 141 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 139 def alternative_reference @alternative_reference end |
#available_payout_speeds ⇒ Object (readonly)
A set of available payout speeds for this payout method.
141 142 143 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 141 def available_payout_speeds @available_payout_speeds end |
#bank_account ⇒ Object (readonly)
The PayoutMethodBankAccount object details.
143 144 145 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 143 def bank_account @bank_account end |
#card ⇒ Object (readonly)
The PayoutMethodCard object details.
145 146 147 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 145 def card @card end |
#created ⇒ Object (readonly)
Created timestamp.
147 148 149 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 147 def created @created end |
#crypto_wallet ⇒ Object (readonly)
The PayoutMethodCryptoWallet object details.
149 150 151 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 149 def crypto_wallet @crypto_wallet end |
#id ⇒ Object (readonly)
ID of the PayoutMethod object.
151 152 153 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 151 def id @id end |
#latest_outbound_setup_intent ⇒ Object (readonly)
ID of the underlying active OutboundSetupIntent object, if any.
153 154 155 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 153 def latest_outbound_setup_intent @latest_outbound_setup_intent end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
155 156 157 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 155 def livemode @livemode end |
#network_business_profile_wallet ⇒ Object (readonly)
The PayoutMethodNetworkBusinessProfileWallet object details.
157 158 159 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 157 def network_business_profile_wallet @network_business_profile_wallet end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
159 160 161 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 159 def object @object end |
#restricted ⇒ Object (readonly)
Whether the Payout Method is currently unusable for money movement, despite potentially being correctly set up. Please reach out to Stripe Support for more information.
162 163 164 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 162 def restricted @restricted end |
#type ⇒ Object (readonly)
Closed Enum. The type of payout method.
164 165 166 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 164 def type @type end |
#usage_status ⇒ Object (readonly)
Indicates whether the payout method has met the necessary requirements for outbound money movement.
166 167 168 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 166 def usage_status @usage_status end |
Class Method Details
.field_remappings ⇒ Object
179 180 181 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 179 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 168 def self.inner_class_types @inner_class_types = { alternative_reference: AlternativeReference, bank_account: BankAccount, card: Card, crypto_wallet: CryptoWallet, network_business_profile_wallet: NetworkBusinessProfileWallet, usage_status: UsageStatus, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 10 def self.object_name "v2.money_management.payout_method" end |