Class: Stripe::V2::MoneyManagement::PayoutMethod

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/payout_method.rb

Overview

Use the PayoutMethods API to list and interact with PayoutMethod objects.

Defined Under Namespace

Classes: AlternativeReference, BankAccount, Card, CryptoWallet, UsageStatus

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.payout_method"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alternative_referenceObject (readonly)

The alternative reference for this payout method, if it’s a projected payout method.



124
125
126
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 124

def alternative_reference
  @alternative_reference
end

#available_payout_speedsObject (readonly)

A set of available payout speeds for this payout method.



126
127
128
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 126

def available_payout_speeds
  @available_payout_speeds
end

#bank_accountObject (readonly)

The PayoutMethodBankAccount object details.



142
143
144
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 142

def 
  @bank_account
end

#cardObject (readonly)

The PayoutMethodCard object details.



144
145
146
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 144

def card
  @card
end

#createdObject (readonly)

Created timestamp.



128
129
130
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 128

def created
  @created
end

#crypto_walletObject (readonly)

The PayoutMethodCryptoWallet object details.



146
147
148
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 146

def crypto_wallet
  @crypto_wallet
end

#idObject (readonly)

ID of the PayoutMethod object.



130
131
132
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 130

def id
  @id
end

#latest_outbound_setup_intentObject (readonly)

ID of the underlying active OutboundSetupIntent object, if any.



132
133
134
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 132

def latest_outbound_setup_intent
  @latest_outbound_setup_intent
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



140
141
142
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 140

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



134
135
136
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 134

def object
  @object
end

#typeObject (readonly)

Closed Enum. The type of payout method.



136
137
138
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 136

def type
  @type
end

#usage_statusObject (readonly)

Indicates whether the payout method has met the necessary requirements for outbound money movement.



138
139
140
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 138

def usage_status
  @usage_status
end

Class Method Details

.field_remappingsObject



158
159
160
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 158

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



148
149
150
151
152
153
154
155
156
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 148

def self.inner_class_types
  @inner_class_types = {
    alternative_reference: AlternativeReference,
    usage_status: UsageStatus,
    bank_account: BankAccount,
    card: Card,
    crypto_wallet: CryptoWallet,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 10

def self.object_name
  "v2.money_management.payout_method"
end