Class: Stripe::V2::MoneyManagement::PayoutMethod

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/payout_method.rb

Overview

Use the PayoutMethods API to list and interact with PayoutMethod objects.

Defined Under Namespace

Classes: BankAccount, Card, CryptoWallet, UsageStatus

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.payout_method"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#available_payout_speedsObject (readonly)

A set of available payout speeds for this payout method.



100
101
102
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 100

def available_payout_speeds
  @available_payout_speeds
end

#bank_accountObject (readonly)

The PayoutMethodBankAccount object details.



116
117
118
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 116

def 
  @bank_account
end

#cardObject (readonly)

The PayoutMethodCard object details.



118
119
120
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 118

def card
  @card
end

#createdObject (readonly)

Created timestamp.



102
103
104
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 102

def created
  @created
end

#crypto_walletObject (readonly)

The PayoutMethodCryptoWallet object details.



120
121
122
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 120

def crypto_wallet
  @crypto_wallet
end

#idObject (readonly)

ID of the PayoutMethod object.



104
105
106
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 104

def id
  @id
end

#latest_outbound_setup_intentObject (readonly)

ID of the underlying active OutboundSetupIntent object, if any.



106
107
108
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 106

def latest_outbound_setup_intent
  @latest_outbound_setup_intent
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



114
115
116
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 114

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



108
109
110
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 108

def object
  @object
end

#typeObject (readonly)

Closed Enum. The type of payout method.



110
111
112
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 110

def type
  @type
end

#usage_statusObject (readonly)

Indicates whether the payout method has met the necessary requirements for outbound money movement.



112
113
114
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 112

def usage_status
  @usage_status
end

Class Method Details

.field_remappingsObject



131
132
133
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 131

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



122
123
124
125
126
127
128
129
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 122

def self.inner_class_types
  @inner_class_types = {
    usage_status: UsageStatus,
    bank_account: BankAccount,
    card: Card,
    crypto_wallet: CryptoWallet,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 10

def self.object_name
  "v2.money_management.payout_method"
end