Class: Stripe::V2::MoneyManagement::PayoutMethod
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::PayoutMethod
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Overview
Use the PayoutMethods API to list and interact with PayoutMethod objects.
Defined Under Namespace
Classes: BankAccount, Card, UsageStatus
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.payout_method"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#available_payout_speeds ⇒ Object
readonly
A set of available payout speeds for this payout method.
-
#bank_account ⇒ Object
readonly
The PayoutMethodBankAccount object details.
-
#card ⇒ Object
readonly
The PayoutMethodCard object details.
-
#created ⇒ Object
readonly
Created timestamp.
-
#id ⇒ Object
readonly
ID of the PayoutMethod object.
-
#latest_outbound_setup_intent ⇒ Object
readonly
ID of the underlying active OutboundSetupIntent object, if any.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#type ⇒ Object
readonly
Closed Enum.
-
#usage_status ⇒ Object
readonly
Indicates whether the payout method has met the necessary requirements for outbound money movement.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#available_payout_speeds ⇒ Object (readonly)
A set of available payout speeds for this payout method.
79 80 81 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 79 def available_payout_speeds @available_payout_speeds end |
#bank_account ⇒ Object (readonly)
The PayoutMethodBankAccount object details.
95 96 97 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 95 def bank_account @bank_account end |
#card ⇒ Object (readonly)
The PayoutMethodCard object details.
97 98 99 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 97 def card @card end |
#created ⇒ Object (readonly)
Created timestamp.
81 82 83 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 81 def created @created end |
#id ⇒ Object (readonly)
ID of the PayoutMethod object.
83 84 85 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 83 def id @id end |
#latest_outbound_setup_intent ⇒ Object (readonly)
ID of the underlying active OutboundSetupIntent object, if any.
85 86 87 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 85 def latest_outbound_setup_intent @latest_outbound_setup_intent end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
93 94 95 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 93 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
87 88 89 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 87 def object @object end |
#type ⇒ Object (readonly)
Closed Enum. The type of payout method.
89 90 91 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 89 def type @type end |
#usage_status ⇒ Object (readonly)
Indicates whether the payout method has met the necessary requirements for outbound money movement.
91 92 93 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 91 def usage_status @usage_status end |
Class Method Details
.field_remappings ⇒ Object
103 104 105 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 103 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
99 100 101 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 99 def self.inner_class_types @inner_class_types = { usage_status: UsageStatus, bank_account: BankAccount, card: Card } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 10 def self.object_name "v2.money_management.payout_method" end |