Class: Stripe::V2::MoneyManagement::PayoutMethod

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/payout_method.rb

Overview

Use the PayoutMethods API to list and interact with PayoutMethod objects.

Defined Under Namespace

Classes: BankAccount, Card, UsageStatus

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.payout_method"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#available_payout_speedsObject (readonly)

A set of available payout speeds for this payout method.



53
54
55
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 53

def available_payout_speeds
  @available_payout_speeds
end

#bank_accountObject (readonly)

The PayoutMethodBankAccount object details.



69
70
71
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 69

def 
  @bank_account
end

#cardObject (readonly)

The PayoutMethodCard object details.



71
72
73
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 71

def card
  @card
end

#createdObject (readonly)

Created timestamp.



55
56
57
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 55

def created
  @created
end

#idObject (readonly)

ID of the PayoutMethod object.



57
58
59
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 57

def id
  @id
end

#latest_outbound_setup_intentObject (readonly)

ID of the underlying active OutboundSetupIntent object, if any.



59
60
61
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 59

def latest_outbound_setup_intent
  @latest_outbound_setup_intent
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



67
68
69
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 67

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



61
62
63
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 61

def object
  @object
end

#typeObject (readonly)

Closed Enum. The type of payout method.



63
64
65
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 63

def type
  @type
end

#usage_statusObject (readonly)

Indicates whether the payout method has met the necessary requirements for outbound money movement.



65
66
67
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 65

def usage_status
  @usage_status
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 10

def self.object_name
  "v2.money_management.payout_method"
end