Class: Stripe::V2::MoneyManagement::PayoutMethod::BankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutMethod::BankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#archived ⇒ Object
readonly
Whether this PayoutMethodBankAccount object was archived.
-
#bank_account_type ⇒ Object
readonly
The type of bank account (checking or savings).
-
#bank_name ⇒ Object
readonly
The name of the bank this bank account is in.
-
#country ⇒ Object
readonly
The country code of the bank account.
-
#enabled_delivery_options ⇒ Object
readonly
List of enabled flows for this bank account (wire or local).
-
#financial_connections_account ⇒ Object
readonly
The ID of the Financial Connections Account used to create the bank account.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#routing_number ⇒ Object
readonly
The routing number of the bank account, if present.
-
#supported_currencies ⇒ Object
readonly
The list of currencies supported by this bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#archived ⇒ Object (readonly)
Whether this PayoutMethodBankAccount object was archived. PayoutMethodBankAccount objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived PayoutMethodBankAccount objects cannot be used as payout methods and will not appear in the payout method list.
48 49 50 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 48 def archived @archived end |
#bank_account_type ⇒ Object (readonly)
The type of bank account (checking or savings).
50 51 52 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 50 def bank_account_type @bank_account_type end |
#bank_name ⇒ Object (readonly)
The name of the bank this bank account is in. This field is populated automatically by Stripe.
52 53 54 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 52 def bank_name @bank_name end |
#country ⇒ Object (readonly)
The country code of the bank account.
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 54 def country @country end |
#enabled_delivery_options ⇒ Object (readonly)
List of enabled flows for this bank account (wire or local).
56 57 58 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 56 def @enabled_delivery_options end |
#financial_connections_account ⇒ Object (readonly)
The ID of the Financial Connections Account used to create the bank account.
58 59 60 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 58 def financial_connections_account @financial_connections_account end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number.
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 60 def last4 @last4 end |
#routing_number ⇒ Object (readonly)
The routing number of the bank account, if present.
62 63 64 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 62 def routing_number @routing_number end |
#supported_currencies ⇒ Object (readonly)
The list of currencies supported by this bank account.
64 65 66 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 64 def supported_currencies @supported_currencies end |
Class Method Details
.field_remappings ⇒ Object
70 71 72 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 70 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
66 67 68 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 66 def self.inner_class_types @inner_class_types = {} end |