Class: Stripe::V2::MoneyManagement::PayoutMethod::BankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/payout_method.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#archivedObject (readonly)

Whether this PayoutMethodBankAccount object was archived. PayoutMethodBankAccount objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived PayoutMethodBankAccount objects cannot be used as payout methods and will not appear in the payout method list.



33
34
35
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 33

def archived
  @archived
end

#bank_account_typeObject (readonly)

The type of bank account (checking or savings).



35
36
37
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 35

def 
  @bank_account_type
end

#bank_nameObject (readonly)

The name of the bank this bank account is in. This field is populated automatically by Stripe.



37
38
39
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 37

def bank_name
  @bank_name
end

#countryObject (readonly)

The country code of the bank account.



39
40
41
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 39

def country
  @country
end

#enabled_delivery_optionsObject (readonly)

List of enabled flows for this bank account (wire or local).



41
42
43
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 41

def enabled_delivery_options
  @enabled_delivery_options
end

#last4Object (readonly)

The last 4 digits of the account number.



43
44
45
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 43

def last4
  @last4
end

#routing_numberObject (readonly)

The routing number of the bank account, if present.



45
46
47
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 45

def routing_number
  @routing_number
end

#supported_currenciesObject (readonly)

The list of currencies supported by this bank account.



47
48
49
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 47

def supported_currencies
  @supported_currencies
end

Class Method Details

.field_remappingsObject



53
54
55
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 53

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



49
50
51
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 49

def self.inner_class_types
  @inner_class_types = {}
end