Class: Stripe::V2::MoneyManagement::PayoutMethod::BankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutMethod::BankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#archived ⇒ Object
readonly
Whether this PayoutMethodBankAccount object was archived.
-
#bank_name ⇒ Object
readonly
The name of the bank this bank account is in.
-
#country ⇒ Object
readonly
The country code of the bank account.
-
#enabled_delivery_options ⇒ Object
readonly
List of enabled flows for this bank account (wire or local).
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#routing_number ⇒ Object
readonly
The routing number of the bank account, if present.
-
#supported_currencies ⇒ Object
readonly
The list of currencies supported by this bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#archived ⇒ Object (readonly)
Whether this PayoutMethodBankAccount object was archived. PayoutMethodBankAccount objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived PayoutMethodBankAccount objects cannot be used as payout methods and will not appear in the payout method list.
25 26 27 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 25 def archived @archived end |
#bank_name ⇒ Object (readonly)
The name of the bank this bank account is in. This field is populated automatically by Stripe.
27 28 29 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 27 def bank_name @bank_name end |
#country ⇒ Object (readonly)
The country code of the bank account.
29 30 31 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 29 def country @country end |
#enabled_delivery_options ⇒ Object (readonly)
List of enabled flows for this bank account (wire or local).
31 32 33 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 31 def @enabled_delivery_options end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number.
33 34 35 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 33 def last4 @last4 end |
#routing_number ⇒ Object (readonly)
The routing number of the bank account, if present.
35 36 37 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 35 def routing_number @routing_number end |
#supported_currencies ⇒ Object (readonly)
The list of currencies supported by this bank account.
37 38 39 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 37 def supported_currencies @supported_currencies end |