Class: Stripe::V2::MoneyManagement::PayoutMethod::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutMethod::Card
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#archived ⇒ Object
readonly
Whether the PayoutMethodCard object was archived.
-
#exp_month ⇒ Object
readonly
The month the card expires.
-
#exp_year ⇒ Object
readonly
The year the card expires.
-
#last4 ⇒ Object
readonly
The last 4 digits of the card number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#archived ⇒ Object (readonly)
Whether the PayoutMethodCard object was archived. PayoutMethodCard objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived PayoutMethodCard objects cannot be used as payout methods and will not appear in the payout method list.
79 80 81 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 79 def archived @archived end |
#exp_month ⇒ Object (readonly)
The month the card expires.
81 82 83 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 81 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The year the card expires.
83 84 85 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 83 def exp_year @exp_year end |
#last4 ⇒ Object (readonly)
The last 4 digits of the card number.
85 86 87 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 85 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
91 92 93 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 91 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
87 88 89 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 87 def self.inner_class_types @inner_class_types = {} end |