Class: Stripe::V2::MoneyManagement::PayoutMethod::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutMethod::Card
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#archived ⇒ Object
readonly
Whether the PayoutMethodCard object was archived.
-
#exp_month ⇒ Object
readonly
The month the card expires.
-
#exp_year ⇒ Object
readonly
The year the card expires.
-
#last4 ⇒ Object
readonly
The last 4 digits of the card number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#archived ⇒ Object (readonly)
Whether the PayoutMethodCard object was archived. PayoutMethodCard objects can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived PayoutMethodCard objects cannot be used as payout methods and will not appear in the payout method list.
62 63 64 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 62 def archived @archived end |
#exp_month ⇒ Object (readonly)
The month the card expires.
64 65 66 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 64 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The year the card expires.
66 67 68 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 66 def exp_year @exp_year end |
#last4 ⇒ Object (readonly)
The last 4 digits of the card number.
68 69 70 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 68 def last4 @last4 end |
Class Method Details
.field_remappings ⇒ Object
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 74 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
70 71 72 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 70 def self.inner_class_types @inner_class_types = {} end |