Class: Stripe::V2::MoneyManagement::PayoutMethod::CryptoWallet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::PayoutMethod::CryptoWallet
- Defined in:
- lib/stripe/resources/v2/money_management/payout_method.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Destination wallet address.
-
#archived ⇒ Object
readonly
Whether the crypto wallet was archived.
-
#memo ⇒ Object
readonly
Optional field, required if network supports memos (only “stellar” currently).
-
#network ⇒ Object
readonly
Which rail is being used to make an outbound money movement to this wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Destination wallet address.
107 108 109 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 107 def address @address end |
#archived ⇒ Object (readonly)
Whether the crypto wallet was archived. Crypto wallets can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived crypto wallets cannot be used as payout method and will not appear in the payout method list.
111 112 113 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 111 def archived @archived end |
#memo ⇒ Object (readonly)
Optional field, required if network supports memos (only “stellar” currently).
113 114 115 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 113 def memo @memo end |
#network ⇒ Object (readonly)
Which rail is being used to make an outbound money movement to this wallet.
115 116 117 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 115 def network @network end |
Class Method Details
.field_remappings ⇒ Object
121 122 123 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 121 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 117 def self.inner_class_types @inner_class_types = {} end |