Class: Stripe::V2::MoneyManagement::PayoutMethod::CryptoWallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/payout_method.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Destination wallet address.



98
99
100
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 98

def address
  @address
end

#archivedObject (readonly)

Whether the crypto wallet was archived. Crypto wallets can be archived through the /archive API, and they will not be automatically archived by Stripe. Archived crypto wallets cannot be used as payout method and will not appear in the payout method list.



102
103
104
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 102

def archived
  @archived
end

#memoObject (readonly)

Optional field, required if network supports memos (only “stellar” currently).



104
105
106
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 104

def memo
  @memo
end

#networkObject (readonly)

Which rail is being used to make an outbound money movement to this wallet.



106
107
108
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 106

def network
  @network
end

Class Method Details

.field_remappingsObject



112
113
114
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 112

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



108
109
110
# File 'lib/stripe/resources/v2/money_management/payout_method.rb', line 108

def self.inner_class_types
  @inner_class_types = {}
end