Class: Stripe::V2::MoneyManagement::PayoutMethodService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::MoneyManagement::PayoutMethodService
- Defined in:
- lib/stripe/services/v2/money_management/payout_method_service.rb
Defined Under Namespace
Classes: ArchiveParams, ListParams, RetrieveParams, UnarchiveParams
Instance Method Summary collapse
-
#archive(id, params = {}, opts = {}) ⇒ Object
Archive a PayoutMethod object.
-
#list(params = {}, opts = {}) ⇒ Object
List objects that adhere to the PayoutMethod interface.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a PayoutMethod object.
-
#unarchive(id, params = {}, opts = {}) ⇒ Object
Unarchive an PayoutMethod object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#archive(id, params = {}, opts = {}) ⇒ Object
Archive a PayoutMethod object. Archived objects cannot be used as payout methods and will not appear in the payout method list.
** raises ControlledByDashboardError ** raises InvalidPayoutMethodError
40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 40 def archive(id, params = {}, opts = {}) request( method: :post, path: format("/v2/money_management/payout_methods/%<id>s/archive", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List objects that adhere to the PayoutMethod interface.
51 52 53 54 55 56 57 58 59 |
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 51 def list(params = {}, opts = {}) request( method: :get, path: "/v2/money_management/payout_methods", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a PayoutMethod object.
** raises InvalidPayoutMethodError
64 65 66 67 68 69 70 71 72 |
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 64 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v2/money_management/payout_methods/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#unarchive(id, params = {}, opts = {}) ⇒ Object
Unarchive an PayoutMethod object.
** raises ControlledByDashboardError ** raises InvalidPayoutMethodError
78 79 80 81 82 83 84 85 86 |
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 78 def unarchive(id, params = {}, opts = {}) request( method: :post, path: format("/v2/money_management/payout_methods/%<id>s/unarchive", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |