Class: Stripe::V2::MoneyManagement::PayoutMethodService

Inherits:
StripeService
  • Object
show all
Defined in:
lib/stripe/services/v2/money_management/payout_method_service.rb

Defined Under Namespace

Classes: ArchiveParams, ListParams, RetrieveParams, UnarchiveParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#archive(id, params = {}, opts = {}) ⇒ Object

Archive a PayoutMethod object. Archived objects cannot be used as payout methods and will not appear in the payout method list.

** raises ControlledByDashboardError ** raises InvalidPayoutMethodError



45
46
47
48
49
50
51
52
53
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 45

def archive(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/money_management/payout_methods/%<id>s/archive", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

List objects that adhere to the PayoutMethod interface.



56
57
58
59
60
61
62
63
64
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 56

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v2/money_management/payout_methods",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieve a PayoutMethod object.

** raises InvalidPayoutMethodError



69
70
71
72
73
74
75
76
77
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 69

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v2/money_management/payout_methods/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#unarchive(id, params = {}, opts = {}) ⇒ Object

Unarchive an PayoutMethod object.

** raises ControlledByDashboardError ** raises InvalidPayoutMethodError



83
84
85
86
87
88
89
90
91
# File 'lib/stripe/services/v2/money_management/payout_method_service.rb', line 83

def unarchive(id, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v2/money_management/payout_methods/%<id>s/unarchive", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end