Class: Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpec
- Inherits:
-
SingletonAPIResource
- Object
- StripeObject
- APIResource
- SingletonAPIResource
- Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpec
- Defined in:
- lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb
Overview
The PayoutMethodsBankAccountSpec object.
Defined Under Namespace
Classes: Countries
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.payout_methods_bank_account_spec"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#countries ⇒ Object
readonly
The list of specs by country.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from SingletonAPIResource
resource_url, #resource_url, retrieve
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#countries ⇒ Object (readonly)
The list of specs by country.
67 68 69 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 67 def countries @countries end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
69 70 71 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 69 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
71 72 73 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 71 def object @object end |
Class Method Details
.field_remappings ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 77 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
73 74 75 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 73 def self.inner_class_types @inner_class_types = { countries: Countries } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/payout_methods_bank_account_spec.rb', line 10 def self.object_name "v2.money_management.payout_methods_bank_account_spec" end |