Class: Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpecService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::V2::MoneyManagement::PayoutMethodsBankAccountSpecService
- Defined in:
- lib/stripe/services/v2/money_management/payout_methods_bank_account_spec_service.rb
Instance Method Summary collapse
-
#retrieve(params = {}, opts = {}) ⇒ Object
Fetch the specifications for a set of countries to know which credential fields are required, the validations for each fields, and how to translate these country-specific fields to the generic fields in the PayoutMethodBankAccount type.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#retrieve(params = {}, opts = {}) ⇒ Object
Fetch the specifications for a set of countries to know which credential fields are required, the validations for each fields, and how to translate these country-specific fields to the generic fields in the PayoutMethodBankAccount type.
11 12 13 14 15 16 17 18 19 |
# File 'lib/stripe/services/v2/money_management/payout_methods_bank_account_spec_service.rb', line 11 def retrieve(params = {}, opts = {}) request( method: :get, path: "/v2/money_management/payout_methods_bank_account_spec", params: params, opts: opts, base_address: :api ) end |