Class: Stripe::V2::MoneyManagement::ReceivedCredit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Overview

Use ReceivedCredits API to retrieve information on when, where, and how funds are sent into your FinancialAccount.

Defined Under Namespace

Classes: BalanceTransfer, BankTransfer, StatusDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_credit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount and currency of the ReceivedCredit.



186
187
188
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 186

def amount
  @amount
end

#balance_transferObject (readonly)

This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `balance_transfer`.



188
189
190
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 188

def balance_transfer
  @balance_transfer
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `bank_transfer`.



190
191
192
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 190

def bank_transfer
  @bank_transfer
end

#createdObject (readonly)

Time at which the ReceivedCredit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



193
194
195
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 193

def created
  @created
end

#descriptionObject (readonly)

Freeform string set by originator of the ReceivedCredit.



195
196
197
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 195

def description
  @description
end

#financial_accountObject (readonly)

Financial Account ID on which funds for ReceivedCredit were received.



197
198
199
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 197

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedCredit.



199
200
201
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 199

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



201
202
203
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 201

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



203
204
205
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 203

def object
  @object
end

#receipt_urlObject (readonly)

A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.



205
206
207
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 205

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedCredit.



207
208
209
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 207

def status
  @status
end

#status_detailsObject (readonly)

This hash contains detailed information that elaborates on the specific status of the ReceivedCredit. e.g the reason behind a failure if the status is marked as ‘failed`.



209
210
211
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 209

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



211
212
213
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 211

def status_transitions
  @status_transitions
end

#typeObject (readonly)

Open Enum. The type of flow that caused the ReceivedCredit.



213
214
215
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 213

def type
  @type
end

Class Method Details

.field_remappingsObject



224
225
226
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 224

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



215
216
217
218
219
220
221
222
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 215

def self.inner_class_types
  @inner_class_types = {
    balance_transfer: BalanceTransfer,
    bank_transfer: BankTransfer,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 10

def self.object_name
  "v2.money_management.received_credit"
end