Class: Stripe::V2::MoneyManagement::ReceivedCredit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Overview

Use ReceivedCredits API to retrieve information on when, where, and how funds are sent into your FinancialAccount.

Defined Under Namespace

Classes: BalanceTransfer, BankTransfer, CardSpend, StatusDetails, StatusTransitions, StripeBalancePayment

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_credit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount and currency of the ReceivedCredit.



241
242
243
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 241

def amount
  @amount
end

#balance_transferObject (readonly)

This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `balance_transfer`.



268
269
270
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 268

def balance_transfer
  @balance_transfer
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `bank_transfer`.



270
271
272
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 270

def bank_transfer
  @bank_transfer
end

#card_spendObject (readonly)

This object stores details about the originating issuing card spend that resulted in the ReceivedCredit. Present if ‘type` field value is `card_spend`.



272
273
274
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 272

def card_spend
  @card_spend
end

#createdObject (readonly)

Time at which the ReceivedCredit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



244
245
246
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 244

def created
  @created
end

#descriptionObject (readonly)

Freeform string set by originator of the ReceivedCredit.



246
247
248
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 246

def description
  @description
end

#external_amountObject (readonly)

The amount and currency of the original/external credit request.



248
249
250
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 248

def external_amount
  @external_amount
end

#financial_accountObject (readonly)

Financial Account ID on which funds for ReceivedCredit were received.



250
251
252
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 250

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedCredit.



252
253
254
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 252

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



266
267
268
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 266

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



254
255
256
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 254

def object
  @object
end

#receipt_urlObject (readonly)

A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.



256
257
258
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 256

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedCredit.



258
259
260
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 258

def status
  @status
end

#status_detailsObject (readonly)

This hash contains detailed information that elaborates on the specific status of the ReceivedCredit. e.g the reason behind a failure if the status is marked as ‘failed`.



260
261
262
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 260

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



262
263
264
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 262

def status_transitions
  @status_transitions
end

#stripe_balance_paymentObject (readonly)

This object stores details about the stripe balance pay refund that resulted in the ReceivedCredit. Present if ‘type` field value is `stripe_balance_payment`.



274
275
276
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 274

def stripe_balance_payment
  @stripe_balance_payment
end

#typeObject (readonly)

Open Enum. The type of flow that caused the ReceivedCredit.



264
265
266
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 264

def type
  @type
end

Class Method Details

.field_remappingsObject



287
288
289
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 287

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



276
277
278
279
280
281
282
283
284
285
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 276

def self.inner_class_types
  @inner_class_types = {
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    balance_transfer: BalanceTransfer,
    bank_transfer: BankTransfer,
    card_spend: CardSpend,
    stripe_balance_payment: StripeBalancePayment,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 10

def self.object_name
  "v2.money_management.received_credit"
end