Class: Stripe::V2::MoneyManagement::ReceivedCredit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedCredit
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Overview
Use ReceivedCredits API to retrieve information on when, where, and how funds are sent into your FinancialAccount.
Defined Under Namespace
Classes: Amount, BalanceTransfer, BankTransfer, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_credit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount and currency of the ReceivedCredit.
-
#balance_transfer ⇒ Object
readonly
This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedCredit.
-
#created ⇒ Object
readonly
Time at which the ReceivedCredit was created.
-
#description ⇒ Object
readonly
Freeform string set by originator of the ReceivedCredit.
-
#financial_account ⇒ Object
readonly
Financial Account ID on which funds for ReceivedCredit were received.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedCredit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
This hash contains detailed information that elaborates on the specific status of the ReceivedCredit.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount and currency of the ReceivedCredit.
201 202 203 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 201 def amount @amount end |
#balance_transfer ⇒ Object (readonly)
This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `balance_transfer`.
226 227 228 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 226 def balance_transfer @balance_transfer end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `bank_transfer`.
228 229 230 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 228 def bank_transfer @bank_transfer end |
#created ⇒ Object (readonly)
Time at which the ReceivedCredit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
204 205 206 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 204 def created @created end |
#description ⇒ Object (readonly)
Freeform string set by originator of the ReceivedCredit.
206 207 208 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 206 def description @description end |
#financial_account ⇒ Object (readonly)
Financial Account ID on which funds for ReceivedCredit were received.
208 209 210 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 208 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedCredit.
210 211 212 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 210 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
224 225 226 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 224 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
212 213 214 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 212 def object @object end |
#receipt_url ⇒ Object (readonly)
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
214 215 216 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 214 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedCredit.
216 217 218 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 216 def status @status end |
#status_details ⇒ Object (readonly)
This hash contains detailed information that elaborates on the specific status of the ReceivedCredit. e.g the reason behind a failure if the status is marked as ‘failed`.
218 219 220 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 218 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
220 221 222 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 220 def status_transitions @status_transitions end |
#type ⇒ Object (readonly)
Open Enum. The type of flow that caused the ReceivedCredit.
222 223 224 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 222 def type @type end |
Class Method Details
.field_remappings ⇒ Object
240 241 242 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 240 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
230 231 232 233 234 235 236 237 238 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 230 def self.inner_class_types @inner_class_types = { amount: Amount, status_details: StatusDetails, status_transitions: StatusTransitions, balance_transfer: BalanceTransfer, bank_transfer: BankTransfer, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 10 def self.object_name "v2.money_management.received_credit" end |