Class: Stripe::V2::MoneyManagement::ReceivedCredit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedCredit
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Overview
Use ReceivedCredits API to retrieve information on when, where, and how funds are sent into your FinancialAccount.
Defined Under Namespace
Classes: Amount, BalanceTransfer, BankTransfer, ExternalAmount, StatusDetails, StatusTransitions, StripeBalancePayment
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_credit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount and currency of the ReceivedCredit.
-
#balance_transfer ⇒ Object
readonly
This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedCredit.
-
#created ⇒ Object
readonly
Time at which the ReceivedCredit was created.
-
#description ⇒ Object
readonly
Freeform string set by originator of the ReceivedCredit.
-
#external_amount ⇒ Object
readonly
The amount and currency of the original/external credit request.
-
#financial_account ⇒ Object
readonly
Financial Account ID on which funds for ReceivedCredit were received.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedCredit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
This hash contains detailed information that elaborates on the specific status of the ReceivedCredit.
-
#status_transitions ⇒ Object
readonly
Hash containing timestamps of when the object transitioned to a particular status.
-
#stripe_balance_payment ⇒ Object
readonly
This object stores details about the stripe balance pay refund that resulted in the ReceivedCredit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount and currency of the ReceivedCredit.
229 230 231 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 229 def amount @amount end |
#balance_transfer ⇒ Object (readonly)
This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `balance_transfer`.
256 257 258 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 256 def balance_transfer @balance_transfer end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `bank_transfer`.
258 259 260 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 258 def bank_transfer @bank_transfer end |
#created ⇒ Object (readonly)
Time at which the ReceivedCredit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
232 233 234 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 232 def created @created end |
#description ⇒ Object (readonly)
Freeform string set by originator of the ReceivedCredit.
234 235 236 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 234 def description @description end |
#external_amount ⇒ Object (readonly)
The amount and currency of the original/external credit request.
236 237 238 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 236 def external_amount @external_amount end |
#financial_account ⇒ Object (readonly)
Financial Account ID on which funds for ReceivedCredit were received.
238 239 240 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 238 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedCredit.
240 241 242 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 240 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
254 255 256 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 254 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
242 243 244 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 242 def object @object end |
#receipt_url ⇒ Object (readonly)
A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.
244 245 246 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 244 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedCredit.
246 247 248 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 246 def status @status end |
#status_details ⇒ Object (readonly)
This hash contains detailed information that elaborates on the specific status of the ReceivedCredit. e.g the reason behind a failure if the status is marked as ‘failed`.
248 249 250 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 248 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
Hash containing timestamps of when the object transitioned to a particular status.
250 251 252 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 250 def status_transitions @status_transitions end |
#stripe_balance_payment ⇒ Object (readonly)
This object stores details about the stripe balance pay refund that resulted in the ReceivedCredit. Present if ‘type` field value is `stripe_balance_payment`.
260 261 262 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 260 def stripe_balance_payment @stripe_balance_payment end |
#type ⇒ Object (readonly)
Open Enum. The type of flow that caused the ReceivedCredit.
252 253 254 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 252 def type @type end |
Class Method Details
.field_remappings ⇒ Object
274 275 276 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 274 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 262 def self.inner_class_types @inner_class_types = { amount: Amount, external_amount: ExternalAmount, status_details: StatusDetails, status_transitions: StatusTransitions, balance_transfer: BalanceTransfer, bank_transfer: BankTransfer, stripe_balance_payment: StripeBalancePayment, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 10 def self.object_name "v2.money_management.received_credit" end |