Class: Stripe::V2::MoneyManagement::ReceivedCredit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Overview

Use ReceivedCredits API to retrieve information on when, where, and how funds are sent into your FinancialAccount.

Defined Under Namespace

Classes: BalanceTransfer, BankTransfer, StatusDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_credit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount and currency of the ReceivedCredit.



85
86
87
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 85

def amount
  @amount
end

#balance_transferObject (readonly)

This object stores details about the originating Stripe transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `balance_transfer`.



110
111
112
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 110

def balance_transfer
  @balance_transfer
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedCredit. Present if ‘type` field value is `external_credit`.



112
113
114
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 112

def bank_transfer
  @bank_transfer
end

#createdObject (readonly)

Time at which the ReceivedCredit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



88
89
90
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 88

def created
  @created
end

#descriptionObject (readonly)

Freeform string set by originator of the ReceivedCredit.



90
91
92
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 90

def description
  @description
end

#financial_accountObject (readonly)

Financial Account ID on which funds for ReceivedCredit were received.



92
93
94
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 92

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedCredit.



94
95
96
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 94

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



108
109
110
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 108

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



96
97
98
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 96

def object
  @object
end

#receipt_urlObject (readonly)

A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe’s money transmission licenses.



98
99
100
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 98

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedCredit.



100
101
102
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 100

def status
  @status
end

#status_detailsObject (readonly)

This hash contains detailed information that elaborates on the specific status of the ReceivedCredit. e.g the reason behind a failure if the status is marked as ‘failed`.



102
103
104
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 102

def status_details
  @status_details
end

#status_transitionsObject (readonly)

Hash containing timestamps of when the object transitioned to a particular status.



104
105
106
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 104

def status_transitions
  @status_transitions
end

#typeObject (readonly)

Open Enum. The type of flow that caused the ReceivedCredit.



106
107
108
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 106

def type
  @type
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 10

def self.object_name
  "v2.money_management.received_credit"
end