Class: Stripe::V2::MoneyManagement::ReceivedCredit::BalanceTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BalanceTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#from_account ⇒ Object
readonly
The ID of the account that owns the source object originated the ReceivedCredit.
-
#outbound_payment ⇒ Object
readonly
The ID of the outbound payment object that originated the ReceivedCredit.
-
#outbound_transfer ⇒ Object
readonly
The ID of the outbound transfer object that originated the ReceivedCredit.
-
#payout_v1 ⇒ Object
readonly
The ID of the payout object that originated the ReceivedCredit.
-
#transfer ⇒ Object
readonly
The ID of the v1 transfer object that originated the ReceivedCredit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#from_account ⇒ Object (readonly)
The ID of the account that owns the source object originated the ReceivedCredit.
76 77 78 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 76 def from_account @from_account end |
#outbound_payment ⇒ Object (readonly)
The ID of the outbound payment object that originated the ReceivedCredit.
80 81 82 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 80 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
The ID of the outbound transfer object that originated the ReceivedCredit.
82 83 84 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 82 def outbound_transfer @outbound_transfer end |
#payout_v1 ⇒ Object (readonly)
The ID of the payout object that originated the ReceivedCredit.
84 85 86 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 84 def payout_v1 @payout_v1 end |
#transfer ⇒ Object (readonly)
The ID of the v1 transfer object that originated the ReceivedCredit.
86 87 88 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 86 def transfer @transfer end |
#type ⇒ Object (readonly)
Open Enum. The type of Stripe Money Movement that originated the ReceivedCredit.
78 79 80 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 78 def type @type end |
Class Method Details
.field_remappings ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 92 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
88 89 90 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 88 def self.inner_class_types @inner_class_types = {} end |