Class: Stripe::V2::MoneyManagement::ReceivedCredit::BalanceTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#from_accountObject (readonly)

The ID of the account that owns the source object originated the ReceivedCredit.



91
92
93
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 91

def 
  @from_account
end

#outbound_paymentObject (readonly)

The ID of the outbound payment object that originated the ReceivedCredit.



95
96
97
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 95

def outbound_payment
  @outbound_payment
end

#outbound_transferObject (readonly)

The ID of the outbound transfer object that originated the ReceivedCredit.



97
98
99
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 97

def outbound_transfer
  @outbound_transfer
end

#payout_v1Object (readonly)

The ID of the payout object that originated the ReceivedCredit.



99
100
101
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 99

def payout_v1
  @payout_v1
end

#transferObject (readonly)

The ID of the v1 transfer object that originated the ReceivedCredit.



101
102
103
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 101

def transfer
  @transfer
end

#typeObject (readonly)

Open Enum. The type of Stripe Money Movement that originated the ReceivedCredit.



93
94
95
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 93

def type
  @type
end

Class Method Details

.field_remappingsObject



107
108
109
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 107

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



103
104
105
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 103

def self.inner_class_types
  @inner_class_types = {}
end