Class: Stripe::V2::MoneyManagement::ReceivedCredit::BalanceTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BalanceTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#from_account ⇒ Object
readonly
The ID of the account that owns the source object originated the ReceivedCredit.
-
#outbound_payment ⇒ Object
readonly
The ID of the outbound payment object that originated the ReceivedCredit.
-
#outbound_transfer ⇒ Object
readonly
The ID of the outbound transfer object that originated the ReceivedCredit.
-
#payout_v1 ⇒ Object
readonly
The ID of the payout object that originated the ReceivedCredit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#from_account ⇒ Object (readonly)
The ID of the account that owns the source object originated the ReceivedCredit.
44 45 46 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 44 def from_account @from_account end |
#outbound_payment ⇒ Object (readonly)
The ID of the outbound payment object that originated the ReceivedCredit.
48 49 50 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 48 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
The ID of the outbound transfer object that originated the ReceivedCredit.
50 51 52 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 50 def outbound_transfer @outbound_transfer end |
#payout_v1 ⇒ Object (readonly)
The ID of the payout object that originated the ReceivedCredit.
52 53 54 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 52 def payout_v1 @payout_v1 end |
#type ⇒ Object (readonly)
Open Enum. The type of Stripe Money Movement that originated the ReceivedCredit.
46 47 48 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 46 def type @type end |