Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Defined Under Namespace

Classes: CaBankAccount, EuBankAccount, GbBankAccount, MxBankAccount, SepaBankAccount, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ca_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `ca_bank_account`.



161
162
163
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 161

def 
  @ca_bank_account
end

#eu_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `eu_bank_account`.



163
164
165
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 163

def 
  @eu_bank_account
end

#financial_addressObject (readonly)

Financial Address on which funds for ReceivedCredit were received.



165
166
167
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 165

def financial_address
  @financial_address
end

#gb_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `gb_bank_account`.



167
168
169
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 167

def 
  @gb_bank_account
end

#mx_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `mx_bank_account`.



169
170
171
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 169

def 
  @mx_bank_account
end

#origin_typeObject (readonly)

Open Enum. Indicates the origin of source from which external funds originated from.



171
172
173
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 171

def origin_type
  @origin_type
end

#sepa_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `sepa_bank_account`.



173
174
175
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 173

def 
  @sepa_bank_account
end

#statement_descriptorObject (readonly)

Freeform string set by originator of the external ReceivedCredit.



175
176
177
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 175

def statement_descriptor
  @statement_descriptor
end

#us_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `us_bank_account`.



177
178
179
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 177

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



190
191
192
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 190

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



179
180
181
182
183
184
185
186
187
188
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 179

def self.inner_class_types
  @inner_class_types = {
    ca_bank_account: CaBankAccount,
    eu_bank_account: EuBankAccount,
    gb_bank_account: GbBankAccount,
    mx_bank_account: MxBankAccount,
    sepa_bank_account: SepaBankAccount,
    us_bank_account: UsBankAccount,
  }
end