Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Defined Under Namespace

Classes: GbBankAccount, SepaBankAccount, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#financial_addressObject (readonly)

Financial Address on which funds for ReceivedCredit were received.



101
102
103
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 101

def financial_address
  @financial_address
end

#gb_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `gb_bank_account`.



103
104
105
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 103

def 
  @gb_bank_account
end

#origin_typeObject (readonly)

Open Enum. Indicates the origin of source from which external funds originated from.



105
106
107
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 105

def origin_type
  @origin_type
end

#sepa_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `sepa_bank_account`.



107
108
109
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 107

def 
  @sepa_bank_account
end

#statement_descriptorObject (readonly)

Freeform string set by originator of the external ReceivedCredit.



109
110
111
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 109

def statement_descriptor
  @statement_descriptor
end

#us_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘origin_type` field value is `us_bank_account`.



111
112
113
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 111

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



121
122
123
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 121

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



113
114
115
116
117
118
119
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 113

def self.inner_class_types
  @inner_class_types = {
    gb_bank_account: GbBankAccount,
    sepa_bank_account: SepaBankAccount,
    us_bank_account: UsBankAccount,
  }
end