Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Defined Under Namespace
Classes: GbBankAccount, SepaBankAccount, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_address ⇒ Object
readonly
Financial Address on which funds for ReceivedCredit were received.
-
#gb_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
-
#origin_type ⇒ Object
readonly
Open Enum.
-
#sepa_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
-
#statement_descriptor ⇒ Object
readonly
Freeform string set by originator of the external ReceivedCredit.
-
#us_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_address ⇒ Object (readonly)
Financial Address on which funds for ReceivedCredit were received.
191 192 193 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 191 def financial_address @financial_address end |
#gb_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `gb_bank_account`.
197 198 199 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 197 def gb_bank_account @gb_bank_account end |
#origin_type ⇒ Object (readonly)
Open Enum. Indicates the origin of source from which external funds originated from.
193 194 195 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 193 def origin_type @origin_type end |
#sepa_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `sepa_bank_account`.
199 200 201 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 199 def sepa_bank_account @sepa_bank_account end |
#statement_descriptor ⇒ Object (readonly)
Freeform string set by originator of the external ReceivedCredit.
195 196 197 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 195 def statement_descriptor @statement_descriptor end |
#us_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘origin_type` field value is `us_bank_account`.
201 202 203 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 201 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
211 212 213 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 211 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
203 204 205 206 207 208 209 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 203 def self.inner_class_types @inner_class_types = { gb_bank_account: GbBankAccount, sepa_bank_account: SepaBankAccount, us_bank_account: UsBankAccount, } end |