Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Defined Under Namespace

Classes: GbBankAccount, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#financial_addressObject (readonly)

Financial Address on which funds for ReceivedCredit were received.



74
75
76
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 74

def financial_address
  @financial_address
end

#gb_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘payment_method_type` field value is `gb_bank_account`.



80
81
82
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 80

def 
  @gb_bank_account
end

#payment_method_typeObject (readonly)

Open Enum. Indicates the type of source via from which external funds originated.



76
77
78
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 76

def payment_method_type
  @payment_method_type
end

#statement_descriptorObject (readonly)

Freeform string set by originator of the external ReceivedCredit.



78
79
80
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 78

def statement_descriptor
  @statement_descriptor
end

#us_bank_accountObject (readonly)

Hash containing the transaction bank details. Present if ‘payment_method_type` field value is `us_bank_account`.



82
83
84
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 82

def 
  @us_bank_account
end