Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Defined Under Namespace
Classes: GbBankAccount, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_address ⇒ Object
readonly
Financial Address on which funds for ReceivedCredit were received.
-
#gb_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
-
#payment_method_type ⇒ Object
readonly
Open Enum.
-
#statement_descriptor ⇒ Object
readonly
Freeform string set by originator of the external ReceivedCredit.
-
#us_bank_account ⇒ Object
readonly
Hash containing the transaction bank details.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_address ⇒ Object (readonly)
Financial Address on which funds for ReceivedCredit were received.
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 74 def financial_address @financial_address end |
#gb_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘payment_method_type` field value is `gb_bank_account`.
80 81 82 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 80 def gb_bank_account @gb_bank_account end |
#payment_method_type ⇒ Object (readonly)
Open Enum. Indicates the type of source via from which external funds originated.
76 77 78 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 76 def payment_method_type @payment_method_type end |
#statement_descriptor ⇒ Object (readonly)
Freeform string set by originator of the external ReceivedCredit.
78 79 80 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 78 def statement_descriptor @statement_descriptor end |
#us_bank_account ⇒ Object (readonly)
Hash containing the transaction bank details. Present if ‘payment_method_type` field value is `us_bank_account`.
82 83 84 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 82 def us_bank_account @us_bank_account end |