Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number that originated the transfer.
-
#network ⇒ Object
readonly
Open Enum.
-
#sort_code ⇒ Object
readonly
The sort code of the account that originated the transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The bank name the transfer was received from.
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 60 def account_holder_name @account_holder_name end |
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
62 63 64 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 62 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number that originated the transfer.
64 65 66 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 64 def last4 @last4 end |
#network ⇒ Object (readonly)
Open Enum. The money transmission network used to send funds for this ReceivedCredit.
66 67 68 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 66 def network @network end |
#sort_code ⇒ Object (readonly)
The sort code of the account that originated the transfer.
68 69 70 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 68 def sort_code @sort_code end |
Class Method Details
.field_remappings ⇒ Object
74 75 76 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 74 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
70 71 72 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 70 def self.inner_class_types @inner_class_types = {} end |