Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The bank name the transfer was received from.



40
41
42
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 40

def 
  @account_holder_name
end

#bank_nameObject (readonly)

The bank name the transfer was received from.



42
43
44
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 42

def bank_name
  @bank_name
end

#last4Object (readonly)

The last 4 digits of the account number that originated the transfer.



44
45
46
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 44

def last4
  @last4
end

#networkObject (readonly)

Open Enum. The money transmission network used to send funds for this ReceivedCredit.



46
47
48
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 46

def network
  @network
end

#sort_codeObject (readonly)

The sort code of the account that originated the transfer.



48
49
50
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 48

def sort_code
  @sort_code
end

Class Method Details

.field_remappingsObject



54
55
56
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 54

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



50
51
52
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 50

def self.inner_class_types
  @inner_class_types = {}
end