Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The bank name the transfer was received from.



130
131
132
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 130

def 
  @account_holder_name
end

#bank_nameObject (readonly)

The bank name the transfer was received from.



132
133
134
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 132

def bank_name
  @bank_name
end

#last4Object (readonly)

The last 4 digits of the account number that originated the transfer.



134
135
136
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 134

def last4
  @last4
end

#networkObject (readonly)

Open Enum. The money transmission network used to send funds for this ReceivedCredit.



136
137
138
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 136

def network
  @network
end

#sort_codeObject (readonly)

The sort code of the account that originated the transfer.



138
139
140
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 138

def sort_code
  @sort_code
end

Class Method Details

.field_remappingsObject



144
145
146
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 144

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



140
141
142
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 140

def self.inner_class_types
  @inner_class_types = {}
end