Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The bank name the transfer was received from.



58
59
60
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 58

def 
  @account_holder_name
end

#bank_nameObject (readonly)

The bank name the transfer was received from.



60
61
62
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 60

def bank_name
  @bank_name
end

#last4Object (readonly)

The last 4 digits of the account number that originated the transfer.



62
63
64
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 62

def last4
  @last4
end

#networkObject (readonly)

Open Enum. The money transmission network used to send funds for this ReceivedCredit.



64
65
66
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 64

def network
  @network
end

#sort_codeObject (readonly)

The sort code of the account that originated the transfer.



66
67
68
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 66

def sort_code
  @sort_code
end