Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::GbBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number that originated the transfer.
-
#network ⇒ Object
readonly
Open Enum.
-
#sort_code ⇒ Object
readonly
The sort code of the account that originated the transfer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The bank name the transfer was received from.
52 53 54 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 52 def account_holder_name @account_holder_name end |
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 54 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number that originated the transfer.
56 57 58 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 56 def last4 @last4 end |
#network ⇒ Object (readonly)
Open Enum. The money transmission network used to send funds for this ReceivedCredit.
58 59 60 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 58 def network @network end |
#sort_code ⇒ Object (readonly)
The sort code of the account that originated the transfer.
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 60 def sort_code @sort_code end |