Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::SepaBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::SepaBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The account holder name of the bank account the transfer was received from.
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#bic ⇒ Object
readonly
The BIC of the SEPA account.
-
#country ⇒ Object
readonly
The origination country of the bank transfer.
-
#iban ⇒ Object
readonly
The IBAN that originated the transfer.
-
#network ⇒ Object
readonly
The money transmission network used to send funds for this ReceivedCredit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The account holder name of the bank account the transfer was received from.
61 62 63 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 61 def account_holder_name @account_holder_name end |
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
63 64 65 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 63 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
The BIC of the SEPA account.
65 66 67 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 65 def bic @bic end |
#country ⇒ Object (readonly)
The origination country of the bank transfer.
67 68 69 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 67 def country @country end |
#iban ⇒ Object (readonly)
The IBAN that originated the transfer.
69 70 71 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 69 def iban @iban end |
#network ⇒ Object (readonly)
The money transmission network used to send funds for this ReceivedCredit.
71 72 73 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 71 def network @network end |
Class Method Details
.field_remappings ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 77 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
73 74 75 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 73 def self.inner_class_types @inner_class_types = {} end |