Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::SepaBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The account holder name of the bank account the transfer was received from.



151
152
153
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 151

def 
  @account_holder_name
end

#bank_nameObject (readonly)

The bank name the transfer was received from.



153
154
155
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 153

def bank_name
  @bank_name
end

#bicObject (readonly)

The BIC of the SEPA account.



155
156
157
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 155

def bic
  @bic
end

#countryObject (readonly)

The origination country of the bank transfer.



157
158
159
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 157

def country
  @country
end

#ibanObject (readonly)

The IBAN that originated the transfer.



159
160
161
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 159

def iban
  @iban
end

#networkObject (readonly)

The money transmission network used to send funds for this ReceivedCredit.



161
162
163
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 161

def network
  @network
end

Class Method Details

.field_remappingsObject



167
168
169
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 167

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



163
164
165
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 163

def self.inner_class_types
  @inner_class_types = {}
end