Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::SepaBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::SepaBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The account holder name of the bank account the transfer was received from.
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#bic ⇒ Object
readonly
The BIC of the SEPA account.
-
#country ⇒ Object
readonly
The origination country of the bank transfer.
-
#iban ⇒ Object
readonly
The IBAN that originated the transfer.
-
#network ⇒ Object
readonly
The money transmission network used to send funds for this ReceivedCredit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The account holder name of the bank account the transfer was received from.
136 137 138 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 136 def account_holder_name @account_holder_name end |
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
138 139 140 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 138 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
The BIC of the SEPA account.
140 141 142 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 140 def bic @bic end |
#country ⇒ Object (readonly)
The origination country of the bank transfer.
142 143 144 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 142 def country @country end |
#iban ⇒ Object (readonly)
The IBAN that originated the transfer.
144 145 146 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 144 def iban @iban end |
#network ⇒ Object (readonly)
The money transmission network used to send funds for this ReceivedCredit.
146 147 148 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 146 def network @network end |
Class Method Details
.field_remappings ⇒ Object
152 153 154 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 152 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
148 149 150 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 148 def self.inner_class_types @inner_class_types = {} end |