Class: Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::BankTransfer::UsBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
The bank name the transfer was received from.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number that originated the transfer.
-
#network ⇒ Object
readonly
Open Enum.
-
#routing_number ⇒ Object
readonly
The routing number of the account that originated the transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
The bank name the transfer was received from.
159 160 161 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 159 def bank_name @bank_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number that originated the transfer.
161 162 163 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 161 def last4 @last4 end |
#network ⇒ Object (readonly)
Open Enum. The money transmission network used to send funds for this ReceivedCredit.
163 164 165 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 163 def network @network end |
#routing_number ⇒ Object (readonly)
The routing number of the account that originated the transfer.
165 166 167 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 165 def routing_number @routing_number end |
Class Method Details
.field_remappings ⇒ Object
171 172 173 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 171 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
167 168 169 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 167 def self.inner_class_types @inner_class_types = {} end |