Class: Stripe::V2::MoneyManagement::ReceivedCredit::CardSpend
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::CardSpend
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_v1_id ⇒ Object
readonly
The reference to the issuing card object.
-
#dispute ⇒ Object
readonly
Hash containing information about the Dispute that triggered this credit.
-
#refund ⇒ Object
readonly
Hash containing information about the Refund that triggered this credit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_v1_id ⇒ Object (readonly)
The reference to the issuing card object.
243 244 245 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 243 def card_v1_id @card_v1_id end |
#dispute ⇒ Object (readonly)
Hash containing information about the Dispute that triggered this credit.
245 246 247 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 245 def dispute @dispute end |
#refund ⇒ Object (readonly)
Hash containing information about the Refund that triggered this credit.
247 248 249 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 247 def refund @refund end |
Class Method Details
.field_remappings ⇒ Object
253 254 255 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 253 def self.field_remappings @field_remappings = {} end |