Class: Stripe::V2::MoneyManagement::ReceivedCredit::CardSpend

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_credit.rb

Defined Under Namespace

Classes: Dispute, Refund

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_v1_idObject (readonly)

The reference to the issuing card object.



96
97
98
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 96

def card_v1_id
  @card_v1_id
end

#disputeObject (readonly)

Hash containing information about the Dispute that triggered this credit.



98
99
100
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 98

def dispute
  @dispute
end

#refundObject (readonly)

Hash containing information about the Refund that triggered this credit.



100
101
102
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 100

def refund
  @refund
end