Class: Stripe::V2::MoneyManagement::ReceivedCredit::CryptoWalletTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::CryptoWalletTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Defined Under Namespace
Classes: CryptoWallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#crypto_wallet ⇒ Object
readonly
Hash containing the transaction crypto wallet details.
-
#financial_address ⇒ Object
readonly
Financial Address on which funds for ReceivedCredit were received.
-
#origin_type ⇒ Object
readonly
Open Enum.
-
#statement_descriptor ⇒ Object
readonly
Freeform string set by originator of the external ReceivedCredit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#crypto_wallet ⇒ Object (readonly)
Hash containing the transaction crypto wallet details.
255 256 257 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 255 def crypto_wallet @crypto_wallet end |
#financial_address ⇒ Object (readonly)
Financial Address on which funds for ReceivedCredit were received.
257 258 259 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 257 def financial_address @financial_address end |
#origin_type ⇒ Object (readonly)
Open Enum. Indicates the origin of source from which external funds originated from.
259 260 261 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 259 def origin_type @origin_type end |
#statement_descriptor ⇒ Object (readonly)
Freeform string set by originator of the external ReceivedCredit.
261 262 263 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 261 def statement_descriptor @statement_descriptor end |
Class Method Details
.field_remappings ⇒ Object
267 268 269 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 267 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
263 264 265 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 263 def self.inner_class_types @inner_class_types = { crypto_wallet: CryptoWallet } end |