Class: Stripe::V2::MoneyManagement::ReceivedCredit::CryptoWalletTransfer::CryptoWallet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::CryptoWalletTransfer::CryptoWallet
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The address of the wallet the crypto was received from.
-
#memo ⇒ Object
readonly
A memo also for identifying the recipient for memo-based blockchains (e.g., Stellar),.
-
#network ⇒ Object
readonly
The network the crypto was received from.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The address of the wallet the crypto was received from.
240 241 242 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 240 def address @address end |
#memo ⇒ Object (readonly)
A memo also for identifying the recipient for memo-based blockchains (e.g., Stellar),.
242 243 244 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 242 def memo @memo end |
#network ⇒ Object (readonly)
The network the crypto was received from.
244 245 246 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 244 def network @network end |
Class Method Details
.field_remappings ⇒ Object
250 251 252 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 250 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
246 247 248 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 246 def self.inner_class_types @inner_class_types = {} end |