Class: Stripe::V2::MoneyManagement::ReceivedCredit::StatusDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedCredit::StatusDetails
- Defined in:
- lib/stripe/resources/v2/money_management/received_credit.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#failed ⇒ Object
readonly
Hash that provides additional information regarding the reason behind a ‘failed` ReceivedCredit status.
-
#returned ⇒ Object
readonly
Hash that provides additional information regarding the reason behind a ‘returned` ReceivedCredit status.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#failed ⇒ Object (readonly)
Hash that provides additional information regarding the reason behind a ‘failed` ReceivedCredit status. It is only present when the ReceivedCredit status is `failed`.
25 26 27 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 25 def failed @failed end |
#returned ⇒ Object (readonly)
Hash that provides additional information regarding the reason behind a ‘returned` ReceivedCredit status. It is only present when the ReceivedCredit status is `returned`.
27 28 29 |
# File 'lib/stripe/resources/v2/money_management/received_credit.rb', line 27 def returned @returned end |