Class: Stripe::V2::MoneyManagement::ReceivedDebit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Overview

ReceivedDebit resource

Defined Under Namespace

Classes: BalanceTransfer, BankTransfer, CardSpend, DisputeDetails, StatusDetails, StatusTransitions, StripeBalancePayment

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount and currency of the ReceivedDebit.



188
189
190
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 188

def amount
  @amount
end

#balance_transferObject (readonly)

This object stores details about the balance transfer object that resulted in the ReceivedDebit.



190
191
192
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 190

def balance_transfer
  @balance_transfer
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.



192
193
194
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 192

def bank_transfer
  @bank_transfer
end

#card_spendObject (readonly)

This object stores details about the issuing transactions that resulted in the ReceivedDebit. Present if ‘type` field value is `card_spend`.



194
195
196
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 194

def card_spend
  @card_spend
end

#createdObject (readonly)

The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.



197
198
199
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 197

def created
  @created
end

#descriptionObject (readonly)

Freeform string sent by the originator of the ReceivedDebit.



199
200
201
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 199

def description
  @description
end

#dispute_detailsObject (readonly)

The dispute details.



201
202
203
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 201

def dispute_details
  @dispute_details
end

#external_amountObject (readonly)

The amount and currency of the original/external debit request.



203
204
205
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 203

def external_amount
  @external_amount
end

#financial_accountObject (readonly)

Financial Account on which funds for ReceivedDebit were debited.



205
206
207
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 205

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedDebit.



207
208
209
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 207

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



209
210
211
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 209

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



211
212
213
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 211

def object
  @object
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this ReceivedDebit.



213
214
215
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 213

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedDebit.



215
216
217
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 215

def status
  @status
end

#status_detailsObject (readonly)

Detailed information about the status of the ReceivedDebit.



217
218
219
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 217

def status_details
  @status_details
end

#status_transitionsObject (readonly)

The time at which the ReceivedDebit transitioned to a particular status.



219
220
221
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 219

def status_transitions
  @status_transitions
end

#stripe_balance_paymentObject (readonly)

This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.



221
222
223
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 221

def stripe_balance_payment
  @stripe_balance_payment
end

#typeObject (readonly)

Open Enum. The type of the ReceivedDebit.



223
224
225
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 223

def type
  @type
end

Class Method Details

.field_remappingsObject



237
238
239
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 237

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



225
226
227
228
229
230
231
232
233
234
235
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 225

def self.inner_class_types
  @inner_class_types = {
    balance_transfer: BalanceTransfer,
    bank_transfer: BankTransfer,
    card_spend: CardSpend,
    dispute_details: DisputeDetails,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    stripe_balance_payment: StripeBalancePayment,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10

def self.object_name
  "v2.money_management.received_debit"
end