Class: Stripe::V2::MoneyManagement::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedDebit
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Overview
ReceivedDebit resource
Defined Under Namespace
Classes: BalanceTransfer, BankTransfer, CardSpend, StatusDetails, StatusTransitions, StripeBalancePayment
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount and currency of the ReceivedDebit.
-
#balance_transfer ⇒ Object
readonly
This object stores details about the balance transfer object that resulted in the ReceivedDebit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedDebit.
-
#card_spend ⇒ Object
readonly
This object stores details about the issuing transactions that resulted in the ReceivedDebit.
-
#created ⇒ Object
readonly
The time at which the ReceivedDebit was created.
-
#description ⇒ Object
readonly
Freeform string sent by the originator of the ReceivedDebit.
-
#external_amount ⇒ Object
readonly
The amount and currency of the original/external debit request.
-
#financial_account ⇒ Object
readonly
Financial Account on which funds for ReceivedDebit were debited.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedDebit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this ReceivedDebit.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the ReceivedDebit.
-
#status_transitions ⇒ Object
readonly
The time at which the ReceivedDebit transitioned to a particular status.
-
#stripe_balance_payment ⇒ Object
readonly
This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount and currency of the ReceivedDebit.
173 174 175 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 173 def amount @amount end |
#balance_transfer ⇒ Object (readonly)
This object stores details about the balance transfer object that resulted in the ReceivedDebit.
175 176 177 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 175 def balance_transfer @balance_transfer end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.
177 178 179 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 177 def bank_transfer @bank_transfer end |
#card_spend ⇒ Object (readonly)
This object stores details about the issuing transactions that resulted in the ReceivedDebit. Present if ‘type` field value is `card_spend`.
179 180 181 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 179 def card_spend @card_spend end |
#created ⇒ Object (readonly)
The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.
182 183 184 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 182 def created @created end |
#description ⇒ Object (readonly)
Freeform string sent by the originator of the ReceivedDebit.
184 185 186 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 184 def description @description end |
#external_amount ⇒ Object (readonly)
The amount and currency of the original/external debit request.
186 187 188 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 186 def external_amount @external_amount end |
#financial_account ⇒ Object (readonly)
Financial Account on which funds for ReceivedDebit were debited.
188 189 190 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 188 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedDebit.
190 191 192 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 190 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
192 193 194 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 192 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
194 195 196 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 194 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this ReceivedDebit.
196 197 198 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 196 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedDebit.
198 199 200 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 198 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the ReceivedDebit.
200 201 202 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 200 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the ReceivedDebit transitioned to a particular status.
202 203 204 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 202 def status_transitions @status_transitions end |
#stripe_balance_payment ⇒ Object (readonly)
This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.
204 205 206 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 204 def stripe_balance_payment @stripe_balance_payment end |
#type ⇒ Object (readonly)
Open Enum. The type of the ReceivedDebit.
206 207 208 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 206 def type @type end |
Class Method Details
.field_remappings ⇒ Object
219 220 221 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 219 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 208 def self.inner_class_types @inner_class_types = { balance_transfer: BalanceTransfer, bank_transfer: BankTransfer, card_spend: CardSpend, status_details: StatusDetails, status_transitions: StatusTransitions, stripe_balance_payment: StripeBalancePayment, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10 def self.object_name "v2.money_management.received_debit" end |