Class: Stripe::V2::MoneyManagement::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedDebit
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Overview
ReceivedDebit resource
Defined Under Namespace
Classes: BankTransfer, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount and currency of the ReceivedDebit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedDebit.
-
#created ⇒ Object
readonly
The time at which the ReceivedDebit was created.
-
#description ⇒ Object
readonly
Freeform string sent by the originator of the ReceivedDebit.
-
#financial_account ⇒ Object
readonly
Financial Account on which funds for ReceivedDebit were debited.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedDebit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this ReceivedDebit.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the ReceivedDebit.
-
#status_transitions ⇒ Object
readonly
The time at which the ReceivedDebit transitioned to a particular status.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount and currency of the ReceivedDebit.
95 96 97 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 95 def amount @amount end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.
97 98 99 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 97 def bank_transfer @bank_transfer end |
#created ⇒ Object (readonly)
The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.
100 101 102 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 100 def created @created end |
#description ⇒ Object (readonly)
Freeform string sent by the originator of the ReceivedDebit.
102 103 104 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 102 def description @description end |
#financial_account ⇒ Object (readonly)
Financial Account on which funds for ReceivedDebit were debited.
104 105 106 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 104 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedDebit.
106 107 108 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 106 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
108 109 110 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 108 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
110 111 112 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 110 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this ReceivedDebit.
112 113 114 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 112 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedDebit.
114 115 116 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 114 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the ReceivedDebit.
116 117 118 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 116 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the ReceivedDebit transitioned to a particular status.
118 119 120 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 118 def status_transitions @status_transitions end |
#type ⇒ Object (readonly)
Open Enum. The type of the ReceivedDebit.
120 121 122 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 120 def type @type end |
Class Method Details
.field_remappings ⇒ Object
130 131 132 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 130 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
122 123 124 125 126 127 128 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 122 def self.inner_class_types @inner_class_types = { bank_transfer: BankTransfer, status_details: StatusDetails, status_transitions: StatusTransitions, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10 def self.object_name "v2.money_management.received_debit" end |