Class: Stripe::V2::MoneyManagement::ReceivedDebit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Overview

ReceivedDebit resource

Defined Under Namespace

Classes: BalanceTransfer, BankTransfer, CardSpend, StatusDetails, StatusTransitions, StripeBalancePayment

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount and currency of the ReceivedDebit.



173
174
175
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 173

def amount
  @amount
end

#balance_transferObject (readonly)

This object stores details about the balance transfer object that resulted in the ReceivedDebit.



200
201
202
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 200

def balance_transfer
  @balance_transfer
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.



202
203
204
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 202

def bank_transfer
  @bank_transfer
end

#card_spendObject (readonly)

This object stores details about the issuing transactions that resulted in the ReceivedDebit. Present if ‘type` field value is `card_spend`.



204
205
206
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 204

def card_spend
  @card_spend
end

#createdObject (readonly)

The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.



176
177
178
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 176

def created
  @created
end

#descriptionObject (readonly)

Freeform string sent by the originator of the ReceivedDebit.



178
179
180
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 178

def description
  @description
end

#external_amountObject (readonly)

The amount and currency of the original/external debit request.



180
181
182
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 180

def external_amount
  @external_amount
end

#financial_accountObject (readonly)

Financial Account on which funds for ReceivedDebit were debited.



182
183
184
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 182

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedDebit.



184
185
186
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 184

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



198
199
200
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 198

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



186
187
188
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 186

def object
  @object
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this ReceivedDebit.



188
189
190
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 188

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedDebit.



190
191
192
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 190

def status
  @status
end

#status_detailsObject (readonly)

Detailed information about the status of the ReceivedDebit.



192
193
194
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 192

def status_details
  @status_details
end

#status_transitionsObject (readonly)

The time at which the ReceivedDebit transitioned to a particular status.



194
195
196
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 194

def status_transitions
  @status_transitions
end

#stripe_balance_paymentObject (readonly)

This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.



206
207
208
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 206

def stripe_balance_payment
  @stripe_balance_payment
end

#typeObject (readonly)

Open Enum. The type of the ReceivedDebit.



196
197
198
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 196

def type
  @type
end

Class Method Details

.field_remappingsObject



219
220
221
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 219

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



208
209
210
211
212
213
214
215
216
217
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 208

def self.inner_class_types
  @inner_class_types = {
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    balance_transfer: BalanceTransfer,
    bank_transfer: BankTransfer,
    card_spend: CardSpend,
    stripe_balance_payment: StripeBalancePayment,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10

def self.object_name
  "v2.money_management.received_debit"
end