Class: Stripe::V2::MoneyManagement::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedDebit
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Overview
ReceivedDebit resource
Defined Under Namespace
Classes: Amount, BalanceTransfer, BankTransfer, CardSpend, ExternalAmount, StatusDetails, StatusTransitions, StripeBalancePayment
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount and currency of the ReceivedDebit.
-
#balance_transfer ⇒ Object
readonly
This object stores details about the balance transfer object that resulted in the ReceivedDebit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedDebit.
-
#card_spend ⇒ Object
readonly
This object stores details about the issuing transactions that resulted in the ReceivedDebit.
-
#created ⇒ Object
readonly
The time at which the ReceivedDebit was created.
-
#description ⇒ Object
readonly
Freeform string sent by the originator of the ReceivedDebit.
-
#external_amount ⇒ Object
readonly
The amount and currency of the original/external debit request.
-
#financial_account ⇒ Object
readonly
Financial Account on which funds for ReceivedDebit were debited.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedDebit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this ReceivedDebit.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the ReceivedDebit.
-
#status_transitions ⇒ Object
readonly
The time at which the ReceivedDebit transitioned to a particular status.
-
#stripe_balance_payment ⇒ Object
readonly
This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount and currency of the ReceivedDebit.
231 232 233 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 231 def amount @amount end |
#balance_transfer ⇒ Object (readonly)
This object stores details about the balance transfer object that resulted in the ReceivedDebit.
258 259 260 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 258 def balance_transfer @balance_transfer end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.
260 261 262 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 260 def bank_transfer @bank_transfer end |
#card_spend ⇒ Object (readonly)
This object stores details about the issuing transactions that resulted in the ReceivedDebit. Present if ‘type` field value is `card_spend`.
262 263 264 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 262 def card_spend @card_spend end |
#created ⇒ Object (readonly)
The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.
234 235 236 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 234 def created @created end |
#description ⇒ Object (readonly)
Freeform string sent by the originator of the ReceivedDebit.
236 237 238 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 236 def description @description end |
#external_amount ⇒ Object (readonly)
The amount and currency of the original/external debit request.
238 239 240 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 238 def external_amount @external_amount end |
#financial_account ⇒ Object (readonly)
Financial Account on which funds for ReceivedDebit were debited.
240 241 242 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 240 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedDebit.
242 243 244 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 242 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
256 257 258 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 256 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
244 245 246 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 244 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this ReceivedDebit.
246 247 248 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 246 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedDebit.
248 249 250 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 248 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the ReceivedDebit.
250 251 252 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 250 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the ReceivedDebit transitioned to a particular status.
252 253 254 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 252 def status_transitions @status_transitions end |
#stripe_balance_payment ⇒ Object (readonly)
This object stores details about the Stripe Balance Payment that resulted in the ReceivedDebit.
264 265 266 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 264 def stripe_balance_payment @stripe_balance_payment end |
#type ⇒ Object (readonly)
Open Enum. The type of the ReceivedDebit.
254 255 256 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 254 def type @type end |
Class Method Details
.field_remappings ⇒ Object
279 280 281 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 279 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 266 def self.inner_class_types @inner_class_types = { amount: Amount, external_amount: ExternalAmount, status_details: StatusDetails, status_transitions: StatusTransitions, balance_transfer: BalanceTransfer, bank_transfer: BankTransfer, card_spend: CardSpend, stripe_balance_payment: StripeBalancePayment, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10 def self.object_name "v2.money_management.received_debit" end |