Class: Stripe::V2::MoneyManagement::ReceivedDebit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Overview

ReceivedDebit resource

Defined Under Namespace

Classes: Amount, BankTransfer, StatusDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount and currency of the ReceivedDebit.



110
111
112
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 110

def amount
  @amount
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.



135
136
137
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 135

def bank_transfer
  @bank_transfer
end

#createdObject (readonly)

The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.



113
114
115
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 113

def created
  @created
end

#descriptionObject (readonly)

Freeform string sent by the originator of the ReceivedDebit.



115
116
117
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 115

def description
  @description
end

#financial_accountObject (readonly)

Financial Account on which funds for ReceivedDebit were debited.



117
118
119
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 117

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedDebit.



119
120
121
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 119

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



133
134
135
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 133

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



121
122
123
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 121

def object
  @object
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this ReceivedDebit.



123
124
125
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 123

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedDebit.



125
126
127
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 125

def status
  @status
end

#status_detailsObject (readonly)

Detailed information about the status of the ReceivedDebit.



127
128
129
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 127

def status_details
  @status_details
end

#status_transitionsObject (readonly)

The time at which the ReceivedDebit transitioned to a particular status.



129
130
131
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 129

def status_transitions
  @status_transitions
end

#typeObject (readonly)

Open enum, the type of the received debit.



131
132
133
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 131

def type
  @type
end

Class Method Details

.field_remappingsObject



146
147
148
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 146

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



137
138
139
140
141
142
143
144
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 137

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    status_details: StatusDetails,
    status_transitions: StatusTransitions,
    bank_transfer: BankTransfer,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10

def self.object_name
  "v2.money_management.received_debit"
end