Class: Stripe::V2::MoneyManagement::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedDebit
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Overview
ReceivedDebit resource
Defined Under Namespace
Classes: Amount, BankTransfer, ExternalAmount, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount and currency of the ReceivedDebit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedDebit.
-
#created ⇒ Object
readonly
The time at which the ReceivedDebit was created.
-
#description ⇒ Object
readonly
Freeform string sent by the originator of the ReceivedDebit.
-
#external_amount ⇒ Object
readonly
The amount and currency of the original/external debit request.
-
#financial_account ⇒ Object
readonly
Financial Account on which funds for ReceivedDebit were debited.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedDebit.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this ReceivedDebit.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the ReceivedDebit.
-
#status_transitions ⇒ Object
readonly
The time at which the ReceivedDebit transitioned to a particular status.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount and currency of the ReceivedDebit.
127 128 129 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 127 def amount @amount end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.
154 155 156 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 154 def bank_transfer @bank_transfer end |
#created ⇒ Object (readonly)
The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.
130 131 132 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 130 def created @created end |
#description ⇒ Object (readonly)
Freeform string sent by the originator of the ReceivedDebit.
132 133 134 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 132 def description @description end |
#external_amount ⇒ Object (readonly)
The amount and currency of the original/external debit request.
134 135 136 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 134 def external_amount @external_amount end |
#financial_account ⇒ Object (readonly)
Financial Account on which funds for ReceivedDebit were debited.
136 137 138 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 136 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedDebit.
138 139 140 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 138 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
152 153 154 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 152 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
140 141 142 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 140 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this ReceivedDebit.
142 143 144 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 142 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedDebit.
144 145 146 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 144 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the ReceivedDebit.
146 147 148 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 146 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the ReceivedDebit transitioned to a particular status.
148 149 150 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 148 def status_transitions @status_transitions end |
#type ⇒ Object (readonly)
Open Enum. The type of the ReceivedDebit.
150 151 152 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 150 def type @type end |
Class Method Details
.field_remappings ⇒ Object
166 167 168 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 166 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
156 157 158 159 160 161 162 163 164 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 156 def self.inner_class_types @inner_class_types = { amount: Amount, external_amount: ExternalAmount, status_details: StatusDetails, status_transitions: StatusTransitions, bank_transfer: BankTransfer, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10 def self.object_name "v2.money_management.received_debit" end |