Class: Stripe::V2::MoneyManagement::ReceivedDebit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Overview

ReceivedDebit resource

Defined Under Namespace

Classes: BankTransfer, StatusDetails, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.received_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount and currency of the ReceivedDebit.



55
56
57
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 55

def amount
  @amount
end

#bank_transferObject (readonly)

This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.



80
81
82
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 80

def bank_transfer
  @bank_transfer
end

#createdObject (readonly)

The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.



58
59
60
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 58

def created
  @created
end

#descriptionObject (readonly)

Freeform string sent by the originator of the ReceivedDebit.



60
61
62
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 60

def description
  @description
end

#financial_accountObject (readonly)

Financial Account on which funds for ReceivedDebit were debited.



62
63
64
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 62

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the ReceivedDebit.



64
65
66
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 64

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



78
79
80
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 78

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



66
67
68
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 66

def object
  @object
end

#receipt_urlObject (readonly)

A link to the Stripe-hosted receipt for this ReceivedDebit.



68
69
70
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 68

def receipt_url
  @receipt_url
end

#statusObject (readonly)

Open Enum. The status of the ReceivedDebit.



70
71
72
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 70

def status
  @status
end

#status_detailsObject (readonly)

Detailed information about the status of the ReceivedDebit.



72
73
74
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 72

def status_details
  @status_details
end

#status_transitionsObject (readonly)

The time at which the ReceivedDebit transitioned to a particular status.



74
75
76
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 74

def status_transitions
  @status_transitions
end

#typeObject (readonly)

Open Enum. The type of the ReceivedDebit.



76
77
78
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 76

def type
  @type
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10

def self.object_name
  "v2.money_management.received_debit"
end