Class: Stripe::V2::MoneyManagement::ReceivedDebit
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::ReceivedDebit
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Overview
ReceivedDebit resource
Defined Under Namespace
Classes: BankTransfer, CardSpend, StatusDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.received_debit"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount and currency of the ReceivedDebit.
-
#bank_transfer ⇒ Object
readonly
This object stores details about the originating banking transaction that resulted in the ReceivedDebit.
-
#card_spend ⇒ Object
readonly
This object stores details about the issuing transactions that resulted in the ReceivedDebit.
-
#created ⇒ Object
readonly
The time at which the ReceivedDebit was created.
-
#description ⇒ Object
readonly
Freeform string sent by the originator of the ReceivedDebit.
-
#financial_account ⇒ Object
readonly
Financial Account on which funds for ReceivedDebit were debited.
-
#id ⇒ Object
readonly
Unique identifier for the ReceivedDebit.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#receipt_url ⇒ Object
readonly
A link to the Stripe-hosted receipt for this ReceivedDebit.
-
#status ⇒ Object
readonly
Open Enum.
-
#status_details ⇒ Object
readonly
Detailed information about the status of the ReceivedDebit.
-
#status_transitions ⇒ Object
readonly
The time at which the ReceivedDebit transitioned to a particular status.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount and currency of the ReceivedDebit.
77 78 79 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 77 def amount @amount end |
#bank_transfer ⇒ Object (readonly)
This object stores details about the originating banking transaction that resulted in the ReceivedDebit. Present if ‘type` field value is `bank_transfer`.
100 101 102 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 100 def bank_transfer @bank_transfer end |
#card_spend ⇒ Object (readonly)
This object stores details about the issuing transactions that resulted in the ReceivedDebit. Present if ‘type` field value is `card_spend`.
102 103 104 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 102 def card_spend @card_spend end |
#created ⇒ Object (readonly)
The time at which the ReceivedDebit was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: ‘2022-09-18T13:22:18.123Z`.
80 81 82 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 80 def created @created end |
#description ⇒ Object (readonly)
Freeform string sent by the originator of the ReceivedDebit.
82 83 84 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 82 def description @description end |
#financial_account ⇒ Object (readonly)
Financial Account on which funds for ReceivedDebit were debited.
84 85 86 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 84 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the ReceivedDebit.
86 87 88 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 86 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
88 89 90 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 88 def object @object end |
#receipt_url ⇒ Object (readonly)
A link to the Stripe-hosted receipt for this ReceivedDebit.
90 91 92 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 90 def receipt_url @receipt_url end |
#status ⇒ Object (readonly)
Open Enum. The status of the ReceivedDebit.
92 93 94 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 92 def status @status end |
#status_details ⇒ Object (readonly)
Detailed information about the status of the ReceivedDebit.
94 95 96 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 94 def status_details @status_details end |
#status_transitions ⇒ Object (readonly)
The time at which the ReceivedDebit transitioned to a particular status.
96 97 98 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 96 def status_transitions @status_transitions end |
#type ⇒ Object (readonly)
Open Enum. The type of the ReceivedDebit.
98 99 100 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 98 def type @type end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 10 def self.object_name "v2.money_management.received_debit" end |