Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Defined Under Namespace
Classes: UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#financial_address ⇒ Object
readonly
The Financial Address that was debited.
-
#payment_method_type ⇒ Object
readonly
Open Enum.
-
#statement_descriptor ⇒ Object
readonly
The statement descriptor set by the originator of the debit.
-
#us_bank_account ⇒ Object
readonly
The payment method used to originate the debit.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#financial_address ⇒ Object (readonly)
The Financial Address that was debited.
32 33 34 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 32 def financial_address @financial_address end |
#payment_method_type ⇒ Object (readonly)
Open Enum. The type of the payment method used to originate the debit.
34 35 36 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 34 def payment_method_type @payment_method_type end |
#statement_descriptor ⇒ Object (readonly)
The statement descriptor set by the originator of the debit.
36 37 38 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 36 def statement_descriptor @statement_descriptor end |
#us_bank_account ⇒ Object (readonly)
The payment method used to originate the debit.
38 39 40 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 38 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
44 45 46 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 44 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
40 41 42 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 40 def self.inner_class_types @inner_class_types = { us_bank_account: UsBankAccount } end |