Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Defined Under Namespace

Classes: UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#financial_addressObject (readonly)

The Financial Address that was debited.



46
47
48
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 46

def financial_address
  @financial_address
end

#payment_method_typeObject (readonly)

Open Enum. The type of the payment method used to originate the debit.



48
49
50
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 48

def payment_method_type
  @payment_method_type
end

#statement_descriptorObject (readonly)

The statement descriptor set by the originator of the debit.



50
51
52
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 50

def statement_descriptor
  @statement_descriptor
end

#us_bank_accountObject (readonly)

The payment method used to originate the debit.



52
53
54
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 52

def 
  @us_bank_account
end