Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/received_debit.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

The name of the bank the debit originated from.



39
40
41
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 39

def bank_name
  @bank_name
end

#networkObject (readonly)

Open Enum. The bank network the debit was originated on.



41
42
43
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 41

def network
  @network
end

#routing_numberObject (readonly)

The routing number of the bank that originated the debit.



43
44
45
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 43

def routing_number
  @routing_number
end