Class: Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::ReceivedDebit::BankTransfer::UsBankAccount
- Defined in:
- lib/stripe/resources/v2/money_management/received_debit.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
The name of the bank the debit originated from.
-
#network ⇒ Object
readonly
Open Enum.
-
#routing_number ⇒ Object
readonly
The routing number of the bank that originated the debit.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
The name of the bank the debit originated from.
39 40 41 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 39 def bank_name @bank_name end |
#network ⇒ Object (readonly)
Open Enum. The bank network the debit was originated on.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 41 def network @network end |
#routing_number ⇒ Object (readonly)
The routing number of the bank that originated the debit.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/received_debit.rb', line 43 def routing_number @routing_number end |