Class: Stripe::V2::MoneyManagement::Transaction

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/transaction.rb

Overview

Use Transactions to view changes to your FinancialAccount balance over time. Every flow that moves money, such as OutboundPayments or ReceivedCredits, will have one or more Transactions that describes how the flow impacted your balance. Note that while the FinancialAccount balance will always be up to date, be aware that Transactions and TransactionEntries are created shortly after to reflect changes.

Defined Under Namespace

Classes: Amount, BalanceImpact, Flow, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.transaction"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the Transaction.



138
139
140
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 138

def amount
  @amount
end

#balance_impactObject (readonly)

The delta to the FinancialAccount’s balance. The balance_impact for the Transaction is equal to sum of its TransactionEntries that have ‘effective_at`s in the past.



141
142
143
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 141

def balance_impact
  @balance_impact
end

#categoryObject (readonly)

Open Enum. A descriptive category used to classify the Transaction.



143
144
145
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 143

def category
  @category
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



145
146
147
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 145

def created
  @created
end

#financial_accountObject (readonly)

Indicates the FinancialAccount affected by this Transaction.



147
148
149
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 147

def 
  @financial_account
end

#flowObject (readonly)

Details about the Flow object that created the Transaction.



149
150
151
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 149

def flow
  @flow
end

#idObject (readonly)

Unique identifier for the object.



151
152
153
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 151

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



163
164
165
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 163

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



153
154
155
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 153

def object
  @object
end

#statusObject (readonly)

Closed Enum. Current status of the Transaction. A Transaction is ‘pending` if either `balance_impact.inbound_pending` or `balance_impact.outbound_pending` is non-zero. A Transaction is `posted` if only `balance_impact.available` is non-zero. A Transaction is `void` if there is no balance impact. `posted` and `void` are terminal states, and no additional entries will be added to the Transaction.



159
160
161
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 159

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for when the Transaction transitioned to a particular status.



161
162
163
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 161

def status_transitions
  @status_transitions
end

Class Method Details

.field_remappingsObject



174
175
176
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 174

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



165
166
167
168
169
170
171
172
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 165

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    balance_impact: BalanceImpact,
    flow: Flow,
    status_transitions: StatusTransitions,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 10

def self.object_name
  "v2.money_management.transaction"
end