Class: Stripe::V2::MoneyManagement::Transaction

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/money_management/transaction.rb

Overview

Use Transactions to view changes to your FinancialAccount balance over time. Every flow that moves money, such as OutboundPayments or ReceivedCredits, will have one or more Transactions that describes how the flow impacted your balance. Note that while the FinancialAccount balance will always be up to date, be aware that Transactions and TransactionEntries are created shortly after to reflect changes.

Defined Under Namespace

Classes: BalanceImpact, Flow, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"v2.money_management.transaction"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the Transaction.



49
50
51
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 49

def amount
  @amount
end

#balance_impactObject (readonly)

The delta to the FinancialAccount’s balance. The balance_impact for the Transaction is equal to sum of its TransactionEntries that have ‘effective_at`s in the past.



52
53
54
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 52

def balance_impact
  @balance_impact
end

#categoryObject (readonly)

Open Enum. A descriptive category used to classify the Transaction.



54
55
56
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 54

def category
  @category
end

#createdObject (readonly)

Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



56
57
58
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 56

def created
  @created
end

#financial_accountObject (readonly)

Indicates the FinancialAccount affected by this Transaction.



58
59
60
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 58

def 
  @financial_account
end

#flowObject (readonly)

Details about the Flow object that created the Transaction.



60
61
62
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 60

def flow
  @flow
end

#idObject (readonly)

Unique identifier for the object.



62
63
64
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 62

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



74
75
76
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 74

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



64
65
66
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 64

def object
  @object
end

#statusObject (readonly)

Closed Enum. Current status of the Transaction. A Transaction is ‘pending` if either `balance_impact.inbound_pending` or `balance_impact.outbound_pending` is non-zero. A Transaction is `posted` if only `balance_impact.available` is non-zero. A Transaction is `void` if there is no balance impact. `posted` and `void` are terminal states, and no additional entries will be added to the Transaction.



70
71
72
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 70

def status
  @status
end

#status_transitionsObject (readonly)

Timestamps for when the Transaction transitioned to a particular status.



72
73
74
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 72

def status_transitions
  @status_transitions
end

Class Method Details

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 10

def self.object_name
  "v2.money_management.transaction"
end