Class: Stripe::V2::MoneyManagement::Transaction::Flow

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adjustmentObject (readonly)

If applicable, the ID of the Adjustment that created this Transaction.



46
47
48
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 46

def adjustment
  @adjustment
end

#currency_conversionObject (readonly)

In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.



48
49
50
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 48

def currency_conversion
  @currency_conversion
end

#fee_transactionObject (readonly)

If applicable, the ID of the FeeTransaction that created this Transaction.



50
51
52
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 50

def fee_transaction
  @fee_transaction
end

#inbound_transferObject (readonly)

If applicable, the ID of the InboundTransfer that created this Transaction.



52
53
54
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 52

def inbound_transfer
  @inbound_transfer
end

#outbound_paymentObject (readonly)

If applicable, the ID of the OutboundPayment that created this Transaction.



54
55
56
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 54

def outbound_payment
  @outbound_payment
end

#outbound_transferObject (readonly)

If applicable, the ID of the OutboundTransfer that created this Transaction.



56
57
58
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 56

def outbound_transfer
  @outbound_transfer
end

#received_creditObject (readonly)

If applicable, the ID of the ReceivedCredit that created this Transaction.



58
59
60
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 58

def received_credit
  @received_credit
end

#received_debitObject (readonly)

If applicable, the ID of the ReceivedDebit that created this Transaction.



60
61
62
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 60

def received_debit
  @received_debit
end

#typeObject (readonly)

Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.



62
63
64
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 62

def type
  @type
end

Class Method Details

.field_remappingsObject



68
69
70
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 68

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



64
65
66
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 64

def self.inner_class_types
  @inner_class_types = {}
end