Class: Stripe::V2::MoneyManagement::Transaction::Flow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::Transaction::Flow
- Defined in:
- lib/stripe/resources/v2/money_management/transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
readonly
If applicable, the ID of the Adjustment that created this Transaction.
-
#application_fee ⇒ Object
readonly
If applicable, the ID of the Application Fee that created this Transaction.
-
#application_fee_refund ⇒ Object
readonly
If applicable, the ID of the Application Fee Refund that created this Transaction.
-
#charge ⇒ Object
readonly
If applicable, the ID of the Charge that created this Transaction.
-
#currency_conversion ⇒ Object
readonly
In the future, this will be the ID of the currency conversion that created this Transaction.
-
#dispute ⇒ Object
readonly
If applicable, the ID of the Dispute that created this Transaction.
-
#fee_transaction ⇒ Object
readonly
If applicable, the ID of the FeeTransaction that created this Transaction.
-
#inbound_transfer ⇒ Object
readonly
If applicable, the ID of the InboundTransfer that created this Transaction.
-
#outbound_payment ⇒ Object
readonly
If applicable, the ID of the OutboundPayment that created this Transaction.
-
#outbound_transfer ⇒ Object
readonly
If applicable, the ID of the OutboundTransfer that created this Transaction.
-
#payout ⇒ Object
readonly
If applicable, the ID of the Payout that created this Transaction.
-
#received_credit ⇒ Object
readonly
If applicable, the ID of the ReceivedCredit that created this Transaction.
-
#received_debit ⇒ Object
readonly
If applicable, the ID of the ReceivedDebit that created this Transaction.
-
#refund ⇒ Object
readonly
If applicable, the ID of the Refund that created this Transaction.
-
#reserve_hold ⇒ Object
readonly
If applicable, the ID of the Reserve Hold that created this Transaction.
-
#reserve_release ⇒ Object
readonly
If applicable, the ID of the Reserve Release that created this Transaction.
-
#topup ⇒ Object
readonly
If applicable, the ID of the Topup that created this Transaction.
-
#transfer ⇒ Object
readonly
If applicable, the ID of the Transfer that created this Transaction.
-
#transfer_reversal ⇒ Object
readonly
If applicable, the ID of the Transfer Reversal that created this Transaction.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjustment ⇒ Object (readonly)
If applicable, the ID of the Adjustment that created this Transaction.
98 99 100 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 98 def adjustment @adjustment end |
#application_fee ⇒ Object (readonly)
If applicable, the ID of the Application Fee that created this Transaction.
100 101 102 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 100 def application_fee @application_fee end |
#application_fee_refund ⇒ Object (readonly)
If applicable, the ID of the Application Fee Refund that created this Transaction.
102 103 104 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 102 def application_fee_refund @application_fee_refund end |
#charge ⇒ Object (readonly)
If applicable, the ID of the Charge that created this Transaction.
104 105 106 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 104 def charge @charge end |
#currency_conversion ⇒ Object (readonly)
In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.
106 107 108 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 106 def currency_conversion @currency_conversion end |
#dispute ⇒ Object (readonly)
If applicable, the ID of the Dispute that created this Transaction.
108 109 110 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 108 def dispute @dispute end |
#fee_transaction ⇒ Object (readonly)
If applicable, the ID of the FeeTransaction that created this Transaction.
110 111 112 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 110 def fee_transaction @fee_transaction end |
#inbound_transfer ⇒ Object (readonly)
If applicable, the ID of the InboundTransfer that created this Transaction.
112 113 114 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 112 def inbound_transfer @inbound_transfer end |
#outbound_payment ⇒ Object (readonly)
If applicable, the ID of the OutboundPayment that created this Transaction.
114 115 116 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 114 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
If applicable, the ID of the OutboundTransfer that created this Transaction.
116 117 118 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 116 def outbound_transfer @outbound_transfer end |
#payout ⇒ Object (readonly)
If applicable, the ID of the Payout that created this Transaction.
118 119 120 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 118 def payout @payout end |
#received_credit ⇒ Object (readonly)
If applicable, the ID of the ReceivedCredit that created this Transaction.
120 121 122 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 120 def received_credit @received_credit end |
#received_debit ⇒ Object (readonly)
If applicable, the ID of the ReceivedDebit that created this Transaction.
122 123 124 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 122 def received_debit @received_debit end |
#refund ⇒ Object (readonly)
If applicable, the ID of the Refund that created this Transaction.
124 125 126 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 124 def refund @refund end |
#reserve_hold ⇒ Object (readonly)
If applicable, the ID of the Reserve Hold that created this Transaction.
126 127 128 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 126 def reserve_hold @reserve_hold end |
#reserve_release ⇒ Object (readonly)
If applicable, the ID of the Reserve Release that created this Transaction.
128 129 130 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 128 def reserve_release @reserve_release end |
#topup ⇒ Object (readonly)
If applicable, the ID of the Topup that created this Transaction.
130 131 132 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 130 def topup @topup end |
#transfer ⇒ Object (readonly)
If applicable, the ID of the Transfer that created this Transaction.
132 133 134 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 132 def transfer @transfer end |
#transfer_reversal ⇒ Object (readonly)
If applicable, the ID of the Transfer Reversal that created this Transaction.
134 135 136 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 134 def transfer_reversal @transfer_reversal end |
#type ⇒ Object (readonly)
Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.
96 97 98 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 96 def type @type end |
Class Method Details
.field_remappings ⇒ Object
140 141 142 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 140 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
136 137 138 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 136 def self.inner_class_types @inner_class_types = {} end |