Class: Stripe::V2::MoneyManagement::Transaction::Flow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::Transaction::Flow
- Defined in:
- lib/stripe/resources/v2/money_management/transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
readonly
If applicable, the ID of the Adjustment that created this Transaction.
-
#currency_conversion ⇒ Object
readonly
In the future, this will be the ID of the currency conversion that created this Transaction.
-
#fee_transaction ⇒ Object
readonly
If applicable, the ID of the FeeTransaction that created this Transaction.
-
#inbound_transfer ⇒ Object
readonly
If applicable, the ID of the InboundTransfer that created this Transaction.
-
#outbound_payment ⇒ Object
readonly
If applicable, the ID of the OutboundPayment that created this Transaction.
-
#outbound_transfer ⇒ Object
readonly
If applicable, the ID of the OutboundTransfer that created this Transaction.
-
#received_credit ⇒ Object
readonly
If applicable, the ID of the ReceivedCredit that created this Transaction.
-
#received_debit ⇒ Object
readonly
If applicable, the ID of the ReceivedDebit that created this Transaction.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjustment ⇒ Object (readonly)
If applicable, the ID of the Adjustment that created this Transaction.
98 99 100 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 98 def adjustment @adjustment end |
#currency_conversion ⇒ Object (readonly)
In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.
100 101 102 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 100 def currency_conversion @currency_conversion end |
#fee_transaction ⇒ Object (readonly)
If applicable, the ID of the FeeTransaction that created this Transaction.
102 103 104 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 102 def fee_transaction @fee_transaction end |
#inbound_transfer ⇒ Object (readonly)
If applicable, the ID of the InboundTransfer that created this Transaction.
104 105 106 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 104 def inbound_transfer @inbound_transfer end |
#outbound_payment ⇒ Object (readonly)
If applicable, the ID of the OutboundPayment that created this Transaction.
106 107 108 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 106 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
If applicable, the ID of the OutboundTransfer that created this Transaction.
108 109 110 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 108 def outbound_transfer @outbound_transfer end |
#received_credit ⇒ Object (readonly)
If applicable, the ID of the ReceivedCredit that created this Transaction.
110 111 112 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 110 def received_credit @received_credit end |
#received_debit ⇒ Object (readonly)
If applicable, the ID of the ReceivedDebit that created this Transaction.
112 113 114 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 112 def received_debit @received_debit end |
#type ⇒ Object (readonly)
Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.
96 97 98 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 96 def type @type end |
Class Method Details
.field_remappings ⇒ Object
118 119 120 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 118 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
114 115 116 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 114 def self.inner_class_types @inner_class_types = {} end |