Class: Stripe::V2::MoneyManagement::Transaction::Flow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::Transaction::Flow
- Defined in:
- lib/stripe/resources/v2/money_management/transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
readonly
If applicable, the ID of the Adjustment that created this Transaction.
-
#currency_conversion ⇒ Object
readonly
In the future, this will be the ID of the currency conversion that created this Transaction.
-
#fee_transaction ⇒ Object
readonly
If applicable, the ID of the FeeTransaction that created this Transaction.
-
#inbound_transfer ⇒ Object
readonly
If applicable, the ID of the InboundTransfer that created this Transaction.
-
#outbound_payment ⇒ Object
readonly
If applicable, the ID of the OutboundPayment that created this Transaction.
-
#outbound_transfer ⇒ Object
readonly
If applicable, the ID of the OutboundTransfer that created this Transaction.
-
#received_credit ⇒ Object
readonly
If applicable, the ID of the ReceivedCredit that created this Transaction.
-
#received_debit ⇒ Object
readonly
If applicable, the ID of the ReceivedDebit that created this Transaction.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjustment ⇒ Object (readonly)
If applicable, the ID of the Adjustment that created this Transaction.
35 36 37 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 35 def adjustment @adjustment end |
#currency_conversion ⇒ Object (readonly)
In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.
37 38 39 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 37 def currency_conversion @currency_conversion end |
#fee_transaction ⇒ Object (readonly)
If applicable, the ID of the FeeTransaction that created this Transaction.
39 40 41 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 39 def fee_transaction @fee_transaction end |
#inbound_transfer ⇒ Object (readonly)
If applicable, the ID of the InboundTransfer that created this Transaction.
41 42 43 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 41 def inbound_transfer @inbound_transfer end |
#outbound_payment ⇒ Object (readonly)
If applicable, the ID of the OutboundPayment that created this Transaction.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 43 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
If applicable, the ID of the OutboundTransfer that created this Transaction.
45 46 47 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 45 def outbound_transfer @outbound_transfer end |
#received_credit ⇒ Object (readonly)
If applicable, the ID of the ReceivedCredit that created this Transaction.
47 48 49 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 47 def received_credit @received_credit end |
#received_debit ⇒ Object (readonly)
If applicable, the ID of the ReceivedDebit that created this Transaction.
49 50 51 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 49 def received_debit @received_debit end |
#type ⇒ Object (readonly)
Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.
33 34 35 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 33 def type @type end |
Class Method Details
.field_remappings ⇒ Object
55 56 57 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 55 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
51 52 53 |
# File 'lib/stripe/resources/v2/money_management/transaction.rb', line 51 def self.inner_class_types @inner_class_types = {} end |