Class: Stripe::V2::MoneyManagement::TransactionEntry
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::MoneyManagement::TransactionEntry
- Defined in:
- lib/stripe/resources/v2/money_management/transaction_entry.rb
Overview
TransactionEntries represent individual money movements across different states within a Transaction.
Defined Under Namespace
Classes: BalanceImpact, TransactionDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.money_management.transaction_entry"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance_impact ⇒ Object
readonly
The delta to the FinancialAccount’s balance.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#effective_at ⇒ Object
readonly
Time at which the entry impacted (or will impact if it’s in the future) the FinancialAccount balance.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#transaction ⇒ Object
readonly
The Transaction that this TransactionEntry belongs to.
-
#transaction_details ⇒ Object
readonly
Details copied from the transaction that this TransactionEntry belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance_impact ⇒ Object (readonly)
The delta to the FinancialAccount’s balance.
50 51 52 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 50 def balance_impact @balance_impact end |
#created ⇒ Object (readonly)
Time at which the object was created.
52 53 54 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 52 def created @created end |
#effective_at ⇒ Object (readonly)
Time at which the entry impacted (or will impact if it’s in the future) the FinancialAccount balance.
54 55 56 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 54 def effective_at @effective_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
56 57 58 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 56 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
58 59 60 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 58 def object @object end |
#transaction ⇒ Object (readonly)
The Transaction that this TransactionEntry belongs to.
60 61 62 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 60 def transaction @transaction end |
#transaction_details ⇒ Object (readonly)
Details copied from the transaction that this TransactionEntry belongs to.
62 63 64 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 62 def transaction_details @transaction_details end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 10 def self.object_name "v2.money_management.transaction_entry" end |