Class: Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails
- Defined in:
- lib/stripe/resources/v2/money_management/transaction_entry.rb
Defined Under Namespace
Classes: Flow
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Closed Enum for now, and will be turned into an Open Enum soon.
-
#financial_account ⇒ Object
readonly
Indicates the FinancialAccount affected by this Transaction.
-
#flow ⇒ Object
readonly
Details about the Flow object that created the Transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Closed Enum for now, and will be turned into an Open Enum soon. A descriptive category used to classify the Transaction.
61 62 63 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 61 def category @category end |
#financial_account ⇒ Object (readonly)
Indicates the FinancialAccount affected by this Transaction.
63 64 65 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 63 def financial_account @financial_account end |
#flow ⇒ Object (readonly)
Details about the Flow object that created the Transaction.
65 66 67 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 65 def flow @flow end |
Class Method Details
.field_remappings ⇒ Object
71 72 73 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 71 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
67 68 69 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 67 def self.inner_class_types @inner_class_types = { flow: Flow } end |