Class: Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/transaction_entry.rb

Defined Under Namespace

Classes: Flow

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

Closed Enum for now, and will be turned into an Open Enum soon. A descriptive category used to classify the Transaction.



109
110
111
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 109

def category
  @category
end

#financial_accountObject (readonly)

Indicates the FinancialAccount affected by this Transaction.



111
112
113
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 111

def 
  @financial_account
end

#flowObject (readonly)

Details about the Flow object that created the Transaction.



113
114
115
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 113

def flow
  @flow
end

Class Method Details

.field_remappingsObject



119
120
121
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 119

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



115
116
117
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 115

def self.inner_class_types
  @inner_class_types = { flow: Flow }
end