Class: Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails
- Defined in:
- lib/stripe/resources/v2/money_management/transaction_entry.rb
Defined Under Namespace
Classes: Flow
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Closed Enum for now, and will be turned into an Open Enum soon.
-
#financial_account ⇒ Object
readonly
Indicates the FinancialAccount affected by this Transaction.
-
#flow ⇒ Object
readonly
Details about the Flow object that created the Transaction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Closed Enum for now, and will be turned into an Open Enum soon. A descriptive category used to classify the Transaction.
43 44 45 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 43 def category @category end |
#financial_account ⇒ Object (readonly)
Indicates the FinancialAccount affected by this Transaction.
45 46 47 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 45 def financial_account @financial_account end |
#flow ⇒ Object (readonly)
Details about the Flow object that created the Transaction.
47 48 49 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 47 def flow @flow end |