Class: Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails::Flow

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/money_management/transaction_entry.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adjustmentObject (readonly)

If applicable, the ID of the Adjustment that created this Transaction.



84
85
86
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 84

def adjustment
  @adjustment
end

#currency_conversionObject (readonly)

In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.



86
87
88
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 86

def currency_conversion
  @currency_conversion
end

#fee_transactionObject (readonly)

If applicable, the ID of the FeeTransaction that created this Transaction.



88
89
90
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 88

def fee_transaction
  @fee_transaction
end

#inbound_transferObject (readonly)

If applicable, the ID of the InboundTransfer that created this Transaction.



90
91
92
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 90

def inbound_transfer
  @inbound_transfer
end

#outbound_paymentObject (readonly)

If applicable, the ID of the OutboundPayment that created this Transaction.



92
93
94
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 92

def outbound_payment
  @outbound_payment
end

#outbound_transferObject (readonly)

If applicable, the ID of the OutboundTransfer that created this Transaction.



94
95
96
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 94

def outbound_transfer
  @outbound_transfer
end

#received_creditObject (readonly)

If applicable, the ID of the ReceivedCredit that created this Transaction.



96
97
98
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 96

def received_credit
  @received_credit
end

#received_debitObject (readonly)

If applicable, the ID of the ReceivedDebit that created this Transaction.



98
99
100
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 98

def received_debit
  @received_debit
end

#typeObject (readonly)

Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.



82
83
84
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 82

def type
  @type
end

Class Method Details

.field_remappingsObject



104
105
106
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 104

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



100
101
102
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 100

def self.inner_class_types
  @inner_class_types = {}
end