Class: Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails::Flow
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::MoneyManagement::TransactionEntry::TransactionDetails::Flow
- Defined in:
- lib/stripe/resources/v2/money_management/transaction_entry.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
readonly
If applicable, the ID of the Adjustment that created this Transaction.
-
#currency_conversion ⇒ Object
readonly
In the future, this will be the ID of the currency conversion that created this Transaction.
-
#fee_transaction ⇒ Object
readonly
If applicable, the ID of the FeeTransaction that created this Transaction.
-
#inbound_transfer ⇒ Object
readonly
If applicable, the ID of the InboundTransfer that created this Transaction.
-
#outbound_payment ⇒ Object
readonly
If applicable, the ID of the OutboundPayment that created this Transaction.
-
#outbound_transfer ⇒ Object
readonly
If applicable, the ID of the OutboundTransfer that created this Transaction.
-
#received_credit ⇒ Object
readonly
If applicable, the ID of the ReceivedCredit that created this Transaction.
-
#received_debit ⇒ Object
readonly
If applicable, the ID of the ReceivedDebit that created this Transaction.
-
#type ⇒ Object
readonly
Open Enum.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjustment ⇒ Object (readonly)
If applicable, the ID of the Adjustment that created this Transaction.
28 29 30 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 28 def adjustment @adjustment end |
#currency_conversion ⇒ Object (readonly)
In the future, this will be the ID of the currency conversion that created this Transaction. For now, this field is always null.
30 31 32 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 30 def currency_conversion @currency_conversion end |
#fee_transaction ⇒ Object (readonly)
If applicable, the ID of the FeeTransaction that created this Transaction.
32 33 34 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 32 def fee_transaction @fee_transaction end |
#inbound_transfer ⇒ Object (readonly)
If applicable, the ID of the InboundTransfer that created this Transaction.
34 35 36 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 34 def inbound_transfer @inbound_transfer end |
#outbound_payment ⇒ Object (readonly)
If applicable, the ID of the OutboundPayment that created this Transaction.
36 37 38 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 36 def outbound_payment @outbound_payment end |
#outbound_transfer ⇒ Object (readonly)
If applicable, the ID of the OutboundTransfer that created this Transaction.
38 39 40 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 38 def outbound_transfer @outbound_transfer end |
#received_credit ⇒ Object (readonly)
If applicable, the ID of the ReceivedCredit that created this Transaction.
40 41 42 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 40 def received_credit @received_credit end |
#received_debit ⇒ Object (readonly)
If applicable, the ID of the ReceivedDebit that created this Transaction.
42 43 44 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 42 def received_debit @received_debit end |
#type ⇒ Object (readonly)
Open Enum. Type of the flow that created the Transaction. The field matching this value will contain the ID of the flow.
26 27 28 |
# File 'lib/stripe/resources/v2/money_management/transaction_entry.rb', line 26 def type @type end |