Class: Stripe::V2::Network::BusinessProfile
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Network::BusinessProfile
- Defined in:
- lib/stripe/resources/v2/network/business_profile.rb
Overview
The Stripe profile represents a business’ public identity on the Stripe network.
Defined Under Namespace
Classes: Branding
Constant Summary collapse
- OBJECT_NAME =
"v2.network.business_profile"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#branding ⇒ Object
readonly
Branding data for the business.
-
#description ⇒ Object
readonly
The description of the business.
-
#display_name ⇒ Object
readonly
The display name of the Stripe profile.
-
#id ⇒ Object
readonly
The ID of the Stripe business profile; also known as the Network ID.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#url ⇒ Object
readonly
The URL of the business.
-
#username ⇒ Object
readonly
The username of the Stripe profile.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#branding ⇒ Object (readonly)
Branding data for the business.
58 59 60 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 58 def branding @branding end |
#description ⇒ Object (readonly)
The description of the business.
60 61 62 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 60 def description @description end |
#display_name ⇒ Object (readonly)
The display name of the Stripe profile.
62 63 64 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 62 def display_name @display_name end |
#id ⇒ Object (readonly)
The ID of the Stripe business profile; also known as the Network ID. This is the ID used to identify the business on the Stripe network.
64 65 66 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 64 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
66 67 68 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 66 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
68 69 70 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 68 def object @object end |
#url ⇒ Object (readonly)
The URL of the business.
70 71 72 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 70 def url @url end |
#username ⇒ Object (readonly)
The username of the Stripe profile.
72 73 74 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 72 def username @username end |
Class Method Details
.field_remappings ⇒ Object
78 79 80 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 78 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
74 75 76 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 74 def self.inner_class_types @inner_class_types = { branding: Branding } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/network/business_profile.rb', line 10 def self.object_name "v2.network.business_profile" end |