Class: Stripe::V2::OrchestratedCommerce::Agreement
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::OrchestratedCommerce::Agreement
- Defined in:
- lib/stripe/resources/v2/orchestrated_commerce/agreement.rb
Overview
An Orchestrated Commerce Agreement represents a mutual agreement between a seller and an orchestrator/agent on the Stripe network.
Defined Under Namespace
Classes: OrchestratorDetails, SellerDetails, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"v2.orchestrated_commerce.agreement"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
The time at which the agreement was created.
-
#id ⇒ Object
readonly
The unique identifier for the agreement.
-
#initiated_by ⇒ Object
readonly
The party that initiated the agreement.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#orchestrator_details ⇒ Object
readonly
Details about the orchestrator.
-
#seller_details ⇒ Object
readonly
Details about the seller.
-
#status ⇒ Object
readonly
The current status of the agreement.
-
#status_transitions ⇒ Object
readonly
Timestamps of key status transitions for the agreement.
-
#terminated_by ⇒ Object
readonly
The party that terminated the agreement, if applicable.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
The time at which the agreement was created.
59 60 61 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 59 def created @created end |
#id ⇒ Object (readonly)
The unique identifier for the agreement.
61 62 63 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 61 def id @id end |
#initiated_by ⇒ Object (readonly)
The party that initiated the agreement.
63 64 65 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 63 def initiated_by @initiated_by end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
65 66 67 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 65 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
67 68 69 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 67 def object @object end |
#orchestrator_details ⇒ Object (readonly)
Details about the orchestrator.
69 70 71 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 69 def orchestrator_details @orchestrator_details end |
#seller_details ⇒ Object (readonly)
Details about the seller.
71 72 73 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 71 def seller_details @seller_details end |
#status ⇒ Object (readonly)
The current status of the agreement.
73 74 75 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 73 def status @status end |
#status_transitions ⇒ Object (readonly)
Timestamps of key status transitions for the agreement.
75 76 77 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 75 def status_transitions @status_transitions end |
#terminated_by ⇒ Object (readonly)
The party that terminated the agreement, if applicable.
77 78 79 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 77 def terminated_by @terminated_by end |
Class Method Details
.field_remappings ⇒ Object
87 88 89 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 87 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
79 80 81 82 83 84 85 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 79 def self.inner_class_types @inner_class_types = { orchestrator_details: OrchestratorDetails, seller_details: SellerDetails, status_transitions: StatusTransitions, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/orchestrated_commerce/agreement.rb', line 10 def self.object_name "v2.orchestrated_commerce.agreement" end |