Class: Stripe::V2::OrchestratedCommerce::AgreementListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::OrchestratedCommerce::AgreementListParams
- Defined in:
- lib/stripe/params/v2/orchestrated_commerce/agreement_list_params.rb
Instance Attribute Summary collapse
-
#limit ⇒ Object
The limit for the number of results per page.
-
#network_business_profile ⇒ Object
Filter list to Orchestrated Commerce Agreements with a specific counterparty.
Instance Method Summary collapse
-
#initialize(limit: nil, network_business_profile: nil) ⇒ AgreementListParams
constructor
A new instance of AgreementListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(limit: nil, network_business_profile: nil) ⇒ AgreementListParams
Returns a new instance of AgreementListParams.
13 14 15 16 |
# File 'lib/stripe/params/v2/orchestrated_commerce/agreement_list_params.rb', line 13 def initialize(limit: nil, network_business_profile: nil) @limit = limit @network_business_profile = network_business_profile end |
Instance Attribute Details
#limit ⇒ Object
The limit for the number of results per page.
9 10 11 |
# File 'lib/stripe/params/v2/orchestrated_commerce/agreement_list_params.rb', line 9 def limit @limit end |
#network_business_profile ⇒ Object
Filter list to Orchestrated Commerce Agreements with a specific counterparty.
11 12 13 |
# File 'lib/stripe/params/v2/orchestrated_commerce/agreement_list_params.rb', line 11 def network_business_profile @network_business_profile end |