Class: Stripe::V2::Payments::OffSessionPayment

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/payments/off_session_payment.rb

Overview

OffSessionPayment resource.

Defined Under Namespace

Classes: AmountCapturable, AmountRequested, Capture, PaymentsOrchestration, RetryDetails, TransferData

Constant Summary collapse

OBJECT_NAME =
"v2.payments.off_session_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_capturableObject (readonly)

The amount available to be captured.



111
112
113
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 111

def amount_capturable
  @amount_capturable
end

#amount_requestedObject (readonly)

The “presentment amount” to be collected from the customer.



113
114
115
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 113

def amount_requested
  @amount_requested
end

#cadenceObject (readonly)

The frequency of the underlying payment.



115
116
117
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 115

def cadence
  @cadence
end

#captureObject (readonly)

Details about the capture configuration for the OffSessionPayment.



117
118
119
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 117

def capture
  @capture
end

#compartment_idObject (readonly)

ID of the owning compartment.



119
120
121
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 119

def compartment_id
  @compartment_id
end

#createdObject (readonly)

Creation time of the OffSessionPayment. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.



122
123
124
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 122

def created
  @created
end

#customerObject (readonly)

ID of the Customer to which this OffSessionPayment belongs.



124
125
126
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 124

def customer
  @customer
end

#failure_reasonObject (readonly)

The reason why the OffSessionPayment failed.



126
127
128
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 126

def failure_reason
  @failure_reason
end

#idObject (readonly)

Unique identifier for the object.



128
129
130
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 128

def id
  @id
end

#last_authorization_attempt_errorObject (readonly)

The payment error encountered in the previous attempt to authorize the payment.



130
131
132
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 130

def last_authorization_attempt_error
  @last_authorization_attempt_error
end

#latest_payment_attempt_recordObject (readonly)

Payment attempt record for the latest attempt, if one exists.



132
133
134
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 132

def latest_payment_attempt_record
  @latest_payment_attempt_record
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



134
135
136
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 134

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).



139
140
141
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 139

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



141
142
143
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 141

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the funds of the OffSessionPayment are intended.



143
144
145
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 143

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method used in this OffSessionPayment.



145
146
147
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 145

def payment_method
  @payment_method
end

#payment_recordObject (readonly)

Payment record associated with the OffSessionPayment.



147
148
149
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 147

def payment_record
  @payment_record
end

#payments_orchestrationObject (readonly)

Details about the payments orchestration configuration.



149
150
151
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 149

def payments_orchestration
  @payments_orchestration
end

#retry_detailsObject (readonly)

Details about the OffSessionPayment retries.



151
152
153
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 151

def retry_details
  @retry_details
end

#statement_descriptorObject (readonly)

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



156
157
158
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 156

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



160
161
162
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 160

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#statusObject (readonly)

Status of this OffSessionPayment, one of ‘pending`, `pending_retry`, `processing`, `failed`, `canceled`, `requires_capture`, or `succeeded`.



163
164
165
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 163

def status
  @status
end

#test_clockObject (readonly)

Test clock that can be used to advance the retry attempts in a sandbox.



165
166
167
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 165

def test_clock
  @test_clock
end

#transfer_dataObject (readonly)

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).



167
168
169
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 167

def transfer_data
  @transfer_data
end

Class Method Details

.field_remappingsObject



180
181
182
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 180

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



169
170
171
172
173
174
175
176
177
178
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 169

def self.inner_class_types
  @inner_class_types = {
    amount_capturable: AmountCapturable,
    amount_requested: AmountRequested,
    capture: Capture,
    payments_orchestration: PaymentsOrchestration,
    retry_details: RetryDetails,
    transfer_data: TransferData,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 10

def self.object_name
  "v2.payments.off_session_payment"
end