Class: Stripe::V2::Payments::OffSessionPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Payments::OffSessionPayment
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Overview
OffSessionPayment resource.
Defined Under Namespace
Classes: AmountDetails, Capture, PaymentsOrchestration, RetryDetails, TransferData
Constant Summary collapse
- OBJECT_NAME =
"v2.payments.off_session_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_capturable ⇒ Object
readonly
The amount available to be captured.
-
#amount_details ⇒ Object
readonly
Provides industry-specific information about the amount.
-
#amount_requested ⇒ Object
readonly
The “presentment amount” to be collected from the customer.
-
#cadence ⇒ Object
readonly
The frequency of the underlying payment.
-
#capture ⇒ Object
readonly
Details about the capture configuration for the OffSessionPayment.
-
#capture_method ⇒ Object
readonly
Whether the OffSessionPayment should be captured automatically or manually.
-
#compartment_id ⇒ Object
readonly
ID of the owning compartment.
-
#created ⇒ Object
readonly
Creation time of the OffSessionPayment.
-
#customer ⇒ Object
readonly
ID of the Customer to which this OffSessionPayment belongs.
-
#failure_reason ⇒ Object
readonly
The reason why the OffSessionPayment failed.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_authorization_attempt_error ⇒ Object
readonly
The payment error encountered in the previous attempt to authorize the payment.
-
#latest_payment_attempt_record ⇒ Object
readonly
Payment attempt record for the latest attempt, if one exists.
-
#livemode ⇒ Object
readonly
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) for which the funds of the OffSessionPayment are intended.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this OffSessionPayment.
-
#payment_record ⇒ Object
readonly
Payment record associated with the OffSessionPayment.
-
#payments_orchestration ⇒ Object
readonly
Details about the payments orchestration configuration.
-
#retry_details ⇒ Object
readonly
Details about the OffSessionPayment retries.
-
#statement_descriptor ⇒ Object
readonly
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
Status of this OffSessionPayment, one of ‘pending`, `pending_retry`, `processing`, `failed`, `canceled`, `requires_capture`, or `succeeded`.
-
#test_clock ⇒ Object
readonly
Test clock that can be used to advance the retry attempts in a sandbox.
-
#transfer_data ⇒ Object
readonly
The data that automatically creates a Transfer after the payment finalizes.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_capturable ⇒ Object (readonly)
The amount available to be captured.
164 165 166 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 164 def amount_capturable @amount_capturable end |
#amount_details ⇒ Object (readonly)
Provides industry-specific information about the amount.
166 167 168 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 166 def amount_details @amount_details end |
#amount_requested ⇒ Object (readonly)
The “presentment amount” to be collected from the customer.
168 169 170 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 168 def amount_requested @amount_requested end |
#cadence ⇒ Object (readonly)
The frequency of the underlying payment.
170 171 172 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 170 def cadence @cadence end |
#capture ⇒ Object (readonly)
Details about the capture configuration for the OffSessionPayment.
172 173 174 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 172 def capture @capture end |
#capture_method ⇒ Object (readonly)
Whether the OffSessionPayment should be captured automatically or manually.
174 175 176 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 174 def capture_method @capture_method end |
#compartment_id ⇒ Object (readonly)
ID of the owning compartment.
176 177 178 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 176 def compartment_id @compartment_id end |
#created ⇒ Object (readonly)
Creation time of the OffSessionPayment. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
179 180 181 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 179 def created @created end |
#customer ⇒ Object (readonly)
ID of the Customer to which this OffSessionPayment belongs.
181 182 183 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 181 def customer @customer end |
#failure_reason ⇒ Object (readonly)
The reason why the OffSessionPayment failed.
183 184 185 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 183 def failure_reason @failure_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object.
185 186 187 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 185 def id @id end |
#last_authorization_attempt_error ⇒ Object (readonly)
The payment error encountered in the previous attempt to authorize the payment.
187 188 189 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 187 def @last_authorization_attempt_error end |
#latest_payment_attempt_record ⇒ Object (readonly)
Payment attempt record for the latest attempt, if one exists.
189 190 191 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 189 def latest_payment_attempt_record @latest_payment_attempt_record end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
191 192 193 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 191 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.corp.stripe.com/payments/payment-intents#storing-information-in-metadata).
196 197 198 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 196 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
198 199 200 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 198 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) for which the funds of the OffSessionPayment are intended.
200 201 202 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 200 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this OffSessionPayment.
202 203 204 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 202 def payment_method @payment_method end |
#payment_record ⇒ Object (readonly)
Payment record associated with the OffSessionPayment.
204 205 206 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 204 def payment_record @payment_record end |
#payments_orchestration ⇒ Object (readonly)
Details about the payments orchestration configuration.
206 207 208 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 206 def payments_orchestration @payments_orchestration end |
#retry_details ⇒ Object (readonly)
Details about the OffSessionPayment retries.
208 209 210 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 208 def retry_details @retry_details end |
#statement_descriptor ⇒ Object (readonly)
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
213 214 215 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 213 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
217 218 219 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 217 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
Status of this OffSessionPayment, one of ‘pending`, `pending_retry`, `processing`, `failed`, `canceled`, `requires_capture`, or `succeeded`.
220 221 222 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 220 def status @status end |
#test_clock ⇒ Object (readonly)
Test clock that can be used to advance the retry attempts in a sandbox.
222 223 224 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 222 def test_clock @test_clock end |
#transfer_data ⇒ Object (readonly)
The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.corp.stripe.com/payments/connected-accounts).
224 225 226 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 224 def transfer_data @transfer_data end |
Class Method Details
.field_remappings ⇒ Object
236 237 238 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 236 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
226 227 228 229 230 231 232 233 234 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 226 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails, capture: Capture, payments_orchestration: PaymentsOrchestration, retry_details: RetryDetails, transfer_data: TransferData, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 10 def self.object_name "v2.payments.off_session_payment" end |