Class: Stripe::V2::Payments::OffSessionPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Payments::OffSessionPayment
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Overview
OffSessionPayment resource.
Defined Under Namespace
Classes: RetryDetails, TransferData
Constant Summary collapse
- OBJECT_NAME =
"v2.payments.off_session_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
readonly
The “presentment amount” to be collected from the customer.
-
#cadence ⇒ Object
readonly
The frequency of the underlying payment.
-
#compartment_id ⇒ Object
readonly
ID of the owning compartment.
-
#created ⇒ Object
readonly
Creation time of the OffSessionPayment.
-
#customer ⇒ Object
readonly
ID of the Customer to which this OffSessionPayment belongs.
-
#failure_reason ⇒ Object
readonly
The reason why the OffSessionPayment failed.
-
#id ⇒ Object
readonly
Unique identifier for the object..
-
#last_authorization_attempt_error ⇒ Object
readonly
The payment error encountered in the previous attempt to authorize the payment.
-
#latest_payment_attempt_record ⇒ Object
readonly
Payment attempt record for the latest attempt, if one exists.
-
#livemode ⇒ Object
readonly
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) for which the funds of the OffSessionPayment are intended.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this OffSessionPayment.
-
#payment_record ⇒ Object
readonly
Payment record associated with the OffSessionPayment.
-
#retry_details ⇒ Object
readonly
Details about the OffSessionPayment retries.
-
#statement_descriptor ⇒ Object
readonly
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
Status of this OffSessionPayment, one of ‘pending`, `pending_retry`, `processing`, `failed`, `canceled`, `requires_capture`, or `succeeded`.
-
#test_clock ⇒ Object
readonly
Test clock that can be used to advance the retry attempts in a sandbox.
-
#transfer_data ⇒ Object
readonly
The data that automatically creates a Transfer after the payment finalizes.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_requested ⇒ Object (readonly)
The “presentment amount” to be collected from the customer.
51 52 53 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 51 def amount_requested @amount_requested end |
#cadence ⇒ Object (readonly)
The frequency of the underlying payment.
53 54 55 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 53 def cadence @cadence end |
#compartment_id ⇒ Object (readonly)
ID of the owning compartment.
55 56 57 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 55 def compartment_id @compartment_id end |
#created ⇒ Object (readonly)
Creation time of the OffSessionPayment. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
58 59 60 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 58 def created @created end |
#customer ⇒ Object (readonly)
ID of the Customer to which this OffSessionPayment belongs.
60 61 62 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 60 def customer @customer end |
#failure_reason ⇒ Object (readonly)
The reason why the OffSessionPayment failed.
62 63 64 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 62 def failure_reason @failure_reason end |
#id ⇒ Object (readonly)
Unique identifier for the object..
64 65 66 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 64 def id @id end |
#last_authorization_attempt_error ⇒ Object (readonly)
The payment error encountered in the previous attempt to authorize the payment.
66 67 68 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 66 def @last_authorization_attempt_error end |
#latest_payment_attempt_record ⇒ Object (readonly)
Payment attempt record for the latest attempt, if one exists.
68 69 70 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 68 def latest_payment_attempt_record @latest_payment_attempt_record end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
70 71 72 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 70 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.corp.stripe.com/payments/payment-intents#storing-information-in-metadata).
75 76 77 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 75 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
77 78 79 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 77 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) for which the funds of the OffSessionPayment are intended.
79 80 81 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 79 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this OffSessionPayment.
81 82 83 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 81 def payment_method @payment_method end |
#payment_record ⇒ Object (readonly)
Payment record associated with the OffSessionPayment.
83 84 85 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 83 def payment_record @payment_record end |
#retry_details ⇒ Object (readonly)
Details about the OffSessionPayment retries.
85 86 87 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 85 def retry_details @retry_details end |
#statement_descriptor ⇒ Object (readonly)
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
90 91 92 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 90 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
94 95 96 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 94 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
Status of this OffSessionPayment, one of ‘pending`, `pending_retry`, `processing`, `failed`, `canceled`, `requires_capture`, or `succeeded`.
97 98 99 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 97 def status @status end |
#test_clock ⇒ Object (readonly)
Test clock that can be used to advance the retry attempts in a sandbox.
99 100 101 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 99 def test_clock @test_clock end |
#transfer_data ⇒ Object (readonly)
The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.corp.stripe.com/payments/connected-accounts).
101 102 103 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 101 def transfer_data @transfer_data end |
Class Method Details
.field_remappings ⇒ Object
107 108 109 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 107 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
103 104 105 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 103 def self.inner_class_types @inner_class_types = { retry_details: RetryDetails, transfer_data: TransferData } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 10 def self.object_name "v2.payments.off_session_payment" end |