Class: Stripe::V2::Payments::OffSessionPayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Payments::OffSessionPayment
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Overview
Off-session payment resource.
Defined Under Namespace
Classes: RetryDetails, TransferData
Constant Summary collapse
- OBJECT_NAME =
"v2.payments.off_session_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
readonly
The amount you requested to be collected on the OSP upon creation.
-
#cadence ⇒ Object
readonly
The frequency of the underlying payment that this OSP represents.
-
#compartment_id ⇒ Object
readonly
ID of owning compartment.
-
#created ⇒ Object
readonly
Timestamp of creation.
-
#customer ⇒ Object
readonly
Customer owning the supplied payment method.
-
#failure_reason ⇒ Object
readonly
Reason why the OSP failed.
-
#id ⇒ Object
readonly
ID of the OSP.
-
#last_authorization_attempt_error ⇒ Object
readonly
Last error returned by the financial partner for a failed authorization.
-
#latest_payment_attempt_record ⇒ Object
readonly
Payment attempt record for the latest attempt, if one exists.
-
#livemode ⇒ Object
readonly
True if the txn is livemode, false otherwise.
-
#metadata ⇒ Object
readonly
Metadata you provided.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
OBO, same as on the PI.
-
#payment_method ⇒ Object
readonly
ID of payment method.
-
#payment_record ⇒ Object
readonly
Payment record associated with the OSP.
-
#retry_details ⇒ Object
readonly
Details about the OSP retries.
-
#statement_descriptor ⇒ Object
readonly
Statement descriptor you provided.
-
#statement_descriptor_suffix ⇒ Object
readonly
Statement descriptor suffix you provided, similar to that on the PI.
-
#status ⇒ Object
readonly
Status of the OSP.
-
#test_clock ⇒ Object
readonly
Test clock to be used to advance the retry attempts.
-
#transfer_data ⇒ Object
readonly
Instructions for the transfer to be made with this OSP after successful money movement.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_requested ⇒ Object (readonly)
The amount you requested to be collected on the OSP upon creation.
28 29 30 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 28 def amount_requested @amount_requested end |
#cadence ⇒ Object (readonly)
The frequency of the underlying payment that this OSP represents.
30 31 32 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 30 def cadence @cadence end |
#compartment_id ⇒ Object (readonly)
ID of owning compartment.
32 33 34 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 32 def compartment_id @compartment_id end |
#created ⇒ Object (readonly)
Timestamp of creation.
34 35 36 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 34 def created @created end |
#customer ⇒ Object (readonly)
Customer owning the supplied payment method.
36 37 38 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 36 def customer @customer end |
#failure_reason ⇒ Object (readonly)
Reason why the OSP failed.
38 39 40 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 38 def failure_reason @failure_reason end |
#id ⇒ Object (readonly)
ID of the OSP.
40 41 42 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 40 def id @id end |
#last_authorization_attempt_error ⇒ Object (readonly)
Last error returned by the financial partner for a failed authorization.
42 43 44 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 42 def @last_authorization_attempt_error end |
#latest_payment_attempt_record ⇒ Object (readonly)
Payment attempt record for the latest attempt, if one exists.
44 45 46 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 44 def latest_payment_attempt_record @latest_payment_attempt_record end |
#livemode ⇒ Object (readonly)
True if the txn is livemode, false otherwise.
46 47 48 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 46 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Metadata you provided.
48 49 50 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 48 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
50 51 52 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 50 def object @object end |
#on_behalf_of ⇒ Object (readonly)
OBO, same as on the PI.
52 53 54 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 52 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of payment method.
54 55 56 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 54 def payment_method @payment_method end |
#payment_record ⇒ Object (readonly)
Payment record associated with the OSP. consistent across attempts.
56 57 58 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 56 def payment_record @payment_record end |
#retry_details ⇒ Object (readonly)
Details about the OSP retries.
58 59 60 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 58 def retry_details @retry_details end |
#statement_descriptor ⇒ Object (readonly)
Statement descriptor you provided.
60 61 62 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 60 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Statement descriptor suffix you provided, similar to that on the PI.
62 63 64 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 62 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
Status of the OSP.
64 65 66 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 64 def status @status end |
#test_clock ⇒ Object (readonly)
Test clock to be used to advance the retry attempts.
66 67 68 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 66 def test_clock @test_clock end |
#transfer_data ⇒ Object (readonly)
Instructions for the transfer to be made with this OSP after successful money movement.
68 69 70 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 68 def transfer_data @transfer_data end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 10 def self.object_name "v2.payments.off_session_payment" end |