Class: Stripe::V2::Payments::OffSessionPayment::AmountDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::OffSessionPayment::AmountDetails
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Defined Under Namespace
Classes: Error, LineItem, Shipping, Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
readonly
The amount the total transaction was discounted for.
-
#error ⇒ Object
readonly
Contains information about the error that occurred when validating the current amount details.
-
#line_items ⇒ Object
readonly
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
readonly
Contains information about the shipping portion of the amount.
-
#tax ⇒ Object
readonly
Contains information about the tax portion of the amount.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount_amount ⇒ Object (readonly)
The amount the total transaction was discounted for.
102 103 104 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 102 def discount_amount @discount_amount end |
#error ⇒ Object (readonly)
Contains information about the error that occurred when validating the current amount details. This field populates when the amount details has a validation error that wasn’t enforced because the [enforce_arithmetic_validation](docs.corp.stripe.com/api/payment_intents/create#create_payment_intent-amount_details-enforce_arithmetic_validation) parameter was set to ‘false`.
105 106 107 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 105 def error @error end |
#line_items ⇒ Object (readonly)
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.
107 108 109 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 107 def line_items @line_items end |
#shipping ⇒ Object (readonly)
Contains information about the shipping portion of the amount.
109 110 111 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 109 def shipping @shipping end |
#tax ⇒ Object (readonly)
Contains information about the tax portion of the amount.
111 112 113 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 111 def tax @tax end |
Class Method Details
.field_remappings ⇒ Object
117 118 119 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 117 def self.field_remappings @field_remappings = {} end |