Class: Stripe::V2::Payments::OffSessionPayment::AmountDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::OffSessionPayment::AmountDetails
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Defined Under Namespace
Classes: LineItem, Shipping, Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
readonly
The amount the total transaction was discounted for.
-
#line_items ⇒ Object
readonly
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
readonly
Contains information about the shipping portion of the amount.
-
#tax ⇒ Object
readonly
Contains information about the tax portion of the amount.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount_amount ⇒ Object (readonly)
The amount the total transaction was discounted for.
80 81 82 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 80 def discount_amount @discount_amount end |
#line_items ⇒ Object (readonly)
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.
82 83 84 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 82 def line_items @line_items end |
#shipping ⇒ Object (readonly)
Contains information about the shipping portion of the amount.
84 85 86 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 84 def shipping @shipping end |
#tax ⇒ Object (readonly)
Contains information about the tax portion of the amount.
86 87 88 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 86 def tax @tax end |
Class Method Details
.field_remappings ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 92 def self.field_remappings @field_remappings = {} end |