Class: Stripe::V2::Payments::OffSessionPayment::PaymentDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::OffSessionPayment::PaymentDetails
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer_reference ⇒ Object
readonly
A unique value to identify the customer.
-
#order_reference ⇒ Object
readonly
A unique value assigned by the business to identify the transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer_reference ⇒ Object (readonly)
A unique value to identify the customer. This field is applicable only for card payments. For card payments, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
139 140 141 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 139 def customer_reference @customer_reference end |
#order_reference ⇒ Object (readonly)
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates. For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
142 143 144 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 142 def order_reference @order_reference end |
Class Method Details
.field_remappings ⇒ Object
148 149 150 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 148 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
144 145 146 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 144 def self.inner_class_types @inner_class_types = {} end |