Class: Stripe::V2::Payments::OffSessionPayment::RetryDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::OffSessionPayment::RetryDetails
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#attempts ⇒ Object
readonly
Number of authorization attempts so far.
-
#retry_policy ⇒ Object
readonly
The pre-configured retry policy to use for the payment.
-
#retry_strategy ⇒ Object
readonly
Indicates the strategy for how you want Stripe to retry the payment.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#attempts ⇒ Object (readonly)
Number of authorization attempts so far.
79 80 81 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 79 def attempts @attempts end |
#retry_policy ⇒ Object (readonly)
The pre-configured retry policy to use for the payment.
81 82 83 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 81 def retry_policy @retry_policy end |
#retry_strategy ⇒ Object (readonly)
Indicates the strategy for how you want Stripe to retry the payment.
83 84 85 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 83 def retry_strategy @retry_strategy end |
Class Method Details
.field_remappings ⇒ Object
89 90 91 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 89 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
85 86 87 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 85 def self.inner_class_types @inner_class_types = {} end |