Class: Stripe::V2::Payments::OffSessionPayment::TransferData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/payments/off_session_payment.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the [amount_requested](docs.stripe.com/api/v2/off-session-payments/object?api-version=2025-05-28.preview#v2_off_session_payment_object-amount_requested), and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).



72
73
74
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 72

def amount
  @amount
end

#destinationObject (readonly)

The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.



75
76
77
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 75

def destination
  @destination
end

Class Method Details

.field_remappingsObject



81
82
83
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 81

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



77
78
79
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 77

def self.inner_class_types
  @inner_class_types = {}
end