Class: Stripe::V2::Payments::OffSessionPayment::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Payments::OffSessionPayment::TransferData
- Defined in:
- lib/stripe/resources/v2/payments/off_session_payment.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount transferred to the destination account.
-
#destination ⇒ Object
readonly
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the [amount_requested](docs.stripe.com/api/v2/off-session-payments/object?api-version=2025-05-28.preview#v2_off_session_payment_object-amount_requested), and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).
102 103 104 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 102 def amount @amount end |
#destination ⇒ Object (readonly)
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
105 106 107 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 105 def destination @destination end |
Class Method Details
.field_remappings ⇒ Object
111 112 113 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 111 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
107 108 109 |
# File 'lib/stripe/resources/v2/payments/off_session_payment.rb', line 107 def self.inner_class_types @inner_class_types = {} end |