Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCaptureParams
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_capture_params.rb
Defined Under Namespace
Classes: TransferData
Instance Attribute Summary collapse
-
#amount_to_capture ⇒ Object
The amount to capture.
-
#application_fee_amount ⇒ Object
The amount of the application fee for this capture.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes.
Instance Method Summary collapse
-
#initialize(amount_to_capture: nil, application_fee_amount: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ OffSessionPaymentCaptureParams
constructor
A new instance of OffSessionPaymentCaptureParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_to_capture: nil, application_fee_amount: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ OffSessionPaymentCaptureParams
Returns a new instance of OffSessionPaymentCaptureParams.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 43 def initialize( amount_to_capture: nil, application_fee_amount: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @amount_to_capture = amount_to_capture @application_fee_amount = application_fee_amount @metadata = @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#amount_to_capture ⇒ Object
The amount to capture.
23 24 25 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 23 def amount_to_capture @amount_to_capture end |
#application_fee_amount ⇒ Object
The amount of the application fee for this capture.
25 26 27 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 25 def application_fee_amount @application_fee_amount end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).
30 31 32 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 30 def @metadata end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
35 36 37 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 35 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
39 40 41 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 39 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).
41 42 43 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 41 def transfer_data @transfer_data end |