Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCaptureParams
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_capture_params.rb
Defined Under Namespace
Classes: TransferData
Instance Attribute Summary collapse
-
#amount_to_capture ⇒ Object
The amount to capture.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes.
Instance Method Summary collapse
-
#initialize(amount_to_capture: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ OffSessionPaymentCaptureParams
constructor
A new instance of OffSessionPaymentCaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_to_capture: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ OffSessionPaymentCaptureParams
Returns a new instance of OffSessionPaymentCaptureParams.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 41 def initialize( amount_to_capture: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @amount_to_capture = amount_to_capture @metadata = @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#amount_to_capture ⇒ Object
The amount to capture.
23 24 25 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 23 def amount_to_capture @amount_to_capture end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).
28 29 30 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 28 def @metadata end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
33 34 35 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 33 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
37 38 39 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 37 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).
39 40 41 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 39 def transfer_data @transfer_data end |