Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_capture_params.rb

Defined Under Namespace

Classes: TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_to_capture: nil, metadata: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ OffSessionPaymentCaptureParams

Returns a new instance of OffSessionPaymentCaptureParams.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 45

def initialize(
  amount_to_capture: nil,
  metadata: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_to_capture = amount_to_capture
  @metadata = 
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_to_captureObject

The amount to capture.



27
28
29
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 27

def amount_to_capture
  @amount_to_capture
end

#metadataObject

Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.corp.stripe.com/payments/payment-intents#storing-information-in-metadata).



32
33
34
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 32

def 
  @metadata
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



37
38
39
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 37

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



41
42
43
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 41

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.corp.stripe.com/payments/connected-accounts).



43
44
45
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 43

def transfer_data
  @transfer_data
end