Class: Stripe::V2::Payments::OffSessionPaymentCaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCaptureParams::TransferData
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_capture_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount transferred to the destination account.
-
#destination ⇒ Object
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
21 22 23 24 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 21 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount transferred to the destination account. This transfer will occur automatically after the payment succeeds. If no amount is specified, by default the entire payment amount is transferred to the destination account. The amount must be less than or equal to the [amount_requested](docs.corp.stripe.com/api/v2/off-session-payments/object?api-version=2025-05-28.preview#v2_off_session_payment_object-amount_requested), and must be a positive integer representing how much to transfer in the smallest currency unit (e.g., 100 cents to charge $1.00).
16 17 18 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 16 def amount @amount end |
#destination ⇒ Object
The account (if any) that the payment is attributed to for tax reporting, and where funds from the payment are transferred to after payment success.
19 20 21 |
# File 'lib/stripe/params/v2/payments/off_session_payment_capture_params.rb', line 19 def destination @destination end |