Class: Stripe::V2::Payments::OffSessionPaymentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Defined Under Namespace
Classes: AmountDetails, Capture, PaymentDetails, PaymentMethodData, PaymentMethodOptions, PaymentsOrchestration, RetryDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” to be collected from the customer.
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#cadence ⇒ Object
The frequency of the underlying payment.
-
#capture ⇒ Object
Details about the capture configuration for the OffSessionPayment.
-
#customer ⇒ Object
ID of the Customer to which this OffSessionPayment belongs.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the OffSessionPayment are intended.
-
#payment_details ⇒ Object
Provides industry-specific information about the payment.
-
#payment_method ⇒ Object
ID of the payment method used in this OffSessionPayment.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method options for the off-session payment.
-
#payments_orchestration ⇒ Object
Details about the payments orchestration configuration.
-
#retry_details ⇒ Object
Details about the OffSessionPayment retries.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#test_clock ⇒ Object
Test clock that can be used to advance the retry attempts in a sandbox.
-
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, cadence: nil, capture: nil, customer: nil, description: nil, metadata: nil, on_behalf_of: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams
constructor
A new instance of OffSessionPaymentCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_details: nil, application_fee_amount: nil, cadence: nil, capture: nil, customer: nil, description: nil, metadata: nil, on_behalf_of: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams
Returns a new instance of OffSessionPaymentCreateParams.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 318 def initialize( amount: nil, amount_details: nil, application_fee_amount: nil, cadence: nil, capture: nil, customer: nil, description: nil, metadata: nil, on_behalf_of: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil ) @amount = amount @amount_details = amount_details @application_fee_amount = application_fee_amount @cadence = cadence @capture = capture @customer = customer @description = description @metadata = @on_behalf_of = on_behalf_of @payment_details = payment_details @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payments_orchestration = payments_orchestration @retry_details = retry_details @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @test_clock = test_clock @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” to be collected from the customer.
271 272 273 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 271 def amount @amount end |
#amount_details ⇒ Object
Provides industry-specific information about the amount.
273 274 275 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 273 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
276 277 278 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 276 def application_fee_amount @application_fee_amount end |
#cadence ⇒ Object
The frequency of the underlying payment.
278 279 280 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 278 def cadence @cadence end |
#capture ⇒ Object
Details about the capture configuration for the OffSessionPayment.
280 281 282 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 280 def capture @capture end |
#customer ⇒ Object
ID of the Customer to which this OffSessionPayment belongs.
282 283 284 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 282 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
284 285 286 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 284 def description @description end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).
289 290 291 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 289 def @metadata end |
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the OffSessionPayment are intended.
291 292 293 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 291 def on_behalf_of @on_behalf_of end |
#payment_details ⇒ Object
Provides industry-specific information about the payment.
293 294 295 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 293 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method used in this OffSessionPayment.
295 296 297 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 295 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the OffSessionPayment.
297 298 299 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 297 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method options for the off-session payment.
299 300 301 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 299 def @payment_method_options end |
#payments_orchestration ⇒ Object
Details about the payments orchestration configuration.
301 302 303 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 301 def payments_orchestration @payments_orchestration end |
#retry_details ⇒ Object
Details about the OffSessionPayment retries.
303 304 305 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 303 def retry_details @retry_details end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
308 309 310 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 308 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
312 313 314 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 312 def statement_descriptor_suffix @statement_descriptor_suffix end |
#test_clock ⇒ Object
Test clock that can be used to advance the retry attempts in a sandbox.
314 315 316 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 314 def test_clock @test_clock end |
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).
316 317 318 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 316 def transfer_data @transfer_data end |