Class: Stripe::V2::Payments::OffSessionPaymentCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Defined Under Namespace
Classes: Capture, PaymentMethodData, PaymentMethodOptions, PaymentsOrchestration, RetryDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The “presentment amount” to be collected from the customer.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#cadence ⇒ Object
The frequency of the underlying payment.
-
#capture ⇒ Object
Details about the capture configuration for the OffSessionPayment.
-
#customer ⇒ Object
ID of the Customer to which this OffSessionPayment belongs.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the OffSessionPayment are intended.
-
#payment_method ⇒ Object
ID of the payment method used in this OffSessionPayment.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method options for the off-session payment.
-
#payments_orchestration ⇒ Object
Details about the payments orchestration configuration.
-
#retry_details ⇒ Object
Details about the OffSessionPayment retries.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#test_clock ⇒ Object
Test clock that can be used to advance the retry attempts in a sandbox.
-
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee_amount: nil, cadence: nil, capture: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams
constructor
A new instance of OffSessionPaymentCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, application_fee_amount: nil, cadence: nil, capture: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams
Returns a new instance of OffSessionPaymentCreateParams.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 200 def initialize( amount: nil, application_fee_amount: nil, cadence: nil, capture: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil ) @amount = amount @application_fee_amount = application_fee_amount @cadence = cadence @capture = capture @customer = customer @metadata = @on_behalf_of = on_behalf_of @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payments_orchestration = payments_orchestration @retry_details = retry_details @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @test_clock = test_clock @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
The “presentment amount” to be collected from the customer.
159 160 161 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 159 def amount @amount end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
162 163 164 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 162 def application_fee_amount @application_fee_amount end |
#cadence ⇒ Object
The frequency of the underlying payment.
164 165 166 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 164 def cadence @cadence end |
#capture ⇒ Object
Details about the capture configuration for the OffSessionPayment.
166 167 168 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 166 def capture @capture end |
#customer ⇒ Object
ID of the Customer to which this OffSessionPayment belongs.
168 169 170 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 168 def customer @customer end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).
173 174 175 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 173 def @metadata end |
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the OffSessionPayment are intended.
175 176 177 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 175 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object
ID of the payment method used in this OffSessionPayment.
177 178 179 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 177 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the OffSessionPayment.
179 180 181 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 179 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method options for the off-session payment.
181 182 183 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 181 def @payment_method_options end |
#payments_orchestration ⇒ Object
Details about the payments orchestration configuration.
183 184 185 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 183 def payments_orchestration @payments_orchestration end |
#retry_details ⇒ Object
Details about the OffSessionPayment retries.
185 186 187 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 185 def retry_details @retry_details end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
190 191 192 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 190 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
194 195 196 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 194 def statement_descriptor_suffix @statement_descriptor_suffix end |
#test_clock ⇒ Object
Test clock that can be used to advance the retry attempts in a sandbox.
196 197 198 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 196 def test_clock @test_clock end |
#transfer_data ⇒ Object
The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).
198 199 200 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 198 def transfer_data @transfer_data end |