Class: Stripe::V2::Payments::OffSessionPaymentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_create_params.rb

Defined Under Namespace

Classes: Amount, Capture, PaymentMethodData, PaymentMethodOptions, PaymentsOrchestration, RetryDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, cadence: nil, capture: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams

Returns a new instance of OffSessionPaymentCreateParams.



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 209

def initialize(
  amount: nil,
  cadence: nil,
  capture: nil,
  customer: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payments_orchestration: nil,
  retry_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  test_clock: nil,
  transfer_data: nil
)
  @amount = amount
  @cadence = cadence
  @capture = capture
  @customer = customer
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payments_orchestration = payments_orchestration
  @retry_details = retry_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @test_clock = test_clock
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The “presentment amount” to be collected from the customer.



171
172
173
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 171

def amount
  @amount
end

#cadenceObject

The frequency of the underlying payment.



173
174
175
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 173

def cadence
  @cadence
end

#captureObject

Details about the capture configuration for the OffSessionPayment.



175
176
177
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 175

def capture
  @capture
end

#customerObject

ID of the Customer to which this OffSessionPayment belongs.



177
178
179
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 177

def customer
  @customer
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).



182
183
184
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 182

def 
  @metadata
end

#on_behalf_ofObject

The account (if any) for which the funds of the OffSessionPayment are intended.



184
185
186
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 184

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method used in this OffSessionPayment.



186
187
188
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 186

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the payment_method property on the OffSessionPayment.



188
189
190
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 188

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method options for the off-session payment.



190
191
192
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 190

def payment_method_options
  @payment_method_options
end

#payments_orchestrationObject

Details about the payments orchestration configuration.



192
193
194
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 192

def payments_orchestration
  @payments_orchestration
end

#retry_detailsObject

Details about the OffSessionPayment retries.



194
195
196
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 194

def retry_details
  @retry_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



199
200
201
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 199

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



203
204
205
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 203

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#test_clockObject

Test clock that can be used to advance the retry attempts in a sandbox.



205
206
207
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 205

def test_clock
  @test_clock
end

#transfer_dataObject

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).



207
208
209
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 207

def transfer_data
  @transfer_data
end