Class: Stripe::V2::Payments::OffSessionPaymentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_create_params.rb

Defined Under Namespace

Classes: Amount, Capture, PaymentMethodOptions, PaymentsOrchestration, RetryDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, cadence: nil, capture: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams

Returns a new instance of OffSessionPaymentCreateParams.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 127

def initialize(
  amount: nil,
  cadence: nil,
  capture: nil,
  customer: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_options: nil,
  payments_orchestration: nil,
  retry_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  test_clock: nil,
  transfer_data: nil
)
  @amount = amount
  @cadence = cadence
  @capture = capture
  @customer = customer
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_options = payment_method_options
  @payments_orchestration = payments_orchestration
  @retry_details = retry_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @test_clock = test_clock
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The “presentment amount” to be collected from the customer.



91
92
93
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 91

def amount
  @amount
end

#cadenceObject

The frequency of the underlying payment.



93
94
95
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 93

def cadence
  @cadence
end

#captureObject

Details about the capture configuration for the OffSessionPayment.



95
96
97
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 95

def capture
  @capture
end

#customerObject

ID of the Customer to which this OffSessionPayment belongs.



97
98
99
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 97

def customer
  @customer
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents#storing-information-in-metadata).



102
103
104
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 102

def 
  @metadata
end

#on_behalf_ofObject

The account (if any) for which the funds of the OffSessionPayment are intended.



104
105
106
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 104

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method used in this OffSessionPayment.



106
107
108
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 106

def payment_method
  @payment_method
end

#payment_method_optionsObject

Payment method options for the off-session payment.



108
109
110
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 108

def payment_method_options
  @payment_method_options
end

#payments_orchestrationObject

Details about the payments orchestration configuration.



110
111
112
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 110

def payments_orchestration
  @payments_orchestration
end

#retry_detailsObject

Details about the OffSessionPayment retries.



112
113
114
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 112

def retry_details
  @retry_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



117
118
119
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 117

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



121
122
123
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 121

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#test_clockObject

Test clock that can be used to advance the retry attempts in a sandbox.



123
124
125
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 123

def test_clock
  @test_clock
end

#transfer_dataObject

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.stripe.com/payments/connected-accounts).



125
126
127
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 125

def transfer_data
  @transfer_data
end