Class: Stripe::V2::Payments::OffSessionPaymentCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_create_params.rb

Defined Under Namespace

Classes: AmountDetails, Capture, PaymentMethodOptions, PaymentsOrchestration, RetryDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, cadence: nil, capture: nil, capture_method: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, payment_method_options: nil, payments_orchestration: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ OffSessionPaymentCreateParams

Returns a new instance of OffSessionPaymentCreateParams.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 199

def initialize(
  amount: nil,
  amount_details: nil,
  cadence: nil,
  capture: nil,
  capture_method: nil,
  customer: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  payment_method_options: nil,
  payments_orchestration: nil,
  retry_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  test_clock: nil,
  transfer_data: nil
)
  @amount = amount
  @amount_details = amount_details
  @cadence = cadence
  @capture = capture
  @capture_method = capture_method
  @customer = customer
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @payment_method_options = payment_method_options
  @payments_orchestration = payments_orchestration
  @retry_details = retry_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @test_clock = test_clock
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The “presentment amount” to be collected from the customer.



159
160
161
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 159

def amount
  @amount
end

#amount_detailsObject

Provides industry-specific information about the amount.



161
162
163
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 161

def amount_details
  @amount_details
end

#cadenceObject

The frequency of the underlying payment.



163
164
165
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 163

def cadence
  @cadence
end

#captureObject

Details about the capture configuration for the OffSessionPayment.



165
166
167
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 165

def capture
  @capture
end

#capture_methodObject

Whether the OffSessionPayment should be captured automatically or manually.



167
168
169
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 167

def capture_method
  @capture_method
end

#customerObject

ID of the Customer to which this OffSessionPayment belongs.



169
170
171
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 169

def customer
  @customer
end

#metadataObject

Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.corp.stripe.com/payments/payment-intents#storing-information-in-metadata).



174
175
176
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 174

def 
  @metadata
end

#on_behalf_ofObject

The account (if any) for which the funds of the OffSessionPayment are intended.



176
177
178
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 176

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method used in this OffSessionPayment.



178
179
180
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 178

def payment_method
  @payment_method
end

#payment_method_optionsObject

Payment method options for the off-session payment.



180
181
182
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 180

def payment_method_options
  @payment_method_options
end

#payments_orchestrationObject

Details about the payments orchestration configuration.



182
183
184
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 182

def payments_orchestration
  @payments_orchestration
end

#retry_detailsObject

Details about the OffSessionPayment retries.



184
185
186
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 184

def retry_details
  @retry_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



189
190
191
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 189

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



193
194
195
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 193

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#test_clockObject

Test clock that can be used to advance the retry attempts in a sandbox.



195
196
197
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 195

def test_clock
  @test_clock
end

#transfer_dataObject

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.corp.stripe.com/payments/connected-accounts).



197
198
199
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 197

def transfer_data
  @transfer_data
end