Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/payments/off_session_payment_create_params.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



80
81
82
83
84
85
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 80

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount the total transaction was discounted for.



72
73
74
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 72

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



74
75
76
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 74

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



76
77
78
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 76

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



78
79
80
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 78

def tax
  @tax
end