Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentDetails
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Instance Attribute Summary collapse
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
Instance Method Summary collapse
-
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer_reference: nil, order_reference: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
120 121 122 123 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 120 def initialize(customer_reference: nil, order_reference: nil) @customer_reference = customer_reference @order_reference = order_reference end |
Instance Attribute Details
#customer_reference ⇒ Object
A unique value to identify the customer. This field is applicable only for card payments. For card payments, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
115 116 117 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 115 def customer_reference @customer_reference end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates. For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
118 119 120 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 118 def order_reference @order_reference end |