Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodData
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Defined Under Namespace
Classes: BillingDetails, Card
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the payment method.
-
#card ⇒ Object
Contains card details that can be used to create a card PaymentMethod for PCI compliant users.
-
#type ⇒ Object
The type of the PaymentMethod.
Instance Method Summary collapse
-
#initialize(billing_details: nil, type: nil, card: nil) ⇒ PaymentMethodData
constructor
A new instance of PaymentMethodData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_details: nil, type: nil, card: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
90 91 92 93 94 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 90 def initialize(billing_details: nil, type: nil, card: nil) @billing_details = billing_details @type = type @card = card end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the payment method.
84 85 86 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 84 def billing_details @billing_details end |
#card ⇒ Object
Contains card details that can be used to create a card PaymentMethod for PCI compliant users.
88 89 90 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 88 def card @card end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
86 87 88 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 86 def type @type end |