Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodData
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Defined Under Namespace
Classes: BillingDetails, Card
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
Billing information associated with the payment method.
-
#card ⇒ Object
Contains card details that can be used to create a card PaymentMethod for PCI compliant users.
-
#type ⇒ Object
The type of the PaymentMethod.
Instance Method Summary collapse
-
#initialize(billing_details: nil, type: nil, card: nil) ⇒ PaymentMethodData
constructor
A new instance of PaymentMethodData.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_details: nil, type: nil, card: nil) ⇒ PaymentMethodData
Returns a new instance of PaymentMethodData.
102 103 104 105 106 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 102 def initialize(billing_details: nil, type: nil, card: nil) @billing_details = billing_details @type = type @card = card end |
Instance Attribute Details
#billing_details ⇒ Object
Billing information associated with the payment method.
96 97 98 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 96 def billing_details @billing_details end |
#card ⇒ Object
Contains card details that can be used to create a card PaymentMethod for PCI compliant users.
100 101 102 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 100 def card @card end |
#type ⇒ Object
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
98 99 100 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 98 def type @type end |