Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Instance Attribute Summary collapse
-
#network_transaction_id ⇒ Object
If you are making a Credential On File transaction with a previously saved card, you should pass the Network Transaction ID from a prior initial authorization on Stripe (from a successful SetupIntent or a PaymentIntent with ‘setup_future_usage` set), or one that you have obtained from another payment processor.
Instance Method Summary collapse
-
#initialize(network_transaction_id: nil) ⇒ Card
constructor
A new instance of Card.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(network_transaction_id: nil) ⇒ Card
Returns a new instance of Card.
107 108 109 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 107 def initialize(network_transaction_id: nil) @network_transaction_id = network_transaction_id end |
Instance Attribute Details
#network_transaction_id ⇒ Object
If you are making a Credential On File transaction with a previously saved card, you should pass the Network Transaction ID from a prior initial authorization on Stripe (from a successful SetupIntent or a PaymentIntent with ‘setup_future_usage` set), or one that you have obtained from another payment processor. This is a token from the network which uniquely identifies the transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. Note that you should pass in a Network Transaction ID if you have one, regardless of whether this is a Customer-Initiated Transaction (CIT) or a Merchant-Initiated Transaction (MIT).
105 106 107 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 105 def network_transaction_id @network_transaction_id end |