Class: Stripe::V2::Payments::OffSessionPaymentCreateParams::RetryDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentCreateParams::RetryDetails
- Defined in:
- lib/stripe/params/v2/payments/off_session_payment_create_params.rb
Instance Attribute Summary collapse
-
#retry_policy ⇒ Object
The pre-configured retry policy to use for the payment.
-
#retry_strategy ⇒ Object
Indicates the strategy for how you want Stripe to retry the payment.
Instance Method Summary collapse
-
#initialize(retry_policy: nil, retry_strategy: nil) ⇒ RetryDetails
constructor
A new instance of RetryDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(retry_policy: nil, retry_strategy: nil) ⇒ RetryDetails
Returns a new instance of RetryDetails.
66 67 68 69 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 66 def initialize(retry_policy: nil, retry_strategy: nil) @retry_policy = retry_policy @retry_strategy = retry_strategy end |
Instance Attribute Details
#retry_policy ⇒ Object
The pre-configured retry policy to use for the payment.
62 63 64 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 62 def retry_policy @retry_policy end |
#retry_strategy ⇒ Object
Indicates the strategy for how you want Stripe to retry the payment.
64 65 66 |
# File 'lib/stripe/params/v2/payments/off_session_payment_create_params.rb', line 64 def retry_strategy @retry_strategy end |