Class: Stripe::V2::Payments::OffSessionPaymentService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/v2/payments/off_session_payment_service.rb

Defined Under Namespace

Classes: RetryDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, cadence: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 76

def initialize(
  amount: nil,
  cadence: nil,
  customer: nil,
  metadata: nil,
  on_behalf_of: nil,
  payment_method: nil,
  retry_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  test_clock: nil,
  transfer_data: nil
)
  @amount = amount
  @cadence = cadence
  @customer = customer
  @metadata = 
  @on_behalf_of = on_behalf_of
  @payment_method = payment_method
  @retry_details = retry_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @test_clock = test_clock
  @transfer_data = transfer_data
end

Instance Attribute Details

#amountObject

The “presentment amount” to be collected from the customer.



46
47
48
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 46

def amount
  @amount
end

#cadenceObject

The frequency of the underlying payment.



48
49
50
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 48

def cadence
  @cadence
end

#customerObject

ID of the Customer to which this OffSessionPayment belongs.



50
51
52
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 50

def customer
  @customer
end

#metadataObject

Set of [key-value pairs](docs.corp.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.corp.stripe.com/payments/payment-intents#storing-information-in-metadata).



55
56
57
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 55

def 
  @metadata
end

#on_behalf_ofObject

The account (if any) for which the funds of the OffSessionPayment are intended.



57
58
59
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 57

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject

ID of the payment method used in this OffSessionPayment.



59
60
61
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 59

def payment_method
  @payment_method
end

#retry_detailsObject

Details about the OffSessionPayment retries.



61
62
63
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 61

def retry_details
  @retry_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see the [Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).



66
67
68
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 66

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



70
71
72
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 70

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#test_clockObject

Test clock that can be used to advance the retry attempts in a sandbox.



72
73
74
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 72

def test_clock
  @test_clock
end

#transfer_dataObject

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](docs.corp.stripe.com/payments/connected-accounts).



74
75
76
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 74

def transfer_data
  @transfer_data
end