Class: Stripe::V2::Payments::OffSessionPaymentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentService::CreateParams
- Defined in:
- lib/stripe/services/v2/payments/off_session_payment_service.rb
Defined Under Namespace
Classes: RetryDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount you want to collect.
-
#cadence ⇒ Object
The frequency of the OSP.
-
#customer ⇒ Object
Customer that owns the provided payment method.
-
#metadata ⇒ Object
Any of your internal data you want to track here.
-
#on_behalf_of ⇒ Object
The OBO merchant you want to use.
-
#payment_method ⇒ Object
Payment method you want to debit.
-
#retry_details ⇒ Object
How you want stripe to retry the OSP.
-
#statement_descriptor ⇒ Object
String you want to appear on your customer’s statement.
-
#statement_descriptor_suffix ⇒ Object
Suffix appended to your account level descriptor.
-
#test_clock ⇒ Object
Test clock to be used for testing your retry handling.
-
#transfer_data ⇒ Object
How you want to transfer the funds to your connected accounts.
Instance Method Summary collapse
-
#initialize(amount: nil, cadence: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, cadence: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 61 def initialize( amount: nil, cadence: nil, customer: nil, metadata: nil, on_behalf_of: nil, payment_method: nil, retry_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, test_clock: nil, transfer_data: nil ) @amount = amount @cadence = cadence @customer = customer @metadata = @on_behalf_of = on_behalf_of @payment_method = payment_method @retry_details = retry_details @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @test_clock = test_clock @transfer_data = transfer_data end |
Instance Attribute Details
#amount ⇒ Object
Amount you want to collect.
39 40 41 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 39 def amount @amount end |
#cadence ⇒ Object
The frequency of the OSP.
41 42 43 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 41 def cadence @cadence end |
#customer ⇒ Object
Customer that owns the provided payment method.
43 44 45 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 43 def customer @customer end |
#metadata ⇒ Object
Any of your internal data you want to track here.
45 46 47 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 45 def @metadata end |
#on_behalf_of ⇒ Object
The OBO merchant you want to use.
47 48 49 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 47 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object
Payment method you want to debit. Must be attached to a customer and set up for off-session usage.
49 50 51 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 49 def payment_method @payment_method end |
#retry_details ⇒ Object
How you want stripe to retry the OSP.
51 52 53 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 51 def retry_details @retry_details end |
#statement_descriptor ⇒ Object
String you want to appear on your customer’s statement.
53 54 55 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 53 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Suffix appended to your account level descriptor.
55 56 57 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 55 def statement_descriptor_suffix @statement_descriptor_suffix end |
#test_clock ⇒ Object
Test clock to be used for testing your retry handling. Only usable in a sandbox.
57 58 59 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 57 def test_clock @test_clock end |
#transfer_data ⇒ Object
How you want to transfer the funds to your connected accounts.
59 60 61 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 59 def transfer_data @transfer_data end |