Class: Stripe::V2::Payments::OffSessionPaymentService::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::OffSessionPaymentService::CreateParams::TransferData
- Defined in:
- lib/stripe/services/v2/payments/off_session_payment_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount in minor units that you want to transfer.
-
#destination ⇒ Object
ID of the connected account where you want money to go.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
33 34 35 36 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 33 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
Amount in minor units that you want to transfer.
29 30 31 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 29 def amount @amount end |
#destination ⇒ Object
ID of the connected account where you want money to go.
31 32 33 |
# File 'lib/stripe/services/v2/payments/off_session_payment_service.rb', line 31 def destination @destination end |