Class: Stripe::V2::Payments::SettlementAllocationIntentListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Payments::SettlementAllocationIntentListParams
- Defined in:
- lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb
Instance Attribute Summary collapse
-
#created_gt ⇒ Object
Filter for objects created after the specified timestamp.
-
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp.
-
#created_lt ⇒ Object
Filter for objects created before the specified timestamp.
-
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp.
-
#financial_account ⇒ Object
Filter the SettlementAllocationIntents by FinancialAccount.
-
#limit ⇒ Object
The page size.
-
#status ⇒ Object
Filter the SettlementAllocationIntents by status.
Instance Method Summary collapse
-
#initialize(created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, financial_account: nil, limit: nil, status: nil) ⇒ SettlementAllocationIntentListParams
constructor
A new instance of SettlementAllocationIntentListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, financial_account: nil, limit: nil, status: nil) ⇒ SettlementAllocationIntentListParams
Returns a new instance of SettlementAllocationIntentListParams.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 27 def initialize( created_gt: nil, created_gte: nil, created_lt: nil, created_lte: nil, financial_account: nil, limit: nil, status: nil ) @created_gt = created_gt @created_gte = created_gte @created_lt = created_lt @created_lte = created_lte @financial_account = financial_account @limit = limit @status = status end |
Instance Attribute Details
#created_gt ⇒ Object
Filter for objects created after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.
10 11 12 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 10 def created_gt @created_gt end |
#created_gte ⇒ Object
Filter for objects created on or after the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.
13 14 15 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 13 def created_gte @created_gte end |
#created_lt ⇒ Object
Filter for objects created before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.
16 17 18 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 16 def created_lt @created_lt end |
#created_lte ⇒ Object
Filter for objects created on or before the specified timestamp. Must be an RFC 3339 date & time value, for example: 2025-10-17T13:22::00Z.
19 20 21 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 19 def created_lte @created_lte end |
#financial_account ⇒ Object
Filter the SettlementAllocationIntents by FinancialAccount.
21 22 23 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 21 def financial_account @financial_account end |
#limit ⇒ Object
The page size.
23 24 25 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 23 def limit @limit end |
#status ⇒ Object
Filter the SettlementAllocationIntents by status.
25 26 27 |
# File 'lib/stripe/params/v2/payments/settlement_allocation_intent_list_params.rb', line 25 def status @status end |