Class: Stripe::V2::Payments::SettlementAllocationIntentSplit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb

Overview

SettlementAllocationIntentSplit resource.

Defined Under Namespace

Classes: Flow

Constant Summary collapse

OBJECT_NAME =
"v2.payments.settlement_allocation_intent_split"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account id against which the SettlementAllocationIntentSplit should be settled.



33
34
35
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 33

def 
  @account
end

#amountObject (readonly)

The amount and currency of the SettlementAllocationIntentSplit.



35
36
37
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 35

def amount
  @amount
end

#createdObject (readonly)

Timestamp at which SettlementAllocationIntentSplit was created.



37
38
39
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 37

def created
  @created
end

#flowObject (readonly)

Details about the Flow object that settled the split.



39
40
41
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 39

def flow
  @flow
end

#idObject (readonly)

Unique identifier for the SettlementAllocationIntentSplit.



41
42
43
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 41

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



53
54
55
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 53

def livemode
  @livemode
end

#metadataObject (readonly)

Metadata associated with the SettlementAllocationIntentSplit.



43
44
45
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 43

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



45
46
47
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 45

def object
  @object
end

#settlement_allocation_intentObject (readonly)

The ID of the SettlementAllocationIntent that this split belongs to.



47
48
49
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 47

def settlement_allocation_intent
  @settlement_allocation_intent
end

#statusObject (readonly)

The status of the SettlementAllocationIntentSplit.



49
50
51
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 49

def status
  @status
end

#typeObject (readonly)

The type of the SettlementAllocationIntentSplit.



51
52
53
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 51

def type
  @type
end

Class Method Details

.field_remappingsObject



59
60
61
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 59

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



55
56
57
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 55

def self.inner_class_types
  @inner_class_types = { flow: Flow }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 10

def self.object_name
  "v2.payments.settlement_allocation_intent_split"
end