Class: Stripe::V2::Payments::SettlementAllocationIntentSplit

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb

Overview

SettlementAllocationIntentSplit resource.

Defined Under Namespace

Classes: Amount, Flow

Constant Summary collapse

OBJECT_NAME =
"v2.payments.settlement_allocation_intent_split"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account id against which the SettlementAllocationIntentSplit should be settled.



48
49
50
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 48

def 
  @account
end

#amountObject (readonly)

The amount and currency of the SettlementAllocationIntentSplit.



50
51
52
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 50

def amount
  @amount
end

#createdObject (readonly)

Timestamp at which SettlementAllocationIntentSplit was created.



52
53
54
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 52

def created
  @created
end

#flowObject (readonly)

Details about the Flow object that settled the split.



54
55
56
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 54

def flow
  @flow
end

#idObject (readonly)

Unique identifier for the SettlementAllocationIntentSplit.



56
57
58
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 56

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



66
67
68
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 66

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



58
59
60
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 58

def object
  @object
end

#settlement_allocation_intentObject (readonly)

The ID of the SettlementAllocationIntent that this split belongs too.



60
61
62
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 60

def settlement_allocation_intent
  @settlement_allocation_intent
end

#statusObject (readonly)

The status of the SettlementAllocationIntentSplit.



62
63
64
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 62

def status
  @status
end

#typeObject (readonly)

The type of the SettlementAllocationIntentSplit.



64
65
66
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 64

def type
  @type
end

Class Method Details

.field_remappingsObject



72
73
74
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 72

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



68
69
70
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 68

def self.inner_class_types
  @inner_class_types = { amount: Amount, flow: Flow }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/payments/settlement_allocation_intent_split.rb', line 10

def self.object_name
  "v2.payments.settlement_allocation_intent_split"
end