Class: Stripe::V2::Reporting::Report::Parameters

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/v2/reporting/report.rb

Defined Under Namespace

Classes: ArrayDetails, EnumDetails, TimestampDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#array_detailsObject (readonly)

For array parameters, provides details about the array elements.



38
39
40
# File 'lib/stripe/resources/v2/reporting/report.rb', line 38

def array_details
  @array_details
end

#descriptionObject (readonly)

Explains the purpose and usage of the parameter.



40
41
42
# File 'lib/stripe/resources/v2/reporting/report.rb', line 40

def description
  @description
end

#enum_detailsObject (readonly)

For enum parameters, provides the list of allowed values.



42
43
44
# File 'lib/stripe/resources/v2/reporting/report.rb', line 42

def enum_details
  @enum_details
end

#requiredObject (readonly)

Indicates whether the parameter must be provided.



44
45
46
# File 'lib/stripe/resources/v2/reporting/report.rb', line 44

def required
  @required
end

#timestamp_detailsObject (readonly)

For timestamp parameters, specifies the allowed date range.



46
47
48
# File 'lib/stripe/resources/v2/reporting/report.rb', line 46

def timestamp_details
  @timestamp_details
end

#typeObject (readonly)

The data type of the parameter.



48
49
50
# File 'lib/stripe/resources/v2/reporting/report.rb', line 48

def type
  @type
end