Class: Stripe::V2::Reporting::ReportRun
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Reporting::ReportRun
- Defined in:
- lib/stripe/resources/v2/reporting/report_run.rb
Overview
The ‘ReportRun` object represents an instance of a `Report` generated with specific run parameters. Once the object is created, Stripe begins processing the report. When the report has finished running, it will give you a reference to the results.
Defined Under Namespace
Classes: ReportParameters, Result, ResultOptions, StatusDetails
Constant Summary collapse
- OBJECT_NAME =
"v2.reporting.report_run"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
The unique identifier of the ‘ReportRun` object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#report ⇒ Object
readonly
The unique identifier of the ‘Report` object which was run.
-
#report_name ⇒ Object
readonly
The human-readable name of the ‘Report` which was run.
-
#report_parameters ⇒ Object
readonly
The parameters used to customize the generation of the report.
-
#result ⇒ Object
readonly
Details how to retrieve the results of a successfully completed ‘ReportRun`.
-
#result_options ⇒ Object
readonly
The options specified for customizing the output file of the ‘ReportRun`.
-
#status ⇒ Object
readonly
The current status of the ‘ReportRun`.
-
#status_details ⇒ Object
readonly
Additional details about the current state of the ‘ReportRun`.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created.
64 65 66 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 64 def created @created end |
#id ⇒ Object (readonly)
The unique identifier of the ‘ReportRun` object.
66 67 68 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 66 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
85 86 87 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 85 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
68 69 70 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 68 def object @object end |
#report ⇒ Object (readonly)
The unique identifier of the ‘Report` object which was run.
70 71 72 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 70 def report @report end |
#report_name ⇒ Object (readonly)
The human-readable name of the ‘Report` which was run.
72 73 74 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 72 def report_name @report_name end |
#report_parameters ⇒ Object (readonly)
The parameters used to customize the generation of the report.
74 75 76 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 74 def report_parameters @report_parameters end |
#result ⇒ Object (readonly)
Details how to retrieve the results of a successfully completed ‘ReportRun`.
76 77 78 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 76 def result @result end |
#result_options ⇒ Object (readonly)
The options specified for customizing the output file of the ‘ReportRun`.
78 79 80 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 78 def @result_options end |
#status ⇒ Object (readonly)
The current status of the ‘ReportRun`.
80 81 82 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 80 def status @status end |
#status_details ⇒ Object (readonly)
Additional details about the current state of the ‘ReportRun`. The field is currently only populated when a `ReportRun` is in the `failed` state, providing more information about why the report failed to generate successfully.
83 84 85 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 83 def status_details @status_details end |
Class Method Details
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/v2/reporting/report_run.rb', line 12 def self.object_name "v2.reporting.report_run" end |