Class: Stripe::V2::Reporting::ReportRunCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/reporting/report_run_create_params.rb

Defined Under Namespace

Classes: ResultOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(report: nil, report_parameters: nil, result_options: nil) ⇒ ReportRunCreateParams

Returns a new instance of ReportRunCreateParams.



25
26
27
28
29
# File 'lib/stripe/params/v2/reporting/report_run_create_params.rb', line 25

def initialize(report: nil, report_parameters: nil, result_options: nil)
  @report = report
  @report_parameters = report_parameters
  @result_options = result_options
end

Instance Attribute Details

#reportObject

The unique identifier of the ‘Report` being requested.



18
19
20
# File 'lib/stripe/params/v2/reporting/report_run_create_params.rb', line 18

def report
  @report
end

#report_parametersObject

A map of parameter names to values, specifying how the report should be customized. The accepted parameters depend on the specific ‘Report` being run.



21
22
23
# File 'lib/stripe/params/v2/reporting/report_run_create_params.rb', line 21

def report_parameters
  @report_parameters
end

#result_optionsObject

Optional settings to customize the results of the ‘ReportRun`.



23
24
25
# File 'lib/stripe/params/v2/reporting/report_run_create_params.rb', line 23

def result_options
  @result_options
end