Class: Stripe::V2::Signals::AccountActivity

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/signals/account_activity.rb

Overview

Account Activity resource for the Signals API.

Defined Under Namespace

Classes: AccountDetails, LoginAttempt, LoginDecision, RegistrationAttempt, RegistrationDecision

Constant Summary collapse

OBJECT_NAME =
"v2.signals.account_activity"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_detailsObject (readonly)

The account, customer, or inline account data associated with the activity.



210
211
212
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 210

def 
  @account_details
end

#account_evaluationObject (readonly)

The account evaluation this activity is associated with, when applicable.



212
213
214
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 212

def 
  @account_evaluation
end

#createdObject (readonly)

Timestamp at which the account activity was created.



214
215
216
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 214

def created
  @created
end

#idObject (readonly)

Unique identifier for the account activity.



216
217
218
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 216

def id
  @id
end

#livemodeObject (readonly)

Has the value true if the object exists in live mode or the value false if the object exists in test mode.



218
219
220
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 218

def livemode
  @livemode
end

#login_attemptObject (readonly)

Details for the login attempt. Present only when type is login_attempt.



220
221
222
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 220

def 
  @login_attempt
end

#login_decisionObject (readonly)

Details for the login decision. Present only when type is login_decision.



222
223
224
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 222

def 
  @login_decision
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value of the object field.



224
225
226
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 224

def object
  @object
end

#occurred_atObject (readonly)

Timestamp at which the activity occurred. Defaults to the created time if not provided.



226
227
228
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 226

def occurred_at
  @occurred_at
end

#registration_attemptObject (readonly)

Details for the registration attempt. Present only when type is registration_attempt.



228
229
230
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 228

def registration_attempt
  @registration_attempt
end

#registration_decisionObject (readonly)

Details for the registration decision. Present only when type is registration_decision.



230
231
232
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 230

def registration_decision
  @registration_decision
end

#typeObject (readonly)

The type of activity.



232
233
234
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 232

def type
  @type
end

Class Method Details

.field_remappingsObject



244
245
246
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 244

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



234
235
236
237
238
239
240
241
242
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 234

def self.inner_class_types
  @inner_class_types = {
    account_details: AccountDetails,
    login_attempt: LoginAttempt,
    login_decision: LoginDecision,
    registration_attempt: RegistrationAttempt,
    registration_decision: RegistrationDecision,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/signals/account_activity.rb', line 10

def self.object_name
  "v2.signals.account_activity"
end