Class: Stripe::V2::Signals::AccountActivityCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::Signals::AccountActivityCreateParams
- Defined in:
- lib/stripe/params/v2/signals/account_activity_create_params.rb
Defined Under Namespace
Classes: AccountDetails, LoginAttempt, LoginDecision, RegistrationAttempt, RegistrationDecision
Instance Attribute Summary collapse
-
#account_details ⇒ Object
The account, customer, or inline account data associated with the activity.
-
#account_evaluation ⇒ Object
The account evaluation this activity is associated with, when applicable.
-
#login_attempt ⇒ Object
Details for the login attempt.
-
#login_decision ⇒ Object
Details for the login decision.
-
#occurred_at ⇒ Object
Timestamp at which the activity occurred.
-
#registration_attempt ⇒ Object
Details for the registration attempt.
-
#registration_decision ⇒ Object
Details for the registration decision.
-
#type ⇒ Object
The type of activity.
Instance Method Summary collapse
-
#initialize(account_details: nil, account_evaluation: nil, login_attempt: nil, login_decision: nil, occurred_at: nil, registration_attempt: nil, registration_decision: nil, type: nil) ⇒ AccountActivityCreateParams
constructor
A new instance of AccountActivityCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_details: nil, account_evaluation: nil, login_attempt: nil, login_decision: nil, occurred_at: nil, registration_attempt: nil, registration_decision: nil, type: nil) ⇒ AccountActivityCreateParams
Returns a new instance of AccountActivityCreateParams.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 175 def initialize( account_details: nil, account_evaluation: nil, login_attempt: nil, login_decision: nil, occurred_at: nil, registration_attempt: nil, registration_decision: nil, type: nil ) @account_details = account_details @account_evaluation = account_evaluation @login_attempt = login_attempt @login_decision = login_decision @occurred_at = occurred_at @registration_attempt = registration_attempt @registration_decision = registration_decision @type = type end |
Instance Attribute Details
#account_details ⇒ Object
The account, customer, or inline account data associated with the activity.
159 160 161 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 159 def account_details @account_details end |
#account_evaluation ⇒ Object
The account evaluation this activity is associated with, when applicable.
161 162 163 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 161 def account_evaluation @account_evaluation end |
#login_attempt ⇒ Object
Details for the login attempt. Provide only when type is login_attempt.
163 164 165 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 163 def login_attempt @login_attempt end |
#login_decision ⇒ Object
Details for the login decision. Provide only when type is login_decision.
165 166 167 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 165 def login_decision @login_decision end |
#occurred_at ⇒ Object
Timestamp at which the activity occurred. Defaults to the created time if not provided.
167 168 169 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 167 def occurred_at @occurred_at end |
#registration_attempt ⇒ Object
Details for the registration attempt. Provide only when type is registration_attempt.
169 170 171 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 169 def registration_attempt @registration_attempt end |
#registration_decision ⇒ Object
Details for the registration decision. Provide only when type is registration_decision.
171 172 173 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 171 def registration_decision @registration_decision end |
#type ⇒ Object
The type of activity.
173 174 175 |
# File 'lib/stripe/params/v2/signals/account_activity_create_params.rb', line 173 def type @type end |