Class: Stripe::V2::Signals::AccountEvaluation::EvaluatedSignals::UserMultiAccounting
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::V2::Signals::AccountEvaluation::EvaluatedSignals::UserMultiAccounting
- Defined in:
- lib/stripe/resources/v2/signals/account_evaluation.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#evaluated_at ⇒ Object
readonly
Timestamp at which the signal was evaluated.
-
#risk_level ⇒ Object
readonly
Categorical assessment of the multi-accounting risk.
-
#score ⇒ Object
readonly
The specific risk score for the account, between 0.00 and 100.00, when available.
-
#signal ⇒ Object
readonly
The account signal ID containing the full user multi-accounting signal result.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#evaluated_at ⇒ Object (readonly)
Timestamp at which the signal was evaluated.
156 157 158 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 156 def evaluated_at @evaluated_at end |
#risk_level ⇒ Object (readonly)
Categorical assessment of the multi-accounting risk.
158 159 160 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 158 def risk_level @risk_level end |
#score ⇒ Object (readonly)
The specific risk score for the account, between 0.00 and 100.00, when available.
160 161 162 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 160 def score @score end |
#signal ⇒ Object (readonly)
The account signal ID containing the full user multi-accounting signal result.
162 163 164 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 162 def signal @signal end |
Class Method Details
.field_encodings ⇒ Object
172 173 174 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 172 def self.field_encodings @field_encodings = { score: :decimal_string } end |
.field_remappings ⇒ Object
168 169 170 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 168 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
164 165 166 |
# File 'lib/stripe/resources/v2/signals/account_evaluation.rb', line 164 def self.inner_class_types @inner_class_types = {} end |