Class: Stripe::V2::Signals::AccountSignal
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Signals::AccountSignal
- Defined in:
- lib/stripe/resources/v2/signals/account_signal.rb
Overview
An automatically evaluated signal on an account. Each Account Signal object corresponds to exactly one signal type, indicated by type. Only the type-specific field is populated; other type-specific payload fields are null. If an account has multiple signals, Stripe creates separate account signal objects.
Defined Under Namespace
Classes: AccountDetails, UserAccountSharing, UserMultiAccounting
Constant Summary collapse
- OBJECT_NAME =
"v2.signals.account_signal"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_details ⇒ Object
readonly
The account or customer this signal is associated with.
-
#account_evaluation ⇒ Object
readonly
The account evaluation that produced this signal, if applicable.
-
#created ⇒ Object
readonly
Timestamp at which the signal was created.
-
#id ⇒ Object
readonly
Unique identifier for the account signal.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#object ⇒ Object
readonly
String representing the object's type.
-
#type ⇒ Object
readonly
The type of signal.
-
#user_account_sharing ⇒ Object
readonly
Data for the user account-sharing signal.
-
#user_multi_accounting ⇒ Object
readonly
Data for the user multi-accounting signal.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_details ⇒ Object (readonly)
The account or customer this signal is associated with.
72 73 74 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 72 def account_details @account_details end |
#account_evaluation ⇒ Object (readonly)
The account evaluation that produced this signal, if applicable.
74 75 76 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 74 def account_evaluation @account_evaluation end |
#created ⇒ Object (readonly)
Timestamp at which the signal was created.
76 77 78 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 76 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the account signal.
78 79 80 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 78 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
80 81 82 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 80 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value of the object field.
82 83 84 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 82 def object @object end |
#type ⇒ Object (readonly)
The type of signal.
84 85 86 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 84 def type @type end |
#user_account_sharing ⇒ Object (readonly)
Data for the user account-sharing signal. Present only when type is user_account_sharing.
86 87 88 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 86 def user_account_sharing @user_account_sharing end |
#user_multi_accounting ⇒ Object (readonly)
Data for the user multi-accounting signal. Present only when type is user_multi_accounting.
88 89 90 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 88 def user_multi_accounting @user_multi_accounting end |
Class Method Details
.field_encodings ⇒ Object
102 103 104 105 106 107 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 102 def self.field_encodings @field_encodings = { user_account_sharing: { kind: :object, fields: { score: :decimal_string } }, user_multi_accounting: { kind: :object, fields: { score: :decimal_string } }, } end |
.field_remappings ⇒ Object
98 99 100 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 98 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
90 91 92 93 94 95 96 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 90 def self.inner_class_types @inner_class_types = { account_details: AccountDetails, user_account_sharing: UserAccountSharing, user_multi_accounting: UserMultiAccounting, } end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 13 def self.object_name "v2.signals.account_signal" end |