Class: Stripe::V2::Signals::AccountSignal
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Signals::AccountSignal
- Defined in:
- lib/stripe/resources/v2/signals/account_signal.rb
Overview
An automatically evaluated signal on a v2 account.
Defined Under Namespace
Classes: AccountDetails, FraudulentMerchant, MerchantDelinquency
Constant Summary collapse
- OBJECT_NAME =
"v2.signals.account_signal"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_details ⇒ Object
readonly
The account or customer this signal is associated with.
-
#created ⇒ Object
readonly
Timestamp at which the signal was created.
-
#fraudulent_merchant ⇒ Object
readonly
Data for the fraudulent merchant signal.
-
#id ⇒ Object
readonly
Unique identifier for the account signal.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#merchant_delinquency ⇒ Object
readonly
Data for the merchant delinquency signal.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#type ⇒ Object
readonly
The type of signal.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_details ⇒ Object (readonly)
The account or customer this signal is associated with.
107 108 109 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 107 def account_details @account_details end |
#created ⇒ Object (readonly)
Timestamp at which the signal was created.
109 110 111 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 109 def created @created end |
#fraudulent_merchant ⇒ Object (readonly)
Data for the fraudulent merchant signal. Present only when type is fraudulent_merchant.
111 112 113 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 111 def fraudulent_merchant @fraudulent_merchant end |
#id ⇒ Object (readonly)
Unique identifier for the account signal.
113 114 115 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 113 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
115 116 117 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 115 def livemode @livemode end |
#merchant_delinquency ⇒ Object (readonly)
Data for the merchant delinquency signal. Present only when type is merchant_delinquency.
117 118 119 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 117 def merchant_delinquency @merchant_delinquency end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
119 120 121 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 119 def object @object end |
#type ⇒ Object (readonly)
The type of signal.
121 122 123 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 121 def type @type end |
Class Method Details
.field_encodings ⇒ Object
135 136 137 138 139 140 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 135 def self.field_encodings @field_encodings = { fraudulent_merchant: { kind: :object, fields: { probability: :decimal_string } }, merchant_delinquency: { kind: :object, fields: { probability: :decimal_string } }, } end |
.field_remappings ⇒ Object
131 132 133 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 131 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
123 124 125 126 127 128 129 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 123 def self.inner_class_types @inner_class_types = { account_details: AccountDetails, fraudulent_merchant: FraudulentMerchant, merchant_delinquency: MerchantDelinquency, } end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/signals/account_signal.rb', line 10 def self.object_name "v2.signals.account_signal" end |