Class: Stripe::V2::Tax::AutomaticRule
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::V2::Tax::AutomaticRule
- Defined in:
- lib/stripe/resources/v2/tax/automatic_rule.rb
Overview
An AutomaticRule holds automatic Tax configuration for a BillableItem.
Constant Summary collapse
- OBJECT_NAME =
"v2.tax.automatic_rule"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billable_item ⇒ Object
readonly
The ID of the BillableItem.
-
#created ⇒ Object
readonly
The time at which the AutomaticRule object was created.
-
#id ⇒ Object
readonly
The ID of the AutomaticRule object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The status of the AutomaticRule object.
-
#tax_code ⇒ Object
readonly
A TaxCode object that will be used for automatic tax calculations.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billable_item ⇒ Object (readonly)
The ID of the BillableItem.
15 16 17 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 15 def billable_item @billable_item end |
#created ⇒ Object (readonly)
The time at which the AutomaticRule object was created.
17 18 19 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 17 def created @created end |
#id ⇒ Object (readonly)
The ID of the AutomaticRule object.
19 20 21 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 19 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
27 28 29 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 27 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value of the object field.
21 22 23 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 21 def object @object end |
#status ⇒ Object (readonly)
The status of the AutomaticRule object.
23 24 25 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 23 def status @status end |
#tax_code ⇒ Object (readonly)
A TaxCode object that will be used for automatic tax calculations.
25 26 27 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 25 def tax_code @tax_code end |
Class Method Details
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/v2/tax/automatic_rule.rb', line 10 def self.object_name "v2.tax.automatic_rule" end |