Class: Stripe::V2::Tax::ManualRule

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/v2/tax/manual_rule.rb

Overview

A ManualRule holds tax rates for a BillableItem. It can hold at most 5 distinct tax rates.

Defined Under Namespace

Classes: Location, Product, ScheduledTaxRate

Constant Summary collapse

OBJECT_NAME =
"v2.tax.manual_rule"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

The time at which the ManualRule object was created.



85
86
87
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 85

def created
  @created
end

#idObject (readonly)

The ID of the ManualRule object.



87
88
89
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 87

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



99
100
101
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 99

def livemode
  @livemode
end

#locationObject (readonly)

Location where the rule applies.



89
90
91
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 89

def location
  @location
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value of the object field.



91
92
93
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 91

def object
  @object
end

#productsObject (readonly)

Products associated with the rule.



93
94
95
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 93

def products
  @products
end

#scheduled_tax_ratesObject (readonly)

Tax rates to be applied.



95
96
97
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 95

def scheduled_tax_rates
  @scheduled_tax_rates
end

#statusObject (readonly)

The status of the ManualRule object.



97
98
99
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 97

def status
  @status
end

Class Method Details

.field_remappingsObject



109
110
111
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 109

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



101
102
103
104
105
106
107
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 101

def self.inner_class_types
  @inner_class_types = {
    location: Location,
    products: Product,
    scheduled_tax_rates: ScheduledTaxRate,
  }
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/v2/tax/manual_rule.rb', line 10

def self.object_name
  "v2.tax.manual_rule"
end