Class: Stripe::V2::TestHelpers::FinancialAddressCreditParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::TestHelpers::FinancialAddressCreditParams
- Defined in:
- lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Object containing the amount value and currency to credit.
-
#network ⇒ Object
Open Enum.
-
#statement_descriptor ⇒ Object
String explaining funds flow.
Instance Method Summary collapse
-
#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ FinancialAddressCreditParams
constructor
A new instance of FinancialAddressCreditParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ FinancialAddressCreditParams
Returns a new instance of FinancialAddressCreditParams.
15 16 17 18 19 |
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 15 def initialize(amount: nil, network: nil, statement_descriptor: nil) @amount = amount @network = network @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Object containing the amount value and currency to credit.
9 10 11 |
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 9 def amount @amount end |
#network ⇒ Object
Open Enum. The network to use in simulating the funds flow. This will be the reflected in the resulting ReceivedCredit.
11 12 13 |
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 11 def network @network end |
#statement_descriptor ⇒ Object
String explaining funds flow. Use this field to populate the statement descriptor of the ReceivedCredit created as an eventual result of this simulation.
13 14 15 |
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 13 def statement_descriptor @statement_descriptor end |