Class: Stripe::V2::TestHelpers::FinancialAddressCreditParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb

Defined Under Namespace

Classes: Amount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ FinancialAddressCreditParams

Returns a new instance of FinancialAddressCreditParams.



26
27
28
29
30
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 26

def initialize(amount: nil, network: nil, statement_descriptor: nil)
  @amount = amount
  @network = network
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#amountObject

Object containing the amount value and currency to credit.



20
21
22
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 20

def amount
  @amount
end

#networkObject

Open Enum. The network to use in simulating the funds flow. This will be the reflected in the resulting ReceivedCredit.



22
23
24
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 22

def network
  @network
end

#statement_descriptorObject

String explaining funds flow. Use this field to populate the statement descriptor of the ReceivedCredit created as an eventual result of this simulation.



24
25
26
# File 'lib/stripe/params/v2/test_helpers/financial_address_credit_params.rb', line 24

def statement_descriptor
  @statement_descriptor
end