Class: Stripe::V2::TestHelpers::FinancialAddressService::CreditParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::V2::TestHelpers::FinancialAddressService::CreditParams
- Defined in:
- lib/stripe/services/v2/test_helpers/financial_address_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Object containing the amount value and currency to credit.
-
#network ⇒ Object
Open Enum.
-
#statement_descriptor ⇒ Object
String explaining funds flow.
Instance Method Summary collapse
-
#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ CreditParams
constructor
A new instance of CreditParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, network: nil, statement_descriptor: nil) ⇒ CreditParams
Returns a new instance of CreditParams.
16 17 18 19 20 |
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 16 def initialize(amount: nil, network: nil, statement_descriptor: nil) @amount = amount @network = network @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#amount ⇒ Object
Object containing the amount value and currency to credit.
10 11 12 |
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 10 def amount @amount end |
#network ⇒ Object
Open Enum. The network to use in simulating the funds flow. This will be the reflected in the resulting ReceivedCredit.
12 13 14 |
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 12 def network @network end |
#statement_descriptor ⇒ Object
String explaining funds flow. Use this field to populate the statement descriptor of the ReceivedCredit created as an eventual result of this simulation.
14 15 16 |
# File 'lib/stripe/services/v2/test_helpers/financial_address_service.rb', line 14 def statement_descriptor @statement_descriptor end |