Class: Stripe::WebhookEndpoint::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/webhook_endpoint.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(api_version: nil, connect: nil, description: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/stripe/resources/webhook_endpoint.rb', line 100

def initialize(
  api_version: nil,
  connect: nil,
  description: nil,
  enabled_events: nil,
  expand: nil,
  metadata: nil,
  url: nil
)
  @api_version = api_version
  @connect = connect
  @description = description
  @enabled_events = enabled_events
  @expand = expand
  @metadata = 
  @url = url
end

Instance Attribute Details

#api_versionObject

Events sent to this endpoint will be generated with this Stripe Version instead of your account’s default Stripe Version.



86
87
88
# File 'lib/stripe/resources/webhook_endpoint.rb', line 86

def api_version
  @api_version
end

#connectObject

Whether this endpoint should receive events from connected accounts (‘true`), or from your account (`false`). Defaults to `false`.



88
89
90
# File 'lib/stripe/resources/webhook_endpoint.rb', line 88

def connect
  @connect
end

#descriptionObject

An optional description of what the webhook is used for.



90
91
92
# File 'lib/stripe/resources/webhook_endpoint.rb', line 90

def description
  @description
end

#enabled_eventsObject

The list of events to enable for this endpoint. You may specify ‘[’*‘]` to enable all events, except those that require explicit selection.



92
93
94
# File 'lib/stripe/resources/webhook_endpoint.rb', line 92

def enabled_events
  @enabled_events
end

#expandObject

Specifies which fields in the response should be expanded.



94
95
96
# File 'lib/stripe/resources/webhook_endpoint.rb', line 94

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



96
97
98
# File 'lib/stripe/resources/webhook_endpoint.rb', line 96

def 
  @metadata
end

#urlObject

The URL of the webhook endpoint.



98
99
100
# File 'lib/stripe/resources/webhook_endpoint.rb', line 98

def url
  @url
end