Class: Stripe::WebhookEndpoint::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/webhook_endpoint.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, disabled: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/stripe/resources/webhook_endpoint.rb', line 49

def initialize(
  description: nil,
  disabled: nil,
  enabled_events: nil,
  expand: nil,
  metadata: nil,
  url: nil
)
  @description = description
  @disabled = disabled
  @enabled_events = enabled_events
  @expand = expand
  @metadata = 
  @url = url
end

Instance Attribute Details

#descriptionObject

An optional description of what the webhook is used for.



37
38
39
# File 'lib/stripe/resources/webhook_endpoint.rb', line 37

def description
  @description
end

#disabledObject

Disable the webhook endpoint if set to true.



39
40
41
# File 'lib/stripe/resources/webhook_endpoint.rb', line 39

def disabled
  @disabled
end

#enabled_eventsObject

The list of events to enable for this endpoint. You may specify ‘[’*‘]` to enable all events, except those that require explicit selection.



41
42
43
# File 'lib/stripe/resources/webhook_endpoint.rb', line 41

def enabled_events
  @enabled_events
end

#expandObject

Specifies which fields in the response should be expanded.



43
44
45
# File 'lib/stripe/resources/webhook_endpoint.rb', line 43

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



45
46
47
# File 'lib/stripe/resources/webhook_endpoint.rb', line 45

def 
  @metadata
end

#urlObject

The URL of the webhook endpoint.



47
48
49
# File 'lib/stripe/resources/webhook_endpoint.rb', line 47

def url
  @url
end