Class: Stripe::WebhookEndpointService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/webhook_endpoint_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, disabled: nil, enabled_events: nil, expand: nil, metadata: nil, url: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 37

def initialize(
  description: nil,
  disabled: nil,
  enabled_events: nil,
  expand: nil,
  metadata: nil,
  url: nil
)
  @description = description
  @disabled = disabled
  @enabled_events = enabled_events
  @expand = expand
  @metadata = 
  @url = url
end

Instance Attribute Details

#descriptionObject

An optional description of what the webhook is used for.



20
21
22
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 20

def description
  @description
end

#disabledObject

Disable the webhook endpoint if set to true.



23
24
25
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 23

def disabled
  @disabled
end

#enabled_eventsObject

The list of events to enable for this endpoint. You may specify ‘[’*‘]` to enable all events, except those that require explicit selection.



26
27
28
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 26

def enabled_events
  @enabled_events
end

#expandObject

Specifies which fields in the response should be expanded.



29
30
31
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 29

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



32
33
34
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 32

def 
  @metadata
end

#urlObject

The URL of the webhook endpoint.



35
36
37
# File 'lib/stripe/services/webhook_endpoint_service.rb', line 35

def url
  @url
end